#ifndef EFL_GENERATED_ELM_HOVERSEL_HH
#define EFL_GENERATED_ELM_HOVERSEL_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elc_hoversel.eo.h"
}

#include "elm_button.eo.hh"
#include "evas_selectable_interface.eo.hh"
#include "elm_interface_atspi_widget_action.eo.hh"
#include <canvas/evas_object.eo.hh>
#include <string>

struct elm_hoversel
      : elm_button,
      efl::eo::detail::extension_inheritance<evas::selectable_interface>::template type< ::elm_hoversel>,
      efl::eo::detail::extension_inheritance<elm_interface_atspi_widget_action>::template type< ::elm_hoversel>

{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_hoversel(Eo* eo)
      : elm_button(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_hoversel(std::nullptr_t)
      : elm_button(nullptr)
   {}

   elm_hoversel(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_hoversel(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_hoversel(elm_hoversel const& other)
      : elm_button(eo_ref(other._eo_ptr()))
   {}

   ~elm_hoversel() {}

   /// @brief @brief This triggers the hoversel popup from code, the same as if the user
   /// had clicked the button.
   ///
   /// @ingroup Hoversel
   ///
   void hover_begin() const
   {
      eo_do(_eo_ptr(), ::elm_obj_hoversel_hover_begin());
   }

   /// @brief @brief This will remove all the children items from the hoversel.
   ///
   /// @warning Should @b not be called while the hoversel is active; use
   /// elm_hoversel_expanded_get() to check first.
   ///
   /// @see elm_object_item_del()
   ///
   /// @ingroup Hoversel
   ///
   void clear() const
   {
      eo_do(_eo_ptr(), ::elm_obj_hoversel_clear());
   }

   /// @brief @brief This dismisses the hoversel popup as if the user had clicked
   /// outside the hover.
   ///
   /// @ingroup Hoversel
   ///
   void hover_end() const
   {
      eo_do(_eo_ptr(), ::elm_obj_hoversel_hover_end());
   }

   /// @brief @brief Add an item to the hoversel button
   ///
   /// @return A handle to the item added.
   ///
   /// This adds an item to the hoversel to show when it is clicked. Note: if you
   /// need to use an icon from an edje file then use
   /// elm_hoversel_item_icon_set() right after this function, and set
   /// icon_file to NULL here.
   ///
   /// For more information on what @p icon_file and @p icon_type are, see the
   /// @ref Icon "icon documentation".
   ///
   /// @ingroup Hoversel
   ///
   /// @param label The text label to use for the item (NULL if not desired)
   /// @param icon_file An image file path on disk to use for the icon or standard
   /// icon name (NULL if not desired)
   /// @param icon_type The icon type if relevant
   /// @param func Convenience function to call when this item is selected. The last
   /// parameter @p event_info of @c func is the selected item pointer.
   /// @param data Data to pass to item-related functions
   ///
   Elm_Object_Item * item_add(std::string label_, std::string icon_file_, Elm_Icon_Type icon_type_, Evas_Smart_Cb func_, const void * data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_hoversel_item_add(efl::eolian::to_c(label_), efl::eolian::to_c(icon_file_), icon_type_, func_, data_));
      return _tmp_ret;
   }

   /// @param horizontal If true, the hover will expand horizontally to the
   /// right.
   ///
   bool horizontal_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_hoversel_horizontal_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param horizontal If true, the hover will expand horizontally to the
   /// right.
   ///
   void horizontal_set(bool horizontal_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_hoversel_horizontal_set(efl::eolian::to_c(horizontal_)));
   }

   /// @param parent The parent to use
   ///
   evas::object hover_parent_get() const
   {
      Evas_Object * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_hoversel_hover_parent_get());
      return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param parent The parent to use
   ///
   void hover_parent_set(evas::object parent_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_hoversel_hover_parent_set(efl::eolian::to_c(parent_)));
   }

   bool expanded_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_hoversel_expanded_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   const Eina_List * items_get() const
   {
      const Eina_List * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_hoversel_items_get());
      return _tmp_ret;
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_selected_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_HOVERSEL_EVENT_SELECTED, priority_,
            &efl::eo::_detail::event_callback<::elm_hoversel, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_hoversel, function_type>,
         ELM_HOVERSEL_EVENT_SELECTED );
   }

   template <typename T>
   void
   callback_selected_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_HOVERSEL_EVENT_SELECTED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_dismissed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_HOVERSEL_EVENT_DISMISSED, priority_,
            &efl::eo::_detail::event_callback<::elm_hoversel, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_hoversel, function_type>,
         ELM_HOVERSEL_EVENT_DISMISSED );
   }

   template <typename T>
   void
   callback_dismissed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_HOVERSEL_EVENT_DISMISSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_expanded_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_HOVERSEL_EVENT_EXPANDED, priority_,
            &efl::eo::_detail::event_callback<::elm_hoversel, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_hoversel, function_type>,
         ELM_HOVERSEL_EVENT_EXPANDED );
   }

   template <typename T>
   void
   callback_expanded_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_HOVERSEL_EVENT_EXPANDED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_item_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_HOVERSEL_EVENT_ITEM_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_hoversel, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_hoversel, function_type>,
         ELM_HOVERSEL_EVENT_ITEM_FOCUSED );
   }

   template <typename T>
   void
   callback_item_focused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_HOVERSEL_EVENT_ITEM_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_item_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_HOVERSEL_EVENT_ITEM_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_hoversel, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_hoversel, function_type>,
         ELM_HOVERSEL_EVENT_ITEM_UNFOCUSED );
   }

   template <typename T>
   void
   callback_item_unfocused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_HOVERSEL_EVENT_ITEM_UNFOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_clicked_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_HOVERSEL_EVENT_CLICKED, priority_,
            &efl::eo::_detail::event_callback<::elm_hoversel, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_hoversel, function_type>,
         ELM_HOVERSEL_EVENT_CLICKED );
   }

   template <typename T>
   void
   callback_clicked_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_HOVERSEL_EVENT_CLICKED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_HOVERSEL_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_hoversel, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_hoversel, function_type>,
         ELM_HOVERSEL_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_HOVERSEL_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_HOVERSEL_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_hoversel, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_hoversel, function_type>,
         ELM_HOVERSEL_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_HOVERSEL_EVENT_ACCESS_CHANGED, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_HOVERSEL_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_HOVERSEL_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
void _elm_hoversel_hover_begin_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->hover_begin();
}

template <typename T>
void _elm_hoversel_clear_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->clear();
}

template <typename T>
void _elm_hoversel_hover_end_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->hover_end();
}

template <typename T>
Elm_Object_Item * _elm_hoversel_item_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * label_, const char * icon_file_, Elm_Icon_Type icon_type_, Evas_Smart_Cb func_, const void * data_)
{
   return static_cast<T*>(self->this_)->item_add(efl::eolian::to_cxx<std::string>(label_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(icon_file_, std::tuple<std::false_type>()), icon_type_, func_, data_);
}

template <typename T>
bool _elm_hoversel_horizontal_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->horizontal_get();
}

template <typename T>
void _elm_hoversel_horizontal_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool horizontal_)
{
   static_cast<T*>(self->this_)->horizontal_set(efl::eolian::to_cxx<bool>(horizontal_, std::tuple<std::false_type>()));
}

template <typename T>
evas::object _elm_hoversel_hover_parent_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->hover_parent_get();
}

template <typename T>
void _elm_hoversel_hover_parent_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * parent_)
{
   static_cast<T*>(self->this_)->hover_parent_set(efl::eolian::to_cxx<evas::object>(parent_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_hoversel_expanded_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->expanded_get();
}

template <typename T>
const Eina_List * _elm_hoversel_items_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->items_get();
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_hoversel >
{
   template <typename T>
   struct type
   {
      virtual void hover_begin()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_hoversel_hover_begin());
      }

      virtual void clear()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_hoversel_clear());
      }

      virtual void hover_end()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_hoversel_hover_end());
      }

      virtual Elm_Object_Item * item_add(std::string label_, std::string icon_file_, Elm_Icon_Type icon_type_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_hoversel_item_add(efl::eolian::to_c(label_), efl::eolian::to_c(icon_file_), icon_type_, func_, data_));
            return _tmp_ret;
      }

      virtual bool horizontal_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_hoversel_horizontal_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void horizontal_set(bool horizontal_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_hoversel_horizontal_set(efl::eolian::to_c(horizontal_)));
      }

      virtual evas::object hover_parent_get()
      {
         Evas_Object * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_hoversel_hover_parent_get());
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void hover_parent_set(evas::object parent_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_hoversel_hover_parent_set(efl::eolian::to_c(parent_)));
      }

      virtual bool expanded_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_hoversel_expanded_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual const Eina_List * items_get()
      {
         const Eina_List * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_hoversel_items_get());
            return _tmp_ret;
      }

   };
};


template<>
struct operation_description_class_size< ::elm_hoversel >
{
   static const int value = 10;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_hoversel>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_hoversel_hover_begin_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_hoversel_hover_begin);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_hoversel_clear_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_hoversel_clear);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_hoversel_hover_end_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_hoversel_hover_end);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_hoversel_item_add_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_hoversel_item_add);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_hoversel_horizontal_get_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_hoversel_horizontal_get);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_hoversel_horizontal_set_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_hoversel_horizontal_set);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_hoversel_hover_parent_get_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_hoversel_hover_parent_get);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_hoversel_hover_parent_set_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_hoversel_hover_parent_set);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_hoversel_expanded_get_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_hoversel_expanded_get);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_hoversel_items_get_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_hoversel_items_get);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_hoversel >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_hoversel, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_hoversel >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_hoversel, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_hoversel>
{
   template <typename U>
   struct type
   {
      operator ::elm_hoversel() const
      {
         return ::elm_hoversel(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      void hover_begin()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_hoversel_hover_begin());
      }

      void clear()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_hoversel_clear());
      }

      void hover_end()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_hoversel_hover_end());
      }

      Elm_Object_Item * item_add(std::string label_, std::string icon_file_, Elm_Icon_Type icon_type_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_hoversel_item_add(efl::eolian::to_c(label_), efl::eolian::to_c(icon_file_), icon_type_, func_, data_));
            return _tmp_ret;
      }

      bool horizontal_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_hoversel_horizontal_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void horizontal_set(bool horizontal_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_hoversel_horizontal_set(efl::eolian::to_c(horizontal_)));
      }

      evas::object hover_parent_get()
      {
         Evas_Object * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_hoversel_hover_parent_get());
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      void hover_parent_set(evas::object parent_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_hoversel_hover_parent_set(efl::eolian::to_c(parent_)));
      }

      bool expanded_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_hoversel_expanded_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      const Eina_List * items_get()
      {
         const Eina_List * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_hoversel_items_get());
            return _tmp_ret;
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_selected_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_HOVERSEL_EVENT_SELECTED, priority_,
            &efl::eo::_detail::event_callback<::elm_hoversel, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_hoversel, function_type>,
         ELM_HOVERSEL_EVENT_SELECTED );
   }

   template <typename T>
   void
   callback_selected_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_HOVERSEL_EVENT_SELECTED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_dismissed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_HOVERSEL_EVENT_DISMISSED, priority_,
            &efl::eo::_detail::event_callback<::elm_hoversel, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_hoversel, function_type>,
         ELM_HOVERSEL_EVENT_DISMISSED );
   }

   template <typename T>
   void
   callback_dismissed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_HOVERSEL_EVENT_DISMISSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_expanded_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_HOVERSEL_EVENT_EXPANDED, priority_,
            &efl::eo::_detail::event_callback<::elm_hoversel, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_hoversel, function_type>,
         ELM_HOVERSEL_EVENT_EXPANDED );
   }

   template <typename T>
   void
   callback_expanded_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_HOVERSEL_EVENT_EXPANDED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_item_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_HOVERSEL_EVENT_ITEM_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_hoversel, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_hoversel, function_type>,
         ELM_HOVERSEL_EVENT_ITEM_FOCUSED );
   }

   template <typename T>
   void
   callback_item_focused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_HOVERSEL_EVENT_ITEM_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_item_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_HOVERSEL_EVENT_ITEM_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_hoversel, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_hoversel, function_type>,
         ELM_HOVERSEL_EVENT_ITEM_UNFOCUSED );
   }

   template <typename T>
   void
   callback_item_unfocused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_HOVERSEL_EVENT_ITEM_UNFOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_clicked_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_HOVERSEL_EVENT_CLICKED, priority_,
            &efl::eo::_detail::event_callback<::elm_hoversel, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_hoversel, function_type>,
         ELM_HOVERSEL_EVENT_CLICKED );
   }

   template <typename T>
   void
   callback_clicked_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_HOVERSEL_EVENT_CLICKED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_HOVERSEL_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_hoversel, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_hoversel, function_type>,
         ELM_HOVERSEL_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_HOVERSEL_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_HOVERSEL_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_hoversel, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_hoversel, function_type>,
         ELM_HOVERSEL_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_HOVERSEL_EVENT_ACCESS_CHANGED, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_hoversel>)
{
   return (ELM_HOVERSEL_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_HOVERSEL_HH

