#ifndef EFL_GENERATED_ELM_POPUP_HH
#define EFL_GENERATED_ELM_POPUP_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elc_popup.eo.h"
}

#include "elm_layout.eo.hh"
#include "elm_interface_atspi_widget_action.eo.hh"
#include <canvas/evas_object.eo.hh>
#include <string>

struct elm_popup
      : elm_layout,
      efl::eo::detail::extension_inheritance<elm_interface_atspi_widget_action>::template type< ::elm_popup>

{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_popup(Eo* eo)
      : elm_layout(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_popup(std::nullptr_t)
      : elm_layout(nullptr)
   {}

   elm_popup(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_popup(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_popup(elm_popup const& other)
      : elm_layout(eo_ref(other._eo_ptr()))
   {}

   ~elm_popup() {}

   /// @brief @brief Add a new item to a Popup object
   ///
   /// Both an item list and a content could not be set at the same time!
   /// once you add an item, the previous content will be removed.
   ///
   /// @return A handle to the item added or @c NULL, on errors
   ///
   /// @ingroup Popup
   /// @warning When the first item is appended to popup object, any previous content
   /// of the content area is deleted. At a time, only one of content, content-text
   /// and item(s) can be there in a popup content area.
   ///
   /// @param label The Label of the new item
   /// @param icon Icon to be set on new item
   /// @param func Convenience function called when item selected
   /// @param data Data passed to @p func above
   ///
   Elm_Object_Item * item_append(std::string label_, evas::object icon_, Evas_Smart_Cb func_, const void * data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_popup_item_append(efl::eolian::to_c(label_), efl::eolian::to_c(icon_), func_, data_));
      return _tmp_ret;
   }

   /// @param horizontal The horizontal alignment of the popup
   /// @param vertical The vertical alignment of the popup
   ///
   void align_get(double* horizontal_, double* vertical_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_popup_align_get(horizontal_, vertical_));
   }

   /// @param horizontal The horizontal alignment of the popup
   /// @param vertical The vertical alignment of the popup
   ///
   void align_set(double horizontal_, double vertical_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_popup_align_set(horizontal_, vertical_));
   }

   /// @param allow @c EINA_TRUE Events are passed to lower objects, else not
   ///
   bool allow_events_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_popup_allow_events_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param allow @c EINA_TRUE Events are passed to lower objects, else not
   ///
   void allow_events_set(bool allow_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_popup_allow_events_set(efl::eolian::to_c(allow_)));
   }

   /// @param wrap wrapping type of type Elm_Wrap_Type
   ///
   Elm_Wrap_Type content_text_wrap_type_get() const
   {
      Elm_Wrap_Type _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_popup_content_text_wrap_type_get());
      return _tmp_ret;
   }

   /// @param wrap wrapping type of type Elm_Wrap_Type
   ///
   void content_text_wrap_type_set(Elm_Wrap_Type wrap_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_popup_content_text_wrap_type_set(wrap_));
   }

   /// @param orient the orientation of the popup
   ///
   Elm_Popup_Orient orient_get() const
   {
      Elm_Popup_Orient _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_popup_orient_get());
      return _tmp_ret;
   }

   /// @param orient the orientation of the popup
   ///
   void orient_set(Elm_Popup_Orient orient_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_popup_orient_set(orient_));
   }

   /// @param timeout The timeout in seconds
   ///
   double timeout_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_popup_timeout_get());
      return _tmp_ret;
   }

   /// @param timeout The timeout in seconds
   ///
   void timeout_set(double timeout_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_popup_timeout_set(timeout_));
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_block_clicked_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_POPUP_EVENT_BLOCK_CLICKED, priority_,
            &efl::eo::_detail::event_callback<::elm_popup, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_popup, function_type>,
         ELM_POPUP_EVENT_BLOCK_CLICKED );
   }

   template <typename T>
   void
   callback_block_clicked_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_POPUP_EVENT_BLOCK_CLICKED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_timeout_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_POPUP_EVENT_TIMEOUT, priority_,
            &efl::eo::_detail::event_callback<::elm_popup, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_popup, function_type>,
         ELM_POPUP_EVENT_TIMEOUT );
   }

   template <typename T>
   void
   callback_timeout_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_POPUP_EVENT_TIMEOUT, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_item_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_POPUP_EVENT_ITEM_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_popup, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_popup, function_type>,
         ELM_POPUP_EVENT_ITEM_FOCUSED );
   }

   template <typename T>
   void
   callback_item_focused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_POPUP_EVENT_ITEM_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_item_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_POPUP_EVENT_ITEM_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_popup, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_popup, function_type>,
         ELM_POPUP_EVENT_ITEM_UNFOCUSED );
   }

   template <typename T>
   void
   callback_item_unfocused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_POPUP_EVENT_ITEM_UNFOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_POPUP_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_popup, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_popup, function_type>,
         ELM_POPUP_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_POPUP_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_POPUP_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_popup, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_popup, function_type>,
         ELM_POPUP_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_POPUP_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_POPUP_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_popup, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_popup, function_type>,
         ELM_POPUP_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_POPUP_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_POPUP_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_popup, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_popup, function_type>,
         ELM_POPUP_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_POPUP_EVENT_UNFOCUSED, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_POPUP_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_POPUP_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
Elm_Object_Item * _elm_popup_item_append_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * label_, Evas_Object * icon_, Evas_Smart_Cb func_, const void * data_)
{
   return static_cast<T*>(self->this_)->item_append(efl::eolian::to_cxx<std::string>(label_, std::tuple<std::false_type>()), efl::eolian::to_cxx<evas::object>(icon_, std::tuple<std::false_type>()), func_, data_);
}

template <typename T>
void _elm_popup_align_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double* horizontal_, double* vertical_)
{
   static_cast<T*>(self->this_)->align_get(horizontal_, vertical_);
}

template <typename T>
void _elm_popup_align_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double horizontal_, double vertical_)
{
   static_cast<T*>(self->this_)->align_set(horizontal_, vertical_);
}

template <typename T>
bool _elm_popup_allow_events_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->allow_events_get();
}

template <typename T>
void _elm_popup_allow_events_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool allow_)
{
   static_cast<T*>(self->this_)->allow_events_set(efl::eolian::to_cxx<bool>(allow_, std::tuple<std::false_type>()));
}

template <typename T>
Elm_Wrap_Type _elm_popup_content_text_wrap_type_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->content_text_wrap_type_get();
}

template <typename T>
void _elm_popup_content_text_wrap_type_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Wrap_Type wrap_)
{
   static_cast<T*>(self->this_)->content_text_wrap_type_set(wrap_);
}

template <typename T>
Elm_Popup_Orient _elm_popup_orient_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->orient_get();
}

template <typename T>
void _elm_popup_orient_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Popup_Orient orient_)
{
   static_cast<T*>(self->this_)->orient_set(orient_);
}

template <typename T>
double _elm_popup_timeout_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->timeout_get();
}

template <typename T>
void _elm_popup_timeout_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double timeout_)
{
   static_cast<T*>(self->this_)->timeout_set(timeout_);
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_popup >
{
   template <typename T>
   struct type
   {
      virtual Elm_Object_Item * item_append(std::string label_, evas::object icon_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_popup_item_append(efl::eolian::to_c(label_), efl::eolian::to_c(icon_), func_, data_));
            return _tmp_ret;
      }

      virtual void align_get(double* horizontal_, double* vertical_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_popup_align_get(horizontal_, vertical_));
      }

      virtual void align_set(double horizontal_, double vertical_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_popup_align_set(horizontal_, vertical_));
      }

      virtual bool allow_events_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_popup_allow_events_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void allow_events_set(bool allow_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_popup_allow_events_set(efl::eolian::to_c(allow_)));
      }

      virtual Elm_Wrap_Type content_text_wrap_type_get()
      {
         Elm_Wrap_Type _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_popup_content_text_wrap_type_get());
            return _tmp_ret;
      }

      virtual void content_text_wrap_type_set(Elm_Wrap_Type wrap_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_popup_content_text_wrap_type_set(wrap_));
      }

      virtual Elm_Popup_Orient orient_get()
      {
         Elm_Popup_Orient _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_popup_orient_get());
            return _tmp_ret;
      }

      virtual void orient_set(Elm_Popup_Orient orient_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_popup_orient_set(orient_));
      }

      virtual double timeout_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_popup_timeout_get());
            return _tmp_ret;
      }

      virtual void timeout_set(double timeout_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_popup_timeout_set(timeout_));
      }

   };
};


template<>
struct operation_description_class_size< ::elm_popup >
{
   static const int value = 11;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_popup>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_popup_item_append_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_popup_item_append);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_popup_align_get_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_popup_align_get);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_popup_align_set_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_popup_align_set);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_popup_allow_events_get_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_popup_allow_events_get);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_popup_allow_events_set_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_popup_allow_events_set);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_popup_content_text_wrap_type_get_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_popup_content_text_wrap_type_get);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_popup_content_text_wrap_type_set_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_popup_content_text_wrap_type_set);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_popup_orient_get_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_popup_orient_get);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_popup_orient_set_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_popup_orient_set);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_popup_timeout_get_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_popup_timeout_get);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::_elm_popup_timeout_set_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::elm_obj_popup_timeout_set);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_popup >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_popup, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_popup >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_popup, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_popup>
{
   template <typename U>
   struct type
   {
      operator ::elm_popup() const
      {
         return ::elm_popup(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      Elm_Object_Item * item_append(std::string label_, evas::object icon_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_popup_item_append(efl::eolian::to_c(label_), efl::eolian::to_c(icon_), func_, data_));
            return _tmp_ret;
      }

      void align_get(double* horizontal_, double* vertical_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_popup_align_get(horizontal_, vertical_));
      }

      void align_set(double horizontal_, double vertical_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_popup_align_set(horizontal_, vertical_));
      }

      bool allow_events_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_popup_allow_events_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void allow_events_set(bool allow_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_popup_allow_events_set(efl::eolian::to_c(allow_)));
      }

      Elm_Wrap_Type content_text_wrap_type_get()
      {
         Elm_Wrap_Type _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_popup_content_text_wrap_type_get());
            return _tmp_ret;
      }

      void content_text_wrap_type_set(Elm_Wrap_Type wrap_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_popup_content_text_wrap_type_set(wrap_));
      }

      Elm_Popup_Orient orient_get()
      {
         Elm_Popup_Orient _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_popup_orient_get());
            return _tmp_ret;
      }

      void orient_set(Elm_Popup_Orient orient_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_popup_orient_set(orient_));
      }

      double timeout_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_popup_timeout_get());
            return _tmp_ret;
      }

      void timeout_set(double timeout_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_popup_timeout_set(timeout_));
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_block_clicked_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_POPUP_EVENT_BLOCK_CLICKED, priority_,
            &efl::eo::_detail::event_callback<::elm_popup, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_popup, function_type>,
         ELM_POPUP_EVENT_BLOCK_CLICKED );
   }

   template <typename T>
   void
   callback_block_clicked_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_POPUP_EVENT_BLOCK_CLICKED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_timeout_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_POPUP_EVENT_TIMEOUT, priority_,
            &efl::eo::_detail::event_callback<::elm_popup, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_popup, function_type>,
         ELM_POPUP_EVENT_TIMEOUT );
   }

   template <typename T>
   void
   callback_timeout_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_POPUP_EVENT_TIMEOUT, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_item_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_POPUP_EVENT_ITEM_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_popup, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_popup, function_type>,
         ELM_POPUP_EVENT_ITEM_FOCUSED );
   }

   template <typename T>
   void
   callback_item_focused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_POPUP_EVENT_ITEM_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_item_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_POPUP_EVENT_ITEM_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_popup, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_popup, function_type>,
         ELM_POPUP_EVENT_ITEM_UNFOCUSED );
   }

   template <typename T>
   void
   callback_item_unfocused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_POPUP_EVENT_ITEM_UNFOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_POPUP_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_popup, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_popup, function_type>,
         ELM_POPUP_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_POPUP_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_POPUP_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_popup, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_popup, function_type>,
         ELM_POPUP_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_POPUP_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_POPUP_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_popup, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_popup, function_type>,
         ELM_POPUP_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_POPUP_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_POPUP_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_popup, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_popup, function_type>,
         ELM_POPUP_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_POPUP_EVENT_UNFOCUSED, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_popup>)
{
   return (ELM_POPUP_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_POPUP_HH

