#ifndef EFL_GENERATED_ELM_APP_SERVER_HH
#define EFL_GENERATED_ELM_APP_SERVER_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_app_server.eo.h"
}

#include <string>

struct elm_app_server
      : efl::eo::base
{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_app_server(Eo* eo)
      : efl::eo::base(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_app_server(std::nullptr_t)
      : efl::eo::base(nullptr)
   {}

   elm_app_server(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_app_server(_c0(_p))
   {}

   /// @param packageid package of application
   /// @param create_view_cb callback to be called when user whants to open some application view
   ///
   elm_app_server(std::string packageid_, Elm_App_Server_Create_View_Cb create_view_cb_, efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_app_server(_c1(packageid_, create_view_cb_, _p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_app_server(elm_app_server const& other)
      : efl::eo::base(eo_ref(other._eo_ptr()))
   {}

   ~elm_app_server() {}

   /// @brief Close all views of application
   ///
   void close_all() const
   {
      eo_do(_eo_ptr(), ::elm_app_server_close_all());
   }

   /// @brief If view id is available and unique, return the full DBus object path of view
   ///
   /// @param id view identifier
   ///
   bool view_check(std::string id_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_app_server_view_check(efl::eolian::to_c(id_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Add a view to elm_app_server. This should only be used if the application open a view that was not requested by create_view_cb.
   ///
   /// @param view elm_app_server_view
   ///
   void view_add(Elm_App_Server_View * view_) const
   {
      eo_do(_eo_ptr(), ::elm_app_server_view_add(view_));
   }

   /// @brief Set a title to application.
   ///
   /// @param title title of application
   ///
   void title_set(std::string title_) const
   {
      eo_do(_eo_ptr(), ::elm_app_server_title_set(efl::eolian::to_c(title_)));
   }

   /// @brief Get title of application
   ///
   Eina_Stringshare * title_get() const
   {
      Eina_Stringshare * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_app_server_title_get());
      return _tmp_ret;
   }

   /// @brief Save the state of all views
   ///
   void save() const
   {
      eo_do(_eo_ptr(), ::elm_app_server_save());
   }

   /// @param icon title of icon
   ///
   Eina_Stringshare * icon_get() const
   {
      Eina_Stringshare * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_app_server_icon_get());
      return _tmp_ret;
   }

   /// @param icon title of icon
   ///
   void icon_set(Eina_Stringshare * icon_) const
   {
      eo_do(_eo_ptr(), ::elm_app_server_icon_set(icon_));
   }

   /// @param ret Iterator with all views of application, you must free iterator after use
   ///
   Eina_Iterator * views_get() const
   {
      Eina_Iterator * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_app_server_views_get());
      return _tmp_ret;
   }

   /// @param ret 
   ///
   std::string path_get() const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_app_server_path_get());
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param ret 
   ///
   Eina_Stringshare * package_get() const
   {
      Eina_Stringshare * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_app_server_package_get());
      return _tmp_ret;
   }

   /// @param w 
   /// @param h 
   /// @param has_alpha 
   /// @param pixels 
   ///
   void pixels_get(unsigned int* w_, unsigned int* h_, Eina_Bool* has_alpha_, const unsigned char ** pixels_) const
   {
      eo_do(_eo_ptr(), ::elm_app_server_pixels_get(w_, h_, has_alpha_, pixels_));
   }

   /// @param w 
   /// @param h 
   /// @param has_alpha 
   /// @param pixels 
   ///
   void pixels_set(unsigned int w_, unsigned int h_, bool has_alpha_, const unsigned char * pixels_) const
   {
      eo_do(_eo_ptr(), ::elm_app_server_pixels_set(w_, h_, efl::eolian::to_c(has_alpha_), pixels_));
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_terminate_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_APP_SERVER_EVENT_TERMINATE, priority_,
            &efl::eo::_detail::event_callback<::elm_app_server, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_app_server, function_type>,
         ELM_APP_SERVER_EVENT_TERMINATE );
   }

   template <typename T>
   void
   callback_terminate_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_APP_SERVER_EVENT_TERMINATE, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_APP_SERVER_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_APP_SERVER_CLASS, _p._eo_raw, eo_constructor());
   }

   static Eo* _c1(std::string packageid_, Elm_App_Server_Create_View_Cb create_view_cb_, efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_APP_SERVER_CLASS, _p._eo_raw, elm_app_server_constructor(efl::eolian::to_c(packageid_), create_view_cb_));
   }

};
template <typename T>
void _elm_app_server_close_all_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->close_all();
}

template <typename T>
bool _elm_app_server_view_check_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * id_)
{
   return static_cast<T*>(self->this_)->view_check(efl::eolian::to_cxx<std::string>(id_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_app_server_view_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_App_Server_View * view_)
{
   static_cast<T*>(self->this_)->view_add(view_);
}

template <typename T>
void _elm_app_server_title_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * title_)
{
   static_cast<T*>(self->this_)->title_set(efl::eolian::to_cxx<std::string>(title_, std::tuple<std::false_type>()));
}

template <typename T>
Eina_Stringshare * _elm_app_server_title_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->title_get();
}

template <typename T>
void _elm_app_server_save_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->save();
}

template <typename T>
Eina_Stringshare * _elm_app_server_icon_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->icon_get();
}

template <typename T>
void _elm_app_server_icon_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Stringshare * icon_)
{
   static_cast<T*>(self->this_)->icon_set(icon_);
}

template <typename T>
Eina_Iterator * _elm_app_server_views_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->views_get();
}

template <typename T>
std::string _elm_app_server_path_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->path_get();
}

template <typename T>
Eina_Stringshare * _elm_app_server_package_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->package_get();
}

template <typename T>
void _elm_app_server_pixels_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, unsigned int* w_, unsigned int* h_, Eina_Bool* has_alpha_, const unsigned char ** pixels_)
{
   static_cast<T*>(self->this_)->pixels_get(w_, h_, has_alpha_, pixels_);
}

template <typename T>
void _elm_app_server_pixels_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, unsigned int w_, unsigned int h_, Eina_Bool has_alpha_, const unsigned char * pixels_)
{
   static_cast<T*>(self->this_)->pixels_set(w_, h_, efl::eolian::to_cxx<bool>(has_alpha_, std::tuple<std::false_type>()), pixels_);
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_app_server >
{
   template <typename T>
   struct type
   {
      virtual void close_all()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_app_server_close_all());
      }

      virtual bool view_check(std::string id_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_app_server_view_check(efl::eolian::to_c(id_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void view_add(Elm_App_Server_View * view_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_app_server_view_add(view_));
      }

      virtual void title_set(std::string title_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_app_server_title_set(efl::eolian::to_c(title_)));
      }

      virtual Eina_Stringshare * title_get()
      {
         Eina_Stringshare * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_app_server_title_get());
            return _tmp_ret;
      }

      virtual void save()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_app_server_save());
      }

      virtual Eina_Stringshare * icon_get()
      {
         Eina_Stringshare * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_app_server_icon_get());
            return _tmp_ret;
      }

      virtual void icon_set(Eina_Stringshare * icon_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_app_server_icon_set(icon_));
      }

      virtual Eina_Iterator * views_get()
      {
         Eina_Iterator * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_app_server_views_get());
            return _tmp_ret;
      }

      virtual std::string path_get()
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_app_server_path_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual Eina_Stringshare * package_get()
      {
         Eina_Stringshare * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_app_server_package_get());
            return _tmp_ret;
      }

      virtual void pixels_get(unsigned int* w_, unsigned int* h_, Eina_Bool* has_alpha_, const unsigned char ** pixels_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_app_server_pixels_get(w_, h_, has_alpha_, pixels_));
      }

      virtual void pixels_set(unsigned int w_, unsigned int h_, bool has_alpha_, const unsigned char * pixels_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_app_server_pixels_set(w_, h_, efl::eolian::to_c(has_alpha_), pixels_));
      }

   };
};


template<>
struct operation_description_class_size< ::elm_app_server >
{
   static const int value = 13;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_app_server>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_app_server_close_all_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_app_server_close_all);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_app_server_view_check_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_app_server_view_check);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_app_server_view_add_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_app_server_view_add);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_app_server_title_set_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_app_server_title_set);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_app_server_title_get_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_app_server_title_get);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_app_server_save_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_app_server_save);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_app_server_icon_get_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_app_server_icon_get);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_app_server_icon_set_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_app_server_icon_set);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_app_server_views_get_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_app_server_views_get);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_app_server_path_get_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_app_server_path_get);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::_elm_app_server_package_get_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::elm_app_server_package_get);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::_elm_app_server_pixels_get_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::elm_app_server_pixels_get);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::_elm_app_server_pixels_set_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::elm_app_server_pixels_set);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_app_server >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_app_server, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_app_server >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_app_server, ::std::tuple<std::string, Elm_App_Server_Create_View_Cb> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::elm_app_server_constructor(::efl::eolian::to_c(args.get<0>()), ::efl::eolian::to_c(args.get<1>())));
}

inline void
call_constructor(tag< ::elm_app_server >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_app_server, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_app_server>
{
   template <typename U>
   struct type
   {
      operator ::elm_app_server() const
      {
         return ::elm_app_server(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      void close_all()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_app_server_close_all());
      }

      bool view_check(std::string id_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_app_server_view_check(efl::eolian::to_c(id_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void view_add(Elm_App_Server_View * view_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_app_server_view_add(view_));
      }

      void title_set(std::string title_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_app_server_title_set(efl::eolian::to_c(title_)));
      }

      Eina_Stringshare * title_get()
      {
         Eina_Stringshare * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_app_server_title_get());
            return _tmp_ret;
      }

      void save()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_app_server_save());
      }

      Eina_Stringshare * icon_get()
      {
         Eina_Stringshare * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_app_server_icon_get());
            return _tmp_ret;
      }

      void icon_set(Eina_Stringshare * icon_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_app_server_icon_set(icon_));
      }

      Eina_Iterator * views_get()
      {
         Eina_Iterator * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_app_server_views_get());
            return _tmp_ret;
      }

      std::string path_get()
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_app_server_path_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      Eina_Stringshare * package_get()
      {
         Eina_Stringshare * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_app_server_package_get());
            return _tmp_ret;
      }

      void pixels_get(unsigned int* w_, unsigned int* h_, Eina_Bool* has_alpha_, const unsigned char ** pixels_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_app_server_pixels_get(w_, h_, has_alpha_, pixels_));
      }

      void pixels_set(unsigned int w_, unsigned int h_, bool has_alpha_, const unsigned char * pixels_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_app_server_pixels_set(w_, h_, efl::eolian::to_c(has_alpha_), pixels_));
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_terminate_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_APP_SERVER_EVENT_TERMINATE, priority_,
            &efl::eo::_detail::event_callback<::elm_app_server, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_app_server, function_type>,
         ELM_APP_SERVER_EVENT_TERMINATE );
   }

   template <typename T>
   void
   callback_terminate_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_APP_SERVER_EVENT_TERMINATE, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_app_server>)
{
   return (ELM_APP_SERVER_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_APP_SERVER_HH

