#ifndef EFL_GENERATED_ELM_BOX_HH
#define EFL_GENERATED_ELM_BOX_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_box.eo.h"
}

#include "elm_widget.eo.hh"
#include <Ecore.h>
#include <canvas/evas_object.eo.hh>

struct elm_box
      : elm_widget
{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_box(Eo* eo)
      : elm_widget(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_box(std::nullptr_t)
      : elm_widget(nullptr)
   {}

   elm_box(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_box(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_box(elm_box const& other)
      : elm_widget(eo_ref(other._eo_ptr()))
   {}

   ~elm_box() {}

   /// @brief Add an object at the end of the pack list
   ///
   /// Pack @p subobj into the box @p obj, placing it last in the list of
   /// children objects. The actual position the object will get on screen
   /// depends on the layout used. If no custom layout is set, it will be at
   /// the bottom or right, depending if the box is vertical or horizontal,
   /// respectively.
   ///
   /// @see elm_box_pack_start()
   /// @see elm_box_pack_before()
   /// @see elm_box_pack_after()
   /// @see elm_box_unpack()
   /// @see elm_box_unpack_all()
   /// @see elm_box_clear()
   ///
   /// @ingroup Box
   ///
   /// @param subobj The object to add to the box
   ///
   void pack_end(evas::object subobj_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_box_pack_end(efl::eolian::to_c(subobj_)));
   }

   /// @brief Remove all items from the box, without deleting them
   ///
   /// Clear the box from all children, but don't delete the respective objects.
   /// If no other references of the box children exist, the objects will never
   /// be deleted, and thus the application will leak the memory. Make sure
   /// when using this function that you hold a reference to all the objects
   /// in the box @p obj.
   ///
   /// @see elm_box_clear()
   /// @see elm_box_unpack()
   ///
   /// @ingroup Box
   ///
   void unpack_all() const
   {
      eo_do(_eo_ptr(), ::elm_obj_box_unpack_all());
   }

   /// @brief Unpack a box item
   ///
   /// Remove the object given by @p subobj from the box @p obj without
   /// deleting it.
   ///
   /// @see elm_box_unpack_all()
   /// @see elm_box_clear()
   ///
   /// @ingroup Box
   ///
   /// @param subobj The object to unpack
   ///
   void unpack(evas::object subobj_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_box_unpack(efl::eolian::to_c(subobj_)));
   }

   /// @brief Adds an object to the box after the indicated object
   ///
   /// This will add the @p subobj to the box indicated after the object
   /// indicated with @p after. If @p after is not already in the box, results
   /// are undefined. After means either to the right of the indicated object or
   /// below it depending on orientation.
   ///
   /// @see elm_box_pack_start()
   /// @see elm_box_pack_end()
   /// @see elm_box_pack_before()
   /// @see elm_box_unpack()
   /// @see elm_box_unpack_all()
   /// @see elm_box_clear()
   ///
   /// @ingroup Box
   ///
   /// @param subobj The object to add to the box
   /// @param after The object after which to add it
   ///
   void pack_after(evas::object subobj_, evas::object after_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_box_pack_after(efl::eolian::to_c(subobj_), efl::eolian::to_c(after_)));
   }

   /// @brief Add an object to the beginning of the pack list
   ///
   /// Pack @p subobj into the box @p obj, placing it first in the list of
   /// children objects. The actual position the object will get on screen
   /// depends on the layout used. If no custom layout is set, it will be at
   /// the top or left, depending if the box is vertical or horizontal,
   /// respectively.
   ///
   /// @see elm_box_pack_end()
   /// @see elm_box_pack_before()
   /// @see elm_box_pack_after()
   /// @see elm_box_unpack()
   /// @see elm_box_unpack_all()
   /// @see elm_box_clear()
   ///
   /// @ingroup Box
   ///
   /// @param subobj The object to add to the box
   ///
   void pack_start(evas::object subobj_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_box_pack_start(efl::eolian::to_c(subobj_)));
   }

   /// @brief Force the box to recalculate its children packing.
   ///
   /// If any children was added or removed, box will not calculate the
   /// values immediately rather leaving it to the next main loop
   /// iteration. While this is great as it would save lots of
   /// recalculation, whenever you need to get the position of a just
   /// added item you must force recalculate before doing so.
   ///
   /// @ingroup Box
   ///
   void recalculate() const
   {
      eo_do(_eo_ptr(), ::elm_obj_box_recalculate());
   }

   /// @brief Adds an object to the box before the indicated object
   ///
   /// This will add the @p subobj to the box indicated before the object
   /// indicated with @p before. If @p before is not already in the box, results
   /// are undefined. Before means either to the left of the indicated object or
   /// above it depending on orientation.
   ///
   /// @see elm_box_pack_start()
   /// @see elm_box_pack_end()
   /// @see elm_box_pack_after()
   /// @see elm_box_unpack()
   /// @see elm_box_unpack_all()
   /// @see elm_box_clear()
   ///
   /// @ingroup Box
   ///
   /// @param subobj The object to add to the box
   /// @param before The object before which to add it
   ///
   void pack_before(evas::object subobj_, evas::object before_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_box_pack_before(efl::eolian::to_c(subobj_), efl::eolian::to_c(before_)));
   }

   /// @brief Clear the box of all children
   ///
   /// Remove all the elements contained by the box, deleting the respective
   /// objects.
   ///
   /// @see elm_box_unpack()
   /// @see elm_box_unpack_all()
   ///
   /// @ingroup Box
   ///
   void clear() const
   {
      eo_do(_eo_ptr(), ::elm_obj_box_clear());
   }

   /// @param homogeneous The homogeneous flag
   ///
   bool homogeneous_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_box_homogeneous_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param homogeneous The homogeneous flag
   ///
   void homogeneous_set(bool homogeneous_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_box_homogeneous_set(efl::eolian::to_c(homogeneous_)));
   }

   /// @param horizontal The horizontal alignment of elements
   /// @param vertical The vertical alignment of elements
   ///
   void align_get(double* horizontal_, double* vertical_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_box_align_get(horizontal_, vertical_));
   }

   /// @param horizontal The horizontal alignment of elements
   /// @param vertical The vertical alignment of elements
   ///
   void align_set(double horizontal_, double vertical_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_box_align_set(horizontal_, vertical_));
   }

   /// @param horizontal The horizontal flag (@c EINA_TRUE = horizontal,
   /// @c EINA_FALSE = vertical)
   ///
   bool horizontal_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_box_horizontal_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param horizontal The horizontal flag (@c EINA_TRUE = horizontal,
   /// @c EINA_FALSE = vertical)
   ///
   void horizontal_set(bool horizontal_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_box_horizontal_set(efl::eolian::to_c(horizontal_)));
   }

   /// @param horizontal The horizontal space between elements
   /// @param vertical The vertical space between elements
   ///
   void padding_get(Evas_Coord* horizontal_, Evas_Coord* vertical_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_box_padding_get(horizontal_, vertical_));
   }

   /// @param horizontal The horizontal space between elements
   /// @param vertical The vertical space between elements
   ///
   void padding_set(Evas_Coord horizontal_, Evas_Coord vertical_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_box_padding_set(horizontal_, vertical_));
   }

   /// @param cb The callback function used for layout
   /// @param data Data that will be passed to layout function
   /// @param free_data Function called to free @p data
   ///
   void layout_set(Evas_Object_Box_Layout cb_, const void * data_, Ecore_Cb free_data_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_box_layout_set(cb_, data_, free_data_));
   }

   efl::eina::list< evas::object > children_get() const
   {
      Eina_List * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_box_children_get());
      return efl::eolian::to_cxx<efl::eina::list< evas::object >>(_tmp_ret, std::tuple<std::true_type, std::false_type>());
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_child_added_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_BOX_EVENT_CHILD_ADDED, priority_,
            &efl::eo::_detail::event_callback<::elm_box, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_box, function_type>,
         ELM_BOX_EVENT_CHILD_ADDED );
   }

   template <typename T>
   void
   callback_child_added_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_BOX_EVENT_CHILD_ADDED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_child_removed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_BOX_EVENT_CHILD_REMOVED, priority_,
            &efl::eo::_detail::event_callback<::elm_box, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_box, function_type>,
         ELM_BOX_EVENT_CHILD_REMOVED );
   }

   template <typename T>
   void
   callback_child_removed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_BOX_EVENT_CHILD_REMOVED, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_BOX_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_BOX_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
void _elm_box_pack_end_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * subobj_)
{
   static_cast<T*>(self->this_)->pack_end(efl::eolian::to_cxx<evas::object>(subobj_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_box_unpack_all_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->unpack_all();
}

template <typename T>
void _elm_box_unpack_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * subobj_)
{
   static_cast<T*>(self->this_)->unpack(efl::eolian::to_cxx<evas::object>(subobj_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_box_pack_after_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * subobj_, Evas_Object * after_)
{
   static_cast<T*>(self->this_)->pack_after(efl::eolian::to_cxx<evas::object>(subobj_, std::tuple<std::false_type>()), efl::eolian::to_cxx<evas::object>(after_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_box_pack_start_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * subobj_)
{
   static_cast<T*>(self->this_)->pack_start(efl::eolian::to_cxx<evas::object>(subobj_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_box_recalculate_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->recalculate();
}

template <typename T>
void _elm_box_pack_before_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * subobj_, Evas_Object * before_)
{
   static_cast<T*>(self->this_)->pack_before(efl::eolian::to_cxx<evas::object>(subobj_, std::tuple<std::false_type>()), efl::eolian::to_cxx<evas::object>(before_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_box_clear_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->clear();
}

template <typename T>
bool _elm_box_homogeneous_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->homogeneous_get();
}

template <typename T>
void _elm_box_homogeneous_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool homogeneous_)
{
   static_cast<T*>(self->this_)->homogeneous_set(efl::eolian::to_cxx<bool>(homogeneous_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_box_align_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double* horizontal_, double* vertical_)
{
   static_cast<T*>(self->this_)->align_get(horizontal_, vertical_);
}

template <typename T>
void _elm_box_align_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double horizontal_, double vertical_)
{
   static_cast<T*>(self->this_)->align_set(horizontal_, vertical_);
}

template <typename T>
bool _elm_box_horizontal_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->horizontal_get();
}

template <typename T>
void _elm_box_horizontal_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool horizontal_)
{
   static_cast<T*>(self->this_)->horizontal_set(efl::eolian::to_cxx<bool>(horizontal_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_box_padding_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord* horizontal_, Evas_Coord* vertical_)
{
   static_cast<T*>(self->this_)->padding_get(horizontal_, vertical_);
}

template <typename T>
void _elm_box_padding_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord horizontal_, Evas_Coord vertical_)
{
   static_cast<T*>(self->this_)->padding_set(horizontal_, vertical_);
}

template <typename T>
void _elm_box_layout_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object_Box_Layout cb_, const void * data_, Ecore_Cb free_data_)
{
   static_cast<T*>(self->this_)->layout_set(cb_, data_, free_data_);
}

template <typename T>
efl::eina::list< evas::object > _elm_box_children_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->children_get();
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_box >
{
   template <typename T>
   struct type
   {
      virtual void pack_end(evas::object subobj_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_box_pack_end(efl::eolian::to_c(subobj_)));
      }

      virtual void unpack_all()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_box_unpack_all());
      }

      virtual void unpack(evas::object subobj_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_box_unpack(efl::eolian::to_c(subobj_)));
      }

      virtual void pack_after(evas::object subobj_, evas::object after_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_box_pack_after(efl::eolian::to_c(subobj_), efl::eolian::to_c(after_)));
      }

      virtual void pack_start(evas::object subobj_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_box_pack_start(efl::eolian::to_c(subobj_)));
      }

      virtual void recalculate()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_box_recalculate());
      }

      virtual void pack_before(evas::object subobj_, evas::object before_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_box_pack_before(efl::eolian::to_c(subobj_), efl::eolian::to_c(before_)));
      }

      virtual void clear()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_box_clear());
      }

      virtual bool homogeneous_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_box_homogeneous_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void homogeneous_set(bool homogeneous_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_box_homogeneous_set(efl::eolian::to_c(homogeneous_)));
      }

      virtual void align_get(double* horizontal_, double* vertical_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_box_align_get(horizontal_, vertical_));
      }

      virtual void align_set(double horizontal_, double vertical_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_box_align_set(horizontal_, vertical_));
      }

      virtual bool horizontal_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_box_horizontal_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void horizontal_set(bool horizontal_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_box_horizontal_set(efl::eolian::to_c(horizontal_)));
      }

      virtual void padding_get(Evas_Coord* horizontal_, Evas_Coord* vertical_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_box_padding_get(horizontal_, vertical_));
      }

      virtual void padding_set(Evas_Coord horizontal_, Evas_Coord vertical_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_box_padding_set(horizontal_, vertical_));
      }

      virtual void layout_set(Evas_Object_Box_Layout cb_, const void * data_, Ecore_Cb free_data_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_box_layout_set(cb_, data_, free_data_));
      }

      virtual efl::eina::list< evas::object > children_get()
      {
         Eina_List * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_box_children_get());
            return efl::eolian::to_cxx<efl::eina::list< evas::object >>(_tmp_ret, std::tuple<std::true_type, std::false_type>());
      }

   };
};


template<>
struct operation_description_class_size< ::elm_box >
{
   static const int value = 18;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_box>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_box_pack_end_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_box_pack_end);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_box_unpack_all_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_box_unpack_all);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_box_unpack_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_box_unpack);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_box_pack_after_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_box_pack_after);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_box_pack_start_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_box_pack_start);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_box_recalculate_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_box_recalculate);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_box_pack_before_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_box_pack_before);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_box_clear_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_box_clear);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_box_homogeneous_get_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_box_homogeneous_get);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_box_homogeneous_set_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_box_homogeneous_set);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::_elm_box_align_get_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::elm_obj_box_align_get);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::_elm_box_align_set_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::elm_obj_box_align_set);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::_elm_box_horizontal_get_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::elm_obj_box_horizontal_get);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::_elm_box_horizontal_set_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::elm_obj_box_horizontal_set);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::_elm_box_padding_get_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::elm_obj_box_padding_get);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::_elm_box_padding_set_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::elm_obj_box_padding_set);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   ops[16].func = reinterpret_cast<void*>(& ::_elm_box_layout_set_wrapper<T>);
   ops[16].api_func = reinterpret_cast<void*>(& ::elm_obj_box_layout_set);
   ops[16].op = EO_OP_OVERRIDE;
   ops[16].op_type = EO_OP_TYPE_REGULAR;
   ops[16].doc = NULL;

   ops[17].func = reinterpret_cast<void*>(& ::_elm_box_children_get_wrapper<T>);
   ops[17].api_func = reinterpret_cast<void*>(& ::elm_obj_box_children_get);
   ops[17].op = EO_OP_OVERRIDE;
   ops[17].op_type = EO_OP_TYPE_REGULAR;
   ops[17].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_box >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_box, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_box >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_box, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_box>
{
   template <typename U>
   struct type
   {
      operator ::elm_box() const
      {
         return ::elm_box(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      void pack_end(evas::object subobj_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_box_pack_end(efl::eolian::to_c(subobj_)));
      }

      void unpack_all()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_box_unpack_all());
      }

      void unpack(evas::object subobj_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_box_unpack(efl::eolian::to_c(subobj_)));
      }

      void pack_after(evas::object subobj_, evas::object after_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_box_pack_after(efl::eolian::to_c(subobj_), efl::eolian::to_c(after_)));
      }

      void pack_start(evas::object subobj_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_box_pack_start(efl::eolian::to_c(subobj_)));
      }

      void recalculate()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_box_recalculate());
      }

      void pack_before(evas::object subobj_, evas::object before_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_box_pack_before(efl::eolian::to_c(subobj_), efl::eolian::to_c(before_)));
      }

      void clear()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_box_clear());
      }

      bool homogeneous_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_box_homogeneous_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void homogeneous_set(bool homogeneous_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_box_homogeneous_set(efl::eolian::to_c(homogeneous_)));
      }

      void align_get(double* horizontal_, double* vertical_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_box_align_get(horizontal_, vertical_));
      }

      void align_set(double horizontal_, double vertical_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_box_align_set(horizontal_, vertical_));
      }

      bool horizontal_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_box_horizontal_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void horizontal_set(bool horizontal_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_box_horizontal_set(efl::eolian::to_c(horizontal_)));
      }

      void padding_get(Evas_Coord* horizontal_, Evas_Coord* vertical_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_box_padding_get(horizontal_, vertical_));
      }

      void padding_set(Evas_Coord horizontal_, Evas_Coord vertical_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_box_padding_set(horizontal_, vertical_));
      }

      void layout_set(Evas_Object_Box_Layout cb_, const void * data_, Ecore_Cb free_data_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_box_layout_set(cb_, data_, free_data_));
      }

      efl::eina::list< evas::object > children_get()
      {
         Eina_List * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_box_children_get());
            return efl::eolian::to_cxx<efl::eina::list< evas::object >>(_tmp_ret, std::tuple<std::true_type, std::false_type>());
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_child_added_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_BOX_EVENT_CHILD_ADDED, priority_,
            &efl::eo::_detail::event_callback<::elm_box, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_box, function_type>,
         ELM_BOX_EVENT_CHILD_ADDED );
   }

   template <typename T>
   void
   callback_child_added_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_BOX_EVENT_CHILD_ADDED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_child_removed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_BOX_EVENT_CHILD_REMOVED, priority_,
            &efl::eo::_detail::event_callback<::elm_box, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_box, function_type>,
         ELM_BOX_EVENT_CHILD_REMOVED );
   }

   template <typename T>
   void
   callback_child_removed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_BOX_EVENT_CHILD_REMOVED, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_box>)
{
   return (ELM_BOX_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_BOX_HH

