#ifndef EFL_GENERATED_ELM_CALENDAR_HH
#define EFL_GENERATED_ELM_CALENDAR_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_calendar.eo.h"
}

#include "elm_layout.eo.hh"
#include "elm_interface_atspi_widget_action.eo.hh"
#include <string>

struct elm_calendar
      : elm_layout,
      efl::eo::detail::extension_inheritance<elm_interface_atspi_widget_action>::template type< ::elm_calendar>

{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_calendar(Eo* eo)
      : elm_layout(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_calendar(std::nullptr_t)
      : elm_layout(nullptr)
   {}

   elm_calendar(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_calendar(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_calendar(elm_calendar const& other)
      : elm_layout(eo_ref(other._eo_ptr()))
   {}

   ~elm_calendar() {}

   /// @brief Set selected date to be highlighted on calendar.
   ///
   /// Set the selected date, changing the displayed month if needed.
   /// Selected date changes when the user goes to next/previous month or
   /// select a day pressing over it on calendar.
   ///
   /// @see elm_calendar_selected_time_get()
   ///
   /// @ref calendar_example_04
   ///
   /// @ingroup Calendar
   ///
   /// @param selected_time A @b tm struct to represent the selected date.
   ///
   void selected_time_set(struct tm * selected_time_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_calendar_selected_time_set(selected_time_));
   }

   /// @brief Get selected date.
   ///
   /// @return EINA_FALSE means an error occurred and returned time shouldn't
   /// be considered.
   ///
   /// Get date selected by the user or set by function
   /// elm_calendar_selected_time_set().
   /// Selected date changes when the user goes to next/previous month or
   /// select a day pressing over it on calendar.
   ///
   /// @see elm_calendar_selected_time_get()
   ///
   /// @ref calendar_example_05
   ///
   /// @ingroup Calendar
   ///
   /// @param[inout] selected_time A @b tm struct to point to selected date
   ///
   bool selected_time_get(struct tm* selected_time_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_calendar_selected_time_get(selected_time_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Add a new mark to the calendar
   ///
   /// @return The created mark or @p NULL upon failure.
   ///
   /// Add a mark that will be drawn in the calendar respecting the insertion
   /// time and periodicity. It will emit the type as signal to the widget theme.
   /// Default theme supports "holiday" and "checked", but it can be extended.
   ///
   /// It won't immediately update the calendar, drawing the marks.
   /// For this, call elm_calendar_marks_draw(). However, when user selects
   /// next or previous month calendar forces marks drawn.
   ///
   /// Marks created with this method can be deleted with
   /// elm_calendar_mark_del().
   ///
   /// Example
   /// @code
   /// struct tm selected_time;
   /// time_t current_time;
   ///
   /// current_time = time(NULL) + 5 * (24 * 60 * 60);
   /// localtime_r(&current_time, &selected_time);
   /// elm_calendar_mark_add(cal, "holiday", selected_time,
   /// ELM_CALENDAR_ANNUALLY);
   ///
   /// current_time = time(NULL) + 1 * (24 * 60 * 60);
   /// localtime_r(&current_time, &selected_time);
   /// elm_calendar_mark_add(cal, "checked", selected_time, ELM_CALENDAR_UNIQUE);
   ///
   /// elm_calendar_marks_draw(cal);
   /// @endcode
   ///
   /// @see elm_calendar_marks_draw()
   /// @see elm_calendar_mark_del()
   ///
   /// @ref calendar_example_06
   ///
   /// @ingroup Calendar
   ///
   /// @param mark_type A string used to define the type of mark. It will be
   /// emitted to the theme, that should display a related modification on these
   /// days representation.
   /// @param mark_time A time struct to represent the date of inclusion of the
   /// mark. For marks that repeats it will just be displayed after the inclusion
   /// date in the calendar.
   /// @param repeat Repeat the event following this periodicity. Can be a unique
   /// mark (that don't repeat), daily, weekly, monthly or annually.
   ///
   Elm_Calendar_Mark * mark_add(std::string mark_type_, struct tm * mark_time_, Elm_Calendar_Mark_Repeat_Type repeat_) const
   {
      Elm_Calendar_Mark * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_calendar_mark_add(efl::eolian::to_c(mark_type_), mark_time_, repeat_));
      return _tmp_ret;
   }

   /// @brief Remove all calendar's marks
   ///
   /// @see elm_calendar_mark_add()
   /// @see elm_calendar_mark_del()
   ///
   /// @ingroup Calendar
   ///
   void marks_clear() const
   {
      eo_do(_eo_ptr(), ::elm_obj_calendar_marks_clear());
   }

   /// @brief Draw calendar marks.
   ///
   /// Should be used after adding, removing or clearing marks.
   /// It will go through the entire marks list updating the calendar.
   /// If lots of marks will be added, add all the marks and then call
   /// this function.
   ///
   /// When the month is changed, i.e. user selects next or previous month,
   /// marks will be drawn.
   ///
   /// @see elm_calendar_mark_add()
   /// @see elm_calendar_mark_del()
   /// @see elm_calendar_marks_clear()
   ///
   /// @ref calendar_example_06
   ///
   /// @ingroup Calendar
   ///
   void marks_draw() const
   {
      eo_do(_eo_ptr(), ::elm_obj_calendar_marks_draw());
   }

   /// @brief Get the current time displayed in the widget
   ///
   /// @return EINA_FALSE means an error occurred. If it's an error the returned
   /// time is zero filled.
   ///
   /// @ingroup Calendar
   /// @since 1.8
   ///
   /// @param[inout] displayed_time A @b tm struct to point to displayed date
   ///
   bool displayed_time_get(struct tm* displayed_time_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_calendar_displayed_time_get(displayed_time_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param day An int which correspond to the first day of the week (Sunday = 0, Monday = 1,
   /// ..., Saturday = 6)
   ///
   Elm_Calendar_Weekday first_day_of_week_get() const
   {
      Elm_Calendar_Weekday _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_calendar_first_day_of_week_get());
      return _tmp_ret;
   }

   /// @param day An int which correspond to the first day of the week (Sunday = 0, Monday = 1,
   /// ..., Saturday = 6)
   ///
   void first_day_of_week_set(Elm_Calendar_Weekday day_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_calendar_first_day_of_week_set(day_));
   }

   /// @param selectable A bitmask of Elm_Calendar_Selectable
   ///
   Elm_Calendar_Selectable selectable_get() const
   {
      Elm_Calendar_Selectable _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_calendar_selectable_get());
      return _tmp_ret;
   }

   /// @param selectable A bitmask of Elm_Calendar_Selectable
   ///
   void selectable_set(Elm_Calendar_Selectable selectable_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_calendar_selectable_set(selectable_));
   }

   /// @param interval The (first) interval value in seconds
   ///
   double interval_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_calendar_interval_get());
      return _tmp_ret;
   }

   /// @param interval The (first) interval value in seconds
   ///
   void interval_set(double interval_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_calendar_interval_set(interval_));
   }

   /// @param weekdays Array of seven strings to be used as weekday names.
   /// @warning It must have 7 elements, or it will access invalid memory.
   /// @warning The strings must be NULL terminated ('@\0').
   ///
   const char ** weekdays_names_get() const
   {
      const char ** _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_calendar_weekdays_names_get());
      return _tmp_ret;
   }

   /// @param weekdays Array of seven strings to be used as weekday names.
   /// @warning It must have 7 elements, or it will access invalid memory.
   /// @warning The strings must be NULL terminated ('@\0').
   ///
   void weekdays_names_set(const char ** weekdays_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_calendar_weekdays_names_set(weekdays_));
   }

   /// @param mode The select mode to use.
   ///
   Elm_Calendar_Select_Mode select_mode_get() const
   {
      Elm_Calendar_Select_Mode _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_calendar_select_mode_get());
      return _tmp_ret;
   }

   /// @param mode The select mode to use.
   ///
   void select_mode_set(Elm_Calendar_Select_Mode mode_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_calendar_select_mode_set(mode_));
   }

   /// @param min The minimum year, greater than 1901;
   /// @param max The maximum year;
   ///
   void min_max_year_get(int* min_, int* max_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_calendar_min_max_year_get(min_, max_));
   }

   /// @param min The minimum year, greater than 1901;
   /// @param max The maximum year;
   ///
   void min_max_year_set(int min_, int max_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_calendar_min_max_year_set(min_, max_));
   }

   /// @param format_function Function to set the month-year string given
   /// the selected date
   ///
   void format_function_set(Elm_Calendar_Format_Cb format_function_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_calendar_format_function_set(format_function_));
   }

   const Eina_List * marks_get() const
   {
      const Eina_List * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_calendar_marks_get());
      return _tmp_ret;
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_CALENDAR_EVENT_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_calendar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_calendar, function_type>,
         ELM_CALENDAR_EVENT_CHANGED );
   }

   template <typename T>
   void
   callback_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_CALENDAR_EVENT_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_display_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_CALENDAR_EVENT_DISPLAY_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_calendar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_calendar, function_type>,
         ELM_CALENDAR_EVENT_DISPLAY_CHANGED );
   }

   template <typename T>
   void
   callback_display_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_CALENDAR_EVENT_DISPLAY_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_CALENDAR_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_calendar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_calendar, function_type>,
         ELM_CALENDAR_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_CALENDAR_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_CALENDAR_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_calendar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_calendar, function_type>,
         ELM_CALENDAR_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_CALENDAR_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_CALENDAR_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_calendar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_calendar, function_type>,
         ELM_CALENDAR_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_CALENDAR_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_CALENDAR_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_calendar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_calendar, function_type>,
         ELM_CALENDAR_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_CALENDAR_EVENT_UNFOCUSED, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_CALENDAR_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_CALENDAR_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
void _elm_calendar_selected_time_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, struct tm * selected_time_)
{
   static_cast<T*>(self->this_)->selected_time_set(selected_time_);
}

template <typename T>
bool _elm_calendar_selected_time_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, struct tm* selected_time_)
{
   return static_cast<T*>(self->this_)->selected_time_get(selected_time_);
}

template <typename T>
Elm_Calendar_Mark * _elm_calendar_mark_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * mark_type_, struct tm * mark_time_, Elm_Calendar_Mark_Repeat_Type repeat_)
{
   return static_cast<T*>(self->this_)->mark_add(efl::eolian::to_cxx<std::string>(mark_type_, std::tuple<std::false_type>()), mark_time_, repeat_);
}

template <typename T>
void _elm_calendar_marks_clear_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->marks_clear();
}

template <typename T>
void _elm_calendar_marks_draw_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->marks_draw();
}

template <typename T>
bool _elm_calendar_displayed_time_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, struct tm* displayed_time_)
{
   return static_cast<T*>(self->this_)->displayed_time_get(displayed_time_);
}

template <typename T>
Elm_Calendar_Weekday _elm_calendar_first_day_of_week_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->first_day_of_week_get();
}

template <typename T>
void _elm_calendar_first_day_of_week_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Calendar_Weekday day_)
{
   static_cast<T*>(self->this_)->first_day_of_week_set(day_);
}

template <typename T>
Elm_Calendar_Selectable _elm_calendar_selectable_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->selectable_get();
}

template <typename T>
void _elm_calendar_selectable_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Calendar_Selectable selectable_)
{
   static_cast<T*>(self->this_)->selectable_set(selectable_);
}

template <typename T>
double _elm_calendar_interval_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->interval_get();
}

template <typename T>
void _elm_calendar_interval_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double interval_)
{
   static_cast<T*>(self->this_)->interval_set(interval_);
}

template <typename T>
const char ** _elm_calendar_weekdays_names_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->weekdays_names_get();
}

template <typename T>
void _elm_calendar_weekdays_names_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char ** weekdays_)
{
   static_cast<T*>(self->this_)->weekdays_names_set(weekdays_);
}

template <typename T>
Elm_Calendar_Select_Mode _elm_calendar_select_mode_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->select_mode_get();
}

template <typename T>
void _elm_calendar_select_mode_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Calendar_Select_Mode mode_)
{
   static_cast<T*>(self->this_)->select_mode_set(mode_);
}

template <typename T>
void _elm_calendar_min_max_year_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int* min_, int* max_)
{
   static_cast<T*>(self->this_)->min_max_year_get(min_, max_);
}

template <typename T>
void _elm_calendar_min_max_year_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int min_, int max_)
{
   static_cast<T*>(self->this_)->min_max_year_set(min_, max_);
}

template <typename T>
void _elm_calendar_format_function_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Calendar_Format_Cb format_function_)
{
   static_cast<T*>(self->this_)->format_function_set(format_function_);
}

template <typename T>
const Eina_List * _elm_calendar_marks_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->marks_get();
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_calendar >
{
   template <typename T>
   struct type
   {
      virtual void selected_time_set(struct tm * selected_time_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_calendar_selected_time_set(selected_time_));
      }

      virtual bool selected_time_get(struct tm* selected_time_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_calendar_selected_time_get(selected_time_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual Elm_Calendar_Mark * mark_add(std::string mark_type_, struct tm * mark_time_, Elm_Calendar_Mark_Repeat_Type repeat_)
      {
         Elm_Calendar_Mark * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_calendar_mark_add(efl::eolian::to_c(mark_type_), mark_time_, repeat_));
            return _tmp_ret;
      }

      virtual void marks_clear()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_calendar_marks_clear());
      }

      virtual void marks_draw()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_calendar_marks_draw());
      }

      virtual bool displayed_time_get(struct tm* displayed_time_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_calendar_displayed_time_get(displayed_time_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual Elm_Calendar_Weekday first_day_of_week_get()
      {
         Elm_Calendar_Weekday _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_calendar_first_day_of_week_get());
            return _tmp_ret;
      }

      virtual void first_day_of_week_set(Elm_Calendar_Weekday day_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_calendar_first_day_of_week_set(day_));
      }

      virtual Elm_Calendar_Selectable selectable_get()
      {
         Elm_Calendar_Selectable _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_calendar_selectable_get());
            return _tmp_ret;
      }

      virtual void selectable_set(Elm_Calendar_Selectable selectable_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_calendar_selectable_set(selectable_));
      }

      virtual double interval_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_calendar_interval_get());
            return _tmp_ret;
      }

      virtual void interval_set(double interval_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_calendar_interval_set(interval_));
      }

      virtual const char ** weekdays_names_get()
      {
         const char ** _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_calendar_weekdays_names_get());
            return _tmp_ret;
      }

      virtual void weekdays_names_set(const char ** weekdays_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_calendar_weekdays_names_set(weekdays_));
      }

      virtual Elm_Calendar_Select_Mode select_mode_get()
      {
         Elm_Calendar_Select_Mode _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_calendar_select_mode_get());
            return _tmp_ret;
      }

      virtual void select_mode_set(Elm_Calendar_Select_Mode mode_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_calendar_select_mode_set(mode_));
      }

      virtual void min_max_year_get(int* min_, int* max_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_calendar_min_max_year_get(min_, max_));
      }

      virtual void min_max_year_set(int min_, int max_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_calendar_min_max_year_set(min_, max_));
      }

      virtual void format_function_set(Elm_Calendar_Format_Cb format_function_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_calendar_format_function_set(format_function_));
      }

      virtual const Eina_List * marks_get()
      {
         const Eina_List * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_calendar_marks_get());
            return _tmp_ret;
      }

   };
};


template<>
struct operation_description_class_size< ::elm_calendar >
{
   static const int value = 20;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_calendar>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_calendar_selected_time_set_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_calendar_selected_time_set);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_calendar_selected_time_get_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_calendar_selected_time_get);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_calendar_mark_add_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_calendar_mark_add);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_calendar_marks_clear_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_calendar_marks_clear);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_calendar_marks_draw_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_calendar_marks_draw);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_calendar_displayed_time_get_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_calendar_displayed_time_get);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_calendar_first_day_of_week_get_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_calendar_first_day_of_week_get);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_calendar_first_day_of_week_set_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_calendar_first_day_of_week_set);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_calendar_selectable_get_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_calendar_selectable_get);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_calendar_selectable_set_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_calendar_selectable_set);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::_elm_calendar_interval_get_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::elm_obj_calendar_interval_get);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::_elm_calendar_interval_set_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::elm_obj_calendar_interval_set);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::_elm_calendar_weekdays_names_get_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::elm_obj_calendar_weekdays_names_get);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::_elm_calendar_weekdays_names_set_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::elm_obj_calendar_weekdays_names_set);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::_elm_calendar_select_mode_get_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::elm_obj_calendar_select_mode_get);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::_elm_calendar_select_mode_set_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::elm_obj_calendar_select_mode_set);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   ops[16].func = reinterpret_cast<void*>(& ::_elm_calendar_min_max_year_get_wrapper<T>);
   ops[16].api_func = reinterpret_cast<void*>(& ::elm_obj_calendar_min_max_year_get);
   ops[16].op = EO_OP_OVERRIDE;
   ops[16].op_type = EO_OP_TYPE_REGULAR;
   ops[16].doc = NULL;

   ops[17].func = reinterpret_cast<void*>(& ::_elm_calendar_min_max_year_set_wrapper<T>);
   ops[17].api_func = reinterpret_cast<void*>(& ::elm_obj_calendar_min_max_year_set);
   ops[17].op = EO_OP_OVERRIDE;
   ops[17].op_type = EO_OP_TYPE_REGULAR;
   ops[17].doc = NULL;

   ops[18].func = reinterpret_cast<void*>(& ::_elm_calendar_format_function_set_wrapper<T>);
   ops[18].api_func = reinterpret_cast<void*>(& ::elm_obj_calendar_format_function_set);
   ops[18].op = EO_OP_OVERRIDE;
   ops[18].op_type = EO_OP_TYPE_REGULAR;
   ops[18].doc = NULL;

   ops[19].func = reinterpret_cast<void*>(& ::_elm_calendar_marks_get_wrapper<T>);
   ops[19].api_func = reinterpret_cast<void*>(& ::elm_obj_calendar_marks_get);
   ops[19].op = EO_OP_OVERRIDE;
   ops[19].op_type = EO_OP_TYPE_REGULAR;
   ops[19].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_calendar >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_calendar, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_calendar >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_calendar, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_calendar>
{
   template <typename U>
   struct type
   {
      operator ::elm_calendar() const
      {
         return ::elm_calendar(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      void selected_time_set(struct tm * selected_time_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_calendar_selected_time_set(selected_time_));
      }

      bool selected_time_get(struct tm* selected_time_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_calendar_selected_time_get(selected_time_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      Elm_Calendar_Mark * mark_add(std::string mark_type_, struct tm * mark_time_, Elm_Calendar_Mark_Repeat_Type repeat_)
      {
         Elm_Calendar_Mark * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_calendar_mark_add(efl::eolian::to_c(mark_type_), mark_time_, repeat_));
            return _tmp_ret;
      }

      void marks_clear()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_calendar_marks_clear());
      }

      void marks_draw()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_calendar_marks_draw());
      }

      bool displayed_time_get(struct tm* displayed_time_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_calendar_displayed_time_get(displayed_time_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      Elm_Calendar_Weekday first_day_of_week_get()
      {
         Elm_Calendar_Weekday _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_calendar_first_day_of_week_get());
            return _tmp_ret;
      }

      void first_day_of_week_set(Elm_Calendar_Weekday day_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_calendar_first_day_of_week_set(day_));
      }

      Elm_Calendar_Selectable selectable_get()
      {
         Elm_Calendar_Selectable _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_calendar_selectable_get());
            return _tmp_ret;
      }

      void selectable_set(Elm_Calendar_Selectable selectable_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_calendar_selectable_set(selectable_));
      }

      double interval_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_calendar_interval_get());
            return _tmp_ret;
      }

      void interval_set(double interval_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_calendar_interval_set(interval_));
      }

      const char ** weekdays_names_get()
      {
         const char ** _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_calendar_weekdays_names_get());
            return _tmp_ret;
      }

      void weekdays_names_set(const char ** weekdays_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_calendar_weekdays_names_set(weekdays_));
      }

      Elm_Calendar_Select_Mode select_mode_get()
      {
         Elm_Calendar_Select_Mode _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_calendar_select_mode_get());
            return _tmp_ret;
      }

      void select_mode_set(Elm_Calendar_Select_Mode mode_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_calendar_select_mode_set(mode_));
      }

      void min_max_year_get(int* min_, int* max_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_calendar_min_max_year_get(min_, max_));
      }

      void min_max_year_set(int min_, int max_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_calendar_min_max_year_set(min_, max_));
      }

      void format_function_set(Elm_Calendar_Format_Cb format_function_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_calendar_format_function_set(format_function_));
      }

      const Eina_List * marks_get()
      {
         const Eina_List * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_calendar_marks_get());
            return _tmp_ret;
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_CALENDAR_EVENT_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_calendar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_calendar, function_type>,
         ELM_CALENDAR_EVENT_CHANGED );
   }

   template <typename T>
   void
   callback_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_CALENDAR_EVENT_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_display_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_CALENDAR_EVENT_DISPLAY_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_calendar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_calendar, function_type>,
         ELM_CALENDAR_EVENT_DISPLAY_CHANGED );
   }

   template <typename T>
   void
   callback_display_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_CALENDAR_EVENT_DISPLAY_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_CALENDAR_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_calendar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_calendar, function_type>,
         ELM_CALENDAR_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_CALENDAR_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_CALENDAR_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_calendar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_calendar, function_type>,
         ELM_CALENDAR_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_CALENDAR_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_CALENDAR_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_calendar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_calendar, function_type>,
         ELM_CALENDAR_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_CALENDAR_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_CALENDAR_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_calendar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_calendar, function_type>,
         ELM_CALENDAR_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_CALENDAR_EVENT_UNFOCUSED, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_calendar>)
{
   return (ELM_CALENDAR_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_CALENDAR_HH

