#ifndef EFL_GENERATED_ELM_DATETIME_HH
#define EFL_GENERATED_ELM_DATETIME_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_datetime.eo.h"
}

#include "elm_layout.eo.hh"
#include <string>

struct elm_datetime
      : elm_layout
{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_datetime(Eo* eo)
      : elm_layout(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_datetime(std::nullptr_t)
      : elm_layout(nullptr)
   {}

   elm_datetime(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_datetime(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_datetime(elm_datetime const& other)
      : elm_layout(eo_ref(other._eo_ptr()))
   {}

   ~elm_datetime() {}

   /// @brief @brief Set the field limits of a field.
   ///
   /// Limits can be set to individual fields, independently, except for AM/PM field.
   /// Any field can display the values only in between these Minimum and Maximum limits unless
   /// the corresponding time value is restricted from MinTime to MaxTime.
   /// That is, Min/ Max field limits always works under the limitations of MinTime/ MaxTime.
   ///
   /// There is no provision to set the limits of AM/PM field.
   ///
   /// @see elm_datetime_field_limit_set()
   /// @ingroup Datetime
   ///
   /// @param fieldtype Type of the field. ELM_DATETIME_YEAR etc.
   /// @param min Reference to field's minimum value
   /// @param max Reference to field's maximum value
   ///
   void field_limit_set(Elm_Datetime_Field_Type fieldtype_, int min_, int max_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_datetime_field_limit_set(fieldtype_, min_, max_));
   }

   /// @brief @brief Get the field limits of a field.
   ///
   /// Limits can be set to individual fields, independently, except for AM/PM field.
   /// Any field can display the values only in between these Minimum and Maximum limits unless
   /// the corresponding time value is restricted from MinTime to MaxTime.
   /// That is, Min/ Max field limits always works under the limitations of MinTime/ MaxTime.
   ///
   /// There is no provision to set the limits of AM/PM field.
   ///
   /// @see elm_datetime_field_limit_set()
   /// @ingroup Datetime
   ///
   /// @param fieldtype Type of the field. ELM_DATETIME_YEAR etc.
   /// @param[out] min Reference to field's minimum value
   /// @param[out] max Reference to field's maximum value
   ///
   void field_limit_get(Elm_Datetime_Field_Type fieldtype_, int* min_, int* max_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_datetime_field_limit_get(fieldtype_, min_, max_));
   }

   /// @brief @brief Set the lower boundary of a field.
   ///
   /// Year: years since 1900. Negative value represents year below 1900 (year
   /// value -30 represents 1870). Year default range is from 70 to 137.
   ///
   /// Month: default value range is from 0 to 11.
   ///
   /// Date: default value range is from 1 to 31 according to the month value.
   ///
   /// Hour: default value will be in terms of 24 hr format (0~23)
   ///
   /// Minute: default value range is from 0 to 59.
   ///
   /// @return @c EINA_TRUE if minimum value is accepted.
   ///
   /// @see elm_datetime_value_min_get()
   /// @ingroup Datetime
   ///
   /// @param mintime Time structure containing the minimum time value.
   ///
   bool value_min_set(const struct tm * mintime_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_datetime_value_min_set(mintime_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief @brief Get the lower boundary of a field.
   ///
   /// Year: years since 1900. Negative value represents year below 1900 (year
   /// value -30 represents 1870). Year default range is from 70 to 137.
   ///
   /// Month: default value range is from 0 to 11.
   ///
   /// Date: default value range is from 1 to 31 according to the month value.
   ///
   /// Hour: default value will be in terms of 24 hr format (0~23)
   ///
   /// Minute: default value range is from 0 to 59.
   ///
   /// @return @c EINA_TRUE if minimum value is successfully returned.
   ///
   /// @see elm_datetime_value_min_set()
   /// @ingroup Datepicker
   ///
   /// @param[inout] mintime Time structure.
   ///
   bool value_min_get(struct tm* mintime_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_datetime_value_min_get(mintime_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief @brief Set the current value of a Datetime object.
   ///
   /// Year: years since 1900. Negative value represents year below 1900 (year
   /// value -30 represents 1870). Year default range is from 70 to 137.
   ///
   /// Month: default value range is from 0 to 11.
   ///
   /// Date: default value range is from 1 to 31 according to the month value.
   ///
   /// Hour: default value will be in terms of 24 hr format (0~23)
   ///
   /// Minute: default value range is from 0 to 59.
   ///
   ///
   /// @return @c EINA_TRUE if current time is set successfully.
   ///
   /// @see elm_datetime_value_set()
   /// @ingroup Datetime
   ///
   /// @param newtime Time structure filled with values to be set.
   ///
   bool value_set(const struct tm * newtime_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_datetime_value_set(newtime_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief @brief Get the current value of a Datetime object.
   ///
   /// Year: years since 1900. Negative value represents year below 1900 (year
   /// value -30 represents 1870). Year default range is from 70 to 137.
   ///
   /// Month: default value range is from 0 to 11.
   ///
   /// Date: default value range is from 1 to 31 according to the month value.
   ///
   /// Hour: default value will be in terms of 24 hr format (0~23)
   ///
   /// Minute: default value range is from 0 to 59.
   ///
   /// @return @c EINA_TRUE if current time is returned successfully.
   ///
   /// @see elm_datetime_value_set()
   /// @ingroup Datetime
   ///
   /// @param[inout] currtime Time structure.
   ///
   bool value_get(struct tm* currtime_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_datetime_value_get(currtime_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief @brief Set a field to be visible or not.
   /// Setting this API True does not ensure that the field is visible, apart from
   /// this, the field's format must be present in Datetime overall format.
   /// If a field's visibility is set to False then it won't appear even though
   /// its format is present in overall format.
   /// So if and only if this API is set true and the corresponding field's format
   /// is present in Datetime format, the field is visible.
   ///
   /// By default the field visibility is set to True.
   ///
   /// @see elm_datetime_field_visible_get()
   /// @ingroup Datetime
   ///
   /// @param fieldtype Type of the field. ELM_DATETIME_YEAR etc.
   /// @param visible @c EINA_TRUE field can be visible, @c EINA_FALSE otherwise.
   ///
   void field_visible_set(Elm_Datetime_Field_Type fieldtype_, bool visible_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_datetime_field_visible_set(fieldtype_, efl::eolian::to_c(visible_)));
   }

   /// @brief @brief Get whether a field can be visible/not
   ///
   /// @return bool @c EINA_TRUE, if field can be visible. @c EINA_FALSE otherwise.
   ///
   /// @see elm_datetime_field_visible_set()
   /// @ingroup Datetime
   ///
   /// @param fieldtype Type of the field. ELM_DATETIME_YEAR etc
   ///
   bool field_visible_get(Elm_Datetime_Field_Type fieldtype_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_datetime_field_visible_get(fieldtype_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief @brief Set the upper boundary of a field.
   ///
   /// Year: years since 1900. Negative value represents year below 1900 (year
   /// value -30 represents 1870). Year default range is from 70 to 137.
   ///
   /// Month: default value range is from 0 to 11.
   ///
   /// Date: default value range is from 1 to 31 according to the month value.
   ///
   /// Hour: default value will be in terms of 24 hr format (0~23)
   ///
   /// Minute: default value range is from 0 to 59.
   ///
   /// @return @c EINA_TRUE if maximum value is accepted.
   ///
   /// @see elm_datetime_value_max_get()
   /// @ingroup Datetime
   ///
   /// @param maxtime Time structure containing the maximum time value.
   ///
   bool value_max_set(const struct tm * maxtime_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_datetime_value_max_set(maxtime_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief @brief Get the upper boundary of a field.
   ///
   /// Year: years since 1900. Negative value represents year below 1900 (year
   /// value -30 represents 1870). Year default range is from 70 to 137.
   ///
   /// Month: default value range is from 0 to 11.
   ///
   /// Date: default value range is from 1 to 31 according to the month value.
   ///
   /// Hour: default value will be in terms of 24 hr format (0~23)
   ///
   /// Minute: default value range is from 0 to 59.
   ///
   /// @return @c EINA_TRUE if maximum value is returned successfully.
   ///
   /// @see elm_datetime_value_max_set()
   /// @ingroup Datetime
   ///
   /// @param[inout] maxtime Time structure containing the maximum time value.
   ///
   bool value_max_get(struct tm* maxtime_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_datetime_value_max_get(maxtime_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param fmt The datetime format
   ///
   std::string format_get() const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_datetime_format_get());
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param fmt The datetime format
   ///
   void format_set(std::string fmt_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_datetime_format_set(efl::eolian::to_c(fmt_)));
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DATETIME_EVENT_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_datetime, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_datetime, function_type>,
         ELM_DATETIME_EVENT_CHANGED );
   }

   template <typename T>
   void
   callback_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_DATETIME_EVENT_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DATETIME_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_datetime, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_datetime, function_type>,
         ELM_DATETIME_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_DATETIME_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DATETIME_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_datetime, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_datetime, function_type>,
         ELM_DATETIME_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_DATETIME_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DATETIME_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_datetime, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_datetime, function_type>,
         ELM_DATETIME_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_DATETIME_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DATETIME_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_datetime, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_datetime, function_type>,
         ELM_DATETIME_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_DATETIME_EVENT_UNFOCUSED, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_DATETIME_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_DATETIME_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
void _elm_datetime_field_limit_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Datetime_Field_Type fieldtype_, int min_, int max_)
{
   static_cast<T*>(self->this_)->field_limit_set(fieldtype_, min_, max_);
}

template <typename T>
void _elm_datetime_field_limit_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Datetime_Field_Type fieldtype_, int* min_, int* max_)
{
   static_cast<T*>(self->this_)->field_limit_get(fieldtype_, min_, max_);
}

template <typename T>
bool _elm_datetime_value_min_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const struct tm * mintime_)
{
   return static_cast<T*>(self->this_)->value_min_set(mintime_);
}

template <typename T>
bool _elm_datetime_value_min_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, struct tm* mintime_)
{
   return static_cast<T*>(self->this_)->value_min_get(mintime_);
}

template <typename T>
bool _elm_datetime_value_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const struct tm * newtime_)
{
   return static_cast<T*>(self->this_)->value_set(newtime_);
}

template <typename T>
bool _elm_datetime_value_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, struct tm* currtime_)
{
   return static_cast<T*>(self->this_)->value_get(currtime_);
}

template <typename T>
void _elm_datetime_field_visible_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Datetime_Field_Type fieldtype_, Eina_Bool visible_)
{
   static_cast<T*>(self->this_)->field_visible_set(fieldtype_, efl::eolian::to_cxx<bool>(visible_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_datetime_field_visible_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Datetime_Field_Type fieldtype_)
{
   return static_cast<T*>(self->this_)->field_visible_get(fieldtype_);
}

template <typename T>
bool _elm_datetime_value_max_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const struct tm * maxtime_)
{
   return static_cast<T*>(self->this_)->value_max_set(maxtime_);
}

template <typename T>
bool _elm_datetime_value_max_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, struct tm* maxtime_)
{
   return static_cast<T*>(self->this_)->value_max_get(maxtime_);
}

template <typename T>
std::string _elm_datetime_format_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->format_get();
}

template <typename T>
void _elm_datetime_format_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * fmt_)
{
   static_cast<T*>(self->this_)->format_set(efl::eolian::to_cxx<std::string>(fmt_, std::tuple<std::false_type>()));
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_datetime >
{
   template <typename T>
   struct type
   {
      virtual void field_limit_set(Elm_Datetime_Field_Type fieldtype_, int min_, int max_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_datetime_field_limit_set(fieldtype_, min_, max_));
      }

      virtual void field_limit_get(Elm_Datetime_Field_Type fieldtype_, int* min_, int* max_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_datetime_field_limit_get(fieldtype_, min_, max_));
      }

      virtual bool value_min_set(const struct tm * mintime_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_datetime_value_min_set(mintime_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool value_min_get(struct tm* mintime_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_datetime_value_min_get(mintime_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool value_set(const struct tm * newtime_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_datetime_value_set(newtime_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool value_get(struct tm* currtime_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_datetime_value_get(currtime_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void field_visible_set(Elm_Datetime_Field_Type fieldtype_, bool visible_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_datetime_field_visible_set(fieldtype_, efl::eolian::to_c(visible_)));
      }

      virtual bool field_visible_get(Elm_Datetime_Field_Type fieldtype_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_datetime_field_visible_get(fieldtype_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool value_max_set(const struct tm * maxtime_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_datetime_value_max_set(maxtime_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool value_max_get(struct tm* maxtime_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_datetime_value_max_get(maxtime_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual std::string format_get()
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_datetime_format_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void format_set(std::string fmt_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_datetime_format_set(efl::eolian::to_c(fmt_)));
      }

   };
};


template<>
struct operation_description_class_size< ::elm_datetime >
{
   static const int value = 12;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_datetime>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_datetime_field_limit_set_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_datetime_field_limit_set);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_datetime_field_limit_get_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_datetime_field_limit_get);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_datetime_value_min_set_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_datetime_value_min_set);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_datetime_value_min_get_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_datetime_value_min_get);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_datetime_value_set_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_datetime_value_set);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_datetime_value_get_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_datetime_value_get);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_datetime_field_visible_set_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_datetime_field_visible_set);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_datetime_field_visible_get_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_datetime_field_visible_get);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_datetime_value_max_set_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_datetime_value_max_set);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_datetime_value_max_get_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_datetime_value_max_get);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::_elm_datetime_format_get_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::elm_obj_datetime_format_get);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::_elm_datetime_format_set_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::elm_obj_datetime_format_set);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_datetime >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_datetime, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_datetime >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_datetime, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_datetime>
{
   template <typename U>
   struct type
   {
      operator ::elm_datetime() const
      {
         return ::elm_datetime(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      void field_limit_set(Elm_Datetime_Field_Type fieldtype_, int min_, int max_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_datetime_field_limit_set(fieldtype_, min_, max_));
      }

      void field_limit_get(Elm_Datetime_Field_Type fieldtype_, int* min_, int* max_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_datetime_field_limit_get(fieldtype_, min_, max_));
      }

      bool value_min_set(const struct tm * mintime_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_datetime_value_min_set(mintime_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool value_min_get(struct tm* mintime_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_datetime_value_min_get(mintime_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool value_set(const struct tm * newtime_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_datetime_value_set(newtime_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool value_get(struct tm* currtime_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_datetime_value_get(currtime_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void field_visible_set(Elm_Datetime_Field_Type fieldtype_, bool visible_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_datetime_field_visible_set(fieldtype_, efl::eolian::to_c(visible_)));
      }

      bool field_visible_get(Elm_Datetime_Field_Type fieldtype_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_datetime_field_visible_get(fieldtype_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool value_max_set(const struct tm * maxtime_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_datetime_value_max_set(maxtime_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool value_max_get(struct tm* maxtime_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_datetime_value_max_get(maxtime_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      std::string format_get()
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_datetime_format_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      void format_set(std::string fmt_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_datetime_format_set(efl::eolian::to_c(fmt_)));
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DATETIME_EVENT_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_datetime, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_datetime, function_type>,
         ELM_DATETIME_EVENT_CHANGED );
   }

   template <typename T>
   void
   callback_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_DATETIME_EVENT_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DATETIME_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_datetime, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_datetime, function_type>,
         ELM_DATETIME_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_DATETIME_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DATETIME_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_datetime, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_datetime, function_type>,
         ELM_DATETIME_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_DATETIME_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DATETIME_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_datetime, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_datetime, function_type>,
         ELM_DATETIME_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_DATETIME_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DATETIME_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_datetime, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_datetime, function_type>,
         ELM_DATETIME_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_DATETIME_EVENT_UNFOCUSED, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_datetime>)
{
   return (ELM_DATETIME_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_DATETIME_HH

