#ifndef EFL_GENERATED_ELM_DAYSELECTOR_HH
#define EFL_GENERATED_ELM_DAYSELECTOR_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_dayselector.eo.h"
}

#include "elm_layout.eo.hh"

struct elm_dayselector
      : elm_layout
{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_dayselector(Eo* eo)
      : elm_layout(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_dayselector(std::nullptr_t)
      : elm_layout(nullptr)
   {}

   elm_dayselector(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_dayselector(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_dayselector(elm_dayselector const& other)
      : elm_layout(eo_ref(other._eo_ptr()))
   {}

   ~elm_dayselector() {}

   /// @brief Set weekdays names to be displayed by the Dayselector.
   ///
   /// By default or if @a weekdays is @c NULL, weekdays abbreviations get from system are displayed:
   /// E.g. for an en_US locale: "Sun, Mon, Tue, Wed, Thu, Fri, Sat"
   ///
   /// The first string should be related to Sunday, the second to Monday...
   ///
   /// The usage should be like this:
   /// @code
   /// const char *weekdays[] =
   /// {
   /// "Sunday", "Monday", "Tuesday", "Wednesday",
   /// "Thursday", "Friday", "Saturday"
   /// };
   /// elm_dayselector_wekdays_names_set(calendar, weekdays);
   /// @endcode
   ///
   /// @see elm_dayselector_weekdays_name_get()
   /// @see elm_dayselector_weekend_start_set()
   ///
   /// @since 1.8
   ///
   /// @ingroup Dayselector
   ///
   /// @param weekdays Array of seven strings to be used as weekday names.
   /// @warning It must have 7 elements, or it will access invalid memory.
   /// @warning The strings must be NULL terminated ('@\0').
   ///
   void weekdays_names_set(const char ** weekdays_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_dayselector_weekdays_names_set(weekdays_));
   }

   /// @brief Get weekdays names displayed by the calendar.
   ///
   /// @return A list of seven strings to be used as weekday names.
   ///
   /// By default, weekdays abbreviations get from system are displayed:
   /// E.g. for an en_US locale: "Sun, Mon, Tue, Wed, Thu, Fri, Sat"
   /// The first string is related to Sunday, the second to Monday...
   ///
   /// @see elm_dayselector_weekdays_name_set()
   ///
   /// @since 1.8
   ///
   /// @ingroup Dayselector
   ///
   Eina_List * weekdays_names_get() const
   {
      Eina_List * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_dayselector_weekdays_names_get());
      return _tmp_ret;
   }

   /// @brief Set the state of given Dayselector_Day.
   ///
   /// @see Elm_Dayselector_Day
   /// @see elm_dayselector_day_selected_get()
   ///
   /// @ingroup Dayselector
   ///
   /// @param day Dayselector_Day that the user want to set state.
   /// @param selected state of the day. @c EINA_TRUE is selected.
   ///
   void day_selected_set(Elm_Dayselector_Day day_, bool selected_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_dayselector_day_selected_set(day_, efl::eolian::to_c(selected_)));
   }

   /// @brief Get the state of given Dayselector_Day.
   ///
   /// @return @c EINA_TRUE, if the Day is selected
   ///
   /// @see Elm_Dayselector_Day
   /// @see elm_dayselector_day_selected_set()
   ///
   /// @ingroup Dayselector
   ///
   /// @param day Dayselector_Day that the user want to know state.
   ///
   bool day_selected_get(Elm_Dayselector_Day day_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_dayselector_day_selected_get(day_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param day Dayselector_Day the first day that the user wants to display.
   ///
   Elm_Dayselector_Day week_start_get() const
   {
      Elm_Dayselector_Day _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_dayselector_week_start_get());
      return _tmp_ret;
   }

   /// @param day Dayselector_Day the first day that the user wants to display.
   ///
   void week_start_set(Elm_Dayselector_Day day_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_dayselector_week_start_set(day_));
   }

   /// @param length Weekend length, number of days as an integer.
   ///
   unsigned int weekend_length_get() const
   {
      unsigned int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_dayselector_weekend_length_get());
      return _tmp_ret;
   }

   /// @param length Weekend length, number of days as an integer.
   ///
   void weekend_length_set(unsigned int length_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_dayselector_weekend_length_set(length_));
   }

   /// @param day Dayselector_Day the first day from where weekend starts.
   ///
   Elm_Dayselector_Day weekend_start_get() const
   {
      Elm_Dayselector_Day _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_dayselector_weekend_start_get());
      return _tmp_ret;
   }

   /// @param day Dayselector_Day the first day from where weekend starts.
   ///
   void weekend_start_set(Elm_Dayselector_Day day_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_dayselector_weekend_start_set(day_));
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_dayselector_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DAYSELECTOR_EVENT_DAYSELECTOR_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_dayselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_dayselector, function_type>,
         ELM_DAYSELECTOR_EVENT_DAYSELECTOR_CHANGED );
   }

   template <typename T>
   void
   callback_dayselector_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_DAYSELECTOR_EVENT_DAYSELECTOR_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DAYSELECTOR_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_dayselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_dayselector, function_type>,
         ELM_DAYSELECTOR_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_DAYSELECTOR_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DAYSELECTOR_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_dayselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_dayselector, function_type>,
         ELM_DAYSELECTOR_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_DAYSELECTOR_EVENT_ACCESS_CHANGED, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_DAYSELECTOR_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_DAYSELECTOR_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
void _elm_dayselector_weekdays_names_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char ** weekdays_)
{
   static_cast<T*>(self->this_)->weekdays_names_set(weekdays_);
}

template <typename T>
Eina_List * _elm_dayselector_weekdays_names_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->weekdays_names_get();
}

template <typename T>
void _elm_dayselector_day_selected_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Dayselector_Day day_, Eina_Bool selected_)
{
   static_cast<T*>(self->this_)->day_selected_set(day_, efl::eolian::to_cxx<bool>(selected_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_dayselector_day_selected_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Dayselector_Day day_)
{
   return static_cast<T*>(self->this_)->day_selected_get(day_);
}

template <typename T>
Elm_Dayselector_Day _elm_dayselector_week_start_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->week_start_get();
}

template <typename T>
void _elm_dayselector_week_start_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Dayselector_Day day_)
{
   static_cast<T*>(self->this_)->week_start_set(day_);
}

template <typename T>
unsigned int _elm_dayselector_weekend_length_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->weekend_length_get();
}

template <typename T>
void _elm_dayselector_weekend_length_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, unsigned int length_)
{
   static_cast<T*>(self->this_)->weekend_length_set(length_);
}

template <typename T>
Elm_Dayselector_Day _elm_dayselector_weekend_start_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->weekend_start_get();
}

template <typename T>
void _elm_dayselector_weekend_start_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Dayselector_Day day_)
{
   static_cast<T*>(self->this_)->weekend_start_set(day_);
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_dayselector >
{
   template <typename T>
   struct type
   {
      virtual void weekdays_names_set(const char ** weekdays_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_dayselector_weekdays_names_set(weekdays_));
      }

      virtual Eina_List * weekdays_names_get()
      {
         Eina_List * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_dayselector_weekdays_names_get());
            return _tmp_ret;
      }

      virtual void day_selected_set(Elm_Dayselector_Day day_, bool selected_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_dayselector_day_selected_set(day_, efl::eolian::to_c(selected_)));
      }

      virtual bool day_selected_get(Elm_Dayselector_Day day_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_dayselector_day_selected_get(day_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual Elm_Dayselector_Day week_start_get()
      {
         Elm_Dayselector_Day _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_dayselector_week_start_get());
            return _tmp_ret;
      }

      virtual void week_start_set(Elm_Dayselector_Day day_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_dayselector_week_start_set(day_));
      }

      virtual unsigned int weekend_length_get()
      {
         unsigned int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_dayselector_weekend_length_get());
            return _tmp_ret;
      }

      virtual void weekend_length_set(unsigned int length_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_dayselector_weekend_length_set(length_));
      }

      virtual Elm_Dayselector_Day weekend_start_get()
      {
         Elm_Dayselector_Day _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_dayselector_weekend_start_get());
            return _tmp_ret;
      }

      virtual void weekend_start_set(Elm_Dayselector_Day day_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_dayselector_weekend_start_set(day_));
      }

   };
};


template<>
struct operation_description_class_size< ::elm_dayselector >
{
   static const int value = 10;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_dayselector>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_dayselector_weekdays_names_set_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_dayselector_weekdays_names_set);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_dayselector_weekdays_names_get_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_dayselector_weekdays_names_get);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_dayselector_day_selected_set_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_dayselector_day_selected_set);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_dayselector_day_selected_get_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_dayselector_day_selected_get);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_dayselector_week_start_get_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_dayselector_week_start_get);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_dayselector_week_start_set_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_dayselector_week_start_set);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_dayselector_weekend_length_get_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_dayselector_weekend_length_get);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_dayselector_weekend_length_set_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_dayselector_weekend_length_set);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_dayselector_weekend_start_get_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_dayselector_weekend_start_get);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_dayselector_weekend_start_set_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_dayselector_weekend_start_set);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_dayselector >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_dayselector, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_dayselector >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_dayselector, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_dayselector>
{
   template <typename U>
   struct type
   {
      operator ::elm_dayselector() const
      {
         return ::elm_dayselector(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      void weekdays_names_set(const char ** weekdays_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_dayselector_weekdays_names_set(weekdays_));
      }

      Eina_List * weekdays_names_get()
      {
         Eina_List * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_dayselector_weekdays_names_get());
            return _tmp_ret;
      }

      void day_selected_set(Elm_Dayselector_Day day_, bool selected_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_dayselector_day_selected_set(day_, efl::eolian::to_c(selected_)));
      }

      bool day_selected_get(Elm_Dayselector_Day day_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_dayselector_day_selected_get(day_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      Elm_Dayselector_Day week_start_get()
      {
         Elm_Dayselector_Day _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_dayselector_week_start_get());
            return _tmp_ret;
      }

      void week_start_set(Elm_Dayselector_Day day_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_dayselector_week_start_set(day_));
      }

      unsigned int weekend_length_get()
      {
         unsigned int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_dayselector_weekend_length_get());
            return _tmp_ret;
      }

      void weekend_length_set(unsigned int length_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_dayselector_weekend_length_set(length_));
      }

      Elm_Dayselector_Day weekend_start_get()
      {
         Elm_Dayselector_Day _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_dayselector_weekend_start_get());
            return _tmp_ret;
      }

      void weekend_start_set(Elm_Dayselector_Day day_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_dayselector_weekend_start_set(day_));
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_dayselector_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DAYSELECTOR_EVENT_DAYSELECTOR_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_dayselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_dayselector, function_type>,
         ELM_DAYSELECTOR_EVENT_DAYSELECTOR_CHANGED );
   }

   template <typename T>
   void
   callback_dayselector_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_DAYSELECTOR_EVENT_DAYSELECTOR_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DAYSELECTOR_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_dayselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_dayselector, function_type>,
         ELM_DAYSELECTOR_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_DAYSELECTOR_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DAYSELECTOR_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_dayselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_dayselector, function_type>,
         ELM_DAYSELECTOR_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_DAYSELECTOR_EVENT_ACCESS_CHANGED, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_dayselector>)
{
   return (ELM_DAYSELECTOR_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_DAYSELECTOR_HH

