#ifndef EFL_GENERATED_ELM_DISKSELECTOR_HH
#define EFL_GENERATED_ELM_DISKSELECTOR_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_diskselector.eo.h"
}

#include "elm_widget.eo.hh"
#include "elm_interface_scrollable.eo.hh"
#include "elm_interface_atspi_widget_action.eo.hh"
#include <canvas/evas_object.eo.hh>
#include <string>

struct elm_diskselector
      : elm_widget,
      efl::eo::detail::extension_inheritance<elm_interface_scrollable>::template type< ::elm_diskselector>,
      efl::eo::detail::extension_inheritance<elm_interface_atspi_widget_action>::template type< ::elm_diskselector>

{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_diskselector(Eo* eo)
      : elm_widget(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_diskselector(std::nullptr_t)
      : elm_widget(nullptr)
   {}

   elm_diskselector(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_diskselector(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_diskselector(elm_diskselector const& other)
      : elm_widget(eo_ref(other._eo_ptr()))
   {}

   ~elm_diskselector() {}

   /// @brief Appends a new item to the diskselector object.
   ///
   /// @return The created item or @c NULL upon failure.
   ///
   /// A new item will be created and appended to the diskselector, i.e., will
   /// be set as last item. Also, if there is no selected item, it will
   /// be selected. This will always happens for the first appended item.
   ///
   /// If no icon is set, label will be centered on item position, otherwise
   /// the icon will be placed at left of the label, that will be shifted
   /// to the right.
   ///
   /// Items created with this method can be deleted with
   /// elm_object_item_del().
   ///
   /// Associated @p data can be properly freed when item is deleted if a
   /// callback function is set with elm_object_item_del_cb_set().
   ///
   /// If a function is passed as argument, it will be called every time this item
   /// is selected, i.e., the user stops the diskselector with this
   /// item on center position. If such function isn't needed, just passing
   /// @c NULL as @p func is enough. The same should be done for @p data.
   ///
   /// Simple example (with no function callback or data associated):
   /// @code
   /// disk = elm_diskselector_add(win);
   /// ic = elm_icon_add(win);
   /// elm_image_file_set(ic, "path/to/image", NULL);
   /// elm_icon_resizable_set(ic, EINA_TRUE, EINA_TRUE);
   /// elm_diskselector_item_append(disk, "label", ic, NULL, NULL);
   /// @endcode
   ///
   /// @see elm_object_item_del()
   /// @see elm_diskselector_clear()
   /// @see elm_icon_add()
   ///
   /// @ingroup Diskselector
   ///
   /// @param label The label of the diskselector item.
   /// @param icon The icon object to use at left side of the item. An
   /// icon can be any Evas object, but usually it is an icon created
   /// with elm_icon_add().
   /// @param func The function to call when the item is selected.
   /// @param data The data to associate with the item for related callbacks.
   ///
   Elm_Object_Item * item_append(std::string label_, evas::object icon_, Evas_Smart_Cb func_, const void * data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_diskselector_item_append(efl::eolian::to_c(label_), efl::eolian::to_c(icon_), func_, data_));
      return _tmp_ret;
   }

   /// @brief Remove all diskselector's items.
   ///
   /// @see elm_object_item_del()
   /// @see elm_diskselector_item_append()
   ///
   /// @ingroup Diskselector
   ///
   void clear() const
   {
      eo_do(_eo_ptr(), ::elm_obj_diskselector_clear());
   }

   /// @param len The max length defined for side labels.
   ///
   int side_text_max_length_get() const
   {
      int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_diskselector_side_text_max_length_get());
      return _tmp_ret;
   }

   /// @param len The max length defined for side labels.
   ///
   void side_text_max_length_set(int len_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_diskselector_side_text_max_length_set(len_));
   }

   /// @param enabled @c EINA_TRUE to enable round mode or @c EINA_FALSE to
   /// disable it.
   ///
   bool round_enabled_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_diskselector_round_enabled_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param enabled @c EINA_TRUE to enable round mode or @c EINA_FALSE to
   /// disable it.
   ///
   void round_enabled_set(bool enabled_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_diskselector_round_enabled_set(efl::eolian::to_c(enabled_)));
   }

   /// @param num The number of items the diskselector will display.
   ///
   int display_item_num_get() const
   {
      int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_diskselector_display_item_num_get());
      return _tmp_ret;
   }

   /// @param num The number of items the diskselector will display.
   ///
   void display_item_num_set(int num_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_diskselector_display_item_num_set(num_));
   }

   Elm_Object_Item * first_item_get() const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_diskselector_first_item_get());
      return _tmp_ret;
   }

   const Eina_List * items_get() const
   {
      const Eina_List * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_diskselector_items_get());
      return _tmp_ret;
   }

   Elm_Object_Item * last_item_get() const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_diskselector_last_item_get());
      return _tmp_ret;
   }

   Elm_Object_Item * selected_item_get() const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_diskselector_selected_item_get());
      return _tmp_ret;
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_selected_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DISKSELECTOR_EVENT_SELECTED, priority_,
            &efl::eo::_detail::event_callback<::elm_diskselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_diskselector, function_type>,
         ELM_DISKSELECTOR_EVENT_SELECTED );
   }

   template <typename T>
   void
   callback_selected_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_DISKSELECTOR_EVENT_SELECTED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_clicked_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DISKSELECTOR_EVENT_CLICKED, priority_,
            &efl::eo::_detail::event_callback<::elm_diskselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_diskselector, function_type>,
         ELM_DISKSELECTOR_EVENT_CLICKED );
   }

   template <typename T>
   void
   callback_clicked_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_DISKSELECTOR_EVENT_CLICKED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_anim_start_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DISKSELECTOR_EVENT_SCROLL_ANIM_START, priority_,
            &efl::eo::_detail::event_callback<::elm_diskselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_diskselector, function_type>,
         ELM_DISKSELECTOR_EVENT_SCROLL_ANIM_START );
   }

   template <typename T>
   void
   callback_scroll_anim_start_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_DISKSELECTOR_EVENT_SCROLL_ANIM_START, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_anim_stop_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DISKSELECTOR_EVENT_SCROLL_ANIM_STOP, priority_,
            &efl::eo::_detail::event_callback<::elm_diskselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_diskselector, function_type>,
         ELM_DISKSELECTOR_EVENT_SCROLL_ANIM_STOP );
   }

   template <typename T>
   void
   callback_scroll_anim_stop_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_DISKSELECTOR_EVENT_SCROLL_ANIM_STOP, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_drag_start_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DISKSELECTOR_EVENT_SCROLL_DRAG_START, priority_,
            &efl::eo::_detail::event_callback<::elm_diskselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_diskselector, function_type>,
         ELM_DISKSELECTOR_EVENT_SCROLL_DRAG_START );
   }

   template <typename T>
   void
   callback_scroll_drag_start_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_DISKSELECTOR_EVENT_SCROLL_DRAG_START, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_drag_stop_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DISKSELECTOR_EVENT_SCROLL_DRAG_STOP, priority_,
            &efl::eo::_detail::event_callback<::elm_diskselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_diskselector, function_type>,
         ELM_DISKSELECTOR_EVENT_SCROLL_DRAG_STOP );
   }

   template <typename T>
   void
   callback_scroll_drag_stop_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_DISKSELECTOR_EVENT_SCROLL_DRAG_STOP, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DISKSELECTOR_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_diskselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_diskselector, function_type>,
         ELM_DISKSELECTOR_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_DISKSELECTOR_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DISKSELECTOR_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_diskselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_diskselector, function_type>,
         ELM_DISKSELECTOR_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_DISKSELECTOR_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DISKSELECTOR_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_diskselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_diskselector, function_type>,
         ELM_DISKSELECTOR_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_DISKSELECTOR_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DISKSELECTOR_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_diskselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_diskselector, function_type>,
         ELM_DISKSELECTOR_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_DISKSELECTOR_EVENT_UNFOCUSED, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_DISKSELECTOR_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_DISKSELECTOR_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
Elm_Object_Item * _elm_diskselector_item_append_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * label_, Evas_Object * icon_, Evas_Smart_Cb func_, const void * data_)
{
   return static_cast<T*>(self->this_)->item_append(efl::eolian::to_cxx<std::string>(label_, std::tuple<std::false_type>()), efl::eolian::to_cxx<evas::object>(icon_, std::tuple<std::false_type>()), func_, data_);
}

template <typename T>
void _elm_diskselector_clear_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->clear();
}

template <typename T>
int _elm_diskselector_side_text_max_length_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->side_text_max_length_get();
}

template <typename T>
void _elm_diskselector_side_text_max_length_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int len_)
{
   static_cast<T*>(self->this_)->side_text_max_length_set(len_);
}

template <typename T>
bool _elm_diskselector_round_enabled_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->round_enabled_get();
}

template <typename T>
void _elm_diskselector_round_enabled_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool enabled_)
{
   static_cast<T*>(self->this_)->round_enabled_set(efl::eolian::to_cxx<bool>(enabled_, std::tuple<std::false_type>()));
}

template <typename T>
int _elm_diskselector_display_item_num_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->display_item_num_get();
}

template <typename T>
void _elm_diskselector_display_item_num_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int num_)
{
   static_cast<T*>(self->this_)->display_item_num_set(num_);
}

template <typename T>
Elm_Object_Item * _elm_diskselector_first_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->first_item_get();
}

template <typename T>
const Eina_List * _elm_diskselector_items_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->items_get();
}

template <typename T>
Elm_Object_Item * _elm_diskselector_last_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->last_item_get();
}

template <typename T>
Elm_Object_Item * _elm_diskselector_selected_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->selected_item_get();
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_diskselector >
{
   template <typename T>
   struct type
   {
      virtual Elm_Object_Item * item_append(std::string label_, evas::object icon_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_diskselector_item_append(efl::eolian::to_c(label_), efl::eolian::to_c(icon_), func_, data_));
            return _tmp_ret;
      }

      virtual void clear()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_diskselector_clear());
      }

      virtual int side_text_max_length_get()
      {
         int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_diskselector_side_text_max_length_get());
            return _tmp_ret;
      }

      virtual void side_text_max_length_set(int len_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_diskselector_side_text_max_length_set(len_));
      }

      virtual bool round_enabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_diskselector_round_enabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void round_enabled_set(bool enabled_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_diskselector_round_enabled_set(efl::eolian::to_c(enabled_)));
      }

      virtual int display_item_num_get()
      {
         int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_diskselector_display_item_num_get());
            return _tmp_ret;
      }

      virtual void display_item_num_set(int num_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_diskselector_display_item_num_set(num_));
      }

      virtual Elm_Object_Item * first_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_diskselector_first_item_get());
            return _tmp_ret;
      }

      virtual const Eina_List * items_get()
      {
         const Eina_List * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_diskselector_items_get());
            return _tmp_ret;
      }

      virtual Elm_Object_Item * last_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_diskselector_last_item_get());
            return _tmp_ret;
      }

      virtual Elm_Object_Item * selected_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_diskselector_selected_item_get());
            return _tmp_ret;
      }

   };
};


template<>
struct operation_description_class_size< ::elm_diskselector >
{
   static const int value = 12;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_diskselector>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_diskselector_item_append_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_diskselector_item_append);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_diskselector_clear_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_diskselector_clear);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_diskselector_side_text_max_length_get_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_diskselector_side_text_max_length_get);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_diskselector_side_text_max_length_set_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_diskselector_side_text_max_length_set);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_diskselector_round_enabled_get_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_diskselector_round_enabled_get);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_diskselector_round_enabled_set_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_diskselector_round_enabled_set);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_diskselector_display_item_num_get_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_diskselector_display_item_num_get);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_diskselector_display_item_num_set_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_diskselector_display_item_num_set);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_diskselector_first_item_get_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_diskselector_first_item_get);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_diskselector_items_get_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_diskselector_items_get);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::_elm_diskselector_last_item_get_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::elm_obj_diskselector_last_item_get);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::_elm_diskselector_selected_item_get_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::elm_obj_diskselector_selected_item_get);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_diskselector >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_diskselector, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_diskselector >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_diskselector, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_diskselector>
{
   template <typename U>
   struct type
   {
      operator ::elm_diskselector() const
      {
         return ::elm_diskselector(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      Elm_Object_Item * item_append(std::string label_, evas::object icon_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_diskselector_item_append(efl::eolian::to_c(label_), efl::eolian::to_c(icon_), func_, data_));
            return _tmp_ret;
      }

      void clear()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_diskselector_clear());
      }

      int side_text_max_length_get()
      {
         int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_diskselector_side_text_max_length_get());
            return _tmp_ret;
      }

      void side_text_max_length_set(int len_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_diskselector_side_text_max_length_set(len_));
      }

      bool round_enabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_diskselector_round_enabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void round_enabled_set(bool enabled_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_diskselector_round_enabled_set(efl::eolian::to_c(enabled_)));
      }

      int display_item_num_get()
      {
         int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_diskselector_display_item_num_get());
            return _tmp_ret;
      }

      void display_item_num_set(int num_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_diskselector_display_item_num_set(num_));
      }

      Elm_Object_Item * first_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_diskselector_first_item_get());
            return _tmp_ret;
      }

      const Eina_List * items_get()
      {
         const Eina_List * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_diskselector_items_get());
            return _tmp_ret;
      }

      Elm_Object_Item * last_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_diskselector_last_item_get());
            return _tmp_ret;
      }

      Elm_Object_Item * selected_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_diskselector_selected_item_get());
            return _tmp_ret;
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_selected_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DISKSELECTOR_EVENT_SELECTED, priority_,
            &efl::eo::_detail::event_callback<::elm_diskselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_diskselector, function_type>,
         ELM_DISKSELECTOR_EVENT_SELECTED );
   }

   template <typename T>
   void
   callback_selected_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_DISKSELECTOR_EVENT_SELECTED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_clicked_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DISKSELECTOR_EVENT_CLICKED, priority_,
            &efl::eo::_detail::event_callback<::elm_diskselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_diskselector, function_type>,
         ELM_DISKSELECTOR_EVENT_CLICKED );
   }

   template <typename T>
   void
   callback_clicked_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_DISKSELECTOR_EVENT_CLICKED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_anim_start_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DISKSELECTOR_EVENT_SCROLL_ANIM_START, priority_,
            &efl::eo::_detail::event_callback<::elm_diskselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_diskselector, function_type>,
         ELM_DISKSELECTOR_EVENT_SCROLL_ANIM_START );
   }

   template <typename T>
   void
   callback_scroll_anim_start_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_DISKSELECTOR_EVENT_SCROLL_ANIM_START, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_anim_stop_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DISKSELECTOR_EVENT_SCROLL_ANIM_STOP, priority_,
            &efl::eo::_detail::event_callback<::elm_diskselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_diskselector, function_type>,
         ELM_DISKSELECTOR_EVENT_SCROLL_ANIM_STOP );
   }

   template <typename T>
   void
   callback_scroll_anim_stop_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_DISKSELECTOR_EVENT_SCROLL_ANIM_STOP, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_drag_start_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DISKSELECTOR_EVENT_SCROLL_DRAG_START, priority_,
            &efl::eo::_detail::event_callback<::elm_diskselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_diskselector, function_type>,
         ELM_DISKSELECTOR_EVENT_SCROLL_DRAG_START );
   }

   template <typename T>
   void
   callback_scroll_drag_start_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_DISKSELECTOR_EVENT_SCROLL_DRAG_START, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_drag_stop_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DISKSELECTOR_EVENT_SCROLL_DRAG_STOP, priority_,
            &efl::eo::_detail::event_callback<::elm_diskselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_diskselector, function_type>,
         ELM_DISKSELECTOR_EVENT_SCROLL_DRAG_STOP );
   }

   template <typename T>
   void
   callback_scroll_drag_stop_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_DISKSELECTOR_EVENT_SCROLL_DRAG_STOP, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DISKSELECTOR_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_diskselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_diskselector, function_type>,
         ELM_DISKSELECTOR_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_DISKSELECTOR_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DISKSELECTOR_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_diskselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_diskselector, function_type>,
         ELM_DISKSELECTOR_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_DISKSELECTOR_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DISKSELECTOR_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_diskselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_diskselector, function_type>,
         ELM_DISKSELECTOR_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_DISKSELECTOR_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_DISKSELECTOR_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_diskselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_diskselector, function_type>,
         ELM_DISKSELECTOR_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_DISKSELECTOR_EVENT_UNFOCUSED, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_diskselector>)
{
   return (ELM_DISKSELECTOR_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_DISKSELECTOR_HH

