#ifndef EFL_GENERATED_ELM_ENTRY_HH
#define EFL_GENERATED_ELM_ENTRY_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_entry.eo.h"
}

#include "elm_layout.eo.hh"
#include "elm_interface_scrollable.eo.hh"
#include "evas_clickable_interface.eo.hh"
#include "elm_interface_atspi_text.eo.hh"
#include "elm_interface_atspi_editable_text.eo.hh"
#include <canvas/evas_object.eo.hh>
#include <string>

struct elm_entry
      : elm_layout,
      efl::eo::detail::extension_inheritance<elm_interface_scrollable>::template type< ::elm_entry>,
      efl::eo::detail::extension_inheritance<evas::clickable_interface>::template type< ::elm_entry>,
      efl::eo::detail::extension_inheritance<elm_interface_atspi_text>::template type< ::elm_entry>,
      efl::eo::detail::extension_inheritance<elm_interface_atspi_editable_text>::template type< ::elm_entry>

{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_entry(Eo* eo)
      : elm_layout(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_entry(std::nullptr_t)
      : elm_layout(nullptr)
   {}

   elm_entry(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_entry(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_entry(elm_entry const& other)
      : elm_layout(eo_ref(other._eo_ptr()))
   {}

   ~elm_entry() {}

   /// @brief This moves the cursor one place to the left within the entry.
   ///
   /// @return EINA_TRUE upon success, EINA_FALSE upon failure
   ///
   /// @ingroup Entry
   ///
   bool cursor_prev() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_cursor_prev());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Remove the style in the top of user style stack.
   ///
   /// @see elm_entry_text_style_user_push()
   ///
   /// @ingroup Entry
   /// @since 1.7
   ///
   void text_style_user_pop() const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_text_style_user_pop());
   }

   /// @brief This prepends a custom item provider to the list for that entry
   ///
   /// This prepends the given callback. See elm_entry_item_provider_append() for
   /// more information
   ///
   /// @ingroup Entry
   ///
   /// @param func The function called to provide the item object
   /// @param data The data passed to @p func
   ///
   void item_provider_prepend(Elm_Entry_Item_Provider_Cb func_, void * data_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_item_provider_prepend(func_, data_));
   }

   /// @brief Show the input panel (virtual keyboard) based on the input panel property of entry such as layout, autocapital types, and so on.
   ///
   /// Note that input panel is shown or hidden automatically according to the focus state of entry widget.
   /// This API can be used in the case of manually controlling by using elm_entry_input_panel_enabled_set(en, EINA_FALSE).
   ///
   /// @ingroup Entry
   ///
   void input_panel_show() const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_input_panel_show());
   }

   /// @brief Reset the input method context of the entry if needed.
   ///
   /// This can be necessary in the case where modifying the buffer would confuse on-going input method behavior.
   /// This will typically cause the Input Method Context to clear the preedit state.
   /// @ingroup Entry
   ///
   void imf_context_reset() const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_imf_context_reset());
   }

   /// @brief Forces calculation of the entry size and text layouting.
   ///
   /// This should be used after modifying the textblock object directly. See
   /// elm_entry_textblock_get() for more information.
   ///
   /// @see elm_entry_textblock_get()
   ///
   /// @ingroup Entry
   ///
   void calc_force() const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_calc_force());
   }

   /// @brief Ends the hover popup in the entry
   ///
   /// When an anchor is clicked, the entry widget will create a hover
   /// object to use as a popup with user provided content. This function
   /// terminates this popup, returning the entry to its normal state.
   ///
   /// @ingroup Entry
   ///
   void anchor_hover_end() const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_anchor_hover_end());
   }

   /// @brief This begins a selection within the entry as though
   /// the user were holding down the mouse button to make a selection.
   ///
   /// @ingroup Entry
   ///
   void cursor_selection_begin() const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_cursor_selection_begin());
   }

   /// @brief This moves the cursor one line down within the entry.
   ///
   /// @return EINA_TRUE upon success, EINA_FALSE upon failure
   ///
   /// @ingroup Entry
   ///
   bool cursor_down() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_cursor_down());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief This function writes any changes made to the file set with
   /// elm_entry_file_set()
   ///
   /// @ingroup Entry
   ///
   void file_save() const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_file_save());
   }

   /// @brief This executes a "copy" action on the selected text in the entry.
   ///
   /// @ingroup Entry
   ///
   void selection_copy() const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_selection_copy());
   }

   /// @brief Push the style to the top of user style stack.
   /// If there is styles in the user style stack, the properties in the top style
   /// of user style stack will replace the properties in current theme.
   /// The input style is specified in format tag='property=value' (i.e. DEFAULT='font=Sans font_size=60'hilight=' + font_weight=Bold').
   ///
   /// @ingroup Entry
   /// @since 1.7
   ///
   /// @param style The style user to push
   ///
   void text_style_user_push(std::string style_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_text_style_user_push(efl::eolian::to_c(style_)));
   }

   /// @brief This removes a custom item provider to the list for that entry
   ///
   /// This removes the given callback. See elm_entry_item_provider_append() for
   /// more information
   ///
   /// @ingroup Entry
   ///
   /// @param func The function called to provide the item object
   /// @param data The data passed to @p func
   ///
   void item_provider_remove(Elm_Entry_Item_Provider_Cb func_, void * data_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_item_provider_remove(func_, data_));
   }

   /// @brief Retrieve the style on the top of user style stack.
   ///
   /// @return style on the top of user style stack if exist, otherwise NULL.
   ///
   /// @see elm_entry_text_style_user_push()
   ///
   /// @ingroup Entry
   /// @since 1.7
   ///
   std::string text_style_user_peek() const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_text_style_user_peek());
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief This clears and frees the items in a entry's contextual (longpress)
   /// menu.
   ///
   /// @see elm_entry_context_menu_item_add()
   ///
   /// @ingroup Entry
   ///
   void context_menu_clear() const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_context_menu_clear());
   }

   /// @brief This moves the cursor one line up within the entry.
   ///
   /// @return EINA_TRUE upon success, EINA_FALSE upon failure
   ///
   /// @ingroup Entry
   ///
   bool cursor_up() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_cursor_up());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Inserts the given text into the entry at the current cursor position.
   ///
   /// This inserts text at the cursor position as if it was typed
   /// by the user (note that this also allows markup which a user
   /// can't just "type" as it would be converted to escaped text, so this
   /// call can be used to insert things like emoticon items or bold push/pop
   /// tags, other font and color change tags etc.)
   ///
   /// If any selection exists, it will be replaced by the inserted text.
   ///
   /// The inserted text is subject to any filters set for the widget.
   ///
   /// @see elm_entry_markup_filter_append()
   ///
   /// @ingroup Entry
   ///
   /// @param entry The text to insert
   ///
   void entry_insert(std::string entry_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_insert(efl::eolian::to_c(entry_)));
   }

   /// @brief Set the input panel-specific data to deliver to the input panel.
   ///
   /// This API is used by applications to deliver specific data to the input panel.
   /// The data format MUST be negotiated by both application and the input panel.
   /// The size and format of data are defined by the input panel.
   ///
   /// @ingroup Entry
   ///
   /// @param data The specific data to be set to the input panel.
   /// @param len the length of data, in bytes, to send to the input panel
   ///
   void input_panel_imdata_set(const void * data_, int len_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_input_panel_imdata_set(data_, len_));
   }

   /// @brief Get the specific data of the current input panel.
   ///
   /// See @ref elm_entry_input_panel_imdata_set for more details.
   ///
   /// @ingroup Entry
   ///
   /// @param[out] data The specific data to be got from the input panel
   /// @param[out] len The length of data
   ///
   void input_panel_imdata_get(void* data_, int* len_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_input_panel_imdata_get(data_, len_));
   }

   /// @brief This executes a "paste" action in the entry.
   ///
   /// @ingroup Entry
   ///
   void selection_paste() const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_selection_paste());
   }

   /// @brief This moves the cursor one place to the right within the entry.
   ///
   /// @return EINA_TRUE upon success, EINA_FALSE upon failure
   ///
   /// @ingroup Entry
   ///
   bool cursor_next() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_cursor_next());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief This drops any existing text selection within the entry.
   ///
   /// @ingroup Entry
   ///
   void select_none() const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_select_none());
   }

   /// @brief Hide the input panel (virtual keyboard).
   ///
   /// Note that input panel is shown or hidden automatically according to the focus state of entry widget.
   /// This API can be used in the case of manually controlling by using elm_entry_input_panel_enabled_set(en, EINA_FALSE)
   ///
   /// @ingroup Entry
   ///
   void input_panel_hide() const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_input_panel_hide());
   }

   /// @brief This selects all text within the entry.
   ///
   /// @ingroup Entry
   ///
   void select_all() const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_select_all());
   }

   /// @brief This ends a selection within the entry as though
   /// the user had just released the mouse button while making a selection.
   ///
   /// @ingroup Entry
   ///
   void cursor_selection_end() const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_cursor_selection_end());
   }

   /// @brief This executes a "cut" action on the selected text in the entry.
   ///
   /// @ingroup Entry
   ///
   void selection_cut() const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_selection_cut());
   }

   /// @brief Get whether the entry is empty.
   ///
   /// Empty means no text at all. If there are any markup tags, like an item
   /// tag for which no provider finds anything, and no text is displayed, this
   /// function still returns EINA_FALSE.
   ///
   /// @return EINA_TRUE if the entry is empty, EINA_FALSE otherwise.
   ///
   /// @ingroup Entry
   ///
   bool is_empty() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_is_empty());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Remove a markup filter from the list
   ///
   /// Removes the given callback from the filter list. See
   /// elm_entry_markup_filter_append() for more information.
   ///
   /// @ingroup Entry
   ///
   /// @param func The filter function to remove
   /// @param data The user data passed when adding the function
   ///
   void markup_filter_remove(Elm_Entry_Filter_Cb func_, void * data_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_markup_filter_remove(func_, data_));
   }

   /// @brief This appends a custom item provider to the list for that entry
   ///
   /// This appends the given callback. The list is walked from beginning to end
   /// with each function called given the item href string in the text. If the
   /// function returns an object handle other than NULL (it should create an
   /// object to do this), then this object is used to replace that item. If
   /// not the next provider is called until one provides an item object, or the
   /// default provider in entry does.
   ///
   /// @see @ref entry-items
   ///
   /// @ingroup Entry
   ///
   /// @param func The function called to provide the item object
   /// @param data The data passed to @p func
   ///
   void item_provider_append(Elm_Entry_Item_Provider_Cb func_, void * data_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_item_provider_append(func_, data_));
   }

   /// @brief Append a markup filter function for text inserted in the entry
   ///
   /// Append the given callback to the list. This functions will be called
   /// whenever any text is inserted into the entry, with the text to be inserted
   /// as a parameter. The type of given text is always markup.
   /// The callback function is free to alter the text in any way it wants, but
   /// it must remember to free the given pointer and update it.
   /// If the new text is to be discarded, the function can free it and set its
   /// text parameter to NULL. This will also prevent any following filters from
   /// being called.
   ///
   /// @ingroup Entry
   ///
   /// @param func The function to use as text filter
   /// @param data User data to pass to @p func
   ///
   void markup_filter_append(Elm_Entry_Filter_Cb func_, void * data_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_markup_filter_append(func_, data_));
   }

   /// @brief Appends @p entry to the text of the entry.
   ///
   /// Adds the text in @p entry to the end of any text already present in the
   /// widget.
   ///
   /// The appended text is subject to any filters set for the widget.
   ///
   /// @see elm_entry_markup_filter_append()
   ///
   /// @ingroup Entry
   ///
   /// @param entry The text to be displayed
   ///
   void entry_append(std::string entry_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_append(efl::eolian::to_c(entry_)));
   }

   /// @brief This adds an item to the entry's contextual menu.
   ///
   /// A longpress on an entry will make the contextual menu show up, if this
   /// hasn't been disabled with elm_entry_context_menu_disabled_set().
   /// By default, this menu provides a few options like enabling selection mode,
   /// which is useful on embedded devices that need to be explicit about it,
   /// and when a selection exists it also shows the copy and cut actions.
   ///
   /// With this function, developers can add other options to this menu to
   /// perform any action they deem necessary.
   ///
   /// @ingroup Entry
   ///
   /// @param label The item's text label
   /// @param icon_file The item's icon file
   /// @param icon_type The item's icon type
   /// @param func The callback to execute when the item is clicked
   /// @param data The data to associate with the item for related functions
   ///
   void context_menu_item_add(std::string label_, std::string icon_file_, Elm_Icon_Type icon_type_, Evas_Smart_Cb func_, const void * data_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_context_menu_item_add(efl::eolian::to_c(label_), efl::eolian::to_c(icon_file_), icon_type_, func_, data_));
   }

   /// @brief Prepend a markup filter function for text inserted in the entry
   ///
   /// Prepend the given callback to the list. See elm_entry_markup_filter_append()
   /// for more information
   ///
   /// @ingroup Entry
   ///
   /// @param func The function to use as text filter
   /// @param data User data to pass to @p func
   ///
   void markup_filter_prepend(Elm_Entry_Filter_Cb func_, void * data_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_markup_filter_prepend(func_, data_));
   }

   /// @param scroll EINA_TRUE if it is to be scrollable, EINA_FALSE otherwise
   ///
   bool scrollable_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_scrollable_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param scroll EINA_TRUE if it is to be scrollable, EINA_FALSE otherwise
   ///
   void scrollable_set(bool scroll_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_scrollable_set(efl::eolian::to_c(scroll_)));
   }

   /// @param ondemand If true, the input panel will be shown in case of only Mouse up event.
   /// (Focus event will be ignored.)
   /// @since 1.9
   ///
   bool input_panel_show_on_demand_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_input_panel_show_on_demand_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param ondemand If true, the input panel will be shown in case of only Mouse up event.
   /// (Focus event will be ignored.)
   /// @since 1.9
   ///
   void input_panel_show_on_demand_set(bool ondemand_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_input_panel_show_on_demand_set(efl::eolian::to_c(ondemand_)));
   }

   /// @param disabled If true, the menu is disabled
   ///
   bool context_menu_disabled_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_context_menu_disabled_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param disabled If true, the menu is disabled
   ///
   void context_menu_disabled_set(bool disabled_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_context_menu_disabled_set(efl::eolian::to_c(disabled_)));
   }

   /// @param cnp_mode One of #Elm_Cnp_Mode: #ELM_CNP_MODE_MARKUP, #ELM_CNP_MODE_NO_IMAGE, #ELM_CNP_MODE_PLAINTEXT.
   ///
   Elm_Cnp_Mode cnp_mode_get() const
   {
      Elm_Cnp_Mode _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_cnp_mode_get());
      return _tmp_ret;
   }

   /// @param cnp_mode One of #Elm_Cnp_Mode: #ELM_CNP_MODE_MARKUP, #ELM_CNP_MODE_NO_IMAGE, #ELM_CNP_MODE_PLAINTEXT.
   ///
   void cnp_mode_set(Elm_Cnp_Mode cnp_mode_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_cnp_mode_set(cnp_mode_));
   }

   /// @param lang language to be set to the input panel.
   ///
   Elm_Input_Panel_Lang input_panel_language_get() const
   {
      Elm_Input_Panel_Lang _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_input_panel_language_get());
      return _tmp_ret;
   }

   /// @param lang language to be set to the input panel.
   ///
   void input_panel_language_set(Elm_Input_Panel_Lang lang_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_input_panel_language_set(lang_));
   }

   /// @param disabled If true, the selection handlers are disabled.
   ///
   bool selection_handler_disabled_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_selection_handler_disabled_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param disabled If true, the selection handlers are disabled.
   ///
   void selection_handler_disabled_set(bool disabled_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_selection_handler_disabled_set(efl::eolian::to_c(disabled_)));
   }

   /// @param variation layout variation type
   ///
   int input_panel_layout_variation_get() const
   {
      int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_input_panel_layout_variation_get());
      return _tmp_ret;
   }

   /// @param variation layout variation type
   ///
   void input_panel_layout_variation_set(int variation_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_input_panel_layout_variation_set(variation_));
   }

   /// @param autocapital_type The type of autocapitalization
   ///
   Elm_Autocapital_Type autocapital_type_get() const
   {
      Elm_Autocapital_Type _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_autocapital_type_get());
      return _tmp_ret;
   }

   /// @param autocapital_type The type of autocapitalization
   ///
   void autocapital_type_set(Elm_Autocapital_Type autocapital_type_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_autocapital_type_set(autocapital_type_));
   }

   /// @param editable If EINA_TRUE, user input will be inserted in the entry,
   /// if not, the entry is read-only and no user input is allowed.
   ///
   bool editable_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_editable_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param editable If EINA_TRUE, user input will be inserted in the entry,
   /// if not, the entry is read-only and no user input is allowed.
   ///
   void editable_set(bool editable_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_editable_set(efl::eolian::to_c(editable_)));
   }

   /// @param style The style to use for the underlying hover
   ///
   std::string anchor_hover_style_get() const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_anchor_hover_style_get());
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param style The style to use for the underlying hover
   ///
   void anchor_hover_style_set(std::string style_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_anchor_hover_style_set(efl::eolian::to_c(style_)));
   }

   /// @param single_line If true, the text in the entry
   /// will be on a single line.
   ///
   bool single_line_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_single_line_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param single_line If true, the text in the entry
   /// will be on a single line.
   ///
   void single_line_set(bool single_line_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_single_line_set(efl::eolian::to_c(single_line_)));
   }

   /// @param password If true, password mode is enabled.
   ///
   bool password_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_password_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param password If true, password mode is enabled.
   ///
   void password_set(bool password_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_password_set(efl::eolian::to_c(password_)));
   }

   /// @param file The path to the file to load and save
   /// @param format The file format
   ///
   void file_get(const char ** file_, Elm_Text_Format* format_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_file_get(file_, format_));
   }

   /// @param file The path to the file to load and save
   /// @param format The file format
   ///
   bool file_set(std::string file_, Elm_Text_Format format_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_file_set(efl::eolian::to_c(file_), format_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param disabled The state to put in in: @c EINA_TRUE for
   /// disabled, @c EINA_FALSE for enabled
   ///
   bool input_panel_return_key_disabled_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_input_panel_return_key_disabled_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param disabled The state to put in in: @c EINA_TRUE for
   /// disabled, @c EINA_FALSE for enabled
   ///
   void input_panel_return_key_disabled_set(bool disabled_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_input_panel_return_key_disabled_set(efl::eolian::to_c(disabled_)));
   }

   /// @param auto_save Autosave the loaded file or not
   ///
   bool autosave_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_autosave_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param auto_save Autosave the loaded file or not
   ///
   void autosave_set(bool auto_save_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_autosave_set(efl::eolian::to_c(auto_save_)));
   }

   /// @param parent The object to use as parent for the hover
   ///
   evas::object anchor_hover_parent_get() const
   {
      Evas_Object * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_anchor_hover_parent_get());
      return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param parent The object to use as parent for the hover
   ///
   void anchor_hover_parent_set(evas::object parent_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_anchor_hover_parent_set(efl::eolian::to_c(parent_)));
   }

   /// @param prediction Whether the entry should allow to use the text prediction.
   ///
   bool prediction_allow_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_prediction_allow_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param prediction Whether the entry should allow to use the text prediction.
   ///
   void prediction_allow_set(bool prediction_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_prediction_allow_set(efl::eolian::to_c(prediction_)));
   }

   /// @param layout layout type
   ///
   Elm_Input_Panel_Layout input_panel_layout_get() const
   {
      Elm_Input_Panel_Layout _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_input_panel_layout_get());
      return _tmp_ret;
   }

   /// @param layout layout type
   ///
   void input_panel_layout_set(Elm_Input_Panel_Layout layout_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_input_panel_layout_set(layout_));
   }

   /// @param return_key_type The type of "return" key on the input panel
   ///
   Elm_Input_Panel_Return_Key_Type input_panel_return_key_type_get() const
   {
      Elm_Input_Panel_Return_Key_Type _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_input_panel_return_key_type_get());
      return _tmp_ret;
   }

   /// @param return_key_type The type of "return" key on the input panel
   ///
   void input_panel_return_key_type_set(Elm_Input_Panel_Return_Key_Type return_key_type_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_input_panel_return_key_type_set(return_key_type_));
   }

   /// @param enabled If true, the input panel is appeared when entry is clicked or has a focus
   ///
   bool input_panel_enabled_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_input_panel_enabled_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param enabled If true, the input panel is appeared when entry is clicked or has a focus
   ///
   void input_panel_enabled_set(bool enabled_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_input_panel_enabled_set(efl::eolian::to_c(enabled_)));
   }

   /// @param wrap The wrap mode to use. See Elm_Wrap_Type for details on them
   ///
   Elm_Wrap_Type line_wrap_get() const
   {
      Elm_Wrap_Type _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_line_wrap_get());
      return _tmp_ret;
   }

   /// @param wrap The wrap mode to use. See Elm_Wrap_Type for details on them
   ///
   void line_wrap_set(Elm_Wrap_Type wrap_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_line_wrap_set(wrap_));
   }

   /// @param pos The position of the cursor
   ///
   int cursor_pos_get() const
   {
      int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_cursor_pos_get());
      return _tmp_ret;
   }

   /// @param pos The position of the cursor
   ///
   void cursor_pos_set(int pos_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_cursor_pos_set(pos_));
   }

   /// @param setting EINA_TRUE if the object should be displayed,
   /// EINA_FALSE if not.
   ///
   void icon_visible_set(bool setting_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_icon_visible_set(efl::eolian::to_c(setting_)));
   }

   void cursor_line_end_set() const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_cursor_line_end_set());
   }

   /// @param start The starting position
   /// @param end The end position
   ///
   void select_region_set(int start_, int end_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_select_region_set(start_, end_));
   }

   /// @param enabled If @p enabled is EINA_TRUE, the return key is automatically disabled when the entry has no text.
   ///
   void input_panel_return_key_autoenabled_set(bool enabled_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_input_panel_return_key_autoenabled_set(efl::eolian::to_c(enabled_)));
   }

   /// @param setting EINA_TRUE if the object should be displayed,
   /// EINA_FALSE if not.
   ///
   void end_visible_set(bool setting_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_end_visible_set(efl::eolian::to_c(setting_)));
   }

   void cursor_begin_set() const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_cursor_begin_set());
   }

   void cursor_line_begin_set() const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_cursor_line_begin_set());
   }

   void cursor_end_set() const
   {
      eo_do(_eo_ptr(), ::elm_obj_entry_cursor_end_set());
   }

   evas::object textblock_get() const
   {
      Evas_Object * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_textblock_get());
      return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param x returned geometry
   /// @param y returned geometry
   /// @param w returned geometry
   /// @param h returned geometry
   ///
   bool cursor_geometry_get(Evas_Coord* x_, Evas_Coord* y_, Evas_Coord* w_, Evas_Coord* h_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_cursor_geometry_get(x_, y_, w_, h_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   void * imf_context_get() const
   {
      void * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_imf_context_get());
      return _tmp_ret;
   }

   bool cursor_is_format_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_cursor_is_format_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   char * cursor_content_get() const
   {
      char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_cursor_content_get());
      return _tmp_ret;
   }

   std::string selection_get() const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_selection_get());
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   bool cursor_is_visible_format_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_entry_cursor_is_visible_format_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_ENTRY_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_entry, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_entry, function_type>,
         ELM_ENTRY_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_ENTRY_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_ENTRY_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_entry, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_entry, function_type>,
         ELM_ENTRY_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_ENTRY_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_activated_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_ENTRY_EVENT_ACTIVATED, priority_,
            &efl::eo::_detail::event_callback<::elm_entry, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_entry, function_type>,
         ELM_ENTRY_EVENT_ACTIVATED );
   }

   template <typename T>
   void
   callback_activated_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_ENTRY_EVENT_ACTIVATED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_ENTRY_EVENT_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_entry, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_entry, function_type>,
         ELM_ENTRY_EVENT_CHANGED );
   }

   template <typename T>
   void
   callback_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_ENTRY_EVENT_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_changed_user_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_ENTRY_EVENT_CHANGED_USER, priority_,
            &efl::eo::_detail::event_callback<::elm_entry, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_entry, function_type>,
         ELM_ENTRY_EVENT_CHANGED_USER );
   }

   template <typename T>
   void
   callback_changed_user_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_ENTRY_EVENT_CHANGED_USER, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_ENTRY_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_ENTRY_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
bool _elm_entry_cursor_prev_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->cursor_prev();
}

template <typename T>
void _elm_entry_text_style_user_pop_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->text_style_user_pop();
}

template <typename T>
void _elm_entry_item_provider_prepend_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Entry_Item_Provider_Cb func_, void * data_)
{
   static_cast<T*>(self->this_)->item_provider_prepend(func_, data_);
}

template <typename T>
void _elm_entry_input_panel_show_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->input_panel_show();
}

template <typename T>
void _elm_entry_imf_context_reset_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->imf_context_reset();
}

template <typename T>
void _elm_entry_calc_force_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->calc_force();
}

template <typename T>
void _elm_entry_anchor_hover_end_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->anchor_hover_end();
}

template <typename T>
void _elm_entry_cursor_selection_begin_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->cursor_selection_begin();
}

template <typename T>
bool _elm_entry_cursor_down_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->cursor_down();
}

template <typename T>
void _elm_entry_file_save_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->file_save();
}

template <typename T>
void _elm_entry_selection_copy_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->selection_copy();
}

template <typename T>
void _elm_entry_text_style_user_push_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * style_)
{
   static_cast<T*>(self->this_)->text_style_user_push(efl::eolian::to_cxx<std::string>(style_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_entry_item_provider_remove_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Entry_Item_Provider_Cb func_, void * data_)
{
   static_cast<T*>(self->this_)->item_provider_remove(func_, data_);
}

template <typename T>
std::string _elm_entry_text_style_user_peek_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->text_style_user_peek();
}

template <typename T>
void _elm_entry_context_menu_clear_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->context_menu_clear();
}

template <typename T>
bool _elm_entry_cursor_up_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->cursor_up();
}

template <typename T>
void _elm_entry_entry_insert_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * entry_)
{
   static_cast<T*>(self->this_)->entry_insert(efl::eolian::to_cxx<std::string>(entry_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_entry_input_panel_imdata_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const void * data_, int len_)
{
   static_cast<T*>(self->this_)->input_panel_imdata_set(data_, len_);
}

template <typename T>
void _elm_entry_input_panel_imdata_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, void* data_, int* len_)
{
   static_cast<T*>(self->this_)->input_panel_imdata_get(data_, len_);
}

template <typename T>
void _elm_entry_selection_paste_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->selection_paste();
}

template <typename T>
bool _elm_entry_cursor_next_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->cursor_next();
}

template <typename T>
void _elm_entry_select_none_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->select_none();
}

template <typename T>
void _elm_entry_input_panel_hide_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->input_panel_hide();
}

template <typename T>
void _elm_entry_select_all_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->select_all();
}

template <typename T>
void _elm_entry_cursor_selection_end_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->cursor_selection_end();
}

template <typename T>
void _elm_entry_selection_cut_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->selection_cut();
}

template <typename T>
bool _elm_entry_is_empty_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->is_empty();
}

template <typename T>
void _elm_entry_markup_filter_remove_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Entry_Filter_Cb func_, void * data_)
{
   static_cast<T*>(self->this_)->markup_filter_remove(func_, data_);
}

template <typename T>
void _elm_entry_item_provider_append_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Entry_Item_Provider_Cb func_, void * data_)
{
   static_cast<T*>(self->this_)->item_provider_append(func_, data_);
}

template <typename T>
void _elm_entry_markup_filter_append_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Entry_Filter_Cb func_, void * data_)
{
   static_cast<T*>(self->this_)->markup_filter_append(func_, data_);
}

template <typename T>
void _elm_entry_entry_append_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * entry_)
{
   static_cast<T*>(self->this_)->entry_append(efl::eolian::to_cxx<std::string>(entry_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_entry_context_menu_item_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * label_, const char * icon_file_, Elm_Icon_Type icon_type_, Evas_Smart_Cb func_, const void * data_)
{
   static_cast<T*>(self->this_)->context_menu_item_add(efl::eolian::to_cxx<std::string>(label_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(icon_file_, std::tuple<std::false_type>()), icon_type_, func_, data_);
}

template <typename T>
void _elm_entry_markup_filter_prepend_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Entry_Filter_Cb func_, void * data_)
{
   static_cast<T*>(self->this_)->markup_filter_prepend(func_, data_);
}

template <typename T>
bool _elm_entry_scrollable_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->scrollable_get();
}

template <typename T>
void _elm_entry_scrollable_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool scroll_)
{
   static_cast<T*>(self->this_)->scrollable_set(efl::eolian::to_cxx<bool>(scroll_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_entry_input_panel_show_on_demand_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->input_panel_show_on_demand_get();
}

template <typename T>
void _elm_entry_input_panel_show_on_demand_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool ondemand_)
{
   static_cast<T*>(self->this_)->input_panel_show_on_demand_set(efl::eolian::to_cxx<bool>(ondemand_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_entry_context_menu_disabled_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->context_menu_disabled_get();
}

template <typename T>
void _elm_entry_context_menu_disabled_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool disabled_)
{
   static_cast<T*>(self->this_)->context_menu_disabled_set(efl::eolian::to_cxx<bool>(disabled_, std::tuple<std::false_type>()));
}

template <typename T>
Elm_Cnp_Mode _elm_entry_cnp_mode_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->cnp_mode_get();
}

template <typename T>
void _elm_entry_cnp_mode_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Cnp_Mode cnp_mode_)
{
   static_cast<T*>(self->this_)->cnp_mode_set(cnp_mode_);
}

template <typename T>
Elm_Input_Panel_Lang _elm_entry_input_panel_language_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->input_panel_language_get();
}

template <typename T>
void _elm_entry_input_panel_language_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Input_Panel_Lang lang_)
{
   static_cast<T*>(self->this_)->input_panel_language_set(lang_);
}

template <typename T>
bool _elm_entry_selection_handler_disabled_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->selection_handler_disabled_get();
}

template <typename T>
void _elm_entry_selection_handler_disabled_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool disabled_)
{
   static_cast<T*>(self->this_)->selection_handler_disabled_set(efl::eolian::to_cxx<bool>(disabled_, std::tuple<std::false_type>()));
}

template <typename T>
int _elm_entry_input_panel_layout_variation_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->input_panel_layout_variation_get();
}

template <typename T>
void _elm_entry_input_panel_layout_variation_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int variation_)
{
   static_cast<T*>(self->this_)->input_panel_layout_variation_set(variation_);
}

template <typename T>
Elm_Autocapital_Type _elm_entry_autocapital_type_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->autocapital_type_get();
}

template <typename T>
void _elm_entry_autocapital_type_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Autocapital_Type autocapital_type_)
{
   static_cast<T*>(self->this_)->autocapital_type_set(autocapital_type_);
}

template <typename T>
bool _elm_entry_editable_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->editable_get();
}

template <typename T>
void _elm_entry_editable_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool editable_)
{
   static_cast<T*>(self->this_)->editable_set(efl::eolian::to_cxx<bool>(editable_, std::tuple<std::false_type>()));
}

template <typename T>
std::string _elm_entry_anchor_hover_style_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->anchor_hover_style_get();
}

template <typename T>
void _elm_entry_anchor_hover_style_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * style_)
{
   static_cast<T*>(self->this_)->anchor_hover_style_set(efl::eolian::to_cxx<std::string>(style_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_entry_single_line_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->single_line_get();
}

template <typename T>
void _elm_entry_single_line_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool single_line_)
{
   static_cast<T*>(self->this_)->single_line_set(efl::eolian::to_cxx<bool>(single_line_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_entry_password_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->password_get();
}

template <typename T>
void _elm_entry_password_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool password_)
{
   static_cast<T*>(self->this_)->password_set(efl::eolian::to_cxx<bool>(password_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_entry_file_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char ** file_, Elm_Text_Format* format_)
{
   static_cast<T*>(self->this_)->file_get(file_, format_);
}

template <typename T>
bool _elm_entry_file_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * file_, Elm_Text_Format format_)
{
   return static_cast<T*>(self->this_)->file_set(efl::eolian::to_cxx<std::string>(file_, std::tuple<std::false_type>()), format_);
}

template <typename T>
bool _elm_entry_input_panel_return_key_disabled_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->input_panel_return_key_disabled_get();
}

template <typename T>
void _elm_entry_input_panel_return_key_disabled_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool disabled_)
{
   static_cast<T*>(self->this_)->input_panel_return_key_disabled_set(efl::eolian::to_cxx<bool>(disabled_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_entry_autosave_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->autosave_get();
}

template <typename T>
void _elm_entry_autosave_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool auto_save_)
{
   static_cast<T*>(self->this_)->autosave_set(efl::eolian::to_cxx<bool>(auto_save_, std::tuple<std::false_type>()));
}

template <typename T>
evas::object _elm_entry_anchor_hover_parent_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->anchor_hover_parent_get();
}

template <typename T>
void _elm_entry_anchor_hover_parent_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * parent_)
{
   static_cast<T*>(self->this_)->anchor_hover_parent_set(efl::eolian::to_cxx<evas::object>(parent_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_entry_prediction_allow_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->prediction_allow_get();
}

template <typename T>
void _elm_entry_prediction_allow_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool prediction_)
{
   static_cast<T*>(self->this_)->prediction_allow_set(efl::eolian::to_cxx<bool>(prediction_, std::tuple<std::false_type>()));
}

template <typename T>
Elm_Input_Panel_Layout _elm_entry_input_panel_layout_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->input_panel_layout_get();
}

template <typename T>
void _elm_entry_input_panel_layout_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Input_Panel_Layout layout_)
{
   static_cast<T*>(self->this_)->input_panel_layout_set(layout_);
}

template <typename T>
Elm_Input_Panel_Return_Key_Type _elm_entry_input_panel_return_key_type_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->input_panel_return_key_type_get();
}

template <typename T>
void _elm_entry_input_panel_return_key_type_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Input_Panel_Return_Key_Type return_key_type_)
{
   static_cast<T*>(self->this_)->input_panel_return_key_type_set(return_key_type_);
}

template <typename T>
bool _elm_entry_input_panel_enabled_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->input_panel_enabled_get();
}

template <typename T>
void _elm_entry_input_panel_enabled_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool enabled_)
{
   static_cast<T*>(self->this_)->input_panel_enabled_set(efl::eolian::to_cxx<bool>(enabled_, std::tuple<std::false_type>()));
}

template <typename T>
Elm_Wrap_Type _elm_entry_line_wrap_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->line_wrap_get();
}

template <typename T>
void _elm_entry_line_wrap_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Wrap_Type wrap_)
{
   static_cast<T*>(self->this_)->line_wrap_set(wrap_);
}

template <typename T>
int _elm_entry_cursor_pos_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->cursor_pos_get();
}

template <typename T>
void _elm_entry_cursor_pos_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int pos_)
{
   static_cast<T*>(self->this_)->cursor_pos_set(pos_);
}

template <typename T>
void _elm_entry_icon_visible_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool setting_)
{
   static_cast<T*>(self->this_)->icon_visible_set(efl::eolian::to_cxx<bool>(setting_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_entry_cursor_line_end_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->cursor_line_end_set();
}

template <typename T>
void _elm_entry_select_region_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int start_, int end_)
{
   static_cast<T*>(self->this_)->select_region_set(start_, end_);
}

template <typename T>
void _elm_entry_input_panel_return_key_autoenabled_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool enabled_)
{
   static_cast<T*>(self->this_)->input_panel_return_key_autoenabled_set(efl::eolian::to_cxx<bool>(enabled_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_entry_end_visible_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool setting_)
{
   static_cast<T*>(self->this_)->end_visible_set(efl::eolian::to_cxx<bool>(setting_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_entry_cursor_begin_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->cursor_begin_set();
}

template <typename T>
void _elm_entry_cursor_line_begin_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->cursor_line_begin_set();
}

template <typename T>
void _elm_entry_cursor_end_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->cursor_end_set();
}

template <typename T>
evas::object _elm_entry_textblock_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->textblock_get();
}

template <typename T>
bool _elm_entry_cursor_geometry_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord* x_, Evas_Coord* y_, Evas_Coord* w_, Evas_Coord* h_)
{
   return static_cast<T*>(self->this_)->cursor_geometry_get(x_, y_, w_, h_);
}

template <typename T>
void * _elm_entry_imf_context_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->imf_context_get();
}

template <typename T>
bool _elm_entry_cursor_is_format_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->cursor_is_format_get();
}

template <typename T>
char * _elm_entry_cursor_content_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->cursor_content_get();
}

template <typename T>
std::string _elm_entry_selection_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->selection_get();
}

template <typename T>
bool _elm_entry_cursor_is_visible_format_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->cursor_is_visible_format_get();
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_entry >
{
   template <typename T>
   struct type
   {
      virtual bool cursor_prev()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_cursor_prev());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void text_style_user_pop()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_text_style_user_pop());
      }

      virtual void item_provider_prepend(Elm_Entry_Item_Provider_Cb func_, void * data_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_item_provider_prepend(func_, data_));
      }

      virtual void input_panel_show()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_input_panel_show());
      }

      virtual void imf_context_reset()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_imf_context_reset());
      }

      virtual void calc_force()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_calc_force());
      }

      virtual void anchor_hover_end()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_anchor_hover_end());
      }

      virtual void cursor_selection_begin()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_cursor_selection_begin());
      }

      virtual bool cursor_down()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_cursor_down());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void file_save()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_file_save());
      }

      virtual void selection_copy()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_selection_copy());
      }

      virtual void text_style_user_push(std::string style_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_text_style_user_push(efl::eolian::to_c(style_)));
      }

      virtual void item_provider_remove(Elm_Entry_Item_Provider_Cb func_, void * data_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_item_provider_remove(func_, data_));
      }

      virtual std::string text_style_user_peek()
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_text_style_user_peek());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void context_menu_clear()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_context_menu_clear());
      }

      virtual bool cursor_up()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_cursor_up());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void entry_insert(std::string entry_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_insert(efl::eolian::to_c(entry_)));
      }

      virtual void input_panel_imdata_set(const void * data_, int len_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_input_panel_imdata_set(data_, len_));
      }

      virtual void input_panel_imdata_get(void* data_, int* len_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_input_panel_imdata_get(data_, len_));
      }

      virtual void selection_paste()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_selection_paste());
      }

      virtual bool cursor_next()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_cursor_next());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void select_none()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_select_none());
      }

      virtual void input_panel_hide()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_input_panel_hide());
      }

      virtual void select_all()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_select_all());
      }

      virtual void cursor_selection_end()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_cursor_selection_end());
      }

      virtual void selection_cut()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_selection_cut());
      }

      virtual bool is_empty()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_is_empty());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void markup_filter_remove(Elm_Entry_Filter_Cb func_, void * data_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_markup_filter_remove(func_, data_));
      }

      virtual void item_provider_append(Elm_Entry_Item_Provider_Cb func_, void * data_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_item_provider_append(func_, data_));
      }

      virtual void markup_filter_append(Elm_Entry_Filter_Cb func_, void * data_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_markup_filter_append(func_, data_));
      }

      virtual void entry_append(std::string entry_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_append(efl::eolian::to_c(entry_)));
      }

      virtual void context_menu_item_add(std::string label_, std::string icon_file_, Elm_Icon_Type icon_type_, Evas_Smart_Cb func_, const void * data_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_context_menu_item_add(efl::eolian::to_c(label_), efl::eolian::to_c(icon_file_), icon_type_, func_, data_));
      }

      virtual void markup_filter_prepend(Elm_Entry_Filter_Cb func_, void * data_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_markup_filter_prepend(func_, data_));
      }

      virtual bool scrollable_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_scrollable_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void scrollable_set(bool scroll_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_scrollable_set(efl::eolian::to_c(scroll_)));
      }

      virtual bool input_panel_show_on_demand_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_input_panel_show_on_demand_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void input_panel_show_on_demand_set(bool ondemand_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_input_panel_show_on_demand_set(efl::eolian::to_c(ondemand_)));
      }

      virtual bool context_menu_disabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_context_menu_disabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void context_menu_disabled_set(bool disabled_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_context_menu_disabled_set(efl::eolian::to_c(disabled_)));
      }

      virtual Elm_Cnp_Mode cnp_mode_get()
      {
         Elm_Cnp_Mode _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_cnp_mode_get());
            return _tmp_ret;
      }

      virtual void cnp_mode_set(Elm_Cnp_Mode cnp_mode_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_cnp_mode_set(cnp_mode_));
      }

      virtual Elm_Input_Panel_Lang input_panel_language_get()
      {
         Elm_Input_Panel_Lang _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_input_panel_language_get());
            return _tmp_ret;
      }

      virtual void input_panel_language_set(Elm_Input_Panel_Lang lang_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_input_panel_language_set(lang_));
      }

      virtual bool selection_handler_disabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_selection_handler_disabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void selection_handler_disabled_set(bool disabled_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_selection_handler_disabled_set(efl::eolian::to_c(disabled_)));
      }

      virtual int input_panel_layout_variation_get()
      {
         int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_input_panel_layout_variation_get());
            return _tmp_ret;
      }

      virtual void input_panel_layout_variation_set(int variation_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_input_panel_layout_variation_set(variation_));
      }

      virtual Elm_Autocapital_Type autocapital_type_get()
      {
         Elm_Autocapital_Type _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_autocapital_type_get());
            return _tmp_ret;
      }

      virtual void autocapital_type_set(Elm_Autocapital_Type autocapital_type_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_autocapital_type_set(autocapital_type_));
      }

      virtual bool editable_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_editable_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void editable_set(bool editable_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_editable_set(efl::eolian::to_c(editable_)));
      }

      virtual std::string anchor_hover_style_get()
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_anchor_hover_style_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void anchor_hover_style_set(std::string style_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_anchor_hover_style_set(efl::eolian::to_c(style_)));
      }

      virtual bool single_line_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_single_line_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void single_line_set(bool single_line_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_single_line_set(efl::eolian::to_c(single_line_)));
      }

      virtual bool password_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_password_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void password_set(bool password_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_password_set(efl::eolian::to_c(password_)));
      }

      virtual void file_get(const char ** file_, Elm_Text_Format* format_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_file_get(file_, format_));
      }

      virtual bool file_set(std::string file_, Elm_Text_Format format_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_file_set(efl::eolian::to_c(file_), format_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool input_panel_return_key_disabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_input_panel_return_key_disabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void input_panel_return_key_disabled_set(bool disabled_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_input_panel_return_key_disabled_set(efl::eolian::to_c(disabled_)));
      }

      virtual bool autosave_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_autosave_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void autosave_set(bool auto_save_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_autosave_set(efl::eolian::to_c(auto_save_)));
      }

      virtual evas::object anchor_hover_parent_get()
      {
         Evas_Object * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_anchor_hover_parent_get());
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void anchor_hover_parent_set(evas::object parent_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_anchor_hover_parent_set(efl::eolian::to_c(parent_)));
      }

      virtual bool prediction_allow_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_prediction_allow_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void prediction_allow_set(bool prediction_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_prediction_allow_set(efl::eolian::to_c(prediction_)));
      }

      virtual Elm_Input_Panel_Layout input_panel_layout_get()
      {
         Elm_Input_Panel_Layout _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_input_panel_layout_get());
            return _tmp_ret;
      }

      virtual void input_panel_layout_set(Elm_Input_Panel_Layout layout_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_input_panel_layout_set(layout_));
      }

      virtual Elm_Input_Panel_Return_Key_Type input_panel_return_key_type_get()
      {
         Elm_Input_Panel_Return_Key_Type _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_input_panel_return_key_type_get());
            return _tmp_ret;
      }

      virtual void input_panel_return_key_type_set(Elm_Input_Panel_Return_Key_Type return_key_type_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_input_panel_return_key_type_set(return_key_type_));
      }

      virtual bool input_panel_enabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_input_panel_enabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void input_panel_enabled_set(bool enabled_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_input_panel_enabled_set(efl::eolian::to_c(enabled_)));
      }

      virtual Elm_Wrap_Type line_wrap_get()
      {
         Elm_Wrap_Type _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_line_wrap_get());
            return _tmp_ret;
      }

      virtual void line_wrap_set(Elm_Wrap_Type wrap_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_line_wrap_set(wrap_));
      }

      virtual int cursor_pos_get()
      {
         int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_cursor_pos_get());
            return _tmp_ret;
      }

      virtual void cursor_pos_set(int pos_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_cursor_pos_set(pos_));
      }

      virtual void icon_visible_set(bool setting_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_icon_visible_set(efl::eolian::to_c(setting_)));
      }

      virtual void cursor_line_end_set()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_cursor_line_end_set());
      }

      virtual void select_region_set(int start_, int end_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_select_region_set(start_, end_));
      }

      virtual void input_panel_return_key_autoenabled_set(bool enabled_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_input_panel_return_key_autoenabled_set(efl::eolian::to_c(enabled_)));
      }

      virtual void end_visible_set(bool setting_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_end_visible_set(efl::eolian::to_c(setting_)));
      }

      virtual void cursor_begin_set()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_cursor_begin_set());
      }

      virtual void cursor_line_begin_set()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_cursor_line_begin_set());
      }

      virtual void cursor_end_set()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_entry_cursor_end_set());
      }

      virtual evas::object textblock_get()
      {
         Evas_Object * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_textblock_get());
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool cursor_geometry_get(Evas_Coord* x_, Evas_Coord* y_, Evas_Coord* w_, Evas_Coord* h_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_cursor_geometry_get(x_, y_, w_, h_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void * imf_context_get()
      {
         void * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_imf_context_get());
            return _tmp_ret;
      }

      virtual bool cursor_is_format_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_cursor_is_format_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual char * cursor_content_get()
      {
         char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_cursor_content_get());
            return _tmp_ret;
      }

      virtual std::string selection_get()
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_selection_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool cursor_is_visible_format_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_entry_cursor_is_visible_format_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

   };
};


template<>
struct operation_description_class_size< ::elm_entry >
{
   static const int value = 92;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_entry>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_entry_cursor_prev_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_cursor_prev);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_entry_text_style_user_pop_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_text_style_user_pop);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_entry_item_provider_prepend_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_item_provider_prepend);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_entry_input_panel_show_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_input_panel_show);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_entry_imf_context_reset_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_imf_context_reset);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_entry_calc_force_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_calc_force);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_entry_anchor_hover_end_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_anchor_hover_end);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_entry_cursor_selection_begin_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_cursor_selection_begin);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_entry_cursor_down_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_cursor_down);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_entry_file_save_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_file_save);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::_elm_entry_selection_copy_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_selection_copy);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::_elm_entry_text_style_user_push_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_text_style_user_push);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::_elm_entry_item_provider_remove_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_item_provider_remove);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::_elm_entry_text_style_user_peek_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_text_style_user_peek);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::_elm_entry_context_menu_clear_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_context_menu_clear);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::_elm_entry_cursor_up_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_cursor_up);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   ops[16].func = reinterpret_cast<void*>(& ::_elm_entry_entry_insert_wrapper<T>);
   ops[16].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_insert);
   ops[16].op = EO_OP_OVERRIDE;
   ops[16].op_type = EO_OP_TYPE_REGULAR;
   ops[16].doc = NULL;

   ops[17].func = reinterpret_cast<void*>(& ::_elm_entry_input_panel_imdata_set_wrapper<T>);
   ops[17].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_input_panel_imdata_set);
   ops[17].op = EO_OP_OVERRIDE;
   ops[17].op_type = EO_OP_TYPE_REGULAR;
   ops[17].doc = NULL;

   ops[18].func = reinterpret_cast<void*>(& ::_elm_entry_input_panel_imdata_get_wrapper<T>);
   ops[18].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_input_panel_imdata_get);
   ops[18].op = EO_OP_OVERRIDE;
   ops[18].op_type = EO_OP_TYPE_REGULAR;
   ops[18].doc = NULL;

   ops[19].func = reinterpret_cast<void*>(& ::_elm_entry_selection_paste_wrapper<T>);
   ops[19].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_selection_paste);
   ops[19].op = EO_OP_OVERRIDE;
   ops[19].op_type = EO_OP_TYPE_REGULAR;
   ops[19].doc = NULL;

   ops[20].func = reinterpret_cast<void*>(& ::_elm_entry_cursor_next_wrapper<T>);
   ops[20].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_cursor_next);
   ops[20].op = EO_OP_OVERRIDE;
   ops[20].op_type = EO_OP_TYPE_REGULAR;
   ops[20].doc = NULL;

   ops[21].func = reinterpret_cast<void*>(& ::_elm_entry_select_none_wrapper<T>);
   ops[21].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_select_none);
   ops[21].op = EO_OP_OVERRIDE;
   ops[21].op_type = EO_OP_TYPE_REGULAR;
   ops[21].doc = NULL;

   ops[22].func = reinterpret_cast<void*>(& ::_elm_entry_input_panel_hide_wrapper<T>);
   ops[22].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_input_panel_hide);
   ops[22].op = EO_OP_OVERRIDE;
   ops[22].op_type = EO_OP_TYPE_REGULAR;
   ops[22].doc = NULL;

   ops[23].func = reinterpret_cast<void*>(& ::_elm_entry_select_all_wrapper<T>);
   ops[23].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_select_all);
   ops[23].op = EO_OP_OVERRIDE;
   ops[23].op_type = EO_OP_TYPE_REGULAR;
   ops[23].doc = NULL;

   ops[24].func = reinterpret_cast<void*>(& ::_elm_entry_cursor_selection_end_wrapper<T>);
   ops[24].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_cursor_selection_end);
   ops[24].op = EO_OP_OVERRIDE;
   ops[24].op_type = EO_OP_TYPE_REGULAR;
   ops[24].doc = NULL;

   ops[25].func = reinterpret_cast<void*>(& ::_elm_entry_selection_cut_wrapper<T>);
   ops[25].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_selection_cut);
   ops[25].op = EO_OP_OVERRIDE;
   ops[25].op_type = EO_OP_TYPE_REGULAR;
   ops[25].doc = NULL;

   ops[26].func = reinterpret_cast<void*>(& ::_elm_entry_is_empty_wrapper<T>);
   ops[26].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_is_empty);
   ops[26].op = EO_OP_OVERRIDE;
   ops[26].op_type = EO_OP_TYPE_REGULAR;
   ops[26].doc = NULL;

   ops[27].func = reinterpret_cast<void*>(& ::_elm_entry_markup_filter_remove_wrapper<T>);
   ops[27].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_markup_filter_remove);
   ops[27].op = EO_OP_OVERRIDE;
   ops[27].op_type = EO_OP_TYPE_REGULAR;
   ops[27].doc = NULL;

   ops[28].func = reinterpret_cast<void*>(& ::_elm_entry_item_provider_append_wrapper<T>);
   ops[28].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_item_provider_append);
   ops[28].op = EO_OP_OVERRIDE;
   ops[28].op_type = EO_OP_TYPE_REGULAR;
   ops[28].doc = NULL;

   ops[29].func = reinterpret_cast<void*>(& ::_elm_entry_markup_filter_append_wrapper<T>);
   ops[29].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_markup_filter_append);
   ops[29].op = EO_OP_OVERRIDE;
   ops[29].op_type = EO_OP_TYPE_REGULAR;
   ops[29].doc = NULL;

   ops[30].func = reinterpret_cast<void*>(& ::_elm_entry_entry_append_wrapper<T>);
   ops[30].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_append);
   ops[30].op = EO_OP_OVERRIDE;
   ops[30].op_type = EO_OP_TYPE_REGULAR;
   ops[30].doc = NULL;

   ops[31].func = reinterpret_cast<void*>(& ::_elm_entry_context_menu_item_add_wrapper<T>);
   ops[31].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_context_menu_item_add);
   ops[31].op = EO_OP_OVERRIDE;
   ops[31].op_type = EO_OP_TYPE_REGULAR;
   ops[31].doc = NULL;

   ops[32].func = reinterpret_cast<void*>(& ::_elm_entry_markup_filter_prepend_wrapper<T>);
   ops[32].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_markup_filter_prepend);
   ops[32].op = EO_OP_OVERRIDE;
   ops[32].op_type = EO_OP_TYPE_REGULAR;
   ops[32].doc = NULL;

   ops[33].func = reinterpret_cast<void*>(& ::_elm_entry_scrollable_get_wrapper<T>);
   ops[33].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_scrollable_get);
   ops[33].op = EO_OP_OVERRIDE;
   ops[33].op_type = EO_OP_TYPE_REGULAR;
   ops[33].doc = NULL;

   ops[34].func = reinterpret_cast<void*>(& ::_elm_entry_scrollable_set_wrapper<T>);
   ops[34].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_scrollable_set);
   ops[34].op = EO_OP_OVERRIDE;
   ops[34].op_type = EO_OP_TYPE_REGULAR;
   ops[34].doc = NULL;

   ops[35].func = reinterpret_cast<void*>(& ::_elm_entry_input_panel_show_on_demand_get_wrapper<T>);
   ops[35].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_input_panel_show_on_demand_get);
   ops[35].op = EO_OP_OVERRIDE;
   ops[35].op_type = EO_OP_TYPE_REGULAR;
   ops[35].doc = NULL;

   ops[36].func = reinterpret_cast<void*>(& ::_elm_entry_input_panel_show_on_demand_set_wrapper<T>);
   ops[36].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_input_panel_show_on_demand_set);
   ops[36].op = EO_OP_OVERRIDE;
   ops[36].op_type = EO_OP_TYPE_REGULAR;
   ops[36].doc = NULL;

   ops[37].func = reinterpret_cast<void*>(& ::_elm_entry_context_menu_disabled_get_wrapper<T>);
   ops[37].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_context_menu_disabled_get);
   ops[37].op = EO_OP_OVERRIDE;
   ops[37].op_type = EO_OP_TYPE_REGULAR;
   ops[37].doc = NULL;

   ops[38].func = reinterpret_cast<void*>(& ::_elm_entry_context_menu_disabled_set_wrapper<T>);
   ops[38].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_context_menu_disabled_set);
   ops[38].op = EO_OP_OVERRIDE;
   ops[38].op_type = EO_OP_TYPE_REGULAR;
   ops[38].doc = NULL;

   ops[39].func = reinterpret_cast<void*>(& ::_elm_entry_cnp_mode_get_wrapper<T>);
   ops[39].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_cnp_mode_get);
   ops[39].op = EO_OP_OVERRIDE;
   ops[39].op_type = EO_OP_TYPE_REGULAR;
   ops[39].doc = NULL;

   ops[40].func = reinterpret_cast<void*>(& ::_elm_entry_cnp_mode_set_wrapper<T>);
   ops[40].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_cnp_mode_set);
   ops[40].op = EO_OP_OVERRIDE;
   ops[40].op_type = EO_OP_TYPE_REGULAR;
   ops[40].doc = NULL;

   ops[41].func = reinterpret_cast<void*>(& ::_elm_entry_input_panel_language_get_wrapper<T>);
   ops[41].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_input_panel_language_get);
   ops[41].op = EO_OP_OVERRIDE;
   ops[41].op_type = EO_OP_TYPE_REGULAR;
   ops[41].doc = NULL;

   ops[42].func = reinterpret_cast<void*>(& ::_elm_entry_input_panel_language_set_wrapper<T>);
   ops[42].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_input_panel_language_set);
   ops[42].op = EO_OP_OVERRIDE;
   ops[42].op_type = EO_OP_TYPE_REGULAR;
   ops[42].doc = NULL;

   ops[43].func = reinterpret_cast<void*>(& ::_elm_entry_selection_handler_disabled_get_wrapper<T>);
   ops[43].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_selection_handler_disabled_get);
   ops[43].op = EO_OP_OVERRIDE;
   ops[43].op_type = EO_OP_TYPE_REGULAR;
   ops[43].doc = NULL;

   ops[44].func = reinterpret_cast<void*>(& ::_elm_entry_selection_handler_disabled_set_wrapper<T>);
   ops[44].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_selection_handler_disabled_set);
   ops[44].op = EO_OP_OVERRIDE;
   ops[44].op_type = EO_OP_TYPE_REGULAR;
   ops[44].doc = NULL;

   ops[45].func = reinterpret_cast<void*>(& ::_elm_entry_input_panel_layout_variation_get_wrapper<T>);
   ops[45].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_input_panel_layout_variation_get);
   ops[45].op = EO_OP_OVERRIDE;
   ops[45].op_type = EO_OP_TYPE_REGULAR;
   ops[45].doc = NULL;

   ops[46].func = reinterpret_cast<void*>(& ::_elm_entry_input_panel_layout_variation_set_wrapper<T>);
   ops[46].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_input_panel_layout_variation_set);
   ops[46].op = EO_OP_OVERRIDE;
   ops[46].op_type = EO_OP_TYPE_REGULAR;
   ops[46].doc = NULL;

   ops[47].func = reinterpret_cast<void*>(& ::_elm_entry_autocapital_type_get_wrapper<T>);
   ops[47].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_autocapital_type_get);
   ops[47].op = EO_OP_OVERRIDE;
   ops[47].op_type = EO_OP_TYPE_REGULAR;
   ops[47].doc = NULL;

   ops[48].func = reinterpret_cast<void*>(& ::_elm_entry_autocapital_type_set_wrapper<T>);
   ops[48].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_autocapital_type_set);
   ops[48].op = EO_OP_OVERRIDE;
   ops[48].op_type = EO_OP_TYPE_REGULAR;
   ops[48].doc = NULL;

   ops[49].func = reinterpret_cast<void*>(& ::_elm_entry_editable_get_wrapper<T>);
   ops[49].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_editable_get);
   ops[49].op = EO_OP_OVERRIDE;
   ops[49].op_type = EO_OP_TYPE_REGULAR;
   ops[49].doc = NULL;

   ops[50].func = reinterpret_cast<void*>(& ::_elm_entry_editable_set_wrapper<T>);
   ops[50].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_editable_set);
   ops[50].op = EO_OP_OVERRIDE;
   ops[50].op_type = EO_OP_TYPE_REGULAR;
   ops[50].doc = NULL;

   ops[51].func = reinterpret_cast<void*>(& ::_elm_entry_anchor_hover_style_get_wrapper<T>);
   ops[51].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_anchor_hover_style_get);
   ops[51].op = EO_OP_OVERRIDE;
   ops[51].op_type = EO_OP_TYPE_REGULAR;
   ops[51].doc = NULL;

   ops[52].func = reinterpret_cast<void*>(& ::_elm_entry_anchor_hover_style_set_wrapper<T>);
   ops[52].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_anchor_hover_style_set);
   ops[52].op = EO_OP_OVERRIDE;
   ops[52].op_type = EO_OP_TYPE_REGULAR;
   ops[52].doc = NULL;

   ops[53].func = reinterpret_cast<void*>(& ::_elm_entry_single_line_get_wrapper<T>);
   ops[53].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_single_line_get);
   ops[53].op = EO_OP_OVERRIDE;
   ops[53].op_type = EO_OP_TYPE_REGULAR;
   ops[53].doc = NULL;

   ops[54].func = reinterpret_cast<void*>(& ::_elm_entry_single_line_set_wrapper<T>);
   ops[54].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_single_line_set);
   ops[54].op = EO_OP_OVERRIDE;
   ops[54].op_type = EO_OP_TYPE_REGULAR;
   ops[54].doc = NULL;

   ops[55].func = reinterpret_cast<void*>(& ::_elm_entry_password_get_wrapper<T>);
   ops[55].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_password_get);
   ops[55].op = EO_OP_OVERRIDE;
   ops[55].op_type = EO_OP_TYPE_REGULAR;
   ops[55].doc = NULL;

   ops[56].func = reinterpret_cast<void*>(& ::_elm_entry_password_set_wrapper<T>);
   ops[56].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_password_set);
   ops[56].op = EO_OP_OVERRIDE;
   ops[56].op_type = EO_OP_TYPE_REGULAR;
   ops[56].doc = NULL;

   ops[57].func = reinterpret_cast<void*>(& ::_elm_entry_file_get_wrapper<T>);
   ops[57].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_file_get);
   ops[57].op = EO_OP_OVERRIDE;
   ops[57].op_type = EO_OP_TYPE_REGULAR;
   ops[57].doc = NULL;

   ops[58].func = reinterpret_cast<void*>(& ::_elm_entry_file_set_wrapper<T>);
   ops[58].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_file_set);
   ops[58].op = EO_OP_OVERRIDE;
   ops[58].op_type = EO_OP_TYPE_REGULAR;
   ops[58].doc = NULL;

   ops[59].func = reinterpret_cast<void*>(& ::_elm_entry_input_panel_return_key_disabled_get_wrapper<T>);
   ops[59].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_input_panel_return_key_disabled_get);
   ops[59].op = EO_OP_OVERRIDE;
   ops[59].op_type = EO_OP_TYPE_REGULAR;
   ops[59].doc = NULL;

   ops[60].func = reinterpret_cast<void*>(& ::_elm_entry_input_panel_return_key_disabled_set_wrapper<T>);
   ops[60].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_input_panel_return_key_disabled_set);
   ops[60].op = EO_OP_OVERRIDE;
   ops[60].op_type = EO_OP_TYPE_REGULAR;
   ops[60].doc = NULL;

   ops[61].func = reinterpret_cast<void*>(& ::_elm_entry_autosave_get_wrapper<T>);
   ops[61].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_autosave_get);
   ops[61].op = EO_OP_OVERRIDE;
   ops[61].op_type = EO_OP_TYPE_REGULAR;
   ops[61].doc = NULL;

   ops[62].func = reinterpret_cast<void*>(& ::_elm_entry_autosave_set_wrapper<T>);
   ops[62].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_autosave_set);
   ops[62].op = EO_OP_OVERRIDE;
   ops[62].op_type = EO_OP_TYPE_REGULAR;
   ops[62].doc = NULL;

   ops[63].func = reinterpret_cast<void*>(& ::_elm_entry_anchor_hover_parent_get_wrapper<T>);
   ops[63].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_anchor_hover_parent_get);
   ops[63].op = EO_OP_OVERRIDE;
   ops[63].op_type = EO_OP_TYPE_REGULAR;
   ops[63].doc = NULL;

   ops[64].func = reinterpret_cast<void*>(& ::_elm_entry_anchor_hover_parent_set_wrapper<T>);
   ops[64].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_anchor_hover_parent_set);
   ops[64].op = EO_OP_OVERRIDE;
   ops[64].op_type = EO_OP_TYPE_REGULAR;
   ops[64].doc = NULL;

   ops[65].func = reinterpret_cast<void*>(& ::_elm_entry_prediction_allow_get_wrapper<T>);
   ops[65].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_prediction_allow_get);
   ops[65].op = EO_OP_OVERRIDE;
   ops[65].op_type = EO_OP_TYPE_REGULAR;
   ops[65].doc = NULL;

   ops[66].func = reinterpret_cast<void*>(& ::_elm_entry_prediction_allow_set_wrapper<T>);
   ops[66].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_prediction_allow_set);
   ops[66].op = EO_OP_OVERRIDE;
   ops[66].op_type = EO_OP_TYPE_REGULAR;
   ops[66].doc = NULL;

   ops[67].func = reinterpret_cast<void*>(& ::_elm_entry_input_panel_layout_get_wrapper<T>);
   ops[67].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_input_panel_layout_get);
   ops[67].op = EO_OP_OVERRIDE;
   ops[67].op_type = EO_OP_TYPE_REGULAR;
   ops[67].doc = NULL;

   ops[68].func = reinterpret_cast<void*>(& ::_elm_entry_input_panel_layout_set_wrapper<T>);
   ops[68].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_input_panel_layout_set);
   ops[68].op = EO_OP_OVERRIDE;
   ops[68].op_type = EO_OP_TYPE_REGULAR;
   ops[68].doc = NULL;

   ops[69].func = reinterpret_cast<void*>(& ::_elm_entry_input_panel_return_key_type_get_wrapper<T>);
   ops[69].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_input_panel_return_key_type_get);
   ops[69].op = EO_OP_OVERRIDE;
   ops[69].op_type = EO_OP_TYPE_REGULAR;
   ops[69].doc = NULL;

   ops[70].func = reinterpret_cast<void*>(& ::_elm_entry_input_panel_return_key_type_set_wrapper<T>);
   ops[70].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_input_panel_return_key_type_set);
   ops[70].op = EO_OP_OVERRIDE;
   ops[70].op_type = EO_OP_TYPE_REGULAR;
   ops[70].doc = NULL;

   ops[71].func = reinterpret_cast<void*>(& ::_elm_entry_input_panel_enabled_get_wrapper<T>);
   ops[71].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_input_panel_enabled_get);
   ops[71].op = EO_OP_OVERRIDE;
   ops[71].op_type = EO_OP_TYPE_REGULAR;
   ops[71].doc = NULL;

   ops[72].func = reinterpret_cast<void*>(& ::_elm_entry_input_panel_enabled_set_wrapper<T>);
   ops[72].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_input_panel_enabled_set);
   ops[72].op = EO_OP_OVERRIDE;
   ops[72].op_type = EO_OP_TYPE_REGULAR;
   ops[72].doc = NULL;

   ops[73].func = reinterpret_cast<void*>(& ::_elm_entry_line_wrap_get_wrapper<T>);
   ops[73].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_line_wrap_get);
   ops[73].op = EO_OP_OVERRIDE;
   ops[73].op_type = EO_OP_TYPE_REGULAR;
   ops[73].doc = NULL;

   ops[74].func = reinterpret_cast<void*>(& ::_elm_entry_line_wrap_set_wrapper<T>);
   ops[74].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_line_wrap_set);
   ops[74].op = EO_OP_OVERRIDE;
   ops[74].op_type = EO_OP_TYPE_REGULAR;
   ops[74].doc = NULL;

   ops[75].func = reinterpret_cast<void*>(& ::_elm_entry_cursor_pos_get_wrapper<T>);
   ops[75].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_cursor_pos_get);
   ops[75].op = EO_OP_OVERRIDE;
   ops[75].op_type = EO_OP_TYPE_REGULAR;
   ops[75].doc = NULL;

   ops[76].func = reinterpret_cast<void*>(& ::_elm_entry_cursor_pos_set_wrapper<T>);
   ops[76].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_cursor_pos_set);
   ops[76].op = EO_OP_OVERRIDE;
   ops[76].op_type = EO_OP_TYPE_REGULAR;
   ops[76].doc = NULL;

   ops[77].func = reinterpret_cast<void*>(& ::_elm_entry_icon_visible_set_wrapper<T>);
   ops[77].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_icon_visible_set);
   ops[77].op = EO_OP_OVERRIDE;
   ops[77].op_type = EO_OP_TYPE_REGULAR;
   ops[77].doc = NULL;

   ops[78].func = reinterpret_cast<void*>(& ::_elm_entry_cursor_line_end_set_wrapper<T>);
   ops[78].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_cursor_line_end_set);
   ops[78].op = EO_OP_OVERRIDE;
   ops[78].op_type = EO_OP_TYPE_REGULAR;
   ops[78].doc = NULL;

   ops[79].func = reinterpret_cast<void*>(& ::_elm_entry_select_region_set_wrapper<T>);
   ops[79].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_select_region_set);
   ops[79].op = EO_OP_OVERRIDE;
   ops[79].op_type = EO_OP_TYPE_REGULAR;
   ops[79].doc = NULL;

   ops[80].func = reinterpret_cast<void*>(& ::_elm_entry_input_panel_return_key_autoenabled_set_wrapper<T>);
   ops[80].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_input_panel_return_key_autoenabled_set);
   ops[80].op = EO_OP_OVERRIDE;
   ops[80].op_type = EO_OP_TYPE_REGULAR;
   ops[80].doc = NULL;

   ops[81].func = reinterpret_cast<void*>(& ::_elm_entry_end_visible_set_wrapper<T>);
   ops[81].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_end_visible_set);
   ops[81].op = EO_OP_OVERRIDE;
   ops[81].op_type = EO_OP_TYPE_REGULAR;
   ops[81].doc = NULL;

   ops[82].func = reinterpret_cast<void*>(& ::_elm_entry_cursor_begin_set_wrapper<T>);
   ops[82].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_cursor_begin_set);
   ops[82].op = EO_OP_OVERRIDE;
   ops[82].op_type = EO_OP_TYPE_REGULAR;
   ops[82].doc = NULL;

   ops[83].func = reinterpret_cast<void*>(& ::_elm_entry_cursor_line_begin_set_wrapper<T>);
   ops[83].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_cursor_line_begin_set);
   ops[83].op = EO_OP_OVERRIDE;
   ops[83].op_type = EO_OP_TYPE_REGULAR;
   ops[83].doc = NULL;

   ops[84].func = reinterpret_cast<void*>(& ::_elm_entry_cursor_end_set_wrapper<T>);
   ops[84].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_cursor_end_set);
   ops[84].op = EO_OP_OVERRIDE;
   ops[84].op_type = EO_OP_TYPE_REGULAR;
   ops[84].doc = NULL;

   ops[85].func = reinterpret_cast<void*>(& ::_elm_entry_textblock_get_wrapper<T>);
   ops[85].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_textblock_get);
   ops[85].op = EO_OP_OVERRIDE;
   ops[85].op_type = EO_OP_TYPE_REGULAR;
   ops[85].doc = NULL;

   ops[86].func = reinterpret_cast<void*>(& ::_elm_entry_cursor_geometry_get_wrapper<T>);
   ops[86].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_cursor_geometry_get);
   ops[86].op = EO_OP_OVERRIDE;
   ops[86].op_type = EO_OP_TYPE_REGULAR;
   ops[86].doc = NULL;

   ops[87].func = reinterpret_cast<void*>(& ::_elm_entry_imf_context_get_wrapper<T>);
   ops[87].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_imf_context_get);
   ops[87].op = EO_OP_OVERRIDE;
   ops[87].op_type = EO_OP_TYPE_REGULAR;
   ops[87].doc = NULL;

   ops[88].func = reinterpret_cast<void*>(& ::_elm_entry_cursor_is_format_get_wrapper<T>);
   ops[88].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_cursor_is_format_get);
   ops[88].op = EO_OP_OVERRIDE;
   ops[88].op_type = EO_OP_TYPE_REGULAR;
   ops[88].doc = NULL;

   ops[89].func = reinterpret_cast<void*>(& ::_elm_entry_cursor_content_get_wrapper<T>);
   ops[89].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_cursor_content_get);
   ops[89].op = EO_OP_OVERRIDE;
   ops[89].op_type = EO_OP_TYPE_REGULAR;
   ops[89].doc = NULL;

   ops[90].func = reinterpret_cast<void*>(& ::_elm_entry_selection_get_wrapper<T>);
   ops[90].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_selection_get);
   ops[90].op = EO_OP_OVERRIDE;
   ops[90].op_type = EO_OP_TYPE_REGULAR;
   ops[90].doc = NULL;

   ops[91].func = reinterpret_cast<void*>(& ::_elm_entry_cursor_is_visible_format_get_wrapper<T>);
   ops[91].api_func = reinterpret_cast<void*>(& ::elm_obj_entry_cursor_is_visible_format_get);
   ops[91].op = EO_OP_OVERRIDE;
   ops[91].op_type = EO_OP_TYPE_REGULAR;
   ops[91].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_entry >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_entry, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_entry >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_entry, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_entry>
{
   template <typename U>
   struct type
   {
      operator ::elm_entry() const
      {
         return ::elm_entry(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      bool cursor_prev()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_cursor_prev());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void text_style_user_pop()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_text_style_user_pop());
      }

      void item_provider_prepend(Elm_Entry_Item_Provider_Cb func_, void * data_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_item_provider_prepend(func_, data_));
      }

      void input_panel_show()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_input_panel_show());
      }

      void imf_context_reset()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_imf_context_reset());
      }

      void calc_force()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_calc_force());
      }

      void anchor_hover_end()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_anchor_hover_end());
      }

      void cursor_selection_begin()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_cursor_selection_begin());
      }

      bool cursor_down()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_cursor_down());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void file_save()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_file_save());
      }

      void selection_copy()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_selection_copy());
      }

      void text_style_user_push(std::string style_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_text_style_user_push(efl::eolian::to_c(style_)));
      }

      void item_provider_remove(Elm_Entry_Item_Provider_Cb func_, void * data_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_item_provider_remove(func_, data_));
      }

      std::string text_style_user_peek()
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_text_style_user_peek());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      void context_menu_clear()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_context_menu_clear());
      }

      bool cursor_up()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_cursor_up());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void entry_insert(std::string entry_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_insert(efl::eolian::to_c(entry_)));
      }

      void input_panel_imdata_set(const void * data_, int len_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_input_panel_imdata_set(data_, len_));
      }

      void input_panel_imdata_get(void* data_, int* len_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_input_panel_imdata_get(data_, len_));
      }

      void selection_paste()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_selection_paste());
      }

      bool cursor_next()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_cursor_next());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void select_none()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_select_none());
      }

      void input_panel_hide()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_input_panel_hide());
      }

      void select_all()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_select_all());
      }

      void cursor_selection_end()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_cursor_selection_end());
      }

      void selection_cut()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_selection_cut());
      }

      bool is_empty()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_is_empty());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void markup_filter_remove(Elm_Entry_Filter_Cb func_, void * data_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_markup_filter_remove(func_, data_));
      }

      void item_provider_append(Elm_Entry_Item_Provider_Cb func_, void * data_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_item_provider_append(func_, data_));
      }

      void markup_filter_append(Elm_Entry_Filter_Cb func_, void * data_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_markup_filter_append(func_, data_));
      }

      void entry_append(std::string entry_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_append(efl::eolian::to_c(entry_)));
      }

      void context_menu_item_add(std::string label_, std::string icon_file_, Elm_Icon_Type icon_type_, Evas_Smart_Cb func_, const void * data_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_context_menu_item_add(efl::eolian::to_c(label_), efl::eolian::to_c(icon_file_), icon_type_, func_, data_));
      }

      void markup_filter_prepend(Elm_Entry_Filter_Cb func_, void * data_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_markup_filter_prepend(func_, data_));
      }

      bool scrollable_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_scrollable_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void scrollable_set(bool scroll_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_scrollable_set(efl::eolian::to_c(scroll_)));
      }

      bool input_panel_show_on_demand_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_input_panel_show_on_demand_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void input_panel_show_on_demand_set(bool ondemand_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_input_panel_show_on_demand_set(efl::eolian::to_c(ondemand_)));
      }

      bool context_menu_disabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_context_menu_disabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void context_menu_disabled_set(bool disabled_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_context_menu_disabled_set(efl::eolian::to_c(disabled_)));
      }

      Elm_Cnp_Mode cnp_mode_get()
      {
         Elm_Cnp_Mode _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_cnp_mode_get());
            return _tmp_ret;
      }

      void cnp_mode_set(Elm_Cnp_Mode cnp_mode_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_cnp_mode_set(cnp_mode_));
      }

      Elm_Input_Panel_Lang input_panel_language_get()
      {
         Elm_Input_Panel_Lang _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_input_panel_language_get());
            return _tmp_ret;
      }

      void input_panel_language_set(Elm_Input_Panel_Lang lang_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_input_panel_language_set(lang_));
      }

      bool selection_handler_disabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_selection_handler_disabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void selection_handler_disabled_set(bool disabled_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_selection_handler_disabled_set(efl::eolian::to_c(disabled_)));
      }

      int input_panel_layout_variation_get()
      {
         int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_input_panel_layout_variation_get());
            return _tmp_ret;
      }

      void input_panel_layout_variation_set(int variation_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_input_panel_layout_variation_set(variation_));
      }

      Elm_Autocapital_Type autocapital_type_get()
      {
         Elm_Autocapital_Type _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_autocapital_type_get());
            return _tmp_ret;
      }

      void autocapital_type_set(Elm_Autocapital_Type autocapital_type_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_autocapital_type_set(autocapital_type_));
      }

      bool editable_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_editable_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void editable_set(bool editable_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_editable_set(efl::eolian::to_c(editable_)));
      }

      std::string anchor_hover_style_get()
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_anchor_hover_style_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      void anchor_hover_style_set(std::string style_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_anchor_hover_style_set(efl::eolian::to_c(style_)));
      }

      bool single_line_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_single_line_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void single_line_set(bool single_line_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_single_line_set(efl::eolian::to_c(single_line_)));
      }

      bool password_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_password_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void password_set(bool password_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_password_set(efl::eolian::to_c(password_)));
      }

      void file_get(const char ** file_, Elm_Text_Format* format_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_file_get(file_, format_));
      }

      bool file_set(std::string file_, Elm_Text_Format format_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_file_set(efl::eolian::to_c(file_), format_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool input_panel_return_key_disabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_input_panel_return_key_disabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void input_panel_return_key_disabled_set(bool disabled_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_input_panel_return_key_disabled_set(efl::eolian::to_c(disabled_)));
      }

      bool autosave_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_autosave_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void autosave_set(bool auto_save_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_autosave_set(efl::eolian::to_c(auto_save_)));
      }

      evas::object anchor_hover_parent_get()
      {
         Evas_Object * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_anchor_hover_parent_get());
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      void anchor_hover_parent_set(evas::object parent_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_anchor_hover_parent_set(efl::eolian::to_c(parent_)));
      }

      bool prediction_allow_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_prediction_allow_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void prediction_allow_set(bool prediction_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_prediction_allow_set(efl::eolian::to_c(prediction_)));
      }

      Elm_Input_Panel_Layout input_panel_layout_get()
      {
         Elm_Input_Panel_Layout _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_input_panel_layout_get());
            return _tmp_ret;
      }

      void input_panel_layout_set(Elm_Input_Panel_Layout layout_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_input_panel_layout_set(layout_));
      }

      Elm_Input_Panel_Return_Key_Type input_panel_return_key_type_get()
      {
         Elm_Input_Panel_Return_Key_Type _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_input_panel_return_key_type_get());
            return _tmp_ret;
      }

      void input_panel_return_key_type_set(Elm_Input_Panel_Return_Key_Type return_key_type_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_input_panel_return_key_type_set(return_key_type_));
      }

      bool input_panel_enabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_input_panel_enabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void input_panel_enabled_set(bool enabled_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_input_panel_enabled_set(efl::eolian::to_c(enabled_)));
      }

      Elm_Wrap_Type line_wrap_get()
      {
         Elm_Wrap_Type _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_line_wrap_get());
            return _tmp_ret;
      }

      void line_wrap_set(Elm_Wrap_Type wrap_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_line_wrap_set(wrap_));
      }

      int cursor_pos_get()
      {
         int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_cursor_pos_get());
            return _tmp_ret;
      }

      void cursor_pos_set(int pos_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_cursor_pos_set(pos_));
      }

      void icon_visible_set(bool setting_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_icon_visible_set(efl::eolian::to_c(setting_)));
      }

      void cursor_line_end_set()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_cursor_line_end_set());
      }

      void select_region_set(int start_, int end_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_select_region_set(start_, end_));
      }

      void input_panel_return_key_autoenabled_set(bool enabled_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_input_panel_return_key_autoenabled_set(efl::eolian::to_c(enabled_)));
      }

      void end_visible_set(bool setting_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_end_visible_set(efl::eolian::to_c(setting_)));
      }

      void cursor_begin_set()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_cursor_begin_set());
      }

      void cursor_line_begin_set()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_cursor_line_begin_set());
      }

      void cursor_end_set()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_entry_cursor_end_set());
      }

      evas::object textblock_get()
      {
         Evas_Object * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_textblock_get());
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool cursor_geometry_get(Evas_Coord* x_, Evas_Coord* y_, Evas_Coord* w_, Evas_Coord* h_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_cursor_geometry_get(x_, y_, w_, h_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void * imf_context_get()
      {
         void * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_imf_context_get());
            return _tmp_ret;
      }

      bool cursor_is_format_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_cursor_is_format_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      char * cursor_content_get()
      {
         char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_cursor_content_get());
            return _tmp_ret;
      }

      std::string selection_get()
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_selection_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool cursor_is_visible_format_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_entry_cursor_is_visible_format_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_ENTRY_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_entry, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_entry, function_type>,
         ELM_ENTRY_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_ENTRY_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_ENTRY_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_entry, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_entry, function_type>,
         ELM_ENTRY_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_ENTRY_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_activated_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_ENTRY_EVENT_ACTIVATED, priority_,
            &efl::eo::_detail::event_callback<::elm_entry, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_entry, function_type>,
         ELM_ENTRY_EVENT_ACTIVATED );
   }

   template <typename T>
   void
   callback_activated_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_ENTRY_EVENT_ACTIVATED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_ENTRY_EVENT_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_entry, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_entry, function_type>,
         ELM_ENTRY_EVENT_CHANGED );
   }

   template <typename T>
   void
   callback_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_ENTRY_EVENT_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_changed_user_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_ENTRY_EVENT_CHANGED_USER, priority_,
            &efl::eo::_detail::event_callback<::elm_entry, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_entry, function_type>,
         ELM_ENTRY_EVENT_CHANGED_USER );
   }

   template <typename T>
   void
   callback_changed_user_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_ENTRY_EVENT_CHANGED_USER, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_entry>)
{
   return (ELM_ENTRY_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_ENTRY_HH

