#ifndef EFL_GENERATED_ELM_FLIP_HH
#define EFL_GENERATED_ELM_FLIP_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_flip.eo.h"
}

#include "elm_container.eo.hh"

struct elm_flip
      : elm_container
{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_flip(Eo* eo)
      : elm_container(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_flip(std::nullptr_t)
      : elm_container(nullptr)
   {}

   elm_flip(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_flip(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_flip(elm_flip const& other)
      : elm_container(eo_ref(other._eo_ptr()))
   {}

   ~elm_flip() {}

   /// @brief @brief Set the amount of the flip that is sensitive to interactive flip
   ///
   /// Set the amount of the flip that is sensitive to interactive flip, with 0
   /// representing no area in the flip and 1 representing the entire flip. There
   /// is however a consideration to be made in that the area will never be
   /// smaller than the finger size set (as set in your Elementary configuration),
   /// and dragging must always start from the opposite half of the flip (eg. right
   /// half of the flip when dragging to the left).
   ///
   /// Note that the @c dir parameter is not actually related to the direction of
   /// the drag, it only refers to the area in the flip where interaction can
   /// occur (top, bottom, left, right).
   ///
   /// Negative values of @c hitsize will disable this hit area.
   ///
   /// @see elm_flip_interaction_set()
   ///
   /// @ingroup Flip
   ///
   /// @param dir The hit area to set
   /// @param hitsize The amount of that dimension (0.0 to 1.0) to use
   ///
   void interaction_direction_hitsize_set(Elm_Flip_Direction dir_, double hitsize_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_flip_interaction_direction_hitsize_set(dir_, hitsize_));
   }

   /// @brief @brief Get the amount of the flip that is sensitive to interactive flip
   ///
   /// @return The size set for that direction
   ///
   /// Returns the amount of sensitive area set by
   /// elm_flip_interaction_direction_hitsize_set().
   ///
   /// @ingroup Flip
   ///
   /// @param dir The direction to check
   ///
   double interaction_direction_hitsize_get(Elm_Flip_Direction dir_) const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_flip_interaction_direction_hitsize_get(dir_));
      return _tmp_ret;
   }

   /// @brief @brief Set which directions of the flip respond to interactive flip
   ///
   /// By default all directions are disabled, so you may want to enable the
   /// desired directions for flipping if you need interactive flipping. You must
   /// call this function once for each direction that should be enabled.
   ///
   /// You can also set the appropriate hit area size by calling
   /// @c elm_flip_interaction_direction_hitsize_set(). By default, a minimum
   /// hit area will be created on the opposite edge of the flip.
   ///
   /// @see elm_flip_interaction_set()
   ///
   /// @ingroup Flip
   ///
   /// @param dir The direction to change
   /// @param enabled If that direction is enabled or not
   ///
   void interaction_direction_enabled_set(Elm_Flip_Direction dir_, bool enabled_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_flip_interaction_direction_enabled_set(dir_, efl::eolian::to_c(enabled_)));
   }

   /// @brief @brief Get the enabled state of that flip direction
   ///
   /// @return If that direction is enabled or not
   ///
   /// Get the enabled state set by elm_flip_interaction_direction_enabled_set()
   ///
   /// @see elm_flip_interaction_set()
   ///
   /// @ingroup Flip
   ///
   /// @param dir The direction to check
   ///
   bool interaction_direction_enabled_get(Elm_Flip_Direction dir_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_flip_interaction_direction_enabled_get(dir_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief @brief Runs the flip animation
   ///
   /// Flips the front and back contents using the @p mode animation. This
   /// effectively hides the currently visible content and shows the hidden one.
   ///
   /// There a number of possible animations to use for the flipping:
   /// @li ELM_FLIP_ROTATE_X_CENTER_AXIS - Rotate the currently visible content
   /// around a horizontal axis in the middle of its height, the other content
   /// is shown as the other side of the flip.
   /// @li ELM_FLIP_ROTATE_Y_CENTER_AXIS - Rotate the currently visible content
   /// around a vertical axis in the middle of its width, the other content is
   /// shown as the other side of the flip.
   /// @li ELM_FLIP_ROTATE_XZ_CENTER_AXIS - Rotate the currently visible content
   /// around a diagonal axis in the middle of its width, the other content is
   /// shown as the other side of the flip.
   /// @li ELM_FLIP_ROTATE_YZ_CENTER_AXIS - Rotate the currently visible content
   /// around a diagonal axis in the middle of its height, the other content is
   /// shown as the other side of the flip.
   /// @li ELM_FLIP_CUBE_LEFT - Rotate the currently visible content to the left
   /// as if the flip was a cube, the other content is show as the right face of
   /// the cube.
   /// @li ELM_FLIP_CUBE_RIGHT - Rotate the currently visible content to the
   /// right as if the flip was a cube, the other content is show as the left
   /// face of the cube.
   /// @li ELM_FLIP_CUBE_UP - Rotate the currently visible content up as if the
   /// flip was a cube, the other content is show as the bottom face of the cube.
   /// @li ELM_FLIP_CUBE_DOWN - Rotate the currently visible content down as if
   /// the flip was a cube, the other content is show as the upper face of the
   /// cube.
   /// @li ELM_FLIP_PAGE_LEFT - Move the currently visible content to the left as
   /// if the flip was a book, the other content is shown as the page below that.
   /// @li ELM_FLIP_PAGE_RIGHT - Move the currently visible content to the right
   /// as if the flip was a book, the other content is shown as the page below
   /// that.
   /// @li ELM_FLIP_PAGE_UP - Move the currently visible content up as if the
   /// flip was a book, the other content is shown as the page below that.
   /// @li ELM_FLIP_PAGE_DOWN - Move the currently visible content down as if the
   /// flip was a book, the other content is shown as the page below that.
   ///
   /// @image html elm_flip.png
   /// @image latex elm_flip.eps width=\textwidth
   ///
   /// @see elm_flip_go_to()
   ///
   /// @ingroup Flip
   ///
   /// @param mode The mode type
   ///
   void go(Elm_Flip_Mode mode_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_flip_go(mode_));
   }

   /// @brief @brief Runs the flip animation to front or back.
   ///
   /// Flips the front and back contents using the @p mode animation. This
   /// effectively hides the currently visible content and shows the hidden one.
   ///
   /// There a number of possible animations to use for the flipping:
   /// @li ELM_FLIP_ROTATE_X_CENTER_AXIS - Rotate the currently visible content
   /// around a horizontal axis in the middle of its height, the other content
   /// is shown as the other side of the flip.
   /// @li ELM_FLIP_ROTATE_Y_CENTER_AXIS - Rotate the currently visible content
   /// around a vertical axis in the middle of its width, the other content is
   /// shown as the other side of the flip.
   /// @li ELM_FLIP_ROTATE_XZ_CENTER_AXIS - Rotate the currently visible content
   /// around a diagonal axis in the middle of its width, the other content is
   /// shown as the other side of the flip.
   /// @li ELM_FLIP_ROTATE_YZ_CENTER_AXIS - Rotate the currently visible content
   /// around a diagonal axis in the middle of its height, the other content is
   /// shown as the other side of the flip.
   /// @li ELM_FLIP_CUBE_LEFT - Rotate the currently visible content to the left
   /// as if the flip was a cube, the other content is show as the right face of
   /// the cube.
   /// @li ELM_FLIP_CUBE_RIGHT - Rotate the currently visible content to the
   /// right as if the flip was a cube, the other content is show as the left
   /// face of the cube.
   /// @li ELM_FLIP_CUBE_UP - Rotate the currently visible content up as if the
   /// flip was a cube, the other content is show as the bottom face of the cube.
   /// @li ELM_FLIP_CUBE_DOWN - Rotate the currently visible content down as if
   /// the flip was a cube, the other content is show as the upper face of the
   /// cube.
   /// @li ELM_FLIP_PAGE_LEFT - Move the currently visible content to the left as
   /// if the flip was a book, the other content is shown as the page below that.
   /// @li ELM_FLIP_PAGE_RIGHT - Move the currently visible content to the right
   /// as if the flip was a book, the other content is shown as the page below
   /// that.
   /// @li ELM_FLIP_PAGE_UP - Move the currently visible content up as if the
   /// flip was a book, the other content is shown as the page below that.
   /// @li ELM_FLIP_PAGE_DOWN - Move the currently visible content down as if the
   /// flip was a book, the other content is shown as the page below that.
   ///
   /// @image html elm_flip.png
   /// @image latex elm_flip.eps width=\textwidth
   ///
   /// @since 1.7
   ///
   /// @ingroup Flip
   ///
   /// @param front if @c EINA_TRUE, makes front visible, otherwise makes back.
   /// @param mode The mode type
   ///
   void go_to(bool front_, Elm_Flip_Mode mode_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_flip_go_to(efl::eolian::to_c(front_), mode_));
   }

   /// @param mode The interactive flip mode to use
   ///
   Elm_Flip_Interaction interaction_get() const
   {
      Elm_Flip_Interaction _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_flip_interaction_get());
      return _tmp_ret;
   }

   /// @param mode The interactive flip mode to use
   ///
   void interaction_set(Elm_Flip_Interaction mode_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_flip_interaction_set(mode_));
   }

   bool front_visible_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_flip_front_visible_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_animate_begin_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_FLIP_EVENT_ANIMATE_BEGIN, priority_,
            &efl::eo::_detail::event_callback<::elm_flip, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_flip, function_type>,
         ELM_FLIP_EVENT_ANIMATE_BEGIN );
   }

   template <typename T>
   void
   callback_animate_begin_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_FLIP_EVENT_ANIMATE_BEGIN, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_animate_done_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_FLIP_EVENT_ANIMATE_DONE, priority_,
            &efl::eo::_detail::event_callback<::elm_flip, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_flip, function_type>,
         ELM_FLIP_EVENT_ANIMATE_DONE );
   }

   template <typename T>
   void
   callback_animate_done_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_FLIP_EVENT_ANIMATE_DONE, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_FLIP_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_FLIP_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
void _elm_flip_interaction_direction_hitsize_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Flip_Direction dir_, double hitsize_)
{
   static_cast<T*>(self->this_)->interaction_direction_hitsize_set(dir_, hitsize_);
}

template <typename T>
double _elm_flip_interaction_direction_hitsize_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Flip_Direction dir_)
{
   return static_cast<T*>(self->this_)->interaction_direction_hitsize_get(dir_);
}

template <typename T>
void _elm_flip_interaction_direction_enabled_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Flip_Direction dir_, Eina_Bool enabled_)
{
   static_cast<T*>(self->this_)->interaction_direction_enabled_set(dir_, efl::eolian::to_cxx<bool>(enabled_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_flip_interaction_direction_enabled_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Flip_Direction dir_)
{
   return static_cast<T*>(self->this_)->interaction_direction_enabled_get(dir_);
}

template <typename T>
void _elm_flip_go_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Flip_Mode mode_)
{
   static_cast<T*>(self->this_)->go(mode_);
}

template <typename T>
void _elm_flip_go_to_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool front_, Elm_Flip_Mode mode_)
{
   static_cast<T*>(self->this_)->go_to(efl::eolian::to_cxx<bool>(front_, std::tuple<std::false_type>()), mode_);
}

template <typename T>
Elm_Flip_Interaction _elm_flip_interaction_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->interaction_get();
}

template <typename T>
void _elm_flip_interaction_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Flip_Interaction mode_)
{
   static_cast<T*>(self->this_)->interaction_set(mode_);
}

template <typename T>
bool _elm_flip_front_visible_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->front_visible_get();
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_flip >
{
   template <typename T>
   struct type
   {
      virtual void interaction_direction_hitsize_set(Elm_Flip_Direction dir_, double hitsize_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_flip_interaction_direction_hitsize_set(dir_, hitsize_));
      }

      virtual double interaction_direction_hitsize_get(Elm_Flip_Direction dir_)
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_flip_interaction_direction_hitsize_get(dir_));
            return _tmp_ret;
      }

      virtual void interaction_direction_enabled_set(Elm_Flip_Direction dir_, bool enabled_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_flip_interaction_direction_enabled_set(dir_, efl::eolian::to_c(enabled_)));
      }

      virtual bool interaction_direction_enabled_get(Elm_Flip_Direction dir_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_flip_interaction_direction_enabled_get(dir_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void go(Elm_Flip_Mode mode_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_flip_go(mode_));
      }

      virtual void go_to(bool front_, Elm_Flip_Mode mode_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_flip_go_to(efl::eolian::to_c(front_), mode_));
      }

      virtual Elm_Flip_Interaction interaction_get()
      {
         Elm_Flip_Interaction _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_flip_interaction_get());
            return _tmp_ret;
      }

      virtual void interaction_set(Elm_Flip_Interaction mode_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_flip_interaction_set(mode_));
      }

      virtual bool front_visible_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_flip_front_visible_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

   };
};


template<>
struct operation_description_class_size< ::elm_flip >
{
   static const int value = 9;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_flip>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_flip_interaction_direction_hitsize_set_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_flip_interaction_direction_hitsize_set);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_flip_interaction_direction_hitsize_get_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_flip_interaction_direction_hitsize_get);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_flip_interaction_direction_enabled_set_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_flip_interaction_direction_enabled_set);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_flip_interaction_direction_enabled_get_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_flip_interaction_direction_enabled_get);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_flip_go_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_flip_go);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_flip_go_to_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_flip_go_to);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_flip_interaction_get_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_flip_interaction_get);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_flip_interaction_set_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_flip_interaction_set);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_flip_front_visible_get_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_flip_front_visible_get);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_flip >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_flip, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_flip >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_flip, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_flip>
{
   template <typename U>
   struct type
   {
      operator ::elm_flip() const
      {
         return ::elm_flip(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      void interaction_direction_hitsize_set(Elm_Flip_Direction dir_, double hitsize_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_flip_interaction_direction_hitsize_set(dir_, hitsize_));
      }

      double interaction_direction_hitsize_get(Elm_Flip_Direction dir_)
      {
         double _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_flip_interaction_direction_hitsize_get(dir_));
            return _tmp_ret;
      }

      void interaction_direction_enabled_set(Elm_Flip_Direction dir_, bool enabled_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_flip_interaction_direction_enabled_set(dir_, efl::eolian::to_c(enabled_)));
      }

      bool interaction_direction_enabled_get(Elm_Flip_Direction dir_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_flip_interaction_direction_enabled_get(dir_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void go(Elm_Flip_Mode mode_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_flip_go(mode_));
      }

      void go_to(bool front_, Elm_Flip_Mode mode_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_flip_go_to(efl::eolian::to_c(front_), mode_));
      }

      Elm_Flip_Interaction interaction_get()
      {
         Elm_Flip_Interaction _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_flip_interaction_get());
            return _tmp_ret;
      }

      void interaction_set(Elm_Flip_Interaction mode_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_flip_interaction_set(mode_));
      }

      bool front_visible_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_flip_front_visible_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_animate_begin_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_FLIP_EVENT_ANIMATE_BEGIN, priority_,
            &efl::eo::_detail::event_callback<::elm_flip, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_flip, function_type>,
         ELM_FLIP_EVENT_ANIMATE_BEGIN );
   }

   template <typename T>
   void
   callback_animate_begin_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_FLIP_EVENT_ANIMATE_BEGIN, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_animate_done_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_FLIP_EVENT_ANIMATE_DONE, priority_,
            &efl::eo::_detail::event_callback<::elm_flip, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_flip, function_type>,
         ELM_FLIP_EVENT_ANIMATE_DONE );
   }

   template <typename T>
   void
   callback_animate_done_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_FLIP_EVENT_ANIMATE_DONE, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_flip>)
{
   return (ELM_FLIP_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_FLIP_HH

