#ifndef EFL_GENERATED_ELM_FLIPSELECTOR_HH
#define EFL_GENERATED_ELM_FLIPSELECTOR_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_flipselector.eo.h"
}

#include "elm_layout.eo.hh"
#include "elm_interface_atspi_widget_action.eo.hh"
#include <string>

struct elm_flipselector
      : elm_layout,
      efl::eo::detail::extension_inheritance<elm_interface_atspi_widget_action>::template type< ::elm_flipselector>

{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_flipselector(Eo* eo)
      : elm_layout(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_flipselector(std::nullptr_t)
      : elm_layout(nullptr)
   {}

   elm_flipselector(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_flipselector(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_flipselector(elm_flipselector const& other)
      : elm_layout(eo_ref(other._eo_ptr()))
   {}

   ~elm_flipselector() {}

   /// @brief Prepend a (text) item to a flip selector widget
   ///
   /// @return A handle to the item added or @c NULL, on errors
   ///
   /// The widget's list of labels to show will be prepended with the
   /// given value. If the user wishes so, a callback function pointer
   /// can be passed, which will get called when this same item is
   /// selected.
   ///
   /// @note The current selection @b won't be modified by prepending
   /// an element to the list.
   ///
   /// @note The maximum length of the text label is going to be
   /// determined <b>by the widget's theme</b>. Strings larger than
   /// that value are going to be @b truncated.
   ///
   /// @ingroup Flipselector
   ///
   /// @param label The (text) label of the new item
   /// @param func Convenience callback function to take place when
   /// item is selected
   /// @param data Data passed to @p func, above
   ///
   Elm_Object_Item * item_prepend(std::string label_, Evas_Smart_Cb func_, void * data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_flipselector_item_prepend(efl::eolian::to_c(label_), func_, data_));
      return _tmp_ret;
   }

   /// @brief Programmatically select the next item of a flip selector widget
   ///
   /// @note The selection will be animated. Also, if it reaches the
   /// end of its list of member items, it will continue with the first
   /// one onwards.
   ///
   /// @ingroup Flipselector
   ///
   void flip_next() const
   {
      eo_do(_eo_ptr(), ::elm_obj_flipselector_flip_next());
   }

   /// @brief Append a (text) item to a flip selector widget
   ///
   /// @return A handle to the item added or @c NULL, on errors
   ///
   /// The widget's list of labels to show will be appended with the
   /// given value. If the user wishes so, a callback function pointer
   /// can be passed, which will get called when this same item is
   /// selected.
   ///
   /// @note The current selection @b won't be modified by appending an
   /// element to the list.
   ///
   /// @note The maximum length of the text label is going to be
   /// determined <b>by the widget's theme</b>. Strings larger than
   /// that value are going to be @b truncated.
   ///
   /// @ingroup Flipselector
   ///
   /// @param label The (text) label of the new item
   /// @param func Convenience callback function to take place when
   /// item is selected
   /// @param data Data passed to @p func, above
   ///
   Elm_Object_Item * item_append(std::string label_, Evas_Smart_Cb func_, const void * data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_flipselector_item_append(efl::eolian::to_c(label_), func_, data_));
      return _tmp_ret;
   }

   /// @brief Programmatically select the previous item of a flip selector
   /// widget
   ///
   /// @note The selection will be animated. Also, if it reaches the
   /// beginning of its list of member items, it will continue with the
   /// last one backwards.
   ///
   /// @ingroup Flipselector
   ///
   void flip_prev() const
   {
      eo_do(_eo_ptr(), ::elm_obj_flipselector_flip_prev());
   }

   /// @param interval The (first) interval value in seconds
   ///
   double first_interval_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_flipselector_first_interval_get());
      return _tmp_ret;
   }

   /// @param interval The (first) interval value in seconds
   ///
   void first_interval_set(double interval_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_flipselector_first_interval_set(interval_));
   }

   const Eina_List * items_get() const
   {
      const Eina_List * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_flipselector_items_get());
      return _tmp_ret;
   }

   Elm_Object_Item * first_item_get() const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_flipselector_first_item_get());
      return _tmp_ret;
   }

   Elm_Object_Item * last_item_get() const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_flipselector_last_item_get());
      return _tmp_ret;
   }

   Elm_Object_Item * selected_item_get() const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_flipselector_selected_item_get());
      return _tmp_ret;
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_selected_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_FLIPSELECTOR_EVENT_SELECTED, priority_,
            &efl::eo::_detail::event_callback<::elm_flipselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_flipselector, function_type>,
         ELM_FLIPSELECTOR_EVENT_SELECTED );
   }

   template <typename T>
   void
   callback_selected_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_FLIPSELECTOR_EVENT_SELECTED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_underflowed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_FLIPSELECTOR_EVENT_UNDERFLOWED, priority_,
            &efl::eo::_detail::event_callback<::elm_flipselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_flipselector, function_type>,
         ELM_FLIPSELECTOR_EVENT_UNDERFLOWED );
   }

   template <typename T>
   void
   callback_underflowed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_FLIPSELECTOR_EVENT_UNDERFLOWED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_overflowed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_FLIPSELECTOR_EVENT_OVERFLOWED, priority_,
            &efl::eo::_detail::event_callback<::elm_flipselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_flipselector, function_type>,
         ELM_FLIPSELECTOR_EVENT_OVERFLOWED );
   }

   template <typename T>
   void
   callback_overflowed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_FLIPSELECTOR_EVENT_OVERFLOWED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_FLIPSELECTOR_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_flipselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_flipselector, function_type>,
         ELM_FLIPSELECTOR_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_FLIPSELECTOR_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_FLIPSELECTOR_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_flipselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_flipselector, function_type>,
         ELM_FLIPSELECTOR_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_FLIPSELECTOR_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_FLIPSELECTOR_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_flipselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_flipselector, function_type>,
         ELM_FLIPSELECTOR_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_FLIPSELECTOR_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_FLIPSELECTOR_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_flipselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_flipselector, function_type>,
         ELM_FLIPSELECTOR_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_FLIPSELECTOR_EVENT_UNFOCUSED, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_FLIPSELECTOR_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_FLIPSELECTOR_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
Elm_Object_Item * _elm_flipselector_item_prepend_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * label_, Evas_Smart_Cb func_, void * data_)
{
   return static_cast<T*>(self->this_)->item_prepend(efl::eolian::to_cxx<std::string>(label_, std::tuple<std::false_type>()), func_, data_);
}

template <typename T>
void _elm_flipselector_flip_next_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->flip_next();
}

template <typename T>
Elm_Object_Item * _elm_flipselector_item_append_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * label_, Evas_Smart_Cb func_, const void * data_)
{
   return static_cast<T*>(self->this_)->item_append(efl::eolian::to_cxx<std::string>(label_, std::tuple<std::false_type>()), func_, data_);
}

template <typename T>
void _elm_flipselector_flip_prev_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->flip_prev();
}

template <typename T>
double _elm_flipselector_first_interval_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->first_interval_get();
}

template <typename T>
void _elm_flipselector_first_interval_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double interval_)
{
   static_cast<T*>(self->this_)->first_interval_set(interval_);
}

template <typename T>
const Eina_List * _elm_flipselector_items_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->items_get();
}

template <typename T>
Elm_Object_Item * _elm_flipselector_first_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->first_item_get();
}

template <typename T>
Elm_Object_Item * _elm_flipselector_last_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->last_item_get();
}

template <typename T>
Elm_Object_Item * _elm_flipselector_selected_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->selected_item_get();
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_flipselector >
{
   template <typename T>
   struct type
   {
      virtual Elm_Object_Item * item_prepend(std::string label_, Evas_Smart_Cb func_, void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_flipselector_item_prepend(efl::eolian::to_c(label_), func_, data_));
            return _tmp_ret;
      }

      virtual void flip_next()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_flipselector_flip_next());
      }

      virtual Elm_Object_Item * item_append(std::string label_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_flipselector_item_append(efl::eolian::to_c(label_), func_, data_));
            return _tmp_ret;
      }

      virtual void flip_prev()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_flipselector_flip_prev());
      }

      virtual double first_interval_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_flipselector_first_interval_get());
            return _tmp_ret;
      }

      virtual void first_interval_set(double interval_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_flipselector_first_interval_set(interval_));
      }

      virtual const Eina_List * items_get()
      {
         const Eina_List * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_flipselector_items_get());
            return _tmp_ret;
      }

      virtual Elm_Object_Item * first_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_flipselector_first_item_get());
            return _tmp_ret;
      }

      virtual Elm_Object_Item * last_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_flipselector_last_item_get());
            return _tmp_ret;
      }

      virtual Elm_Object_Item * selected_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_flipselector_selected_item_get());
            return _tmp_ret;
      }

   };
};


template<>
struct operation_description_class_size< ::elm_flipselector >
{
   static const int value = 10;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_flipselector>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_flipselector_item_prepend_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_flipselector_item_prepend);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_flipselector_flip_next_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_flipselector_flip_next);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_flipselector_item_append_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_flipselector_item_append);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_flipselector_flip_prev_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_flipselector_flip_prev);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_flipselector_first_interval_get_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_flipselector_first_interval_get);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_flipselector_first_interval_set_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_flipselector_first_interval_set);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_flipselector_items_get_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_flipselector_items_get);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_flipselector_first_item_get_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_flipselector_first_item_get);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_flipselector_last_item_get_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_flipselector_last_item_get);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_flipselector_selected_item_get_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_flipselector_selected_item_get);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_flipselector >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_flipselector, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_flipselector >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_flipselector, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_flipselector>
{
   template <typename U>
   struct type
   {
      operator ::elm_flipselector() const
      {
         return ::elm_flipselector(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      Elm_Object_Item * item_prepend(std::string label_, Evas_Smart_Cb func_, void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_flipselector_item_prepend(efl::eolian::to_c(label_), func_, data_));
            return _tmp_ret;
      }

      void flip_next()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_flipselector_flip_next());
      }

      Elm_Object_Item * item_append(std::string label_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_flipselector_item_append(efl::eolian::to_c(label_), func_, data_));
            return _tmp_ret;
      }

      void flip_prev()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_flipselector_flip_prev());
      }

      double first_interval_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_flipselector_first_interval_get());
            return _tmp_ret;
      }

      void first_interval_set(double interval_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_flipselector_first_interval_set(interval_));
      }

      const Eina_List * items_get()
      {
         const Eina_List * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_flipselector_items_get());
            return _tmp_ret;
      }

      Elm_Object_Item * first_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_flipselector_first_item_get());
            return _tmp_ret;
      }

      Elm_Object_Item * last_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_flipselector_last_item_get());
            return _tmp_ret;
      }

      Elm_Object_Item * selected_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_flipselector_selected_item_get());
            return _tmp_ret;
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_selected_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_FLIPSELECTOR_EVENT_SELECTED, priority_,
            &efl::eo::_detail::event_callback<::elm_flipselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_flipselector, function_type>,
         ELM_FLIPSELECTOR_EVENT_SELECTED );
   }

   template <typename T>
   void
   callback_selected_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_FLIPSELECTOR_EVENT_SELECTED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_underflowed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_FLIPSELECTOR_EVENT_UNDERFLOWED, priority_,
            &efl::eo::_detail::event_callback<::elm_flipselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_flipselector, function_type>,
         ELM_FLIPSELECTOR_EVENT_UNDERFLOWED );
   }

   template <typename T>
   void
   callback_underflowed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_FLIPSELECTOR_EVENT_UNDERFLOWED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_overflowed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_FLIPSELECTOR_EVENT_OVERFLOWED, priority_,
            &efl::eo::_detail::event_callback<::elm_flipselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_flipselector, function_type>,
         ELM_FLIPSELECTOR_EVENT_OVERFLOWED );
   }

   template <typename T>
   void
   callback_overflowed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_FLIPSELECTOR_EVENT_OVERFLOWED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_FLIPSELECTOR_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_flipselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_flipselector, function_type>,
         ELM_FLIPSELECTOR_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_FLIPSELECTOR_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_FLIPSELECTOR_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_flipselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_flipselector, function_type>,
         ELM_FLIPSELECTOR_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_FLIPSELECTOR_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_FLIPSELECTOR_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_flipselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_flipselector, function_type>,
         ELM_FLIPSELECTOR_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_FLIPSELECTOR_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_FLIPSELECTOR_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_flipselector, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_flipselector, function_type>,
         ELM_FLIPSELECTOR_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_FLIPSELECTOR_EVENT_UNFOCUSED, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_flipselector>)
{
   return (ELM_FLIPSELECTOR_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_FLIPSELECTOR_HH

