#ifndef EFL_GENERATED_ELM_GENGRID_HH
#define EFL_GENERATED_ELM_GENGRID_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_gengrid.eo.h"
}

#include "elm_layout.eo.hh"
#include "elm_interface_scrollable.eo.hh"
#include "evas_clickable_interface.eo.hh"
#include <string>

struct elm_gengrid
      : elm_layout,
      efl::eo::detail::extension_inheritance<elm_interface_scrollable>::template type< ::elm_gengrid>,
      efl::eo::detail::extension_inheritance<evas::clickable_interface>::template type< ::elm_gengrid>

{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_gengrid(Eo* eo)
      : elm_layout(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_gengrid(std::nullptr_t)
      : elm_layout(nullptr)
   {}

   elm_gengrid(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_gengrid(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_gengrid(elm_gengrid const& other)
      : elm_layout(eo_ref(other._eo_ptr()))
   {}

   ~elm_gengrid() {}

   /// @brief Insert an item before another in a gengrid widget
   ///
   /// @return A handle to the item added or @c NULL, on errors.
   ///
   /// This inserts an item before another in the gengrid.
   ///
   /// @see elm_gengrid_item_append()
   /// @see elm_gengrid_item_prepend()
   /// @see elm_gengrid_item_insert_after()
   /// @see elm_object_item_del()
   ///
   /// @ingroup Gengrid
   ///
   /// @param itc The item class for the item.
   /// @param data The item data.
   /// @param relative The item to place this new one before.
   /// @param func Convenience function called when the item is
   /// selected.
   /// @param func_data Data to be passed to @p func.
   ///
   Elm_Object_Item * item_insert_before(const Elm_Gengrid_Item_Class * itc_, const void * data_, Elm_Object_Item * relative_, Evas_Smart_Cb func_, const void * func_data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_item_insert_before(itc_, data_, relative_, func_, func_data_));
      return _tmp_ret;
   }

   /// @brief Update the contents of all realized items.
   ///
   /// This updates all realized items by calling all the item class functions again
   /// to get the contents, texts and states. Use this when the original
   /// item data has changed and the changes are desired to be reflected.
   ///
   /// To update just one item, use elm_gengrid_item_update().
   ///
   /// @see elm_gengrid_realized_items_get()
   /// @see elm_gengrid_item_update()
   ///
   /// @ingroup Gengrid
   ///
   void realized_items_update() const
   {
      eo_do(_eo_ptr(), ::elm_obj_gengrid_realized_items_update());
   }

   /// @brief Insert an item after another in a gengrid widget
   ///
   /// @return A handle to the item added or @c NULL, on errors.
   ///
   /// This inserts an item after another in the gengrid.
   ///
   /// @see elm_gengrid_item_append()
   /// @see elm_gengrid_item_prepend()
   /// @see elm_gengrid_item_insert_after()
   /// @see elm_object_item_del()
   ///
   /// @ingroup Gengrid
   ///
   /// @param itc The item class for the item.
   /// @param data The item data.
   /// @param relative The item to place this new one after.
   /// @param func Convenience function called when the item is
   /// selected.
   /// @param func_data Data to be passed to @p func.
   ///
   Elm_Object_Item * item_insert_after(const Elm_Gengrid_Item_Class * itc_, const void * data_, Elm_Object_Item * relative_, Evas_Smart_Cb func_, const void * func_data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_item_insert_after(itc_, data_, relative_, func_, func_data_));
      return _tmp_ret;
   }

   /// @brief Return how many items are currently in a list
   ///
   /// @return The total number of list items in the list
   ///
   /// This behavior is O(1) and includes items which may or may not be realized.
   ///
   /// @ingroup Gengrid
   ///
   unsigned int items_count() const
   {
      unsigned int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_items_count());
      return _tmp_ret;
   }

   /// @brief Get the item that is at the x, y canvas coords.
   ///
   /// @return The item at the coordinates or NULL if none
   ///
   /// This returns the item at the given coordinates (which are canvas
   /// relative, not object-relative). If an item is at that coordinate,
   /// that item handle is returned, and if @p xposret is not NULL, the
   /// integer pointed to is set to a value of -1, 0 or 1, depending if
   /// the coordinate is on the left portion of that item (-1), on the
   /// middle section (0) or on the right part (1).
   /// if @p yposret is not NULL, the
   /// integer pointed to is set to a value of -1, 0 or 1, depending if
   /// the coordinate is on the upper portion of that item (-1), on the
   /// middle section (0) or on the lower part (1). If NULL is returned as
   /// an item (no item found there), then posret may indicate -1 or 1
   /// based if the coordinate is above or below all items respectively in
   /// the gengrid.
   ///
   /// @ingroup Gengrid
   ///
   /// @param x The input x coordinate
   /// @param y The input y coordinate
   /// @param[out] xposret The position relative to the item returned here
   /// @param[out] yposret The position relative to the item returned here
   ///
   Elm_Object_Item * at_xy_item_get(Evas_Coord x_, Evas_Coord y_, int* xposret_, int* yposret_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_at_xy_item_get(x_, y_, xposret_, yposret_));
      return _tmp_ret;
   }

   /// @brief Append a new item in a given gengrid widget.
   ///
   /// @return A handle to the item added or @c NULL, on errors.
   ///
   /// This adds an item to the beginning of the gengrid.
   ///
   /// @see elm_gengrid_item_prepend()
   /// @see elm_gengrid_item_insert_before()
   /// @see elm_gengrid_item_insert_after()
   /// @see elm_object_item_del()
   ///
   /// @ingroup Gengrid
   ///
   /// @param itc The item class for the item.
   /// @param data The item data.
   /// @param func Convenience function called when the item is
   /// selected.
   /// @param func_data Data to be passed to @p func.
   ///
   Elm_Object_Item * item_append(const Elm_Gengrid_Item_Class * itc_, const void * data_, Evas_Smart_Cb func_, const void * func_data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_item_append(itc_, data_, func_, func_data_));
      return _tmp_ret;
   }

   /// @brief Prepend a new item in a given gengrid widget.
   ///
   /// @return A handle to the item added or @c NULL, on errors.
   ///
   /// This adds an item to the end of the gengrid.
   ///
   /// @see elm_gengrid_item_append()
   /// @see elm_gengrid_item_insert_before()
   /// @see elm_gengrid_item_insert_after()
   /// @see elm_object_item_del()
   ///
   /// @ingroup Gengrid
   ///
   /// @param itc The item class for the item.
   /// @param data The item data.
   /// @param func Convenience function called when the item is
   /// selected.
   /// @param func_data Data to be passed to @p func.
   ///
   Elm_Object_Item * item_prepend(const Elm_Gengrid_Item_Class * itc_, const void * data_, Evas_Smart_Cb func_, const void * func_data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_item_prepend(itc_, data_, func_, func_data_));
      return _tmp_ret;
   }

   /// @brief Remove all items from a given gengrid widget
   ///
   /// This removes (and deletes) all items in @p obj, leaving it
   /// empty.
   ///
   /// @see elm_object_item_del(), to remove just one item.
   ///
   /// @ingroup Gengrid
   ///
   void clear() const
   {
      eo_do(_eo_ptr(), ::elm_obj_gengrid_clear());
   }

   /// @brief Insert an item in a gengrid widget using a user-defined sort function.
   ///
   /// @return A handle to the item added or @c NULL, on errors.
   ///
   /// This inserts an item in the gengrid based on user defined comparison
   /// function. The two arguments passed to the function @p func are gengrid
   /// item handles to compare.
   ///
   /// @see elm_gengrid_item_append()
   /// @see elm_gengrid_item_prepend()
   /// @see elm_gengrid_item_insert_after()
   /// @see elm_object_item_data_get()
   /// @see elm_object_item_del()
   ///
   /// @ingroup Gengrid
   ///
   /// @param itc The item class for the item.
   /// @param data The item data.
   /// @param comp User defined comparison function that defines the sort order
   /// based on gengrid item and its data.
   /// @param func Convenience function called when the item is selected.
   /// @param func_data Data to be passed to @p func.
   ///
   Elm_Object_Item * item_sorted_insert(const Elm_Gengrid_Item_Class * itc_, const void * data_, Eina_Compare_Cb comp_, Evas_Smart_Cb func_, const void * func_data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_item_sorted_insert(itc_, data_, comp_, func_, func_data_));
      return _tmp_ret;
   }

   /// @brief Get gengrid item by given string.
   ///
   /// @return Pointer to the gengrid item which matches search_string in case of success, otherwise returns NULL.
   ///
   /// It takes pointer to the gengrid item that will be used to start
   /// search from it.
   ///
   /// This function uses globs (like "*.jpg") for searching and takes
   /// search flags as last parameter That is a bitfield with values
   /// to be ored together or 0 for no flags.
   ///
   /// @ingroup Gengrid
   /// @since 1.11
   ///
   /// @param item_to_search_from Pointer to item to start search from. If NULL search will be started from the first item of the gengrid.
   /// @param part_name Name of the TEXT part of gengrid item to search string in.
   /// @param pattern The search pattern.
   /// @param flags Search flags
   ///
   Elm_Object_Item * search_by_text_item_get(Elm_Object_Item * item_to_search_from_, std::string part_name_, std::string pattern_, Elm_Glob_Match_Flags flags_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_search_by_text_item_get(item_to_search_from_, efl::eolian::to_c(part_name_), efl::eolian::to_c(pattern_), flags_));
      return _tmp_ret;
   }

   /// @param align_x Alignment in the horizontal axis (0 <= align_x <= 1).
   /// @param align_y Alignment in the vertical axis (0 <= align_y <= 1).
   ///
   void align_get(double* align_x_, double* align_y_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_gengrid_align_get(align_x_, align_y_));
   }

   /// @param align_x Alignment in the horizontal axis (0 <= align_x <= 1).
   /// @param align_y Alignment in the vertical axis (0 <= align_y <= 1).
   ///
   void align_set(double align_x_, double align_y_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_gengrid_align_set(align_x_, align_y_));
   }

   /// @param fill Filled if True
   ///
   bool filled_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_filled_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param fill Filled if True
   ///
   void filled_set(bool fill_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_gengrid_filled_set(efl::eolian::to_c(fill_)));
   }

   /// @param h_pagerel 
   /// @param v_pagerel 
   ///
   void page_relative_get(double* h_pagerel_, double* v_pagerel_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_gengrid_page_relative_get(h_pagerel_, v_pagerel_));
   }

   /// @param h_pagerel 
   /// @param v_pagerel 
   ///
   void page_relative_set(double h_pagerel_, double v_pagerel_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_gengrid_page_relative_set(h_pagerel_, v_pagerel_));
   }

   /// @param multi @c EINA_TRUE, to enable multi-selection,
   /// @c EINA_FALSE to disable it.
   ///
   bool multi_select_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_multi_select_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param multi @c EINA_TRUE, to enable multi-selection,
   /// @c EINA_FALSE to disable it.
   ///
   void multi_select_set(bool multi_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_gengrid_multi_select_set(efl::eolian::to_c(multi_)));
   }

   /// @param w The group items' width.
   /// @param h The group items' height.
   ///
   void group_item_size_get(Evas_Coord* w_, Evas_Coord* h_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_gengrid_group_item_size_get(w_, h_));
   }

   /// @param w The group items' width.
   /// @param h The group items' height.
   ///
   void group_item_size_set(Evas_Coord w_, Evas_Coord h_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_gengrid_group_item_size_set(w_, h_));
   }

   /// @param mode The select mode
   ///
   Elm_Object_Select_Mode select_mode_get() const
   {
      Elm_Object_Select_Mode _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_select_mode_get());
      return _tmp_ret;
   }

   /// @param mode The select mode
   ///
   void select_mode_set(Elm_Object_Select_Mode mode_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_gengrid_select_mode_set(mode_));
   }

   /// @param reorder_mode Use @c EINA_TRUE to turn reordering on,
   /// @c EINA_FALSE to turn it off
   ///
   bool reorder_mode_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_reorder_mode_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param reorder_mode Use @c EINA_TRUE to turn reordering on,
   /// @c EINA_FALSE to turn it off
   ///
   void reorder_mode_set(bool reorder_mode_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_gengrid_reorder_mode_set(efl::eolian::to_c(reorder_mode_)));
   }

   /// @param highlight 
   ///
   bool highlight_mode_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_highlight_mode_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param highlight 
   ///
   void highlight_mode_set(bool highlight_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_gengrid_highlight_mode_set(efl::eolian::to_c(highlight_)));
   }

   /// @param w The items' width.
   /// @param h The items' height.
   ///
   void item_size_get(Evas_Coord* w_, Evas_Coord* h_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_gengrid_item_size_get(w_, h_));
   }

   /// @param w The items' width.
   /// @param h The items' height.
   ///
   void item_size_set(Evas_Coord w_, Evas_Coord h_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_gengrid_item_size_set(w_, h_));
   }

   /// @param mode The multi select mode
   ///
   Elm_Object_Multi_Select_Mode multi_select_mode_get() const
   {
      Elm_Object_Multi_Select_Mode _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_multi_select_mode_get());
      return _tmp_ret;
   }

   /// @param mode The multi select mode
   ///
   void multi_select_mode_set(Elm_Object_Multi_Select_Mode mode_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_gengrid_multi_select_mode_set(mode_));
   }

   /// @param horizontal @c EINA_TRUE to make the gengrid expand horizontally,
   /// @c EINA_FALSE to expand vertically.
   ///
   bool horizontal_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_horizontal_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param horizontal @c EINA_TRUE to make the gengrid expand horizontally,
   /// @c EINA_FALSE to expand vertically.
   ///
   void horizontal_set(bool horizontal_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_gengrid_horizontal_set(efl::eolian::to_c(horizontal_)));
   }

   /// @param h_pagesize 
   /// @param v_pagesize 
   ///
   void page_size_set(Evas_Coord h_pagesize_, Evas_Coord v_pagesize_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_gengrid_page_size_set(h_pagesize_, v_pagesize_));
   }

   Elm_Object_Item * selected_item_get() const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_selected_item_get());
      return _tmp_ret;
   }

   Eina_List * realized_items_get() const
   {
      Eina_List * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_realized_items_get());
      return _tmp_ret;
   }

   Elm_Object_Item * first_item_get() const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_first_item_get());
      return _tmp_ret;
   }

   const Eina_List * selected_items_get() const
   {
      const Eina_List * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_selected_items_get());
      return _tmp_ret;
   }

   Elm_Object_Item * last_item_get() const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_last_item_get());
      return _tmp_ret;
   }

   /// @param disabled Use @c EINA_TRUE to disable mouse wheel or @c EINA_FALSE
   /// to enable it.
   ///
   bool wheel_disabled_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_wheel_disabled_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param disabled Use @c EINA_TRUE to disable mouse wheel or @c EINA_FALSE
   /// to enable it.
   ///
   void wheel_disabled_set(bool disabled_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_gengrid_wheel_disabled_set(efl::eolian::to_c(disabled_)));
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_GENGRID_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_gengrid, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_gengrid, function_type>,
         ELM_GENGRID_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_GENGRID_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_GENGRID_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_gengrid, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_gengrid, function_type>,
         ELM_GENGRID_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_GENGRID_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_GENGRID_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_gengrid, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_gengrid, function_type>,
         ELM_GENGRID_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_GENGRID_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_GENGRID_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_gengrid, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_gengrid, function_type>,
         ELM_GENGRID_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_GENGRID_EVENT_UNFOCUSED, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_GENGRID_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_GENGRID_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
Elm_Object_Item * _elm_gengrid_item_insert_before_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const Elm_Gengrid_Item_Class * itc_, const void * data_, Elm_Object_Item * relative_, Evas_Smart_Cb func_, const void * func_data_)
{
   return static_cast<T*>(self->this_)->item_insert_before(itc_, data_, relative_, func_, func_data_);
}

template <typename T>
void _elm_gengrid_realized_items_update_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->realized_items_update();
}

template <typename T>
Elm_Object_Item * _elm_gengrid_item_insert_after_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const Elm_Gengrid_Item_Class * itc_, const void * data_, Elm_Object_Item * relative_, Evas_Smart_Cb func_, const void * func_data_)
{
   return static_cast<T*>(self->this_)->item_insert_after(itc_, data_, relative_, func_, func_data_);
}

template <typename T>
unsigned int _elm_gengrid_items_count_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->items_count();
}

template <typename T>
Elm_Object_Item * _elm_gengrid_at_xy_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord x_, Evas_Coord y_, int* xposret_, int* yposret_)
{
   return static_cast<T*>(self->this_)->at_xy_item_get(x_, y_, xposret_, yposret_);
}

template <typename T>
Elm_Object_Item * _elm_gengrid_item_append_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const Elm_Gengrid_Item_Class * itc_, const void * data_, Evas_Smart_Cb func_, const void * func_data_)
{
   return static_cast<T*>(self->this_)->item_append(itc_, data_, func_, func_data_);
}

template <typename T>
Elm_Object_Item * _elm_gengrid_item_prepend_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const Elm_Gengrid_Item_Class * itc_, const void * data_, Evas_Smart_Cb func_, const void * func_data_)
{
   return static_cast<T*>(self->this_)->item_prepend(itc_, data_, func_, func_data_);
}

template <typename T>
void _elm_gengrid_clear_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->clear();
}

template <typename T>
Elm_Object_Item * _elm_gengrid_item_sorted_insert_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const Elm_Gengrid_Item_Class * itc_, const void * data_, Eina_Compare_Cb comp_, Evas_Smart_Cb func_, const void * func_data_)
{
   return static_cast<T*>(self->this_)->item_sorted_insert(itc_, data_, comp_, func_, func_data_);
}

template <typename T>
Elm_Object_Item * _elm_gengrid_search_by_text_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Object_Item * item_to_search_from_, const char * part_name_, const char * pattern_, Elm_Glob_Match_Flags flags_)
{
   return static_cast<T*>(self->this_)->search_by_text_item_get(item_to_search_from_, efl::eolian::to_cxx<std::string>(part_name_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(pattern_, std::tuple<std::false_type>()), flags_);
}

template <typename T>
void _elm_gengrid_align_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double* align_x_, double* align_y_)
{
   static_cast<T*>(self->this_)->align_get(align_x_, align_y_);
}

template <typename T>
void _elm_gengrid_align_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double align_x_, double align_y_)
{
   static_cast<T*>(self->this_)->align_set(align_x_, align_y_);
}

template <typename T>
bool _elm_gengrid_filled_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->filled_get();
}

template <typename T>
void _elm_gengrid_filled_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool fill_)
{
   static_cast<T*>(self->this_)->filled_set(efl::eolian::to_cxx<bool>(fill_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_gengrid_page_relative_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double* h_pagerel_, double* v_pagerel_)
{
   static_cast<T*>(self->this_)->page_relative_get(h_pagerel_, v_pagerel_);
}

template <typename T>
void _elm_gengrid_page_relative_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double h_pagerel_, double v_pagerel_)
{
   static_cast<T*>(self->this_)->page_relative_set(h_pagerel_, v_pagerel_);
}

template <typename T>
bool _elm_gengrid_multi_select_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->multi_select_get();
}

template <typename T>
void _elm_gengrid_multi_select_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool multi_)
{
   static_cast<T*>(self->this_)->multi_select_set(efl::eolian::to_cxx<bool>(multi_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_gengrid_group_item_size_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord* w_, Evas_Coord* h_)
{
   static_cast<T*>(self->this_)->group_item_size_get(w_, h_);
}

template <typename T>
void _elm_gengrid_group_item_size_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord w_, Evas_Coord h_)
{
   static_cast<T*>(self->this_)->group_item_size_set(w_, h_);
}

template <typename T>
Elm_Object_Select_Mode _elm_gengrid_select_mode_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->select_mode_get();
}

template <typename T>
void _elm_gengrid_select_mode_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Object_Select_Mode mode_)
{
   static_cast<T*>(self->this_)->select_mode_set(mode_);
}

template <typename T>
bool _elm_gengrid_reorder_mode_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->reorder_mode_get();
}

template <typename T>
void _elm_gengrid_reorder_mode_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool reorder_mode_)
{
   static_cast<T*>(self->this_)->reorder_mode_set(efl::eolian::to_cxx<bool>(reorder_mode_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_gengrid_highlight_mode_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->highlight_mode_get();
}

template <typename T>
void _elm_gengrid_highlight_mode_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool highlight_)
{
   static_cast<T*>(self->this_)->highlight_mode_set(efl::eolian::to_cxx<bool>(highlight_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_gengrid_item_size_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord* w_, Evas_Coord* h_)
{
   static_cast<T*>(self->this_)->item_size_get(w_, h_);
}

template <typename T>
void _elm_gengrid_item_size_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord w_, Evas_Coord h_)
{
   static_cast<T*>(self->this_)->item_size_set(w_, h_);
}

template <typename T>
Elm_Object_Multi_Select_Mode _elm_gengrid_multi_select_mode_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->multi_select_mode_get();
}

template <typename T>
void _elm_gengrid_multi_select_mode_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Object_Multi_Select_Mode mode_)
{
   static_cast<T*>(self->this_)->multi_select_mode_set(mode_);
}

template <typename T>
bool _elm_gengrid_horizontal_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->horizontal_get();
}

template <typename T>
void _elm_gengrid_horizontal_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool horizontal_)
{
   static_cast<T*>(self->this_)->horizontal_set(efl::eolian::to_cxx<bool>(horizontal_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_gengrid_page_size_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord h_pagesize_, Evas_Coord v_pagesize_)
{
   static_cast<T*>(self->this_)->page_size_set(h_pagesize_, v_pagesize_);
}

template <typename T>
Elm_Object_Item * _elm_gengrid_selected_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->selected_item_get();
}

template <typename T>
Eina_List * _elm_gengrid_realized_items_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->realized_items_get();
}

template <typename T>
Elm_Object_Item * _elm_gengrid_first_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->first_item_get();
}

template <typename T>
const Eina_List * _elm_gengrid_selected_items_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->selected_items_get();
}

template <typename T>
Elm_Object_Item * _elm_gengrid_last_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->last_item_get();
}

template <typename T>
bool _elm_gengrid_wheel_disabled_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->wheel_disabled_get();
}

template <typename T>
void _elm_gengrid_wheel_disabled_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool disabled_)
{
   static_cast<T*>(self->this_)->wheel_disabled_set(efl::eolian::to_cxx<bool>(disabled_, std::tuple<std::false_type>()));
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_gengrid >
{
   template <typename T>
   struct type
   {
      virtual Elm_Object_Item * item_insert_before(const Elm_Gengrid_Item_Class * itc_, const void * data_, Elm_Object_Item * relative_, Evas_Smart_Cb func_, const void * func_data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_gengrid_item_insert_before(itc_, data_, relative_, func_, func_data_));
            return _tmp_ret;
      }

      virtual void realized_items_update()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_gengrid_realized_items_update());
      }

      virtual Elm_Object_Item * item_insert_after(const Elm_Gengrid_Item_Class * itc_, const void * data_, Elm_Object_Item * relative_, Evas_Smart_Cb func_, const void * func_data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_gengrid_item_insert_after(itc_, data_, relative_, func_, func_data_));
            return _tmp_ret;
      }

      virtual unsigned int items_count()
      {
         unsigned int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_gengrid_items_count());
            return _tmp_ret;
      }

      virtual Elm_Object_Item * at_xy_item_get(Evas_Coord x_, Evas_Coord y_, int* xposret_, int* yposret_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_gengrid_at_xy_item_get(x_, y_, xposret_, yposret_));
            return _tmp_ret;
      }

      virtual Elm_Object_Item * item_append(const Elm_Gengrid_Item_Class * itc_, const void * data_, Evas_Smart_Cb func_, const void * func_data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_gengrid_item_append(itc_, data_, func_, func_data_));
            return _tmp_ret;
      }

      virtual Elm_Object_Item * item_prepend(const Elm_Gengrid_Item_Class * itc_, const void * data_, Evas_Smart_Cb func_, const void * func_data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_gengrid_item_prepend(itc_, data_, func_, func_data_));
            return _tmp_ret;
      }

      virtual void clear()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_gengrid_clear());
      }

      virtual Elm_Object_Item * item_sorted_insert(const Elm_Gengrid_Item_Class * itc_, const void * data_, Eina_Compare_Cb comp_, Evas_Smart_Cb func_, const void * func_data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_gengrid_item_sorted_insert(itc_, data_, comp_, func_, func_data_));
            return _tmp_ret;
      }

      virtual Elm_Object_Item * search_by_text_item_get(Elm_Object_Item * item_to_search_from_, std::string part_name_, std::string pattern_, Elm_Glob_Match_Flags flags_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_gengrid_search_by_text_item_get(item_to_search_from_, efl::eolian::to_c(part_name_), efl::eolian::to_c(pattern_), flags_));
            return _tmp_ret;
      }

      virtual void align_get(double* align_x_, double* align_y_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_gengrid_align_get(align_x_, align_y_));
      }

      virtual void align_set(double align_x_, double align_y_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_gengrid_align_set(align_x_, align_y_));
      }

      virtual bool filled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_gengrid_filled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void filled_set(bool fill_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_gengrid_filled_set(efl::eolian::to_c(fill_)));
      }

      virtual void page_relative_get(double* h_pagerel_, double* v_pagerel_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_gengrid_page_relative_get(h_pagerel_, v_pagerel_));
      }

      virtual void page_relative_set(double h_pagerel_, double v_pagerel_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_gengrid_page_relative_set(h_pagerel_, v_pagerel_));
      }

      virtual bool multi_select_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_gengrid_multi_select_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void multi_select_set(bool multi_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_gengrid_multi_select_set(efl::eolian::to_c(multi_)));
      }

      virtual void group_item_size_get(Evas_Coord* w_, Evas_Coord* h_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_gengrid_group_item_size_get(w_, h_));
      }

      virtual void group_item_size_set(Evas_Coord w_, Evas_Coord h_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_gengrid_group_item_size_set(w_, h_));
      }

      virtual Elm_Object_Select_Mode select_mode_get()
      {
         Elm_Object_Select_Mode _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_gengrid_select_mode_get());
            return _tmp_ret;
      }

      virtual void select_mode_set(Elm_Object_Select_Mode mode_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_gengrid_select_mode_set(mode_));
      }

      virtual bool reorder_mode_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_gengrid_reorder_mode_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void reorder_mode_set(bool reorder_mode_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_gengrid_reorder_mode_set(efl::eolian::to_c(reorder_mode_)));
      }

      virtual bool highlight_mode_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_gengrid_highlight_mode_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void highlight_mode_set(bool highlight_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_gengrid_highlight_mode_set(efl::eolian::to_c(highlight_)));
      }

      virtual void item_size_get(Evas_Coord* w_, Evas_Coord* h_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_gengrid_item_size_get(w_, h_));
      }

      virtual void item_size_set(Evas_Coord w_, Evas_Coord h_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_gengrid_item_size_set(w_, h_));
      }

      virtual Elm_Object_Multi_Select_Mode multi_select_mode_get()
      {
         Elm_Object_Multi_Select_Mode _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_gengrid_multi_select_mode_get());
            return _tmp_ret;
      }

      virtual void multi_select_mode_set(Elm_Object_Multi_Select_Mode mode_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_gengrid_multi_select_mode_set(mode_));
      }

      virtual bool horizontal_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_gengrid_horizontal_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void horizontal_set(bool horizontal_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_gengrid_horizontal_set(efl::eolian::to_c(horizontal_)));
      }

      virtual void page_size_set(Evas_Coord h_pagesize_, Evas_Coord v_pagesize_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_gengrid_page_size_set(h_pagesize_, v_pagesize_));
      }

      virtual Elm_Object_Item * selected_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_gengrid_selected_item_get());
            return _tmp_ret;
      }

      virtual Eina_List * realized_items_get()
      {
         Eina_List * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_gengrid_realized_items_get());
            return _tmp_ret;
      }

      virtual Elm_Object_Item * first_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_gengrid_first_item_get());
            return _tmp_ret;
      }

      virtual const Eina_List * selected_items_get()
      {
         const Eina_List * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_gengrid_selected_items_get());
            return _tmp_ret;
      }

      virtual Elm_Object_Item * last_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_gengrid_last_item_get());
            return _tmp_ret;
      }

      virtual bool wheel_disabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_gengrid_wheel_disabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void wheel_disabled_set(bool disabled_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_gengrid_wheel_disabled_set(efl::eolian::to_c(disabled_)));
      }

   };
};


template<>
struct operation_description_class_size< ::elm_gengrid >
{
   static const int value = 40;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_gengrid>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_gengrid_item_insert_before_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_item_insert_before);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_gengrid_realized_items_update_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_realized_items_update);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_gengrid_item_insert_after_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_item_insert_after);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_gengrid_items_count_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_items_count);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_gengrid_at_xy_item_get_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_at_xy_item_get);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_gengrid_item_append_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_item_append);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_gengrid_item_prepend_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_item_prepend);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_gengrid_clear_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_clear);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_gengrid_item_sorted_insert_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_item_sorted_insert);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_gengrid_search_by_text_item_get_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_search_by_text_item_get);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::_elm_gengrid_align_get_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_align_get);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::_elm_gengrid_align_set_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_align_set);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::_elm_gengrid_filled_get_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_filled_get);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::_elm_gengrid_filled_set_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_filled_set);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::_elm_gengrid_page_relative_get_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_page_relative_get);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::_elm_gengrid_page_relative_set_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_page_relative_set);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   ops[16].func = reinterpret_cast<void*>(& ::_elm_gengrid_multi_select_get_wrapper<T>);
   ops[16].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_multi_select_get);
   ops[16].op = EO_OP_OVERRIDE;
   ops[16].op_type = EO_OP_TYPE_REGULAR;
   ops[16].doc = NULL;

   ops[17].func = reinterpret_cast<void*>(& ::_elm_gengrid_multi_select_set_wrapper<T>);
   ops[17].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_multi_select_set);
   ops[17].op = EO_OP_OVERRIDE;
   ops[17].op_type = EO_OP_TYPE_REGULAR;
   ops[17].doc = NULL;

   ops[18].func = reinterpret_cast<void*>(& ::_elm_gengrid_group_item_size_get_wrapper<T>);
   ops[18].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_group_item_size_get);
   ops[18].op = EO_OP_OVERRIDE;
   ops[18].op_type = EO_OP_TYPE_REGULAR;
   ops[18].doc = NULL;

   ops[19].func = reinterpret_cast<void*>(& ::_elm_gengrid_group_item_size_set_wrapper<T>);
   ops[19].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_group_item_size_set);
   ops[19].op = EO_OP_OVERRIDE;
   ops[19].op_type = EO_OP_TYPE_REGULAR;
   ops[19].doc = NULL;

   ops[20].func = reinterpret_cast<void*>(& ::_elm_gengrid_select_mode_get_wrapper<T>);
   ops[20].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_select_mode_get);
   ops[20].op = EO_OP_OVERRIDE;
   ops[20].op_type = EO_OP_TYPE_REGULAR;
   ops[20].doc = NULL;

   ops[21].func = reinterpret_cast<void*>(& ::_elm_gengrid_select_mode_set_wrapper<T>);
   ops[21].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_select_mode_set);
   ops[21].op = EO_OP_OVERRIDE;
   ops[21].op_type = EO_OP_TYPE_REGULAR;
   ops[21].doc = NULL;

   ops[22].func = reinterpret_cast<void*>(& ::_elm_gengrid_reorder_mode_get_wrapper<T>);
   ops[22].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_reorder_mode_get);
   ops[22].op = EO_OP_OVERRIDE;
   ops[22].op_type = EO_OP_TYPE_REGULAR;
   ops[22].doc = NULL;

   ops[23].func = reinterpret_cast<void*>(& ::_elm_gengrid_reorder_mode_set_wrapper<T>);
   ops[23].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_reorder_mode_set);
   ops[23].op = EO_OP_OVERRIDE;
   ops[23].op_type = EO_OP_TYPE_REGULAR;
   ops[23].doc = NULL;

   ops[24].func = reinterpret_cast<void*>(& ::_elm_gengrid_highlight_mode_get_wrapper<T>);
   ops[24].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_highlight_mode_get);
   ops[24].op = EO_OP_OVERRIDE;
   ops[24].op_type = EO_OP_TYPE_REGULAR;
   ops[24].doc = NULL;

   ops[25].func = reinterpret_cast<void*>(& ::_elm_gengrid_highlight_mode_set_wrapper<T>);
   ops[25].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_highlight_mode_set);
   ops[25].op = EO_OP_OVERRIDE;
   ops[25].op_type = EO_OP_TYPE_REGULAR;
   ops[25].doc = NULL;

   ops[26].func = reinterpret_cast<void*>(& ::_elm_gengrid_item_size_get_wrapper<T>);
   ops[26].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_item_size_get);
   ops[26].op = EO_OP_OVERRIDE;
   ops[26].op_type = EO_OP_TYPE_REGULAR;
   ops[26].doc = NULL;

   ops[27].func = reinterpret_cast<void*>(& ::_elm_gengrid_item_size_set_wrapper<T>);
   ops[27].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_item_size_set);
   ops[27].op = EO_OP_OVERRIDE;
   ops[27].op_type = EO_OP_TYPE_REGULAR;
   ops[27].doc = NULL;

   ops[28].func = reinterpret_cast<void*>(& ::_elm_gengrid_multi_select_mode_get_wrapper<T>);
   ops[28].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_multi_select_mode_get);
   ops[28].op = EO_OP_OVERRIDE;
   ops[28].op_type = EO_OP_TYPE_REGULAR;
   ops[28].doc = NULL;

   ops[29].func = reinterpret_cast<void*>(& ::_elm_gengrid_multi_select_mode_set_wrapper<T>);
   ops[29].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_multi_select_mode_set);
   ops[29].op = EO_OP_OVERRIDE;
   ops[29].op_type = EO_OP_TYPE_REGULAR;
   ops[29].doc = NULL;

   ops[30].func = reinterpret_cast<void*>(& ::_elm_gengrid_horizontal_get_wrapper<T>);
   ops[30].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_horizontal_get);
   ops[30].op = EO_OP_OVERRIDE;
   ops[30].op_type = EO_OP_TYPE_REGULAR;
   ops[30].doc = NULL;

   ops[31].func = reinterpret_cast<void*>(& ::_elm_gengrid_horizontal_set_wrapper<T>);
   ops[31].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_horizontal_set);
   ops[31].op = EO_OP_OVERRIDE;
   ops[31].op_type = EO_OP_TYPE_REGULAR;
   ops[31].doc = NULL;

   ops[32].func = reinterpret_cast<void*>(& ::_elm_gengrid_page_size_set_wrapper<T>);
   ops[32].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_page_size_set);
   ops[32].op = EO_OP_OVERRIDE;
   ops[32].op_type = EO_OP_TYPE_REGULAR;
   ops[32].doc = NULL;

   ops[33].func = reinterpret_cast<void*>(& ::_elm_gengrid_selected_item_get_wrapper<T>);
   ops[33].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_selected_item_get);
   ops[33].op = EO_OP_OVERRIDE;
   ops[33].op_type = EO_OP_TYPE_REGULAR;
   ops[33].doc = NULL;

   ops[34].func = reinterpret_cast<void*>(& ::_elm_gengrid_realized_items_get_wrapper<T>);
   ops[34].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_realized_items_get);
   ops[34].op = EO_OP_OVERRIDE;
   ops[34].op_type = EO_OP_TYPE_REGULAR;
   ops[34].doc = NULL;

   ops[35].func = reinterpret_cast<void*>(& ::_elm_gengrid_first_item_get_wrapper<T>);
   ops[35].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_first_item_get);
   ops[35].op = EO_OP_OVERRIDE;
   ops[35].op_type = EO_OP_TYPE_REGULAR;
   ops[35].doc = NULL;

   ops[36].func = reinterpret_cast<void*>(& ::_elm_gengrid_selected_items_get_wrapper<T>);
   ops[36].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_selected_items_get);
   ops[36].op = EO_OP_OVERRIDE;
   ops[36].op_type = EO_OP_TYPE_REGULAR;
   ops[36].doc = NULL;

   ops[37].func = reinterpret_cast<void*>(& ::_elm_gengrid_last_item_get_wrapper<T>);
   ops[37].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_last_item_get);
   ops[37].op = EO_OP_OVERRIDE;
   ops[37].op_type = EO_OP_TYPE_REGULAR;
   ops[37].doc = NULL;

   ops[38].func = reinterpret_cast<void*>(& ::_elm_gengrid_wheel_disabled_get_wrapper<T>);
   ops[38].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_wheel_disabled_get);
   ops[38].op = EO_OP_OVERRIDE;
   ops[38].op_type = EO_OP_TYPE_REGULAR;
   ops[38].doc = NULL;

   ops[39].func = reinterpret_cast<void*>(& ::_elm_gengrid_wheel_disabled_set_wrapper<T>);
   ops[39].api_func = reinterpret_cast<void*>(& ::elm_obj_gengrid_wheel_disabled_set);
   ops[39].op = EO_OP_OVERRIDE;
   ops[39].op_type = EO_OP_TYPE_REGULAR;
   ops[39].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_gengrid >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_gengrid, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_gengrid >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_gengrid, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_gengrid>
{
   template <typename U>
   struct type
   {
      operator ::elm_gengrid() const
      {
         return ::elm_gengrid(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      Elm_Object_Item * item_insert_before(const Elm_Gengrid_Item_Class * itc_, const void * data_, Elm_Object_Item * relative_, Evas_Smart_Cb func_, const void * func_data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_item_insert_before(itc_, data_, relative_, func_, func_data_));
            return _tmp_ret;
      }

      void realized_items_update()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_gengrid_realized_items_update());
      }

      Elm_Object_Item * item_insert_after(const Elm_Gengrid_Item_Class * itc_, const void * data_, Elm_Object_Item * relative_, Evas_Smart_Cb func_, const void * func_data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_item_insert_after(itc_, data_, relative_, func_, func_data_));
            return _tmp_ret;
      }

      unsigned int items_count()
      {
         unsigned int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_items_count());
            return _tmp_ret;
      }

      Elm_Object_Item * at_xy_item_get(Evas_Coord x_, Evas_Coord y_, int* xposret_, int* yposret_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_at_xy_item_get(x_, y_, xposret_, yposret_));
            return _tmp_ret;
      }

      Elm_Object_Item * item_append(const Elm_Gengrid_Item_Class * itc_, const void * data_, Evas_Smart_Cb func_, const void * func_data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_item_append(itc_, data_, func_, func_data_));
            return _tmp_ret;
      }

      Elm_Object_Item * item_prepend(const Elm_Gengrid_Item_Class * itc_, const void * data_, Evas_Smart_Cb func_, const void * func_data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_item_prepend(itc_, data_, func_, func_data_));
            return _tmp_ret;
      }

      void clear()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_gengrid_clear());
      }

      Elm_Object_Item * item_sorted_insert(const Elm_Gengrid_Item_Class * itc_, const void * data_, Eina_Compare_Cb comp_, Evas_Smart_Cb func_, const void * func_data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_item_sorted_insert(itc_, data_, comp_, func_, func_data_));
            return _tmp_ret;
      }

      Elm_Object_Item * search_by_text_item_get(Elm_Object_Item * item_to_search_from_, std::string part_name_, std::string pattern_, Elm_Glob_Match_Flags flags_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_search_by_text_item_get(item_to_search_from_, efl::eolian::to_c(part_name_), efl::eolian::to_c(pattern_), flags_));
            return _tmp_ret;
      }

      void align_get(double* align_x_, double* align_y_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_gengrid_align_get(align_x_, align_y_));
      }

      void align_set(double align_x_, double align_y_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_gengrid_align_set(align_x_, align_y_));
      }

      bool filled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_filled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void filled_set(bool fill_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_gengrid_filled_set(efl::eolian::to_c(fill_)));
      }

      void page_relative_get(double* h_pagerel_, double* v_pagerel_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_gengrid_page_relative_get(h_pagerel_, v_pagerel_));
      }

      void page_relative_set(double h_pagerel_, double v_pagerel_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_gengrid_page_relative_set(h_pagerel_, v_pagerel_));
      }

      bool multi_select_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_multi_select_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void multi_select_set(bool multi_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_gengrid_multi_select_set(efl::eolian::to_c(multi_)));
      }

      void group_item_size_get(Evas_Coord* w_, Evas_Coord* h_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_gengrid_group_item_size_get(w_, h_));
      }

      void group_item_size_set(Evas_Coord w_, Evas_Coord h_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_gengrid_group_item_size_set(w_, h_));
      }

      Elm_Object_Select_Mode select_mode_get()
      {
         Elm_Object_Select_Mode _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_select_mode_get());
            return _tmp_ret;
      }

      void select_mode_set(Elm_Object_Select_Mode mode_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_gengrid_select_mode_set(mode_));
      }

      bool reorder_mode_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_reorder_mode_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void reorder_mode_set(bool reorder_mode_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_gengrid_reorder_mode_set(efl::eolian::to_c(reorder_mode_)));
      }

      bool highlight_mode_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_highlight_mode_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void highlight_mode_set(bool highlight_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_gengrid_highlight_mode_set(efl::eolian::to_c(highlight_)));
      }

      void item_size_get(Evas_Coord* w_, Evas_Coord* h_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_gengrid_item_size_get(w_, h_));
      }

      void item_size_set(Evas_Coord w_, Evas_Coord h_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_gengrid_item_size_set(w_, h_));
      }

      Elm_Object_Multi_Select_Mode multi_select_mode_get()
      {
         Elm_Object_Multi_Select_Mode _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_multi_select_mode_get());
            return _tmp_ret;
      }

      void multi_select_mode_set(Elm_Object_Multi_Select_Mode mode_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_gengrid_multi_select_mode_set(mode_));
      }

      bool horizontal_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_horizontal_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void horizontal_set(bool horizontal_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_gengrid_horizontal_set(efl::eolian::to_c(horizontal_)));
      }

      void page_size_set(Evas_Coord h_pagesize_, Evas_Coord v_pagesize_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_gengrid_page_size_set(h_pagesize_, v_pagesize_));
      }

      Elm_Object_Item * selected_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_selected_item_get());
            return _tmp_ret;
      }

      Eina_List * realized_items_get()
      {
         Eina_List * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_realized_items_get());
            return _tmp_ret;
      }

      Elm_Object_Item * first_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_first_item_get());
            return _tmp_ret;
      }

      const Eina_List * selected_items_get()
      {
         const Eina_List * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_selected_items_get());
            return _tmp_ret;
      }

      Elm_Object_Item * last_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_last_item_get());
            return _tmp_ret;
      }

      bool wheel_disabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_gengrid_wheel_disabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void wheel_disabled_set(bool disabled_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_gengrid_wheel_disabled_set(efl::eolian::to_c(disabled_)));
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_GENGRID_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_gengrid, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_gengrid, function_type>,
         ELM_GENGRID_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_GENGRID_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_GENGRID_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_gengrid, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_gengrid, function_type>,
         ELM_GENGRID_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_GENGRID_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_GENGRID_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_gengrid, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_gengrid, function_type>,
         ELM_GENGRID_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_GENGRID_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_GENGRID_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_gengrid, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_gengrid, function_type>,
         ELM_GENGRID_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_GENGRID_EVENT_UNFOCUSED, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_gengrid>)
{
   return (ELM_GENGRID_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_GENGRID_HH

