#ifndef EFL_GENERATED_ELM_GENLIST_HH
#define EFL_GENERATED_ELM_GENLIST_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_genlist.eo.h"
}

#include "elm_layout.eo.hh"
#include "elm_interface_scrollable.eo.hh"
#include "evas_clickable_interface.eo.hh"
#include "elm_interface_atspi_widget_action.eo.hh"
#include <string>

struct elm_genlist
      : elm_layout,
      efl::eo::detail::extension_inheritance<elm_interface_scrollable>::template type< ::elm_genlist>,
      efl::eo::detail::extension_inheritance<evas::clickable_interface>::template type< ::elm_genlist>,
      efl::eo::detail::extension_inheritance<elm_interface_atspi_widget_action>::template type< ::elm_genlist>

{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_genlist(Eo* eo)
      : elm_layout(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_genlist(std::nullptr_t)
      : elm_layout(nullptr)
   {}

   elm_genlist(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_genlist(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_genlist(elm_genlist const& other)
      : elm_layout(eo_ref(other._eo_ptr()))
   {}

   ~elm_genlist() {}

   /// @brief Insert an item before another in a genlist widget
   ///
   /// @return A handle to the item added or @c NULL if not possible
   ///
   /// This inserts an item before another in the list. It will be in the
   /// same tree level or group as the item it is inserted before.
   ///
   /// @see elm_genlist_item_append()
   /// @see elm_genlist_item_prepend()
   /// @see elm_genlist_item_insert_after()
   /// @see elm_object_item_del()
   ///
   /// @ingroup Genlist
   ///
   /// @param itc The item class for the item
   /// @param data The item data
   /// @param parent The parent item, or NULL if none
   /// @param before_it The item to place this new one before.
   /// @param type Item type
   /// @param func Convenience function called when the item is selected
   /// @param func_data Data passed to @p func above.
   ///
   Elm_Object_Item * item_insert_before(const Elm_Genlist_Item_Class * itc_, const void * data_, Elm_Object_Item * parent_, Elm_Object_Item * before_it_, Elm_Genlist_Item_Type type_, Evas_Smart_Cb func_, const void * func_data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_genlist_item_insert_before(itc_, data_, parent_, before_it_, type_, func_, func_data_));
      return _tmp_ret;
   }

   /// @brief Update the contents of all realized items.
   ///
   /// This updates all realized items by calling all the item class functions again
   /// to get the contents, texts and states. Use this when the original
   /// item data has changed and the changes are desired to be reflected.
   ///
   /// To update just one item, use elm_genlist_item_update().
   ///
   /// @see elm_genlist_realized_items_get()
   /// @see elm_genlist_item_update()
   ///
   /// @ingroup Genlist
   ///
   void realized_items_update() const
   {
      eo_do(_eo_ptr(), ::elm_obj_genlist_realized_items_update());
   }

   /// @brief Insert an item after another in a genlist widget
   ///
   /// @return A handle to the item added or @c NULL if not possible
   ///
   /// This inserts an item after another in the list. It will be in the
   /// same tree level or group as the item it is inserted after.
   ///
   /// @see elm_genlist_item_append()
   /// @see elm_genlist_item_prepend()
   /// @see elm_genlist_item_insert_before()
   /// @see elm_object_item_del()
   ///
   /// @ingroup Genlist
   ///
   /// @param itc The item class for the item
   /// @param data The item data
   /// @param parent The parent item, or NULL if none
   /// @param after_it The item to place this new one after.
   /// @param type Item type
   /// @param func Convenience function called when the item is selected
   /// @param func_data Data passed to @p func above.
   ///
   Elm_Object_Item * item_insert_after(const Elm_Genlist_Item_Class * itc_, const void * data_, Elm_Object_Item * parent_, Elm_Object_Item * after_it_, Elm_Genlist_Item_Type type_, Evas_Smart_Cb func_, const void * func_data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_genlist_item_insert_after(itc_, data_, parent_, after_it_, type_, func_, func_data_));
      return _tmp_ret;
   }

   /// @brief Get the item that is at the x, y canvas coords.
   ///
   /// @return The item at the coordinates or NULL if none
   ///
   /// This returns the item at the given coordinates (which are canvas
   /// relative, not object-relative). If an item is at that coordinate,
   /// that item handle is returned, and if @p posret is not NULL, the
   /// integer pointed to is set to a value of -1, 0 or 1, depending if
   /// the coordinate is on the upper portion of that item (-1), on the
   /// middle section (0) or on the lower part (1). If NULL is returned as
   /// an item (no item found there), then posret may indicate -1 or 1
   /// based if the coordinate is above or below all items respectively in
   /// the genlist.
   ///
   /// @ingroup Genlist
   ///
   /// @param x The input x coordinate
   /// @param y The input y coordinate
   /// @param[out] posret The position relative to the item returned here
   ///
   Elm_Object_Item * at_xy_item_get(Evas_Coord x_, Evas_Coord y_, int* posret_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_genlist_at_xy_item_get(x_, y_, posret_));
      return _tmp_ret;
   }

   /// @brief Return how many items are currently in a list
   ///
   /// @return The total number of list items in the list
   ///
   /// This behavior is O(1) and includes items which may or may not be realized.
   ///
   /// @ingroup Genlist
   ///
   unsigned int items_count() const
   {
      unsigned int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_genlist_items_count());
      return _tmp_ret;
   }

   /// @brief Prepend a new item in a given genlist widget.
   ///
   /// @return A handle to the item added or NULL if not possible
   ///
   /// This adds an item to the beginning of the list or beginning of the
   /// children of the parent if given.
   ///
   /// @see elm_genlist_item_append()
   /// @see elm_genlist_item_insert_before()
   /// @see elm_genlist_item_insert_after()
   /// @see elm_object_item_del()
   ///
   /// @ingroup Genlist
   ///
   /// @param itc The item class for the item
   /// @param data The item data
   /// @param parent The parent item, or NULL if none
   /// @param type Item type
   /// @param func Convenience function called when the item is selected
   /// @param func_data Data passed to @p func above.
   ///
   Elm_Object_Item * item_prepend(const Elm_Genlist_Item_Class * itc_, const void * data_, Elm_Object_Item * parent_, Elm_Genlist_Item_Type type_, Evas_Smart_Cb func_, const void * func_data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_genlist_item_prepend(itc_, data_, parent_, type_, func_, func_data_));
      return _tmp_ret;
   }

   /// @brief Remove all items from a given genlist widget.
   ///
   /// This removes (and deletes) all items in @p obj, leaving it empty.
   ///
   /// @see elm_object_item_del(), to remove just one item.
   ///
   /// @ingroup Genlist
   ///
   void clear() const
   {
      eo_do(_eo_ptr(), ::elm_obj_genlist_clear());
   }

   /// @brief Append a new item in a given genlist widget.
   ///
   /// @return A handle to the item added or @c NULL if not possible
   ///
   /// This adds the given item to the end of the list or the end of
   /// the children list if the @p parent is given.
   ///
   /// @see elm_genlist_item_prepend()
   /// @see elm_genlist_item_insert_before()
   /// @see elm_genlist_item_insert_after()
   /// @see elm_object_item_del()
   ///
   /// @ingroup Genlist
   ///
   /// @param itc The item class for the item
   /// @param data The item data
   /// @param parent The parent item, or NULL if none
   /// @param type Item type
   /// @param func Convenience function called when the item is selected
   /// @param func_data Data passed to @p func above.
   ///
   Elm_Object_Item * item_append(const Elm_Genlist_Item_Class * itc_, const void * data_, Elm_Object_Item * parent_, Elm_Genlist_Item_Type type_, Evas_Smart_Cb func_, const void * func_data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_genlist_item_append(itc_, data_, parent_, type_, func_, func_data_));
      return _tmp_ret;
   }

   /// @brief Insert a new item into the sorted genlist object
   ///
   /// @return A handle to the item added or NULL if not possible
   ///
   /// This inserts an item in the genlist based on user defined comparison
   /// function. The two arguments passed to the function @p func are genlist item
   /// handles to compare.
   ///
   /// @see elm_genlist_item_append()
   /// @see elm_genlist_item_prepend()
   /// @see elm_genlist_item_insert_after()
   /// @see elm_object_item_del()
   ///
   /// @ingroup Genlist
   ///
   /// @param itc The item class for the item
   /// @param data The item data
   /// @param parent The parent item, or NULL if none
   /// @param type Item type
   /// @param comp The function called for the sort
   /// @param func Convenience function called when item selected
   /// @param func_data Data passed to @p func above.
   ///
   Elm_Object_Item * item_sorted_insert(const Elm_Genlist_Item_Class * itc_, const void * data_, Elm_Object_Item * parent_, Elm_Genlist_Item_Type type_, Eina_Compare_Cb comp_, Evas_Smart_Cb func_, const void * func_data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_genlist_item_sorted_insert(itc_, data_, parent_, type_, comp_, func_, func_data_));
      return _tmp_ret;
   }

   /// @brief Get genlist item by given string.
   ///
   /// @return Pointer to the genlist item which matches search_string in case of success, otherwise returns NULL.
   ///
   /// It takes pointer to the genlist item that will be used to start
   /// search from it.
   ///
   /// This function uses globs (like "*.jpg") for searching and takes
   /// search flags as last parameter That is a bitfield with values
   /// to be ored together or 0 for no flags.
   ///
   /// @ingroup Genlist
   /// @since 1.11
   ///
   /// @param item_to_search_from Pointer to item to start search from. If NULL search will be started from the first item of the genlist.
   /// @param part_name Name of the TEXT part of genlist item to search string in.
   /// @param pattern The search pattern.
   /// @param flags Search flags
   ///
   Elm_Object_Item * search_by_text_item_get(Elm_Object_Item * item_to_search_from_, std::string part_name_, std::string pattern_, Elm_Glob_Match_Flags flags_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_genlist_search_by_text_item_get(item_to_search_from_, efl::eolian::to_c(part_name_), efl::eolian::to_c(pattern_), flags_));
      return _tmp_ret;
   }

   /// @param homogeneous Assume the items within the genlist are of the
   /// same height and width (EINA_TRUE = on, EINA_FALSE = off). Default is @c
   /// EINA_FALSE.
   ///
   bool homogeneous_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_genlist_homogeneous_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param homogeneous Assume the items within the genlist are of the
   /// same height and width (EINA_TRUE = on, EINA_FALSE = off). Default is @c
   /// EINA_FALSE.
   ///
   void homogeneous_set(bool homogeneous_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_genlist_homogeneous_set(efl::eolian::to_c(homogeneous_)));
   }

   /// @param mode The select mode
   ///
   Elm_Object_Select_Mode select_mode_get() const
   {
      Elm_Object_Select_Mode _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_genlist_select_mode_get());
      return _tmp_ret;
   }

   /// @param mode The select mode
   ///
   void select_mode_set(Elm_Object_Select_Mode mode_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_genlist_select_mode_set(mode_));
   }

   /// @param enabled The tree effect status
   /// (EINA_TRUE = enabled, EINA_FALSE = disabled)
   ///
   bool focus_on_selection_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_genlist_focus_on_selection_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param enabled The tree effect status
   /// (EINA_TRUE = enabled, EINA_FALSE = disabled)
   ///
   void focus_on_selection_set(bool enabled_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_genlist_focus_on_selection_set(efl::eolian::to_c(enabled_)));
   }

   /// @param timeout timeout in seconds. Default is elm config value(1.0)
   ///
   double longpress_timeout_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_genlist_longpress_timeout_get());
      return _tmp_ret;
   }

   /// @param timeout timeout in seconds. Default is elm config value(1.0)
   ///
   void longpress_timeout_set(double timeout_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_genlist_longpress_timeout_set(timeout_));
   }

   /// @param multi Multi-select enable/disable. Default is disabled.
   ///
   bool multi_select_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_genlist_multi_select_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param multi Multi-select enable/disable. Default is disabled.
   ///
   void multi_select_set(bool multi_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_genlist_multi_select_set(efl::eolian::to_c(multi_)));
   }

   /// @param reorder_mode The reorder mode
   /// (EINA_TRUE = on, EINA_FALSE = off)
   ///
   bool reorder_mode_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_genlist_reorder_mode_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param reorder_mode The reorder mode
   /// (EINA_TRUE = on, EINA_FALSE = off)
   ///
   void reorder_mode_set(bool reorder_mode_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_genlist_reorder_mode_set(efl::eolian::to_c(reorder_mode_)));
   }

   /// @param decorated The decorate mode status
   /// (EINA_TRUE = decorate mode, EINA_FALSE = normal mode
   ///
   bool decorate_mode_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_genlist_decorate_mode_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param decorated The decorate mode status
   /// (EINA_TRUE = decorate mode, EINA_FALSE = normal mode
   ///
   void decorate_mode_set(bool decorated_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_genlist_decorate_mode_set(efl::eolian::to_c(decorated_)));
   }

   /// @param mode The multi select mode
   ///
   Elm_Object_Multi_Select_Mode multi_select_mode_get() const
   {
      Elm_Object_Multi_Select_Mode _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_genlist_multi_select_mode_get());
      return _tmp_ret;
   }

   /// @param mode The multi select mode
   ///
   void multi_select_mode_set(Elm_Object_Multi_Select_Mode mode_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_genlist_multi_select_mode_set(mode_));
   }

   /// @param count Maximum number of items within an item block. Default is 32.
   ///
   int block_count_get() const
   {
      int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_genlist_block_count_get());
      return _tmp_ret;
   }

   /// @param count Maximum number of items within an item block. Default is 32.
   ///
   void block_count_set(int count_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_genlist_block_count_set(count_));
   }

   /// @param enabled The tree effect status
   /// (EINA_TRUE = enabled, EINA_FALSE = disabled
   ///
   bool tree_effect_enabled_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_genlist_tree_effect_enabled_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param enabled The tree effect status
   /// (EINA_TRUE = enabled, EINA_FALSE = disabled
   ///
   void tree_effect_enabled_set(bool enabled_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_genlist_tree_effect_enabled_set(efl::eolian::to_c(enabled_)));
   }

   /// @param highlight @c EINA_TRUE to enable highlighting or @c EINA_FALSE to
   /// disable it.
   ///
   bool highlight_mode_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_genlist_highlight_mode_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param highlight @c EINA_TRUE to enable highlighting or @c EINA_FALSE to
   /// disable it.
   ///
   void highlight_mode_set(bool highlight_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_genlist_highlight_mode_set(efl::eolian::to_c(highlight_)));
   }

   /// @param mode The mode to use (one of #ELM_LIST_SCROLL or #ELM_LIST_LIMIT).
   ///
   Elm_List_Mode mode_get() const
   {
      Elm_List_Mode _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_genlist_mode_get());
      return _tmp_ret;
   }

   /// @param mode The mode to use (one of #ELM_LIST_SCROLL or #ELM_LIST_LIMIT).
   ///
   void mode_set(Elm_List_Mode mode_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_genlist_mode_set(mode_));
   }

   Elm_Object_Item * decorated_item_get() const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_genlist_decorated_item_get());
      return _tmp_ret;
   }

   Elm_Object_Item * selected_item_get() const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_genlist_selected_item_get());
      return _tmp_ret;
   }

   Elm_Object_Item * first_item_get() const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_genlist_first_item_get());
      return _tmp_ret;
   }

   Eina_List * realized_items_get() const
   {
      Eina_List * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_genlist_realized_items_get());
      return _tmp_ret;
   }

   const Eina_List * selected_items_get() const
   {
      const Eina_List * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_genlist_selected_items_get());
      return _tmp_ret;
   }

   Elm_Object_Item * last_item_get() const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_genlist_last_item_get());
      return _tmp_ret;
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_GENLIST_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_genlist, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_genlist, function_type>,
         ELM_GENLIST_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_GENLIST_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_GENLIST_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_genlist, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_genlist, function_type>,
         ELM_GENLIST_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_GENLIST_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_GENLIST_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_genlist, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_genlist, function_type>,
         ELM_GENLIST_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_GENLIST_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_GENLIST_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_genlist, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_genlist, function_type>,
         ELM_GENLIST_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_GENLIST_EVENT_UNFOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_item_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_GENLIST_EVENT_ITEM_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_genlist, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_genlist, function_type>,
         ELM_GENLIST_EVENT_ITEM_FOCUSED );
   }

   template <typename T>
   void
   callback_item_focused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_GENLIST_EVENT_ITEM_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_item_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_GENLIST_EVENT_ITEM_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_genlist, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_genlist, function_type>,
         ELM_GENLIST_EVENT_ITEM_UNFOCUSED );
   }

   template <typename T>
   void
   callback_item_unfocused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_GENLIST_EVENT_ITEM_UNFOCUSED, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_GENLIST_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_GENLIST_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
Elm_Object_Item * _elm_genlist_item_insert_before_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const Elm_Genlist_Item_Class * itc_, const void * data_, Elm_Object_Item * parent_, Elm_Object_Item * before_it_, Elm_Genlist_Item_Type type_, Evas_Smart_Cb func_, const void * func_data_)
{
   return static_cast<T*>(self->this_)->item_insert_before(itc_, data_, parent_, before_it_, type_, func_, func_data_);
}

template <typename T>
void _elm_genlist_realized_items_update_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->realized_items_update();
}

template <typename T>
Elm_Object_Item * _elm_genlist_item_insert_after_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const Elm_Genlist_Item_Class * itc_, const void * data_, Elm_Object_Item * parent_, Elm_Object_Item * after_it_, Elm_Genlist_Item_Type type_, Evas_Smart_Cb func_, const void * func_data_)
{
   return static_cast<T*>(self->this_)->item_insert_after(itc_, data_, parent_, after_it_, type_, func_, func_data_);
}

template <typename T>
Elm_Object_Item * _elm_genlist_at_xy_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord x_, Evas_Coord y_, int* posret_)
{
   return static_cast<T*>(self->this_)->at_xy_item_get(x_, y_, posret_);
}

template <typename T>
unsigned int _elm_genlist_items_count_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->items_count();
}

template <typename T>
Elm_Object_Item * _elm_genlist_item_prepend_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const Elm_Genlist_Item_Class * itc_, const void * data_, Elm_Object_Item * parent_, Elm_Genlist_Item_Type type_, Evas_Smart_Cb func_, const void * func_data_)
{
   return static_cast<T*>(self->this_)->item_prepend(itc_, data_, parent_, type_, func_, func_data_);
}

template <typename T>
void _elm_genlist_clear_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->clear();
}

template <typename T>
Elm_Object_Item * _elm_genlist_item_append_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const Elm_Genlist_Item_Class * itc_, const void * data_, Elm_Object_Item * parent_, Elm_Genlist_Item_Type type_, Evas_Smart_Cb func_, const void * func_data_)
{
   return static_cast<T*>(self->this_)->item_append(itc_, data_, parent_, type_, func_, func_data_);
}

template <typename T>
Elm_Object_Item * _elm_genlist_item_sorted_insert_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const Elm_Genlist_Item_Class * itc_, const void * data_, Elm_Object_Item * parent_, Elm_Genlist_Item_Type type_, Eina_Compare_Cb comp_, Evas_Smart_Cb func_, const void * func_data_)
{
   return static_cast<T*>(self->this_)->item_sorted_insert(itc_, data_, parent_, type_, comp_, func_, func_data_);
}

template <typename T>
Elm_Object_Item * _elm_genlist_search_by_text_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Object_Item * item_to_search_from_, const char * part_name_, const char * pattern_, Elm_Glob_Match_Flags flags_)
{
   return static_cast<T*>(self->this_)->search_by_text_item_get(item_to_search_from_, efl::eolian::to_cxx<std::string>(part_name_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(pattern_, std::tuple<std::false_type>()), flags_);
}

template <typename T>
bool _elm_genlist_homogeneous_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->homogeneous_get();
}

template <typename T>
void _elm_genlist_homogeneous_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool homogeneous_)
{
   static_cast<T*>(self->this_)->homogeneous_set(efl::eolian::to_cxx<bool>(homogeneous_, std::tuple<std::false_type>()));
}

template <typename T>
Elm_Object_Select_Mode _elm_genlist_select_mode_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->select_mode_get();
}

template <typename T>
void _elm_genlist_select_mode_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Object_Select_Mode mode_)
{
   static_cast<T*>(self->this_)->select_mode_set(mode_);
}

template <typename T>
bool _elm_genlist_focus_on_selection_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->focus_on_selection_get();
}

template <typename T>
void _elm_genlist_focus_on_selection_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool enabled_)
{
   static_cast<T*>(self->this_)->focus_on_selection_set(efl::eolian::to_cxx<bool>(enabled_, std::tuple<std::false_type>()));
}

template <typename T>
double _elm_genlist_longpress_timeout_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->longpress_timeout_get();
}

template <typename T>
void _elm_genlist_longpress_timeout_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double timeout_)
{
   static_cast<T*>(self->this_)->longpress_timeout_set(timeout_);
}

template <typename T>
bool _elm_genlist_multi_select_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->multi_select_get();
}

template <typename T>
void _elm_genlist_multi_select_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool multi_)
{
   static_cast<T*>(self->this_)->multi_select_set(efl::eolian::to_cxx<bool>(multi_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_genlist_reorder_mode_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->reorder_mode_get();
}

template <typename T>
void _elm_genlist_reorder_mode_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool reorder_mode_)
{
   static_cast<T*>(self->this_)->reorder_mode_set(efl::eolian::to_cxx<bool>(reorder_mode_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_genlist_decorate_mode_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->decorate_mode_get();
}

template <typename T>
void _elm_genlist_decorate_mode_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool decorated_)
{
   static_cast<T*>(self->this_)->decorate_mode_set(efl::eolian::to_cxx<bool>(decorated_, std::tuple<std::false_type>()));
}

template <typename T>
Elm_Object_Multi_Select_Mode _elm_genlist_multi_select_mode_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->multi_select_mode_get();
}

template <typename T>
void _elm_genlist_multi_select_mode_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Object_Multi_Select_Mode mode_)
{
   static_cast<T*>(self->this_)->multi_select_mode_set(mode_);
}

template <typename T>
int _elm_genlist_block_count_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->block_count_get();
}

template <typename T>
void _elm_genlist_block_count_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int count_)
{
   static_cast<T*>(self->this_)->block_count_set(count_);
}

template <typename T>
bool _elm_genlist_tree_effect_enabled_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->tree_effect_enabled_get();
}

template <typename T>
void _elm_genlist_tree_effect_enabled_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool enabled_)
{
   static_cast<T*>(self->this_)->tree_effect_enabled_set(efl::eolian::to_cxx<bool>(enabled_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_genlist_highlight_mode_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->highlight_mode_get();
}

template <typename T>
void _elm_genlist_highlight_mode_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool highlight_)
{
   static_cast<T*>(self->this_)->highlight_mode_set(efl::eolian::to_cxx<bool>(highlight_, std::tuple<std::false_type>()));
}

template <typename T>
Elm_List_Mode _elm_genlist_mode_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->mode_get();
}

template <typename T>
void _elm_genlist_mode_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_List_Mode mode_)
{
   static_cast<T*>(self->this_)->mode_set(mode_);
}

template <typename T>
Elm_Object_Item * _elm_genlist_decorated_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->decorated_item_get();
}

template <typename T>
Elm_Object_Item * _elm_genlist_selected_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->selected_item_get();
}

template <typename T>
Elm_Object_Item * _elm_genlist_first_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->first_item_get();
}

template <typename T>
Eina_List * _elm_genlist_realized_items_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->realized_items_get();
}

template <typename T>
const Eina_List * _elm_genlist_selected_items_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->selected_items_get();
}

template <typename T>
Elm_Object_Item * _elm_genlist_last_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->last_item_get();
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_genlist >
{
   template <typename T>
   struct type
   {
      virtual Elm_Object_Item * item_insert_before(const Elm_Genlist_Item_Class * itc_, const void * data_, Elm_Object_Item * parent_, Elm_Object_Item * before_it_, Elm_Genlist_Item_Type type_, Evas_Smart_Cb func_, const void * func_data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_genlist_item_insert_before(itc_, data_, parent_, before_it_, type_, func_, func_data_));
            return _tmp_ret;
      }

      virtual void realized_items_update()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_genlist_realized_items_update());
      }

      virtual Elm_Object_Item * item_insert_after(const Elm_Genlist_Item_Class * itc_, const void * data_, Elm_Object_Item * parent_, Elm_Object_Item * after_it_, Elm_Genlist_Item_Type type_, Evas_Smart_Cb func_, const void * func_data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_genlist_item_insert_after(itc_, data_, parent_, after_it_, type_, func_, func_data_));
            return _tmp_ret;
      }

      virtual Elm_Object_Item * at_xy_item_get(Evas_Coord x_, Evas_Coord y_, int* posret_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_genlist_at_xy_item_get(x_, y_, posret_));
            return _tmp_ret;
      }

      virtual unsigned int items_count()
      {
         unsigned int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_genlist_items_count());
            return _tmp_ret;
      }

      virtual Elm_Object_Item * item_prepend(const Elm_Genlist_Item_Class * itc_, const void * data_, Elm_Object_Item * parent_, Elm_Genlist_Item_Type type_, Evas_Smart_Cb func_, const void * func_data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_genlist_item_prepend(itc_, data_, parent_, type_, func_, func_data_));
            return _tmp_ret;
      }

      virtual void clear()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_genlist_clear());
      }

      virtual Elm_Object_Item * item_append(const Elm_Genlist_Item_Class * itc_, const void * data_, Elm_Object_Item * parent_, Elm_Genlist_Item_Type type_, Evas_Smart_Cb func_, const void * func_data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_genlist_item_append(itc_, data_, parent_, type_, func_, func_data_));
            return _tmp_ret;
      }

      virtual Elm_Object_Item * item_sorted_insert(const Elm_Genlist_Item_Class * itc_, const void * data_, Elm_Object_Item * parent_, Elm_Genlist_Item_Type type_, Eina_Compare_Cb comp_, Evas_Smart_Cb func_, const void * func_data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_genlist_item_sorted_insert(itc_, data_, parent_, type_, comp_, func_, func_data_));
            return _tmp_ret;
      }

      virtual Elm_Object_Item * search_by_text_item_get(Elm_Object_Item * item_to_search_from_, std::string part_name_, std::string pattern_, Elm_Glob_Match_Flags flags_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_genlist_search_by_text_item_get(item_to_search_from_, efl::eolian::to_c(part_name_), efl::eolian::to_c(pattern_), flags_));
            return _tmp_ret;
      }

      virtual bool homogeneous_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_genlist_homogeneous_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void homogeneous_set(bool homogeneous_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_genlist_homogeneous_set(efl::eolian::to_c(homogeneous_)));
      }

      virtual Elm_Object_Select_Mode select_mode_get()
      {
         Elm_Object_Select_Mode _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_genlist_select_mode_get());
            return _tmp_ret;
      }

      virtual void select_mode_set(Elm_Object_Select_Mode mode_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_genlist_select_mode_set(mode_));
      }

      virtual bool focus_on_selection_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_genlist_focus_on_selection_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void focus_on_selection_set(bool enabled_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_genlist_focus_on_selection_set(efl::eolian::to_c(enabled_)));
      }

      virtual double longpress_timeout_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_genlist_longpress_timeout_get());
            return _tmp_ret;
      }

      virtual void longpress_timeout_set(double timeout_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_genlist_longpress_timeout_set(timeout_));
      }

      virtual bool multi_select_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_genlist_multi_select_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void multi_select_set(bool multi_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_genlist_multi_select_set(efl::eolian::to_c(multi_)));
      }

      virtual bool reorder_mode_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_genlist_reorder_mode_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void reorder_mode_set(bool reorder_mode_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_genlist_reorder_mode_set(efl::eolian::to_c(reorder_mode_)));
      }

      virtual bool decorate_mode_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_genlist_decorate_mode_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void decorate_mode_set(bool decorated_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_genlist_decorate_mode_set(efl::eolian::to_c(decorated_)));
      }

      virtual Elm_Object_Multi_Select_Mode multi_select_mode_get()
      {
         Elm_Object_Multi_Select_Mode _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_genlist_multi_select_mode_get());
            return _tmp_ret;
      }

      virtual void multi_select_mode_set(Elm_Object_Multi_Select_Mode mode_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_genlist_multi_select_mode_set(mode_));
      }

      virtual int block_count_get()
      {
         int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_genlist_block_count_get());
            return _tmp_ret;
      }

      virtual void block_count_set(int count_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_genlist_block_count_set(count_));
      }

      virtual bool tree_effect_enabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_genlist_tree_effect_enabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void tree_effect_enabled_set(bool enabled_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_genlist_tree_effect_enabled_set(efl::eolian::to_c(enabled_)));
      }

      virtual bool highlight_mode_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_genlist_highlight_mode_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void highlight_mode_set(bool highlight_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_genlist_highlight_mode_set(efl::eolian::to_c(highlight_)));
      }

      virtual Elm_List_Mode mode_get()
      {
         Elm_List_Mode _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_genlist_mode_get());
            return _tmp_ret;
      }

      virtual void mode_set(Elm_List_Mode mode_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_genlist_mode_set(mode_));
      }

      virtual Elm_Object_Item * decorated_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_genlist_decorated_item_get());
            return _tmp_ret;
      }

      virtual Elm_Object_Item * selected_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_genlist_selected_item_get());
            return _tmp_ret;
      }

      virtual Elm_Object_Item * first_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_genlist_first_item_get());
            return _tmp_ret;
      }

      virtual Eina_List * realized_items_get()
      {
         Eina_List * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_genlist_realized_items_get());
            return _tmp_ret;
      }

      virtual const Eina_List * selected_items_get()
      {
         const Eina_List * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_genlist_selected_items_get());
            return _tmp_ret;
      }

      virtual Elm_Object_Item * last_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_genlist_last_item_get());
            return _tmp_ret;
      }

   };
};


template<>
struct operation_description_class_size< ::elm_genlist >
{
   static const int value = 40;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_genlist>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_genlist_item_insert_before_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_item_insert_before);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_genlist_realized_items_update_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_realized_items_update);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_genlist_item_insert_after_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_item_insert_after);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_genlist_at_xy_item_get_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_at_xy_item_get);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_genlist_items_count_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_items_count);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_genlist_item_prepend_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_item_prepend);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_genlist_clear_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_clear);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_genlist_item_append_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_item_append);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_genlist_item_sorted_insert_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_item_sorted_insert);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_genlist_search_by_text_item_get_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_search_by_text_item_get);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::_elm_genlist_homogeneous_get_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_homogeneous_get);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::_elm_genlist_homogeneous_set_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_homogeneous_set);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::_elm_genlist_select_mode_get_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_select_mode_get);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::_elm_genlist_select_mode_set_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_select_mode_set);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::_elm_genlist_focus_on_selection_get_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_focus_on_selection_get);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::_elm_genlist_focus_on_selection_set_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_focus_on_selection_set);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   ops[16].func = reinterpret_cast<void*>(& ::_elm_genlist_longpress_timeout_get_wrapper<T>);
   ops[16].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_longpress_timeout_get);
   ops[16].op = EO_OP_OVERRIDE;
   ops[16].op_type = EO_OP_TYPE_REGULAR;
   ops[16].doc = NULL;

   ops[17].func = reinterpret_cast<void*>(& ::_elm_genlist_longpress_timeout_set_wrapper<T>);
   ops[17].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_longpress_timeout_set);
   ops[17].op = EO_OP_OVERRIDE;
   ops[17].op_type = EO_OP_TYPE_REGULAR;
   ops[17].doc = NULL;

   ops[18].func = reinterpret_cast<void*>(& ::_elm_genlist_multi_select_get_wrapper<T>);
   ops[18].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_multi_select_get);
   ops[18].op = EO_OP_OVERRIDE;
   ops[18].op_type = EO_OP_TYPE_REGULAR;
   ops[18].doc = NULL;

   ops[19].func = reinterpret_cast<void*>(& ::_elm_genlist_multi_select_set_wrapper<T>);
   ops[19].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_multi_select_set);
   ops[19].op = EO_OP_OVERRIDE;
   ops[19].op_type = EO_OP_TYPE_REGULAR;
   ops[19].doc = NULL;

   ops[20].func = reinterpret_cast<void*>(& ::_elm_genlist_reorder_mode_get_wrapper<T>);
   ops[20].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_reorder_mode_get);
   ops[20].op = EO_OP_OVERRIDE;
   ops[20].op_type = EO_OP_TYPE_REGULAR;
   ops[20].doc = NULL;

   ops[21].func = reinterpret_cast<void*>(& ::_elm_genlist_reorder_mode_set_wrapper<T>);
   ops[21].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_reorder_mode_set);
   ops[21].op = EO_OP_OVERRIDE;
   ops[21].op_type = EO_OP_TYPE_REGULAR;
   ops[21].doc = NULL;

   ops[22].func = reinterpret_cast<void*>(& ::_elm_genlist_decorate_mode_get_wrapper<T>);
   ops[22].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_decorate_mode_get);
   ops[22].op = EO_OP_OVERRIDE;
   ops[22].op_type = EO_OP_TYPE_REGULAR;
   ops[22].doc = NULL;

   ops[23].func = reinterpret_cast<void*>(& ::_elm_genlist_decorate_mode_set_wrapper<T>);
   ops[23].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_decorate_mode_set);
   ops[23].op = EO_OP_OVERRIDE;
   ops[23].op_type = EO_OP_TYPE_REGULAR;
   ops[23].doc = NULL;

   ops[24].func = reinterpret_cast<void*>(& ::_elm_genlist_multi_select_mode_get_wrapper<T>);
   ops[24].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_multi_select_mode_get);
   ops[24].op = EO_OP_OVERRIDE;
   ops[24].op_type = EO_OP_TYPE_REGULAR;
   ops[24].doc = NULL;

   ops[25].func = reinterpret_cast<void*>(& ::_elm_genlist_multi_select_mode_set_wrapper<T>);
   ops[25].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_multi_select_mode_set);
   ops[25].op = EO_OP_OVERRIDE;
   ops[25].op_type = EO_OP_TYPE_REGULAR;
   ops[25].doc = NULL;

   ops[26].func = reinterpret_cast<void*>(& ::_elm_genlist_block_count_get_wrapper<T>);
   ops[26].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_block_count_get);
   ops[26].op = EO_OP_OVERRIDE;
   ops[26].op_type = EO_OP_TYPE_REGULAR;
   ops[26].doc = NULL;

   ops[27].func = reinterpret_cast<void*>(& ::_elm_genlist_block_count_set_wrapper<T>);
   ops[27].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_block_count_set);
   ops[27].op = EO_OP_OVERRIDE;
   ops[27].op_type = EO_OP_TYPE_REGULAR;
   ops[27].doc = NULL;

   ops[28].func = reinterpret_cast<void*>(& ::_elm_genlist_tree_effect_enabled_get_wrapper<T>);
   ops[28].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_tree_effect_enabled_get);
   ops[28].op = EO_OP_OVERRIDE;
   ops[28].op_type = EO_OP_TYPE_REGULAR;
   ops[28].doc = NULL;

   ops[29].func = reinterpret_cast<void*>(& ::_elm_genlist_tree_effect_enabled_set_wrapper<T>);
   ops[29].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_tree_effect_enabled_set);
   ops[29].op = EO_OP_OVERRIDE;
   ops[29].op_type = EO_OP_TYPE_REGULAR;
   ops[29].doc = NULL;

   ops[30].func = reinterpret_cast<void*>(& ::_elm_genlist_highlight_mode_get_wrapper<T>);
   ops[30].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_highlight_mode_get);
   ops[30].op = EO_OP_OVERRIDE;
   ops[30].op_type = EO_OP_TYPE_REGULAR;
   ops[30].doc = NULL;

   ops[31].func = reinterpret_cast<void*>(& ::_elm_genlist_highlight_mode_set_wrapper<T>);
   ops[31].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_highlight_mode_set);
   ops[31].op = EO_OP_OVERRIDE;
   ops[31].op_type = EO_OP_TYPE_REGULAR;
   ops[31].doc = NULL;

   ops[32].func = reinterpret_cast<void*>(& ::_elm_genlist_mode_get_wrapper<T>);
   ops[32].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_mode_get);
   ops[32].op = EO_OP_OVERRIDE;
   ops[32].op_type = EO_OP_TYPE_REGULAR;
   ops[32].doc = NULL;

   ops[33].func = reinterpret_cast<void*>(& ::_elm_genlist_mode_set_wrapper<T>);
   ops[33].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_mode_set);
   ops[33].op = EO_OP_OVERRIDE;
   ops[33].op_type = EO_OP_TYPE_REGULAR;
   ops[33].doc = NULL;

   ops[34].func = reinterpret_cast<void*>(& ::_elm_genlist_decorated_item_get_wrapper<T>);
   ops[34].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_decorated_item_get);
   ops[34].op = EO_OP_OVERRIDE;
   ops[34].op_type = EO_OP_TYPE_REGULAR;
   ops[34].doc = NULL;

   ops[35].func = reinterpret_cast<void*>(& ::_elm_genlist_selected_item_get_wrapper<T>);
   ops[35].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_selected_item_get);
   ops[35].op = EO_OP_OVERRIDE;
   ops[35].op_type = EO_OP_TYPE_REGULAR;
   ops[35].doc = NULL;

   ops[36].func = reinterpret_cast<void*>(& ::_elm_genlist_first_item_get_wrapper<T>);
   ops[36].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_first_item_get);
   ops[36].op = EO_OP_OVERRIDE;
   ops[36].op_type = EO_OP_TYPE_REGULAR;
   ops[36].doc = NULL;

   ops[37].func = reinterpret_cast<void*>(& ::_elm_genlist_realized_items_get_wrapper<T>);
   ops[37].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_realized_items_get);
   ops[37].op = EO_OP_OVERRIDE;
   ops[37].op_type = EO_OP_TYPE_REGULAR;
   ops[37].doc = NULL;

   ops[38].func = reinterpret_cast<void*>(& ::_elm_genlist_selected_items_get_wrapper<T>);
   ops[38].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_selected_items_get);
   ops[38].op = EO_OP_OVERRIDE;
   ops[38].op_type = EO_OP_TYPE_REGULAR;
   ops[38].doc = NULL;

   ops[39].func = reinterpret_cast<void*>(& ::_elm_genlist_last_item_get_wrapper<T>);
   ops[39].api_func = reinterpret_cast<void*>(& ::elm_obj_genlist_last_item_get);
   ops[39].op = EO_OP_OVERRIDE;
   ops[39].op_type = EO_OP_TYPE_REGULAR;
   ops[39].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_genlist >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_genlist, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_genlist >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_genlist, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_genlist>
{
   template <typename U>
   struct type
   {
      operator ::elm_genlist() const
      {
         return ::elm_genlist(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      Elm_Object_Item * item_insert_before(const Elm_Genlist_Item_Class * itc_, const void * data_, Elm_Object_Item * parent_, Elm_Object_Item * before_it_, Elm_Genlist_Item_Type type_, Evas_Smart_Cb func_, const void * func_data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_genlist_item_insert_before(itc_, data_, parent_, before_it_, type_, func_, func_data_));
            return _tmp_ret;
      }

      void realized_items_update()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_genlist_realized_items_update());
      }

      Elm_Object_Item * item_insert_after(const Elm_Genlist_Item_Class * itc_, const void * data_, Elm_Object_Item * parent_, Elm_Object_Item * after_it_, Elm_Genlist_Item_Type type_, Evas_Smart_Cb func_, const void * func_data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_genlist_item_insert_after(itc_, data_, parent_, after_it_, type_, func_, func_data_));
            return _tmp_ret;
      }

      Elm_Object_Item * at_xy_item_get(Evas_Coord x_, Evas_Coord y_, int* posret_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_genlist_at_xy_item_get(x_, y_, posret_));
            return _tmp_ret;
      }

      unsigned int items_count()
      {
         unsigned int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_genlist_items_count());
            return _tmp_ret;
      }

      Elm_Object_Item * item_prepend(const Elm_Genlist_Item_Class * itc_, const void * data_, Elm_Object_Item * parent_, Elm_Genlist_Item_Type type_, Evas_Smart_Cb func_, const void * func_data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_genlist_item_prepend(itc_, data_, parent_, type_, func_, func_data_));
            return _tmp_ret;
      }

      void clear()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_genlist_clear());
      }

      Elm_Object_Item * item_append(const Elm_Genlist_Item_Class * itc_, const void * data_, Elm_Object_Item * parent_, Elm_Genlist_Item_Type type_, Evas_Smart_Cb func_, const void * func_data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_genlist_item_append(itc_, data_, parent_, type_, func_, func_data_));
            return _tmp_ret;
      }

      Elm_Object_Item * item_sorted_insert(const Elm_Genlist_Item_Class * itc_, const void * data_, Elm_Object_Item * parent_, Elm_Genlist_Item_Type type_, Eina_Compare_Cb comp_, Evas_Smart_Cb func_, const void * func_data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_genlist_item_sorted_insert(itc_, data_, parent_, type_, comp_, func_, func_data_));
            return _tmp_ret;
      }

      Elm_Object_Item * search_by_text_item_get(Elm_Object_Item * item_to_search_from_, std::string part_name_, std::string pattern_, Elm_Glob_Match_Flags flags_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_genlist_search_by_text_item_get(item_to_search_from_, efl::eolian::to_c(part_name_), efl::eolian::to_c(pattern_), flags_));
            return _tmp_ret;
      }

      bool homogeneous_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_genlist_homogeneous_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void homogeneous_set(bool homogeneous_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_genlist_homogeneous_set(efl::eolian::to_c(homogeneous_)));
      }

      Elm_Object_Select_Mode select_mode_get()
      {
         Elm_Object_Select_Mode _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_genlist_select_mode_get());
            return _tmp_ret;
      }

      void select_mode_set(Elm_Object_Select_Mode mode_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_genlist_select_mode_set(mode_));
      }

      bool focus_on_selection_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_genlist_focus_on_selection_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void focus_on_selection_set(bool enabled_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_genlist_focus_on_selection_set(efl::eolian::to_c(enabled_)));
      }

      double longpress_timeout_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_genlist_longpress_timeout_get());
            return _tmp_ret;
      }

      void longpress_timeout_set(double timeout_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_genlist_longpress_timeout_set(timeout_));
      }

      bool multi_select_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_genlist_multi_select_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void multi_select_set(bool multi_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_genlist_multi_select_set(efl::eolian::to_c(multi_)));
      }

      bool reorder_mode_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_genlist_reorder_mode_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void reorder_mode_set(bool reorder_mode_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_genlist_reorder_mode_set(efl::eolian::to_c(reorder_mode_)));
      }

      bool decorate_mode_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_genlist_decorate_mode_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void decorate_mode_set(bool decorated_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_genlist_decorate_mode_set(efl::eolian::to_c(decorated_)));
      }

      Elm_Object_Multi_Select_Mode multi_select_mode_get()
      {
         Elm_Object_Multi_Select_Mode _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_genlist_multi_select_mode_get());
            return _tmp_ret;
      }

      void multi_select_mode_set(Elm_Object_Multi_Select_Mode mode_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_genlist_multi_select_mode_set(mode_));
      }

      int block_count_get()
      {
         int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_genlist_block_count_get());
            return _tmp_ret;
      }

      void block_count_set(int count_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_genlist_block_count_set(count_));
      }

      bool tree_effect_enabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_genlist_tree_effect_enabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void tree_effect_enabled_set(bool enabled_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_genlist_tree_effect_enabled_set(efl::eolian::to_c(enabled_)));
      }

      bool highlight_mode_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_genlist_highlight_mode_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void highlight_mode_set(bool highlight_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_genlist_highlight_mode_set(efl::eolian::to_c(highlight_)));
      }

      Elm_List_Mode mode_get()
      {
         Elm_List_Mode _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_genlist_mode_get());
            return _tmp_ret;
      }

      void mode_set(Elm_List_Mode mode_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_genlist_mode_set(mode_));
      }

      Elm_Object_Item * decorated_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_genlist_decorated_item_get());
            return _tmp_ret;
      }

      Elm_Object_Item * selected_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_genlist_selected_item_get());
            return _tmp_ret;
      }

      Elm_Object_Item * first_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_genlist_first_item_get());
            return _tmp_ret;
      }

      Eina_List * realized_items_get()
      {
         Eina_List * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_genlist_realized_items_get());
            return _tmp_ret;
      }

      const Eina_List * selected_items_get()
      {
         const Eina_List * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_genlist_selected_items_get());
            return _tmp_ret;
      }

      Elm_Object_Item * last_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_genlist_last_item_get());
            return _tmp_ret;
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_GENLIST_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_genlist, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_genlist, function_type>,
         ELM_GENLIST_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_GENLIST_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_GENLIST_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_genlist, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_genlist, function_type>,
         ELM_GENLIST_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_GENLIST_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_GENLIST_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_genlist, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_genlist, function_type>,
         ELM_GENLIST_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_GENLIST_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_GENLIST_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_genlist, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_genlist, function_type>,
         ELM_GENLIST_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_GENLIST_EVENT_UNFOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_item_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_GENLIST_EVENT_ITEM_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_genlist, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_genlist, function_type>,
         ELM_GENLIST_EVENT_ITEM_FOCUSED );
   }

   template <typename T>
   void
   callback_item_focused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_GENLIST_EVENT_ITEM_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_item_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_GENLIST_EVENT_ITEM_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_genlist, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_genlist, function_type>,
         ELM_GENLIST_EVENT_ITEM_UNFOCUSED );
   }

   template <typename T>
   void
   callback_item_unfocused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_GENLIST_EVENT_ITEM_UNFOCUSED, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_genlist>)
{
   return (ELM_GENLIST_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_GENLIST_HH

