#ifndef EFL_GENERATED_ELM_GESTURE_LAYER_HH
#define EFL_GENERATED_ELM_GESTURE_LAYER_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_gesture_layer.eo.h"
}

#include "elm_widget.eo.hh"
#include <canvas/evas_object.eo.hh>

struct elm_gesture_layer
      : elm_widget
{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_gesture_layer(Eo* eo)
      : elm_widget(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_gesture_layer(std::nullptr_t)
      : elm_widget(nullptr)
   {}

   elm_gesture_layer(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_gesture_layer(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_gesture_layer(elm_gesture_layer const& other)
      : elm_widget(eo_ref(other._eo_ptr()))
   {}

   ~elm_gesture_layer() {}

   /// @brief Attach a given gesture layer widget to an Evas object, thus setting
   /// the widget's @b target.
   ///
   /// A gesture layer target may be whichever Evas object one
   /// chooses. This will be object @a obj will listen all mouse and key
   /// events from, to report the gestures made upon it back.
   ///
   /// @return @c EINA_TRUE, on success, @c EINA_FALSE otherwise.
   ///
   /// @param target Object to attach to @a obj (target)
   ///
   bool attach(evas::object target_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_gesture_layer_attach(efl::eolian::to_c(target_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Use this function to remove a callback that has been added
   /// to be notified about change of state of gesture.
   ///
   /// @param idx The gesture you would like to track its state.
   /// @param cb_type what event this callback tracks: START, MOVE, END, ABORT.
   /// @param cb callback function pointer.
   /// @param data user info for the callback (usually, Smart Data)
   ///
   void cb_del(Elm_Gesture_Type idx_, Elm_Gesture_State cb_type_, Elm_Gesture_Event_Cb cb_, void * data_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_gesture_layer_cb_del(idx_, cb_type_, cb_, data_));
   }

   /// @brief Use function to add callbacks to be notified about
   /// change of state of gesture.
   /// When a user registers a callback with this function
   /// this means this gesture has to be tested.
   ///
   /// When ALL callbacks for a gesture are set to NULL
   /// it means user isn't interested in gesture-state
   /// and it will not be tested.
   ///
   /// If a function was already set for this gesture/type/state, it will be
   /// replaced by the new one. For ABI compat, callbacks added by
   /// elm_gesture_layer_cb_add will be removed. It is recommended to
   /// use only one of these functions for a gesture object.
   ///
   /// @param idx The gesture you would like to track its state.
   /// @param cb_type what event this callback tracks: START, MOVE, END, ABORT.
   /// @param cb callback function pointer.
   /// @param data user info to be sent to callback (usually, Smart Data)
   ///
   void cb_add(Elm_Gesture_Type idx_, Elm_Gesture_State cb_type_, Elm_Gesture_Event_Cb cb_, void * data_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_gesture_layer_cb_add(idx_, cb_type_, cb_, data_));
   }

   /// @param step new zoom step value.
   ///
   double zoom_step_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_gesture_layer_zoom_step_get());
      return _tmp_ret;
   }

   /// @param step new zoom step value.
   ///
   void zoom_step_set(double step_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_gesture_layer_zoom_step_set(step_));
   }

   /// @param sz Finger size
   ///
   Evas_Coord tap_finger_size_get() const
   {
      Evas_Coord _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_gesture_layer_tap_finger_size_get());
      return _tmp_ret;
   }

   /// @param sz Finger size
   ///
   void tap_finger_size_set(Evas_Coord sz_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_gesture_layer_tap_finger_size_set(sz_));
   }

   /// @param hold_events hold events or not.
   ///
   bool hold_events_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_gesture_layer_hold_events_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param hold_events hold events or not.
   ///
   void hold_events_set(bool hold_events_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_gesture_layer_hold_events_set(efl::eolian::to_c(hold_events_)));
   }

   /// @param step new rotate step value.
   ///
   double rotate_step_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_gesture_layer_rotate_step_get());
      return _tmp_ret;
   }

   /// @param step new rotate step value.
   ///
   void rotate_step_set(double step_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_gesture_layer_rotate_step_set(step_));
   }

   /// @param idx The gesture you would like to track its state.
   /// @param cb_type what event this callback tracks: START, MOVE, END, ABORT.
   /// @param cb callback function pointer.
   /// @param data user info to be sent to callback (usually, Smart Data)
   ///
   void cb_set(Elm_Gesture_Type idx_, Elm_Gesture_State cb_type_, Elm_Gesture_Event_Cb cb_, void * data_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_gesture_layer_cb_set(idx_, cb_type_, cb_, data_));
   }

   static Eo_Class const* _eo_class()
   {
      return(ELM_GESTURE_LAYER_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_GESTURE_LAYER_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
bool _elm_gesture_layer_attach_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * target_)
{
   return static_cast<T*>(self->this_)->attach(efl::eolian::to_cxx<evas::object>(target_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_gesture_layer_cb_del_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Gesture_Type idx_, Elm_Gesture_State cb_type_, Elm_Gesture_Event_Cb cb_, void * data_)
{
   static_cast<T*>(self->this_)->cb_del(idx_, cb_type_, cb_, data_);
}

template <typename T>
void _elm_gesture_layer_cb_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Gesture_Type idx_, Elm_Gesture_State cb_type_, Elm_Gesture_Event_Cb cb_, void * data_)
{
   static_cast<T*>(self->this_)->cb_add(idx_, cb_type_, cb_, data_);
}

template <typename T>
double _elm_gesture_layer_zoom_step_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->zoom_step_get();
}

template <typename T>
void _elm_gesture_layer_zoom_step_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double step_)
{
   static_cast<T*>(self->this_)->zoom_step_set(step_);
}

template <typename T>
Evas_Coord _elm_gesture_layer_tap_finger_size_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->tap_finger_size_get();
}

template <typename T>
void _elm_gesture_layer_tap_finger_size_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord sz_)
{
   static_cast<T*>(self->this_)->tap_finger_size_set(sz_);
}

template <typename T>
bool _elm_gesture_layer_hold_events_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->hold_events_get();
}

template <typename T>
void _elm_gesture_layer_hold_events_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool hold_events_)
{
   static_cast<T*>(self->this_)->hold_events_set(efl::eolian::to_cxx<bool>(hold_events_, std::tuple<std::false_type>()));
}

template <typename T>
double _elm_gesture_layer_rotate_step_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->rotate_step_get();
}

template <typename T>
void _elm_gesture_layer_rotate_step_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double step_)
{
   static_cast<T*>(self->this_)->rotate_step_set(step_);
}

template <typename T>
void _elm_gesture_layer_cb_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Gesture_Type idx_, Elm_Gesture_State cb_type_, Elm_Gesture_Event_Cb cb_, void * data_)
{
   static_cast<T*>(self->this_)->cb_set(idx_, cb_type_, cb_, data_);
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_gesture_layer >
{
   template <typename T>
   struct type
   {
      virtual bool attach(evas::object target_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_gesture_layer_attach(efl::eolian::to_c(target_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void cb_del(Elm_Gesture_Type idx_, Elm_Gesture_State cb_type_, Elm_Gesture_Event_Cb cb_, void * data_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_gesture_layer_cb_del(idx_, cb_type_, cb_, data_));
      }

      virtual void cb_add(Elm_Gesture_Type idx_, Elm_Gesture_State cb_type_, Elm_Gesture_Event_Cb cb_, void * data_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_gesture_layer_cb_add(idx_, cb_type_, cb_, data_));
      }

      virtual double zoom_step_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_gesture_layer_zoom_step_get());
            return _tmp_ret;
      }

      virtual void zoom_step_set(double step_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_gesture_layer_zoom_step_set(step_));
      }

      virtual Evas_Coord tap_finger_size_get()
      {
         Evas_Coord _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_gesture_layer_tap_finger_size_get());
            return _tmp_ret;
      }

      virtual void tap_finger_size_set(Evas_Coord sz_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_gesture_layer_tap_finger_size_set(sz_));
      }

      virtual bool hold_events_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_gesture_layer_hold_events_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void hold_events_set(bool hold_events_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_gesture_layer_hold_events_set(efl::eolian::to_c(hold_events_)));
      }

      virtual double rotate_step_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_gesture_layer_rotate_step_get());
            return _tmp_ret;
      }

      virtual void rotate_step_set(double step_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_gesture_layer_rotate_step_set(step_));
      }

      virtual void cb_set(Elm_Gesture_Type idx_, Elm_Gesture_State cb_type_, Elm_Gesture_Event_Cb cb_, void * data_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_gesture_layer_cb_set(idx_, cb_type_, cb_, data_));
      }

   };
};


template<>
struct operation_description_class_size< ::elm_gesture_layer >
{
   static const int value = 12;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_gesture_layer>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_gesture_layer_attach_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_gesture_layer_attach);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_gesture_layer_cb_del_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_gesture_layer_cb_del);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_gesture_layer_cb_add_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_gesture_layer_cb_add);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_gesture_layer_zoom_step_get_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_gesture_layer_zoom_step_get);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_gesture_layer_zoom_step_set_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_gesture_layer_zoom_step_set);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_gesture_layer_tap_finger_size_get_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_gesture_layer_tap_finger_size_get);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_gesture_layer_tap_finger_size_set_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_gesture_layer_tap_finger_size_set);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_gesture_layer_hold_events_get_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_gesture_layer_hold_events_get);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_gesture_layer_hold_events_set_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_gesture_layer_hold_events_set);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_gesture_layer_rotate_step_get_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_gesture_layer_rotate_step_get);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::_elm_gesture_layer_rotate_step_set_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::elm_obj_gesture_layer_rotate_step_set);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::_elm_gesture_layer_cb_set_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::elm_obj_gesture_layer_cb_set);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_gesture_layer >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_gesture_layer, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_gesture_layer >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_gesture_layer, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_gesture_layer>
{
   template <typename U>
   struct type
   {
      operator ::elm_gesture_layer() const
      {
         return ::elm_gesture_layer(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      bool attach(evas::object target_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_gesture_layer_attach(efl::eolian::to_c(target_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void cb_del(Elm_Gesture_Type idx_, Elm_Gesture_State cb_type_, Elm_Gesture_Event_Cb cb_, void * data_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_gesture_layer_cb_del(idx_, cb_type_, cb_, data_));
      }

      void cb_add(Elm_Gesture_Type idx_, Elm_Gesture_State cb_type_, Elm_Gesture_Event_Cb cb_, void * data_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_gesture_layer_cb_add(idx_, cb_type_, cb_, data_));
      }

      double zoom_step_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_gesture_layer_zoom_step_get());
            return _tmp_ret;
      }

      void zoom_step_set(double step_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_gesture_layer_zoom_step_set(step_));
      }

      Evas_Coord tap_finger_size_get()
      {
         Evas_Coord _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_gesture_layer_tap_finger_size_get());
            return _tmp_ret;
      }

      void tap_finger_size_set(Evas_Coord sz_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_gesture_layer_tap_finger_size_set(sz_));
      }

      bool hold_events_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_gesture_layer_hold_events_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void hold_events_set(bool hold_events_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_gesture_layer_hold_events_set(efl::eolian::to_c(hold_events_)));
      }

      double rotate_step_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_gesture_layer_rotate_step_get());
            return _tmp_ret;
      }

      void rotate_step_set(double step_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_gesture_layer_rotate_step_set(step_));
      }

      void cb_set(Elm_Gesture_Type idx_, Elm_Gesture_State cb_type_, Elm_Gesture_Event_Cb cb_, void * data_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_gesture_layer_cb_set(idx_, cb_type_, cb_, data_));
      }

   };
};

inline Eo_Class const* get_eo_class(tag<::elm_gesture_layer>)
{
   return (ELM_GESTURE_LAYER_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_GESTURE_LAYER_HH

