#ifndef EFL_GENERATED_ELM_HOVER_HH
#define EFL_GENERATED_ELM_HOVER_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_hover.eo.h"
}

#include "elm_layout.eo.hh"
#include "evas_clickable_interface.eo.hh"
#include <canvas/evas_object.eo.hh>

struct elm_hover
      : elm_layout,
      efl::eo::detail::extension_inheritance<evas::clickable_interface>::template type< ::elm_hover>

{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_hover(Eo* eo)
      : elm_layout(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_hover(std::nullptr_t)
      : elm_layout(nullptr)
   {}

   elm_hover(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_hover(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_hover(elm_hover const& other)
      : elm_layout(eo_ref(other._eo_ptr()))
   {}

   ~elm_hover() {}

   /// @brief @brief Returns the best swallow location for content in the hover.
   ///
   /// @return The edje location to place content into the hover or @c
   /// NULL, on errors.
   ///
   /// Best is defined here as the location at which there is the most available
   /// space.
   ///
   /// @p pref_axis may be one of
   /// - @c ELM_HOVER_AXIS_NONE -- no preferred orientation
   /// - @c ELM_HOVER_AXIS_HORIZONTAL -- horizontal
   /// - @c ELM_HOVER_AXIS_VERTICAL -- vertical
   /// - @c ELM_HOVER_AXIS_BOTH -- both
   ///
   /// If ELM_HOVER_AXIS_HORIZONTAL is chosen the returned position will
   /// necessarily be along the horizontal axis("left" or "right"). If
   /// ELM_HOVER_AXIS_VERTICAL is chosen the returned position will necessarily
   /// be along the vertical axis("top" or "bottom"). Choosing
   /// ELM_HOVER_AXIS_BOTH or ELM_HOVER_AXIS_NONE has the same effect and the
   /// returned position may be in either axis.
   ///
   /// @see elm_object_part_content_set()
   ///
   /// @ingroup Hover
   ///
   /// @param pref_axis The preferred orientation axis for the hover object to use
   ///
   std::string best_content_location_get(Elm_Hover_Axis pref_axis_) const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_hover_best_content_location_get(pref_axis_));
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief @brief Dismiss a hover object
   ///
   /// @ingroup Hover
   ///
   void dismiss() const
   {
      eo_do(_eo_ptr(), ::elm_obj_hover_dismiss());
   }

   /// @param target The object to center the hover onto.
   ///
   evas::object target_get() const
   {
      Evas_Object * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_hover_target_get());
      return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param target The object to center the hover onto.
   ///
   void target_set(evas::object target_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_hover_target_set(efl::eolian::to_c(target_)));
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_HOVER_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_hover, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_hover, function_type>,
         ELM_HOVER_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_HOVER_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_HOVER_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_hover, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_hover, function_type>,
         ELM_HOVER_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_HOVER_EVENT_UNFOCUSED, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_HOVER_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_HOVER_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
std::string _elm_hover_best_content_location_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Hover_Axis pref_axis_)
{
   return static_cast<T*>(self->this_)->best_content_location_get(pref_axis_);
}

template <typename T>
void _elm_hover_dismiss_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->dismiss();
}

template <typename T>
evas::object _elm_hover_target_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->target_get();
}

template <typename T>
void _elm_hover_target_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * target_)
{
   static_cast<T*>(self->this_)->target_set(efl::eolian::to_cxx<evas::object>(target_, std::tuple<std::false_type>()));
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_hover >
{
   template <typename T>
   struct type
   {
      virtual std::string best_content_location_get(Elm_Hover_Axis pref_axis_)
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_hover_best_content_location_get(pref_axis_));
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void dismiss()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_hover_dismiss());
      }

      virtual evas::object target_get()
      {
         Evas_Object * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_hover_target_get());
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void target_set(evas::object target_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_hover_target_set(efl::eolian::to_c(target_)));
      }

   };
};


template<>
struct operation_description_class_size< ::elm_hover >
{
   static const int value = 4;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_hover>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_hover_best_content_location_get_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_hover_best_content_location_get);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_hover_dismiss_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_hover_dismiss);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_hover_target_get_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_hover_target_get);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_hover_target_set_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_hover_target_set);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_hover >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_hover, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_hover >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_hover, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_hover>
{
   template <typename U>
   struct type
   {
      operator ::elm_hover() const
      {
         return ::elm_hover(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      std::string best_content_location_get(Elm_Hover_Axis pref_axis_)
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_hover_best_content_location_get(pref_axis_));
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      void dismiss()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_hover_dismiss());
      }

      evas::object target_get()
      {
         Evas_Object * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_hover_target_get());
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      void target_set(evas::object target_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_hover_target_set(efl::eolian::to_c(target_)));
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_HOVER_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_hover, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_hover, function_type>,
         ELM_HOVER_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_HOVER_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_HOVER_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_hover, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_hover, function_type>,
         ELM_HOVER_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_HOVER_EVENT_UNFOCUSED, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_hover>)
{
   return (ELM_HOVER_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_HOVER_HH

