#ifndef EFL_GENERATED_ELM_INDEX_HH
#define EFL_GENERATED_ELM_INDEX_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_index.eo.h"
}

#include "elm_layout.eo.hh"
#include <string>

struct elm_index
      : elm_layout
{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_index(Eo* eo)
      : elm_layout(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_index(std::nullptr_t)
      : elm_layout(nullptr)
   {}

   elm_index(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_index(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_index(elm_index const& other)
      : elm_layout(eo_ref(other._eo_ptr()))
   {}

   ~elm_index() {}

   /// @brief Flush the changes made to the index items so they work correctly
   ///
   /// This flushes any changes made to items indicating the object is ready to
   /// go. You should call this before any changes you expect to work. This
   /// is similar to elm_list_go().
   ///
   /// @warning If not called, it won't display the index properly.
   ///
   /// @ingroup Index
   ///
   /// @param level The index level (one of @c 0 or @c 1) where changes were made
   ///
   void level_go(int level_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_index_level_go(level_));
   }

   /// @brief Prepend a new item on a given index widget.
   ///
   /// @return A handle to the item added or @c NULL, on errors
   ///
   /// Despite the most common usage of the @p letter argument is for
   /// single char strings, one could use arbitrary strings as index
   /// entries.
   ///
   /// @c item will be the pointer returned back on @c "changed", @c
   /// "delay,changed" and @c "selected" smart events.
   ///
   /// @ingroup Index
   ///
   /// @param letter Letter under which the item should be indexed
   /// @param func The function to call when the item is selected.
   /// @param data The item data to set for the index's item
   ///
   Elm_Object_Item * item_prepend(std::string letter_, Evas_Smart_Cb func_, const void * data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_index_item_prepend(efl::eolian::to_c(letter_), func_, data_));
      return _tmp_ret;
   }

   /// @brief Removes @b all items from a given index widget.
   ///
   /// If deletion callbacks are set, via elm_object_item_del_cb_set(),
   /// that callback function will be called for each item in @p obj.
   ///
   /// @ingroup Index
   ///
   void item_clear() const
   {
      eo_do(_eo_ptr(), ::elm_obj_index_item_clear());
   }

   /// @brief Insert a new item into the index object after item @p after.
   ///
   /// @return A handle to the item added or @c NULL, on errors
   ///
   /// Despite the most common usage of the @p letter argument is for
   /// single char strings, one could use arbitrary strings as index
   /// entries.
   ///
   /// @c item will be the pointer returned back on @c "changed", @c
   /// "delay,changed" and @c "selected" smart events.
   ///
   /// @note If @p relative is @c NULL this function will behave as
   /// elm_index_item_append().
   ///
   /// @ingroup Index
   ///
   /// @param after The index item to insert after.
   /// @param letter Letter under which the item should be indexed
   /// @param func The function to call when the item is clicked.
   /// @param data The item data to set for the index's item
   ///
   Elm_Object_Item * item_insert_after(Elm_Object_Item * after_, std::string letter_, Evas_Smart_Cb func_, const void * data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_index_item_insert_after(after_, efl::eolian::to_c(letter_), func_, data_));
      return _tmp_ret;
   }

   /// @brief Find a given index widget's item, <b>using item data</b>.
   ///
   /// @return The index item handle, if found, or @c NULL otherwise
   ///
   /// @ingroup Index
   ///
   /// @param data The item data pointed to by the desired index item
   ///
   Elm_Object_Item * item_find(const void * data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_index_item_find(data_));
      return _tmp_ret;
   }

   /// @brief Insert a new item into the index object before item @p before.
   ///
   /// @return A handle to the item added or @c NULL, on errors
   ///
   /// Despite the most common usage of the @p letter argument is for
   /// single char strings, one could use arbitrary strings as index
   /// entries.
   ///
   /// @c item will be the pointer returned back on @c "changed", @c
   /// "delay,changed" and @c "selected" smart events.
   ///
   /// @note If @p relative is @c NULL this function will behave as
   /// elm_index_item_prepend().
   ///
   /// @ingroup Index
   ///
   /// @param before The index item to insert after.
   /// @param letter Letter under which the item should be indexed
   /// @param func The function to call when the item is clicked.
   /// @param data The item data to set for the index's item
   ///
   Elm_Object_Item * item_insert_before(Elm_Object_Item * before_, std::string letter_, Evas_Smart_Cb func_, const void * data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_index_item_insert_before(before_, efl::eolian::to_c(letter_), func_, data_));
      return _tmp_ret;
   }

   /// @brief Append a new item on a given index widget.
   ///
   /// @return A handle to the item added or @c NULL, on errors
   ///
   /// Despite the most common usage of the @p letter argument is for
   /// single char strings, one could use arbitrary strings as index
   /// entries.
   ///
   /// @c item will be the pointer returned back on @c "changed", @c
   /// "delay,changed" and @c "selected" smart events.
   ///
   /// @ingroup Index
   ///
   /// @param letter Letter under which the item should be indexed
   /// @param func The function to call when the item is selected.
   /// @param data The item data to set for the index's item
   ///
   Elm_Object_Item * item_append(std::string letter_, Evas_Smart_Cb func_, const void * data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_index_item_append(efl::eolian::to_c(letter_), func_, data_));
      return _tmp_ret;
   }

   /// @brief Returns the last selected item, for a given index widget.
   ///
   /// @return The last item @b selected on @p obj (or @c NULL, on errors).
   ///
   /// @ingroup Index
   ///
   /// @param level @c 0 or @c 1, the currently implemented levels.
   ///
   Elm_Object_Item * selected_item_get(int level_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_index_selected_item_get(level_));
      return _tmp_ret;
   }

   /// @brief Insert a new item into the given index widget, using @p cmp_func
   /// function to sort items (by item handles).
   ///
   /// @return A handle to the item added or @c NULL, on errors
   ///
   /// Despite the most common usage of the @p letter argument is for
   /// single char strings, one could use arbitrary strings as index
   /// entries.
   ///
   /// @c item will be the pointer returned back on @c "changed", @c
   /// "delay,changed" and @c "selected" smart events.
   ///
   /// @ingroup Index
   ///
   /// @param letter Letter under which the item should be indexed
   /// @param func The function to call when the item is clicked.
   /// @param data The item data to set for the index's item
   /// @param cmp_func The comparing function to be used to sort index
   /// items <b>by index item handles</b>
   /// @param cmp_data_func A @b fallback function to be called for the
   /// sorting of index items <b>by item data</b>). It will be used
   /// when @p cmp_func returns @c 0 (equality), which means an index
   /// item with provided item data already exists. To decide which
   /// data item should be pointed to by the index item in question, @p
   /// cmp_data_func will be used. If @p cmp_data_func returns a
   /// non-negative value, the previous index item data will be
   /// replaced by the given @p item pointer. If the previous data need
   /// to be freed, it should be done by the @p cmp_data_func function,
   /// because all references to it will be lost. If this function is
   /// not provided (@c NULL is given), index items will be @b
   /// duplicated, if @p cmp_func returns @c 0.
   ///
   Elm_Object_Item * item_sorted_insert(std::string letter_, Evas_Smart_Cb func_, const void * data_, Eina_Compare_Cb cmp_func_, Eina_Compare_Cb cmp_data_func_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_index_item_sorted_insert(efl::eolian::to_c(letter_), func_, data_, cmp_func_, cmp_data_func_));
      return _tmp_ret;
   }

   /// @param disabled @c EINA_TRUE to disable auto hiding, @c EINA_FALSE to enable
   ///
   bool autohide_disabled_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_index_autohide_disabled_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param disabled @c EINA_TRUE to disable auto hiding, @c EINA_FALSE to enable
   ///
   void autohide_disabled_set(bool disabled_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_index_autohide_disabled_set(efl::eolian::to_c(disabled_)));
   }

   /// @param enabled @c EINA_TRUE to enable omit feature, @c EINA_FALSE to disable
   ///
   bool omit_enabled_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_index_omit_enabled_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param enabled @c EINA_TRUE to enable omit feature, @c EINA_FALSE to disable
   ///
   void omit_enabled_set(bool enabled_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_index_omit_enabled_set(efl::eolian::to_c(enabled_)));
   }

   /// @param horizontal @c EINA_TRUE to enable horizontal or @c EINA_FALSE to
   /// disable it, i.e., to enable vertical mode. it's an area one @ref Fingers
   /// "finger" wide on the bottom side of the index widget's container.
   ///
   bool horizontal_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_index_horizontal_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param horizontal @c EINA_TRUE to enable horizontal or @c EINA_FALSE to
   /// disable it, i.e., to enable vertical mode. it's an area one @ref Fingers
   /// "finger" wide on the bottom side of the index widget's container.
   ///
   void horizontal_set(bool horizontal_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_index_horizontal_set(efl::eolian::to_c(horizontal_)));
   }

   /// @param dtime The delay change time to set.
   ///
   double delay_change_time_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_index_delay_change_time_get());
      return _tmp_ret;
   }

   /// @param dtime The delay change time to set.
   ///
   void delay_change_time_set(double dtime_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_index_delay_change_time_set(dtime_));
   }

   /// @param disabled @c EINA_TRUE to disable it, @c EINA_FALSE to enable it
   ///
   bool indicator_disabled_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_index_indicator_disabled_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param disabled @c EINA_TRUE to disable it, @c EINA_FALSE to enable it
   ///
   void indicator_disabled_set(bool disabled_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_index_indicator_disabled_set(efl::eolian::to_c(disabled_)));
   }

   /// @param level @c 0 or @c 1, the currently implemented levels.
   ///
   int item_level_get() const
   {
      int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_index_item_level_get());
      return _tmp_ret;
   }

   /// @param level @c 0 or @c 1, the currently implemented levels.
   ///
   void item_level_set(int level_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_index_item_level_set(level_));
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_INDEX_EVENT_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_index, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_index, function_type>,
         ELM_INDEX_EVENT_CHANGED );
   }

   template <typename T>
   void
   callback_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_INDEX_EVENT_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_delay_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_INDEX_EVENT_DELAY_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_index, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_index, function_type>,
         ELM_INDEX_EVENT_DELAY_CHANGED );
   }

   template <typename T>
   void
   callback_delay_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_INDEX_EVENT_DELAY_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_selected_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_INDEX_EVENT_SELECTED, priority_,
            &efl::eo::_detail::event_callback<::elm_index, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_index, function_type>,
         ELM_INDEX_EVENT_SELECTED );
   }

   template <typename T>
   void
   callback_selected_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_INDEX_EVENT_SELECTED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_level_up_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_INDEX_EVENT_LEVEL_UP, priority_,
            &efl::eo::_detail::event_callback<::elm_index, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_index, function_type>,
         ELM_INDEX_EVENT_LEVEL_UP );
   }

   template <typename T>
   void
   callback_level_up_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_INDEX_EVENT_LEVEL_UP, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_level_down_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_INDEX_EVENT_LEVEL_DOWN, priority_,
            &efl::eo::_detail::event_callback<::elm_index, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_index, function_type>,
         ELM_INDEX_EVENT_LEVEL_DOWN );
   }

   template <typename T>
   void
   callback_level_down_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_INDEX_EVENT_LEVEL_DOWN, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_INDEX_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_index, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_index, function_type>,
         ELM_INDEX_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_INDEX_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_INDEX_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_index, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_index, function_type>,
         ELM_INDEX_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_INDEX_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_INDEX_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_index, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_index, function_type>,
         ELM_INDEX_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_INDEX_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_INDEX_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_index, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_index, function_type>,
         ELM_INDEX_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_INDEX_EVENT_UNFOCUSED, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_INDEX_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_INDEX_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
void _elm_index_level_go_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int level_)
{
   static_cast<T*>(self->this_)->level_go(level_);
}

template <typename T>
Elm_Object_Item * _elm_index_item_prepend_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * letter_, Evas_Smart_Cb func_, const void * data_)
{
   return static_cast<T*>(self->this_)->item_prepend(efl::eolian::to_cxx<std::string>(letter_, std::tuple<std::false_type>()), func_, data_);
}

template <typename T>
void _elm_index_item_clear_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->item_clear();
}

template <typename T>
Elm_Object_Item * _elm_index_item_insert_after_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Object_Item * after_, const char * letter_, Evas_Smart_Cb func_, const void * data_)
{
   return static_cast<T*>(self->this_)->item_insert_after(after_, efl::eolian::to_cxx<std::string>(letter_, std::tuple<std::false_type>()), func_, data_);
}

template <typename T>
Elm_Object_Item * _elm_index_item_find_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const void * data_)
{
   return static_cast<T*>(self->this_)->item_find(data_);
}

template <typename T>
Elm_Object_Item * _elm_index_item_insert_before_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Object_Item * before_, const char * letter_, Evas_Smart_Cb func_, const void * data_)
{
   return static_cast<T*>(self->this_)->item_insert_before(before_, efl::eolian::to_cxx<std::string>(letter_, std::tuple<std::false_type>()), func_, data_);
}

template <typename T>
Elm_Object_Item * _elm_index_item_append_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * letter_, Evas_Smart_Cb func_, const void * data_)
{
   return static_cast<T*>(self->this_)->item_append(efl::eolian::to_cxx<std::string>(letter_, std::tuple<std::false_type>()), func_, data_);
}

template <typename T>
Elm_Object_Item * _elm_index_selected_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int level_)
{
   return static_cast<T*>(self->this_)->selected_item_get(level_);
}

template <typename T>
Elm_Object_Item * _elm_index_item_sorted_insert_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * letter_, Evas_Smart_Cb func_, const void * data_, Eina_Compare_Cb cmp_func_, Eina_Compare_Cb cmp_data_func_)
{
   return static_cast<T*>(self->this_)->item_sorted_insert(efl::eolian::to_cxx<std::string>(letter_, std::tuple<std::false_type>()), func_, data_, cmp_func_, cmp_data_func_);
}

template <typename T>
bool _elm_index_autohide_disabled_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->autohide_disabled_get();
}

template <typename T>
void _elm_index_autohide_disabled_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool disabled_)
{
   static_cast<T*>(self->this_)->autohide_disabled_set(efl::eolian::to_cxx<bool>(disabled_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_index_omit_enabled_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->omit_enabled_get();
}

template <typename T>
void _elm_index_omit_enabled_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool enabled_)
{
   static_cast<T*>(self->this_)->omit_enabled_set(efl::eolian::to_cxx<bool>(enabled_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_index_horizontal_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->horizontal_get();
}

template <typename T>
void _elm_index_horizontal_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool horizontal_)
{
   static_cast<T*>(self->this_)->horizontal_set(efl::eolian::to_cxx<bool>(horizontal_, std::tuple<std::false_type>()));
}

template <typename T>
double _elm_index_delay_change_time_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->delay_change_time_get();
}

template <typename T>
void _elm_index_delay_change_time_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double dtime_)
{
   static_cast<T*>(self->this_)->delay_change_time_set(dtime_);
}

template <typename T>
bool _elm_index_indicator_disabled_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->indicator_disabled_get();
}

template <typename T>
void _elm_index_indicator_disabled_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool disabled_)
{
   static_cast<T*>(self->this_)->indicator_disabled_set(efl::eolian::to_cxx<bool>(disabled_, std::tuple<std::false_type>()));
}

template <typename T>
int _elm_index_item_level_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->item_level_get();
}

template <typename T>
void _elm_index_item_level_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int level_)
{
   static_cast<T*>(self->this_)->item_level_set(level_);
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_index >
{
   template <typename T>
   struct type
   {
      virtual void level_go(int level_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_index_level_go(level_));
      }

      virtual Elm_Object_Item * item_prepend(std::string letter_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_index_item_prepend(efl::eolian::to_c(letter_), func_, data_));
            return _tmp_ret;
      }

      virtual void item_clear()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_index_item_clear());
      }

      virtual Elm_Object_Item * item_insert_after(Elm_Object_Item * after_, std::string letter_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_index_item_insert_after(after_, efl::eolian::to_c(letter_), func_, data_));
            return _tmp_ret;
      }

      virtual Elm_Object_Item * item_find(const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_index_item_find(data_));
            return _tmp_ret;
      }

      virtual Elm_Object_Item * item_insert_before(Elm_Object_Item * before_, std::string letter_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_index_item_insert_before(before_, efl::eolian::to_c(letter_), func_, data_));
            return _tmp_ret;
      }

      virtual Elm_Object_Item * item_append(std::string letter_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_index_item_append(efl::eolian::to_c(letter_), func_, data_));
            return _tmp_ret;
      }

      virtual Elm_Object_Item * selected_item_get(int level_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_index_selected_item_get(level_));
            return _tmp_ret;
      }

      virtual Elm_Object_Item * item_sorted_insert(std::string letter_, Evas_Smart_Cb func_, const void * data_, Eina_Compare_Cb cmp_func_, Eina_Compare_Cb cmp_data_func_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_index_item_sorted_insert(efl::eolian::to_c(letter_), func_, data_, cmp_func_, cmp_data_func_));
            return _tmp_ret;
      }

      virtual bool autohide_disabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_index_autohide_disabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void autohide_disabled_set(bool disabled_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_index_autohide_disabled_set(efl::eolian::to_c(disabled_)));
      }

      virtual bool omit_enabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_index_omit_enabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void omit_enabled_set(bool enabled_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_index_omit_enabled_set(efl::eolian::to_c(enabled_)));
      }

      virtual bool horizontal_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_index_horizontal_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void horizontal_set(bool horizontal_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_index_horizontal_set(efl::eolian::to_c(horizontal_)));
      }

      virtual double delay_change_time_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_index_delay_change_time_get());
            return _tmp_ret;
      }

      virtual void delay_change_time_set(double dtime_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_index_delay_change_time_set(dtime_));
      }

      virtual bool indicator_disabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_index_indicator_disabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void indicator_disabled_set(bool disabled_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_index_indicator_disabled_set(efl::eolian::to_c(disabled_)));
      }

      virtual int item_level_get()
      {
         int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_index_item_level_get());
            return _tmp_ret;
      }

      virtual void item_level_set(int level_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_index_item_level_set(level_));
      }

   };
};


template<>
struct operation_description_class_size< ::elm_index >
{
   static const int value = 21;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_index>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_index_level_go_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_index_level_go);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_index_item_prepend_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_index_item_prepend);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_index_item_clear_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_index_item_clear);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_index_item_insert_after_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_index_item_insert_after);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_index_item_find_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_index_item_find);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_index_item_insert_before_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_index_item_insert_before);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_index_item_append_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_index_item_append);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_index_selected_item_get_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_index_selected_item_get);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_index_item_sorted_insert_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_index_item_sorted_insert);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_index_autohide_disabled_get_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_index_autohide_disabled_get);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::_elm_index_autohide_disabled_set_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::elm_obj_index_autohide_disabled_set);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::_elm_index_omit_enabled_get_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::elm_obj_index_omit_enabled_get);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::_elm_index_omit_enabled_set_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::elm_obj_index_omit_enabled_set);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::_elm_index_horizontal_get_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::elm_obj_index_horizontal_get);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::_elm_index_horizontal_set_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::elm_obj_index_horizontal_set);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::_elm_index_delay_change_time_get_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::elm_obj_index_delay_change_time_get);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   ops[16].func = reinterpret_cast<void*>(& ::_elm_index_delay_change_time_set_wrapper<T>);
   ops[16].api_func = reinterpret_cast<void*>(& ::elm_obj_index_delay_change_time_set);
   ops[16].op = EO_OP_OVERRIDE;
   ops[16].op_type = EO_OP_TYPE_REGULAR;
   ops[16].doc = NULL;

   ops[17].func = reinterpret_cast<void*>(& ::_elm_index_indicator_disabled_get_wrapper<T>);
   ops[17].api_func = reinterpret_cast<void*>(& ::elm_obj_index_indicator_disabled_get);
   ops[17].op = EO_OP_OVERRIDE;
   ops[17].op_type = EO_OP_TYPE_REGULAR;
   ops[17].doc = NULL;

   ops[18].func = reinterpret_cast<void*>(& ::_elm_index_indicator_disabled_set_wrapper<T>);
   ops[18].api_func = reinterpret_cast<void*>(& ::elm_obj_index_indicator_disabled_set);
   ops[18].op = EO_OP_OVERRIDE;
   ops[18].op_type = EO_OP_TYPE_REGULAR;
   ops[18].doc = NULL;

   ops[19].func = reinterpret_cast<void*>(& ::_elm_index_item_level_get_wrapper<T>);
   ops[19].api_func = reinterpret_cast<void*>(& ::elm_obj_index_item_level_get);
   ops[19].op = EO_OP_OVERRIDE;
   ops[19].op_type = EO_OP_TYPE_REGULAR;
   ops[19].doc = NULL;

   ops[20].func = reinterpret_cast<void*>(& ::_elm_index_item_level_set_wrapper<T>);
   ops[20].api_func = reinterpret_cast<void*>(& ::elm_obj_index_item_level_set);
   ops[20].op = EO_OP_OVERRIDE;
   ops[20].op_type = EO_OP_TYPE_REGULAR;
   ops[20].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_index >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_index, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_index >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_index, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_index>
{
   template <typename U>
   struct type
   {
      operator ::elm_index() const
      {
         return ::elm_index(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      void level_go(int level_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_index_level_go(level_));
      }

      Elm_Object_Item * item_prepend(std::string letter_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_index_item_prepend(efl::eolian::to_c(letter_), func_, data_));
            return _tmp_ret;
      }

      void item_clear()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_index_item_clear());
      }

      Elm_Object_Item * item_insert_after(Elm_Object_Item * after_, std::string letter_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_index_item_insert_after(after_, efl::eolian::to_c(letter_), func_, data_));
            return _tmp_ret;
      }

      Elm_Object_Item * item_find(const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_index_item_find(data_));
            return _tmp_ret;
      }

      Elm_Object_Item * item_insert_before(Elm_Object_Item * before_, std::string letter_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_index_item_insert_before(before_, efl::eolian::to_c(letter_), func_, data_));
            return _tmp_ret;
      }

      Elm_Object_Item * item_append(std::string letter_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_index_item_append(efl::eolian::to_c(letter_), func_, data_));
            return _tmp_ret;
      }

      Elm_Object_Item * selected_item_get(int level_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_index_selected_item_get(level_));
            return _tmp_ret;
      }

      Elm_Object_Item * item_sorted_insert(std::string letter_, Evas_Smart_Cb func_, const void * data_, Eina_Compare_Cb cmp_func_, Eina_Compare_Cb cmp_data_func_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_index_item_sorted_insert(efl::eolian::to_c(letter_), func_, data_, cmp_func_, cmp_data_func_));
            return _tmp_ret;
      }

      bool autohide_disabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_index_autohide_disabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void autohide_disabled_set(bool disabled_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_index_autohide_disabled_set(efl::eolian::to_c(disabled_)));
      }

      bool omit_enabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_index_omit_enabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void omit_enabled_set(bool enabled_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_index_omit_enabled_set(efl::eolian::to_c(enabled_)));
      }

      bool horizontal_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_index_horizontal_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void horizontal_set(bool horizontal_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_index_horizontal_set(efl::eolian::to_c(horizontal_)));
      }

      double delay_change_time_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_index_delay_change_time_get());
            return _tmp_ret;
      }

      void delay_change_time_set(double dtime_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_index_delay_change_time_set(dtime_));
      }

      bool indicator_disabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_index_indicator_disabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void indicator_disabled_set(bool disabled_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_index_indicator_disabled_set(efl::eolian::to_c(disabled_)));
      }

      int item_level_get()
      {
         int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_index_item_level_get());
            return _tmp_ret;
      }

      void item_level_set(int level_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_index_item_level_set(level_));
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_INDEX_EVENT_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_index, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_index, function_type>,
         ELM_INDEX_EVENT_CHANGED );
   }

   template <typename T>
   void
   callback_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_INDEX_EVENT_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_delay_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_INDEX_EVENT_DELAY_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_index, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_index, function_type>,
         ELM_INDEX_EVENT_DELAY_CHANGED );
   }

   template <typename T>
   void
   callback_delay_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_INDEX_EVENT_DELAY_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_selected_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_INDEX_EVENT_SELECTED, priority_,
            &efl::eo::_detail::event_callback<::elm_index, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_index, function_type>,
         ELM_INDEX_EVENT_SELECTED );
   }

   template <typename T>
   void
   callback_selected_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_INDEX_EVENT_SELECTED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_level_up_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_INDEX_EVENT_LEVEL_UP, priority_,
            &efl::eo::_detail::event_callback<::elm_index, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_index, function_type>,
         ELM_INDEX_EVENT_LEVEL_UP );
   }

   template <typename T>
   void
   callback_level_up_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_INDEX_EVENT_LEVEL_UP, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_level_down_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_INDEX_EVENT_LEVEL_DOWN, priority_,
            &efl::eo::_detail::event_callback<::elm_index, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_index, function_type>,
         ELM_INDEX_EVENT_LEVEL_DOWN );
   }

   template <typename T>
   void
   callback_level_down_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_INDEX_EVENT_LEVEL_DOWN, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_INDEX_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_index, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_index, function_type>,
         ELM_INDEX_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_INDEX_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_INDEX_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_index, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_index, function_type>,
         ELM_INDEX_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_INDEX_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_INDEX_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_index, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_index, function_type>,
         ELM_INDEX_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_INDEX_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_INDEX_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_index, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_index, function_type>,
         ELM_INDEX_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_INDEX_EVENT_UNFOCUSED, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_index>)
{
   return (ELM_INDEX_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_INDEX_HH

