#ifndef EFL_GENERATED_ELM_LAYOUT_HH
#define EFL_GENERATED_ELM_LAYOUT_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_layout.eo.h"
}

#include "elm_container.eo.hh"
#include <canvas/evas_object.eo.hh>
#include <string>

struct elm_layout
      : elm_container
{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_layout(Eo* eo)
      : elm_container(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_layout(std::nullptr_t)
      : elm_container(nullptr)
   {}

   elm_layout(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_layout(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_layout(elm_layout const& other)
      : elm_container(eo_ref(other._eo_ptr()))
   {}

   ~elm_layout() {}

   /// @brief Remove all children of the given part box.
   ///
   /// @return @c EINA_TRUE on success, @c EINA_FALSE otherwise
   ///
   /// The objects will be removed from the box part and their lifetime will
   /// not be handled by the layout anymore. This is equivalent to
   /// elm_layout_box_remove() for all box children.
   ///
   /// @see elm_layout_box_append()
   /// @see elm_layout_box_remove()
   ///
   /// @ingroup Layout
   ///
   /// @param part The box part name to remove child.
   /// @param clear If EINA_TRUE, then all objects will be deleted as
   /// well, otherwise they will just be removed and will be
   /// dangling on the canvas.
   ///
   bool box_remove_all(std::string part_, bool clear_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_box_remove_all(efl::eolian::to_c(part_), efl::eolian::to_c(clear_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Sets if the cursor set should be searched on the theme or should use
   /// the provided by the engine, only.
   ///
   /// @note before you set if should look on theme you should define a
   /// cursor with elm_layout_part_cursor_set(). By default it will only
   /// look for cursors provided by the engine.
   ///
   /// @return EINA_TRUE on success or EINA_FALSE on failure, that may be
   /// part not exists or it did not had a cursor set.
   ///
   /// @ingroup Layout
   ///
   /// @param part_name a part from loaded edje group.
   /// @param engine_only if cursors should be just provided by the engine (EINA_TRUE)
   /// or should also search on widget's theme as well (EINA_FALSE)
   ///
   bool part_cursor_engine_only_set(std::string part_name_, bool engine_only_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_part_cursor_engine_only_set(efl::eolian::to_c(part_name_), efl::eolian::to_c(engine_only_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Get a specific cursor engine_only for an edje part.
   ///
   /// @return whenever the cursor is just provided by engine or also from theme.
   ///
   /// @ingroup Layout
   ///
   /// @param part_name a part from loaded edje group.
   ///
   bool part_cursor_engine_only_get(std::string part_name_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_part_cursor_engine_only_get(efl::eolian::to_c(part_name_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Unpack (remove) a child of the given part table.
   ///
   /// @return The object that was being used, or NULL if not found.
   ///
   /// The object will be unpacked from the table part and its lifetime
   /// will not be handled by the layout anymore. This is equivalent to
   /// elm_layout_content_unset() for table.
   ///
   /// @see elm_layout_table_pack()
   /// @see elm_layout_table_clear()
   ///
   /// @ingroup Layout
   ///
   /// @param part The table part name to remove child.
   /// @param child The object to remove from table.
   ///
   evas::object table_unpack(std::string part_, evas::object child_) const
   {
      Evas_Object * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_table_unpack(efl::eolian::to_c(part_), efl::eolian::to_c(child_)));
      return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief @brief Freezes the Elementary layout object.
   ///
   /// @return The frozen state or 0 on Error
   ///
   /// This function puts all changes on hold. Successive freezes will
   /// nest, requiring an equal number of thaws.
   ///
   /// @see elm_layout_thaw()
   ///
   int freeze() const
   {
      int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_freeze());
      return _tmp_ret;
   }

   /// @brief No description supplied by the EAPI.
   ///
   bool theme_enable() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_theme_enable());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Eval sizing
   ///
   /// Manually forces a sizing re-evaluation. This is useful when the minimum
   /// size required by the edje theme of this layout has changed. The change on
   /// the minimum size required by the edje theme is not immediately reported to
   /// the elementary layout, so one needs to call this function in order to tell
   /// the widget (layout) that it needs to reevaluate its own size.
   ///
   /// The minimum size of the theme is calculated based on minimum size of
   /// parts, the size of elements inside containers like box and table, etc. All
   /// of this can change due to state changes, and that's when this function
   /// should be called.
   ///
   /// Also note that a standard signal of "size,eval" "elm" emitted from the
   /// edje object will cause this to happen too.
   ///
   /// @ingroup Layout
   ///
   void sizing_eval() const
   {
      eo_do(_eo_ptr(), ::elm_obj_layout_sizing_eval());
   }

   /// @brief Remove a child of the given part box.
   ///
   /// @return The object that was being used, or NULL if not found.
   ///
   /// The object will be removed from the box part and its lifetime will
   /// not be handled by the layout anymore. This is equivalent to
   /// elm_layout_content_unset() for box.
   ///
   /// @see elm_layout_box_append()
   /// @see elm_layout_box_remove_all()
   ///
   /// @ingroup Layout
   ///
   /// @param part The box part name to remove child.
   /// @param child The object to remove from box.
   ///
   evas::object box_remove(std::string part_, evas::object child_) const
   {
      Evas_Object * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_box_remove(efl::eolian::to_c(part_), efl::eolian::to_c(child_)));
      return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Request sizing reevaluation, restricted to current width and/or height
   ///
   /// Useful mostly when there are TEXTBLOCK parts defining the height of the
   /// object and nothing else restricting it to a minimum width. Calling this
   /// function will restrict the minimum size in the Edje calculation to whatever
   /// size it the layout has at the moment.
   ///
   /// @since 1.8
   ///
   /// @ingroup Layout
   ///
   /// @param width Restrict minimum size to the current width
   /// @param height Restrict minimum size ot the current height
   ///
   void sizing_restricted_eval(bool width_, bool height_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_layout_sizing_restricted_eval(efl::eolian::to_c(width_), efl::eolian::to_c(height_)));
   }

   /// @brief Sets a specific cursor style for an edje part.
   ///
   /// @return EINA_TRUE on success or EINA_FALSE on failure, that may be
   /// part not exists or it did not had a cursor set.
   ///
   /// @ingroup Layout
   ///
   /// @param part_name a part from loaded edje group.
   /// @param style the theme style to use (default, transparent, ...)
   ///
   bool part_cursor_style_set(std::string part_name_, std::string style_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_part_cursor_style_set(efl::eolian::to_c(part_name_), efl::eolian::to_c(style_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Get a specific cursor style for an edje part.
   ///
   /// @return the theme style in use, defaults to "default". If the
   /// object does not have a cursor set, then NULL is returned.
   ///
   /// @ingroup Layout
   ///
   /// @param part_name a part from loaded edje group.
   ///
   std::string part_cursor_style_get(std::string part_name_) const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_part_cursor_style_get(efl::eolian::to_c(part_name_)));
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Set the text of the given part
   ///
   /// @return @c EINA_TRUE on success, @c EINA_FALSE otherwise
   ///
   /// @ingroup Layout
   ///
   /// @param part The TEXT part where to set the text
   /// @param text The text to set
   ///
   bool text_set(std::string part_, std::string text_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_text_set(efl::eolian::to_c(part_), efl::eolian::to_c(text_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Get the text set in the given part
   ///
   /// @return The text set in @p part
   ///
   /// @ingroup Layout
   ///
   /// @param part The TEXT part to retrieve the text off
   ///
   std::string text_get(std::string part_) const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_text_get(efl::eolian::to_c(part_)));
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Add a callback for a (Edje) signal emitted by a layout widget's
   /// underlying Edje object.
   ///
   /// This function connects a callback function to a signal emitted by
   /// the underlying Edje object of @a obj. Globs are accepted in either
   /// the emission or source strings (see @c
   /// edje_object_signal_callback_add()).
   ///
   /// @ingroup Layout
   ///
   /// @param emission The signal's name string
   /// @param source The signal's source string
   /// @param func The callback function to be executed when the signal is
   /// emitted.
   /// @param data A pointer to data to pass in to the callback function.
   ///
   void signal_callback_add(std::string emission_, std::string source_, Edje_Signal_Cb func_, void * data_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_layout_signal_callback_add(efl::eolian::to_c(emission_), efl::eolian::to_c(source_), func_, data_));
   }

   /// @brief Sets a specific cursor for an edje part.
   ///
   /// @return EINA_TRUE on success or EINA_FALSE on failure, that may be
   /// part not exists or it has "mouse_events: 0".
   ///
   /// @ingroup Layout
   ///
   /// @param part_name a part from loaded edje group.
   /// @param cursor cursor name to use, see Elementary_Cursor.h
   ///
   bool part_cursor_set(std::string part_name_, std::string cursor_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_part_cursor_set(efl::eolian::to_c(part_name_), efl::eolian::to_c(cursor_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Get the cursor to be shown when mouse is over an edje part
   ///
   /// @return the cursor name.
   ///
   /// @ingroup Layout
   ///
   /// @param part_name a part from loaded edje group.
   ///
   std::string part_cursor_get(std::string part_name_) const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_part_cursor_get(efl::eolian::to_c(part_name_)));
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Insert child to layout box part before a reference object.
   ///
   /// @return @c EINA_TRUE on success, @c EINA_FALSE otherwise
   ///
   /// Once the object is inserted, it will become child of the layout. Its
   /// lifetime will be bound to the layout, whenever the layout dies the child
   /// will be deleted automatically. One should use elm_layout_box_remove() to
   /// make this layout forget about the object.
   ///
   /// @see elm_layout_box_append()
   /// @see elm_layout_box_prepend()
   /// @see elm_layout_box_insert_before()
   /// @see elm_layout_box_remove()
   ///
   /// @ingroup Layout
   ///
   /// @param part the box part to insert.
   /// @param child the child object to insert into box.
   /// @param reference another reference object to insert before in box.
   ///
   bool box_insert_before(std::string part_, evas::object child_, const Evas_Object * reference_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_box_insert_before(efl::eolian::to_c(part_), efl::eolian::to_c(child_), reference_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Insert child to layout box part at a given position.
   ///
   /// @return @c EINA_TRUE on success, @c EINA_FALSE otherwise
   ///
   /// Once the object is inserted, it will become child of the layout. Its
   /// lifetime will be bound to the layout, whenever the layout dies the child
   /// will be deleted automatically. One should use elm_layout_box_remove() to
   /// make this layout forget about the object.
   ///
   /// @see elm_layout_box_append()
   /// @see elm_layout_box_prepend()
   /// @see elm_layout_box_insert_before()
   /// @see elm_layout_box_remove()
   ///
   /// @ingroup Layout
   ///
   /// @param part the box part to insert.
   /// @param child the child object to insert into box.
   /// @param pos the numeric position >=0 to insert the child.
   ///
   bool box_insert_at(std::string part_, evas::object child_, unsigned int pos_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_box_insert_at(efl::eolian::to_c(part_), efl::eolian::to_c(child_), pos_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief No description supplied by the EAPI.
   ///
   bool sub_object_add_enable() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_sub_object_add_enable());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Get the edje data from the given layout
   ///
   /// @return The edje data string
   ///
   /// This function fetches data specified inside the edje theme of this layout.
   /// This function return NULL if data is not found.
   ///
   /// In EDC this comes from a data block within the group block that @p
   /// obj was loaded from. E.g.
   ///
   /// @code
   /// collections {
   /// group {
   /// name: "a_group";
   /// data {
   /// item: "key1" "value1";
   /// item: "key2" "value2";
   /// }
   /// }
   /// }
   /// @endcode
   ///
   /// @ingroup Layout
   ///
   /// @param key The data key
   ///
   std::string data_get(std::string key_) const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_data_get(efl::eolian::to_c(key_)));
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Append child to layout box part.
   ///
   /// @return @c EINA_TRUE on success, @c EINA_FALSE otherwise
   ///
   /// Once the object is appended, it will become child of the layout. Its
   /// lifetime will be bound to the layout, whenever the layout dies the child
   /// will be deleted automatically. One should use elm_layout_box_remove() to
   /// make this layout forget about the object.
   ///
   /// @see elm_layout_box_prepend()
   /// @see elm_layout_box_insert_before()
   /// @see elm_layout_box_insert_at()
   /// @see elm_layout_box_remove()
   ///
   /// @ingroup Layout
   ///
   /// @param part the box part to which the object will be appended.
   /// @param child the child object to append to box.
   ///
   bool box_append(std::string part_, evas::object child_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_box_append(efl::eolian::to_c(part_), efl::eolian::to_c(child_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Remove a signal-triggered callback from a given layout widget.
   ///
   /// @return The data pointer of the signal callback (passed on
   /// elm_layout_signal_callback_add()) or @c NULL, on errors.
   ///
   /// This function removes the @b last callback attached to a signal
   /// emitted by the undelying Edje object of @a obj, with parameters @a
   /// emission, @a source and @c func matching exactly those passed to a
   /// previous call to elm_layout_signal_callback_add(). The data pointer
   /// that was passed to this call will be returned.
   ///
   /// @ingroup Layout
   ///
   /// @param emission The signal's name string
   /// @param source The signal's source string
   /// @param func The callback function being executed when the signal
   /// was emitted.
   ///
   void * signal_callback_del(std::string emission_, std::string source_, Edje_Signal_Cb func_) const
   {
      void * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_signal_callback_del(efl::eolian::to_c(emission_), efl::eolian::to_c(source_), func_));
      return _tmp_ret;
   }

   /// @brief @brief Thaws the Elementary object.
   ///
   /// @return The frozen state or 0 if the object is not frozen or on error.
   ///
   /// This function thaws the given Edje object and the Elementary sizing calc.
   ///
   /// @note: If sucessives freezes were done, an equal number of
   /// thaws will be required.
   ///
   /// @see elm_layout_freeze()
   ///
   int thaw() const
   {
      int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_thaw());
      return _tmp_ret;
   }

   /// @brief Prepend child to layout box part.
   ///
   /// @return @c EINA_TRUE on success, @c EINA_FALSE otherwise
   ///
   /// Once the object is prepended, it will become child of the layout. Its
   /// lifetime will be bound to the layout, whenever the layout dies the child
   /// will be deleted automatically. One should use elm_layout_box_remove() to
   /// make this layout forget about the object.
   ///
   /// @see elm_layout_box_append()
   /// @see elm_layout_box_insert_before()
   /// @see elm_layout_box_insert_at()
   /// @see elm_layout_box_remove()
   ///
   /// @ingroup Layout
   ///
   /// @param part the box part to prepend.
   /// @param child the child object to prepend to box.
   ///
   bool box_prepend(std::string part_, evas::object child_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_box_prepend(efl::eolian::to_c(part_), efl::eolian::to_c(child_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Send a (Edje) signal to a given layout widget's underlying Edje
   /// object.
   ///
   /// This function sends a signal to the underlying Edje object of @a
   /// obj. An Edje program on that Edje object's definition can respond
   /// to a signal by specifying matching 'signal' and 'source' fields.
   ///
   /// @ingroup Layout
   ///
   /// @param emission The signal's name string
   /// @param source The signal's source string
   ///
   void signal_emit(std::string emission_, std::string source_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_layout_signal_emit(efl::eolian::to_c(emission_), efl::eolian::to_c(source_)));
   }

   /// @brief Insert child to layout table part.
   ///
   /// @return @c EINA_TRUE on success, @c EINA_FALSE otherwise
   ///
   /// Once the object is inserted, it will become child of the table. Its
   /// lifetime will be bound to the layout, and whenever the layout dies the
   /// child will be deleted automatically. One should use
   /// elm_layout_table_unpack() to make this layout forget about the object.
   ///
   /// If @p colspan or @p rowspan are bigger than 1, that object will occupy
   /// more space than a single cell. For instance, the following code:
   /// @code
   /// elm_layout_table_pack(layout, "table_part", child, 0, 1, 3, 1);
   /// @endcode
   ///
   /// Would result in an object being added like the following picture:
   ///
   /// @image html layout_colspan.png
   /// @image latex layout_colspan.eps width=\textwidth
   ///
   /// @see elm_layout_table_unpack()
   /// @see elm_layout_table_clear()
   ///
   /// @ingroup Layout
   ///
   /// @param part the box part to pack child.
   /// @param child the child object to pack into table.
   /// @param col the column to which the child should be added. (>= 0)
   /// @param row the row to which the child should be added. (>= 0)
   /// @param colspan how many columns should be used to store this object. (>=
   /// 1)
   /// @param rowspan how many rows should be used to store this object. (>= 1)
   ///
   bool table_pack(std::string part_, evas::object child_, unsigned short col_, unsigned short row_, unsigned short colspan_, unsigned short rowspan_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_table_pack(efl::eolian::to_c(part_), efl::eolian::to_c(child_), col_, row_, colspan_, rowspan_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Unsets a cursor previously set with elm_layout_part_cursor_set().
   ///
   /// @return @c EINA_TRUE on success, @c EINA_FALSE otherwise
   ///
   /// @ingroup Layout
   ///
   /// @param part_name a part from loaded edje group, that had a cursor set
   /// with elm_layout_part_cursor_set().
   ///
   bool part_cursor_unset(std::string part_name_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_part_cursor_unset(efl::eolian::to_c(part_name_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Remove all the child objects of the given part table.
   ///
   /// @return @c EINA_TRUE on success, @c EINA_FALSE otherwise
   ///
   /// The objects will be removed from the table part and their lifetime will
   /// not be handled by the layout anymore. This is equivalent to
   /// elm_layout_table_unpack() for all table children.
   ///
   /// @see elm_layout_table_pack()
   /// @see elm_layout_table_unpack()
   ///
   /// @ingroup Layout
   ///
   /// @param part The table part name to remove child.
   /// @param clear If EINA_TRUE, then all objects will be deleted as
   /// well, otherwise they will just be removed and will be
   /// dangling on the canvas.
   ///
   bool table_clear(std::string part_, bool clear_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_table_clear(efl::eolian::to_c(part_), efl::eolian::to_c(clear_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param can_access makes all textblock(text) parts in the layout @p obj possible
   /// to have accessibility. @c EINA_TRUE means textblock(text) parts can be accessible
   ///
   bool edje_object_can_access_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_edje_object_can_access_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param can_access makes all textblock(text) parts in the layout @p obj possible
   /// to have accessibility. @c EINA_TRUE means textblock(text) parts can be accessible
   ///
   bool edje_object_can_access_set(bool can_access_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_edje_object_can_access_set(efl::eolian::to_c(can_access_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param file The path to file (edj) that will be used as layout
   /// @param group The group that the layout belongs in edje file
   ///
   bool file_set(std::string file_, std::string group_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_file_set(efl::eolian::to_c(file_), efl::eolian::to_c(group_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param klass the class of the group
   /// @param group the group
   /// @param style the style to used
   ///
   bool theme_set(std::string klass_, std::string group_, std::string style_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_theme_set(efl::eolian::to_c(klass_), efl::eolian::to_c(group_), efl::eolian::to_c(style_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param aliases 
   ///
   const Elm_Layout_Part_Alias_Description * text_aliases_get() const
   {
      const Elm_Layout_Part_Alias_Description * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_text_aliases_get());
      return _tmp_ret;
   }

   /// @param aliases 
   ///
   const Elm_Layout_Part_Alias_Description * content_aliases_get() const
   {
      const Elm_Layout_Part_Alias_Description * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_content_aliases_get());
      return _tmp_ret;
   }

   evas::object edje_get() const
   {
      Evas_Object * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_layout_edje_get());
      return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_theme_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LAYOUT_EVENT_THEME_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_layout, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_layout, function_type>,
         ELM_LAYOUT_EVENT_THEME_CHANGED );
   }

   template <typename T>
   void
   callback_theme_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_LAYOUT_EVENT_THEME_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LAYOUT_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_layout, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_layout, function_type>,
         ELM_LAYOUT_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_LAYOUT_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LAYOUT_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_layout, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_layout, function_type>,
         ELM_LAYOUT_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_LAYOUT_EVENT_UNFOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LAYOUT_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_layout, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_layout, function_type>,
         ELM_LAYOUT_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_LAYOUT_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LAYOUT_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_layout, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_layout, function_type>,
         ELM_LAYOUT_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_LAYOUT_EVENT_ACCESS_CHANGED, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_LAYOUT_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_LAYOUT_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
bool _elm_layout_box_remove_all_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * part_, Eina_Bool clear_)
{
   return static_cast<T*>(self->this_)->box_remove_all(efl::eolian::to_cxx<std::string>(part_, std::tuple<std::false_type>()), efl::eolian::to_cxx<bool>(clear_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_layout_part_cursor_engine_only_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * part_name_, Eina_Bool engine_only_)
{
   return static_cast<T*>(self->this_)->part_cursor_engine_only_set(efl::eolian::to_cxx<std::string>(part_name_, std::tuple<std::false_type>()), efl::eolian::to_cxx<bool>(engine_only_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_layout_part_cursor_engine_only_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * part_name_)
{
   return static_cast<T*>(self->this_)->part_cursor_engine_only_get(efl::eolian::to_cxx<std::string>(part_name_, std::tuple<std::false_type>()));
}

template <typename T>
evas::object _elm_layout_table_unpack_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * part_, Evas_Object * child_)
{
   return static_cast<T*>(self->this_)->table_unpack(efl::eolian::to_cxx<std::string>(part_, std::tuple<std::false_type>()), efl::eolian::to_cxx<evas::object>(child_, std::tuple<std::false_type>()));
}

template <typename T>
int _elm_layout_freeze_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->freeze();
}

template <typename T>
bool _elm_layout_theme_enable_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->theme_enable();
}

template <typename T>
void _elm_layout_sizing_eval_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->sizing_eval();
}

template <typename T>
evas::object _elm_layout_box_remove_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * part_, Evas_Object * child_)
{
   return static_cast<T*>(self->this_)->box_remove(efl::eolian::to_cxx<std::string>(part_, std::tuple<std::false_type>()), efl::eolian::to_cxx<evas::object>(child_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_layout_sizing_restricted_eval_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool width_, Eina_Bool height_)
{
   static_cast<T*>(self->this_)->sizing_restricted_eval(efl::eolian::to_cxx<bool>(width_, std::tuple<std::false_type>()), efl::eolian::to_cxx<bool>(height_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_layout_part_cursor_style_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * part_name_, const char * style_)
{
   return static_cast<T*>(self->this_)->part_cursor_style_set(efl::eolian::to_cxx<std::string>(part_name_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(style_, std::tuple<std::false_type>()));
}

template <typename T>
std::string _elm_layout_part_cursor_style_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * part_name_)
{
   return static_cast<T*>(self->this_)->part_cursor_style_get(efl::eolian::to_cxx<std::string>(part_name_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_layout_text_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * part_, const char * text_)
{
   return static_cast<T*>(self->this_)->text_set(efl::eolian::to_cxx<std::string>(part_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(text_, std::tuple<std::false_type>()));
}

template <typename T>
std::string _elm_layout_text_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * part_)
{
   return static_cast<T*>(self->this_)->text_get(efl::eolian::to_cxx<std::string>(part_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_layout_signal_callback_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * emission_, const char * source_, Edje_Signal_Cb func_, void * data_)
{
   static_cast<T*>(self->this_)->signal_callback_add(efl::eolian::to_cxx<std::string>(emission_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(source_, std::tuple<std::false_type>()), func_, data_);
}

template <typename T>
bool _elm_layout_part_cursor_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * part_name_, const char * cursor_)
{
   return static_cast<T*>(self->this_)->part_cursor_set(efl::eolian::to_cxx<std::string>(part_name_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(cursor_, std::tuple<std::false_type>()));
}

template <typename T>
std::string _elm_layout_part_cursor_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * part_name_)
{
   return static_cast<T*>(self->this_)->part_cursor_get(efl::eolian::to_cxx<std::string>(part_name_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_layout_box_insert_before_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * part_, Evas_Object * child_, const Evas_Object * reference_)
{
   return static_cast<T*>(self->this_)->box_insert_before(efl::eolian::to_cxx<std::string>(part_, std::tuple<std::false_type>()), efl::eolian::to_cxx<evas::object>(child_, std::tuple<std::false_type>()), reference_);
}

template <typename T>
bool _elm_layout_box_insert_at_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * part_, Evas_Object * child_, unsigned int pos_)
{
   return static_cast<T*>(self->this_)->box_insert_at(efl::eolian::to_cxx<std::string>(part_, std::tuple<std::false_type>()), efl::eolian::to_cxx<evas::object>(child_, std::tuple<std::false_type>()), pos_);
}

template <typename T>
bool _elm_layout_sub_object_add_enable_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->sub_object_add_enable();
}

template <typename T>
std::string _elm_layout_data_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * key_)
{
   return static_cast<T*>(self->this_)->data_get(efl::eolian::to_cxx<std::string>(key_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_layout_box_append_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * part_, Evas_Object * child_)
{
   return static_cast<T*>(self->this_)->box_append(efl::eolian::to_cxx<std::string>(part_, std::tuple<std::false_type>()), efl::eolian::to_cxx<evas::object>(child_, std::tuple<std::false_type>()));
}

template <typename T>
void * _elm_layout_signal_callback_del_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * emission_, const char * source_, Edje_Signal_Cb func_)
{
   return static_cast<T*>(self->this_)->signal_callback_del(efl::eolian::to_cxx<std::string>(emission_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(source_, std::tuple<std::false_type>()), func_);
}

template <typename T>
int _elm_layout_thaw_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->thaw();
}

template <typename T>
bool _elm_layout_box_prepend_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * part_, Evas_Object * child_)
{
   return static_cast<T*>(self->this_)->box_prepend(efl::eolian::to_cxx<std::string>(part_, std::tuple<std::false_type>()), efl::eolian::to_cxx<evas::object>(child_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_layout_signal_emit_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * emission_, const char * source_)
{
   static_cast<T*>(self->this_)->signal_emit(efl::eolian::to_cxx<std::string>(emission_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(source_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_layout_table_pack_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * part_, Evas_Object * child_, unsigned short col_, unsigned short row_, unsigned short colspan_, unsigned short rowspan_)
{
   return static_cast<T*>(self->this_)->table_pack(efl::eolian::to_cxx<std::string>(part_, std::tuple<std::false_type>()), efl::eolian::to_cxx<evas::object>(child_, std::tuple<std::false_type>()), col_, row_, colspan_, rowspan_);
}

template <typename T>
bool _elm_layout_part_cursor_unset_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * part_name_)
{
   return static_cast<T*>(self->this_)->part_cursor_unset(efl::eolian::to_cxx<std::string>(part_name_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_layout_table_clear_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * part_, Eina_Bool clear_)
{
   return static_cast<T*>(self->this_)->table_clear(efl::eolian::to_cxx<std::string>(part_, std::tuple<std::false_type>()), efl::eolian::to_cxx<bool>(clear_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_layout_edje_object_can_access_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->edje_object_can_access_get();
}

template <typename T>
bool _elm_layout_edje_object_can_access_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool can_access_)
{
   return static_cast<T*>(self->this_)->edje_object_can_access_set(efl::eolian::to_cxx<bool>(can_access_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_layout_file_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * file_, const char * group_)
{
   return static_cast<T*>(self->this_)->file_set(efl::eolian::to_cxx<std::string>(file_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(group_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_layout_theme_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * klass_, const char * group_, const char * style_)
{
   return static_cast<T*>(self->this_)->theme_set(efl::eolian::to_cxx<std::string>(klass_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(group_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(style_, std::tuple<std::false_type>()));
}

template <typename T>
const Elm_Layout_Part_Alias_Description * _elm_layout_text_aliases_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->text_aliases_get();
}

template <typename T>
const Elm_Layout_Part_Alias_Description * _elm_layout_content_aliases_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->content_aliases_get();
}

template <typename T>
evas::object _elm_layout_edje_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->edje_get();
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_layout >
{
   template <typename T>
   struct type
   {
      virtual bool box_remove_all(std::string part_, bool clear_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_box_remove_all(efl::eolian::to_c(part_), efl::eolian::to_c(clear_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool part_cursor_engine_only_set(std::string part_name_, bool engine_only_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_part_cursor_engine_only_set(efl::eolian::to_c(part_name_), efl::eolian::to_c(engine_only_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool part_cursor_engine_only_get(std::string part_name_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_part_cursor_engine_only_get(efl::eolian::to_c(part_name_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual evas::object table_unpack(std::string part_, evas::object child_)
      {
         Evas_Object * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_table_unpack(efl::eolian::to_c(part_), efl::eolian::to_c(child_)));
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual int freeze()
      {
         int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_freeze());
            return _tmp_ret;
      }

      virtual bool theme_enable()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_theme_enable());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void sizing_eval()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_layout_sizing_eval());
      }

      virtual evas::object box_remove(std::string part_, evas::object child_)
      {
         Evas_Object * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_box_remove(efl::eolian::to_c(part_), efl::eolian::to_c(child_)));
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void sizing_restricted_eval(bool width_, bool height_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_layout_sizing_restricted_eval(efl::eolian::to_c(width_), efl::eolian::to_c(height_)));
      }

      virtual bool part_cursor_style_set(std::string part_name_, std::string style_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_part_cursor_style_set(efl::eolian::to_c(part_name_), efl::eolian::to_c(style_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual std::string part_cursor_style_get(std::string part_name_)
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_part_cursor_style_get(efl::eolian::to_c(part_name_)));
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool text_set(std::string part_, std::string text_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_text_set(efl::eolian::to_c(part_), efl::eolian::to_c(text_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual std::string text_get(std::string part_)
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_text_get(efl::eolian::to_c(part_)));
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void signal_callback_add(std::string emission_, std::string source_, Edje_Signal_Cb func_, void * data_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_layout_signal_callback_add(efl::eolian::to_c(emission_), efl::eolian::to_c(source_), func_, data_));
      }

      virtual bool part_cursor_set(std::string part_name_, std::string cursor_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_part_cursor_set(efl::eolian::to_c(part_name_), efl::eolian::to_c(cursor_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual std::string part_cursor_get(std::string part_name_)
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_part_cursor_get(efl::eolian::to_c(part_name_)));
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool box_insert_before(std::string part_, evas::object child_, const Evas_Object * reference_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_box_insert_before(efl::eolian::to_c(part_), efl::eolian::to_c(child_), reference_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool box_insert_at(std::string part_, evas::object child_, unsigned int pos_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_box_insert_at(efl::eolian::to_c(part_), efl::eolian::to_c(child_), pos_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool sub_object_add_enable()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_sub_object_add_enable());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual std::string data_get(std::string key_)
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_data_get(efl::eolian::to_c(key_)));
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool box_append(std::string part_, evas::object child_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_box_append(efl::eolian::to_c(part_), efl::eolian::to_c(child_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void * signal_callback_del(std::string emission_, std::string source_, Edje_Signal_Cb func_)
      {
         void * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_signal_callback_del(efl::eolian::to_c(emission_), efl::eolian::to_c(source_), func_));
            return _tmp_ret;
      }

      virtual int thaw()
      {
         int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_thaw());
            return _tmp_ret;
      }

      virtual bool box_prepend(std::string part_, evas::object child_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_box_prepend(efl::eolian::to_c(part_), efl::eolian::to_c(child_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void signal_emit(std::string emission_, std::string source_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_layout_signal_emit(efl::eolian::to_c(emission_), efl::eolian::to_c(source_)));
      }

      virtual bool table_pack(std::string part_, evas::object child_, unsigned short col_, unsigned short row_, unsigned short colspan_, unsigned short rowspan_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_table_pack(efl::eolian::to_c(part_), efl::eolian::to_c(child_), col_, row_, colspan_, rowspan_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool part_cursor_unset(std::string part_name_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_part_cursor_unset(efl::eolian::to_c(part_name_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool table_clear(std::string part_, bool clear_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_table_clear(efl::eolian::to_c(part_), efl::eolian::to_c(clear_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool edje_object_can_access_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_edje_object_can_access_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool edje_object_can_access_set(bool can_access_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_edje_object_can_access_set(efl::eolian::to_c(can_access_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool file_set(std::string file_, std::string group_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_file_set(efl::eolian::to_c(file_), efl::eolian::to_c(group_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool theme_set(std::string klass_, std::string group_, std::string style_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_theme_set(efl::eolian::to_c(klass_), efl::eolian::to_c(group_), efl::eolian::to_c(style_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual const Elm_Layout_Part_Alias_Description * text_aliases_get()
      {
         const Elm_Layout_Part_Alias_Description * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_text_aliases_get());
            return _tmp_ret;
      }

      virtual const Elm_Layout_Part_Alias_Description * content_aliases_get()
      {
         const Elm_Layout_Part_Alias_Description * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_content_aliases_get());
            return _tmp_ret;
      }

      virtual evas::object edje_get()
      {
         Evas_Object * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_layout_edje_get());
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

   };
};


template<>
struct operation_description_class_size< ::elm_layout >
{
   static const int value = 35;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_layout>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_layout_box_remove_all_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_box_remove_all);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_layout_part_cursor_engine_only_set_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_part_cursor_engine_only_set);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_layout_part_cursor_engine_only_get_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_part_cursor_engine_only_get);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_layout_table_unpack_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_table_unpack);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_layout_freeze_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_freeze);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_layout_theme_enable_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_theme_enable);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_layout_sizing_eval_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_sizing_eval);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_layout_box_remove_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_box_remove);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_layout_sizing_restricted_eval_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_sizing_restricted_eval);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_layout_part_cursor_style_set_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_part_cursor_style_set);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::_elm_layout_part_cursor_style_get_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_part_cursor_style_get);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::_elm_layout_text_set_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_text_set);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::_elm_layout_text_get_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_text_get);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::_elm_layout_signal_callback_add_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_signal_callback_add);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::_elm_layout_part_cursor_set_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_part_cursor_set);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::_elm_layout_part_cursor_get_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_part_cursor_get);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   ops[16].func = reinterpret_cast<void*>(& ::_elm_layout_box_insert_before_wrapper<T>);
   ops[16].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_box_insert_before);
   ops[16].op = EO_OP_OVERRIDE;
   ops[16].op_type = EO_OP_TYPE_REGULAR;
   ops[16].doc = NULL;

   ops[17].func = reinterpret_cast<void*>(& ::_elm_layout_box_insert_at_wrapper<T>);
   ops[17].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_box_insert_at);
   ops[17].op = EO_OP_OVERRIDE;
   ops[17].op_type = EO_OP_TYPE_REGULAR;
   ops[17].doc = NULL;

   ops[18].func = reinterpret_cast<void*>(& ::_elm_layout_sub_object_add_enable_wrapper<T>);
   ops[18].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_sub_object_add_enable);
   ops[18].op = EO_OP_OVERRIDE;
   ops[18].op_type = EO_OP_TYPE_REGULAR;
   ops[18].doc = NULL;

   ops[19].func = reinterpret_cast<void*>(& ::_elm_layout_data_get_wrapper<T>);
   ops[19].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_data_get);
   ops[19].op = EO_OP_OVERRIDE;
   ops[19].op_type = EO_OP_TYPE_REGULAR;
   ops[19].doc = NULL;

   ops[20].func = reinterpret_cast<void*>(& ::_elm_layout_box_append_wrapper<T>);
   ops[20].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_box_append);
   ops[20].op = EO_OP_OVERRIDE;
   ops[20].op_type = EO_OP_TYPE_REGULAR;
   ops[20].doc = NULL;

   ops[21].func = reinterpret_cast<void*>(& ::_elm_layout_signal_callback_del_wrapper<T>);
   ops[21].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_signal_callback_del);
   ops[21].op = EO_OP_OVERRIDE;
   ops[21].op_type = EO_OP_TYPE_REGULAR;
   ops[21].doc = NULL;

   ops[22].func = reinterpret_cast<void*>(& ::_elm_layout_thaw_wrapper<T>);
   ops[22].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_thaw);
   ops[22].op = EO_OP_OVERRIDE;
   ops[22].op_type = EO_OP_TYPE_REGULAR;
   ops[22].doc = NULL;

   ops[23].func = reinterpret_cast<void*>(& ::_elm_layout_box_prepend_wrapper<T>);
   ops[23].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_box_prepend);
   ops[23].op = EO_OP_OVERRIDE;
   ops[23].op_type = EO_OP_TYPE_REGULAR;
   ops[23].doc = NULL;

   ops[24].func = reinterpret_cast<void*>(& ::_elm_layout_signal_emit_wrapper<T>);
   ops[24].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_signal_emit);
   ops[24].op = EO_OP_OVERRIDE;
   ops[24].op_type = EO_OP_TYPE_REGULAR;
   ops[24].doc = NULL;

   ops[25].func = reinterpret_cast<void*>(& ::_elm_layout_table_pack_wrapper<T>);
   ops[25].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_table_pack);
   ops[25].op = EO_OP_OVERRIDE;
   ops[25].op_type = EO_OP_TYPE_REGULAR;
   ops[25].doc = NULL;

   ops[26].func = reinterpret_cast<void*>(& ::_elm_layout_part_cursor_unset_wrapper<T>);
   ops[26].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_part_cursor_unset);
   ops[26].op = EO_OP_OVERRIDE;
   ops[26].op_type = EO_OP_TYPE_REGULAR;
   ops[26].doc = NULL;

   ops[27].func = reinterpret_cast<void*>(& ::_elm_layout_table_clear_wrapper<T>);
   ops[27].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_table_clear);
   ops[27].op = EO_OP_OVERRIDE;
   ops[27].op_type = EO_OP_TYPE_REGULAR;
   ops[27].doc = NULL;

   ops[28].func = reinterpret_cast<void*>(& ::_elm_layout_edje_object_can_access_get_wrapper<T>);
   ops[28].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_edje_object_can_access_get);
   ops[28].op = EO_OP_OVERRIDE;
   ops[28].op_type = EO_OP_TYPE_REGULAR;
   ops[28].doc = NULL;

   ops[29].func = reinterpret_cast<void*>(& ::_elm_layout_edje_object_can_access_set_wrapper<T>);
   ops[29].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_edje_object_can_access_set);
   ops[29].op = EO_OP_OVERRIDE;
   ops[29].op_type = EO_OP_TYPE_REGULAR;
   ops[29].doc = NULL;

   ops[30].func = reinterpret_cast<void*>(& ::_elm_layout_file_set_wrapper<T>);
   ops[30].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_file_set);
   ops[30].op = EO_OP_OVERRIDE;
   ops[30].op_type = EO_OP_TYPE_REGULAR;
   ops[30].doc = NULL;

   ops[31].func = reinterpret_cast<void*>(& ::_elm_layout_theme_set_wrapper<T>);
   ops[31].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_theme_set);
   ops[31].op = EO_OP_OVERRIDE;
   ops[31].op_type = EO_OP_TYPE_REGULAR;
   ops[31].doc = NULL;

   ops[32].func = reinterpret_cast<void*>(& ::_elm_layout_text_aliases_get_wrapper<T>);
   ops[32].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_text_aliases_get);
   ops[32].op = EO_OP_OVERRIDE;
   ops[32].op_type = EO_OP_TYPE_REGULAR;
   ops[32].doc = NULL;

   ops[33].func = reinterpret_cast<void*>(& ::_elm_layout_content_aliases_get_wrapper<T>);
   ops[33].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_content_aliases_get);
   ops[33].op = EO_OP_OVERRIDE;
   ops[33].op_type = EO_OP_TYPE_REGULAR;
   ops[33].doc = NULL;

   ops[34].func = reinterpret_cast<void*>(& ::_elm_layout_edje_get_wrapper<T>);
   ops[34].api_func = reinterpret_cast<void*>(& ::elm_obj_layout_edje_get);
   ops[34].op = EO_OP_OVERRIDE;
   ops[34].op_type = EO_OP_TYPE_REGULAR;
   ops[34].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_layout >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_layout, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_layout >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_layout, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_layout>
{
   template <typename U>
   struct type
   {
      operator ::elm_layout() const
      {
         return ::elm_layout(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      bool box_remove_all(std::string part_, bool clear_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_box_remove_all(efl::eolian::to_c(part_), efl::eolian::to_c(clear_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool part_cursor_engine_only_set(std::string part_name_, bool engine_only_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_part_cursor_engine_only_set(efl::eolian::to_c(part_name_), efl::eolian::to_c(engine_only_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool part_cursor_engine_only_get(std::string part_name_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_part_cursor_engine_only_get(efl::eolian::to_c(part_name_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      evas::object table_unpack(std::string part_, evas::object child_)
      {
         Evas_Object * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_table_unpack(efl::eolian::to_c(part_), efl::eolian::to_c(child_)));
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      int freeze()
      {
         int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_freeze());
            return _tmp_ret;
      }

      bool theme_enable()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_theme_enable());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void sizing_eval()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_layout_sizing_eval());
      }

      evas::object box_remove(std::string part_, evas::object child_)
      {
         Evas_Object * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_box_remove(efl::eolian::to_c(part_), efl::eolian::to_c(child_)));
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      void sizing_restricted_eval(bool width_, bool height_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_layout_sizing_restricted_eval(efl::eolian::to_c(width_), efl::eolian::to_c(height_)));
      }

      bool part_cursor_style_set(std::string part_name_, std::string style_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_part_cursor_style_set(efl::eolian::to_c(part_name_), efl::eolian::to_c(style_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      std::string part_cursor_style_get(std::string part_name_)
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_part_cursor_style_get(efl::eolian::to_c(part_name_)));
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool text_set(std::string part_, std::string text_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_text_set(efl::eolian::to_c(part_), efl::eolian::to_c(text_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      std::string text_get(std::string part_)
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_text_get(efl::eolian::to_c(part_)));
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      void signal_callback_add(std::string emission_, std::string source_, Edje_Signal_Cb func_, void * data_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_layout_signal_callback_add(efl::eolian::to_c(emission_), efl::eolian::to_c(source_), func_, data_));
      }

      bool part_cursor_set(std::string part_name_, std::string cursor_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_part_cursor_set(efl::eolian::to_c(part_name_), efl::eolian::to_c(cursor_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      std::string part_cursor_get(std::string part_name_)
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_part_cursor_get(efl::eolian::to_c(part_name_)));
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool box_insert_before(std::string part_, evas::object child_, const Evas_Object * reference_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_box_insert_before(efl::eolian::to_c(part_), efl::eolian::to_c(child_), reference_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool box_insert_at(std::string part_, evas::object child_, unsigned int pos_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_box_insert_at(efl::eolian::to_c(part_), efl::eolian::to_c(child_), pos_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool sub_object_add_enable()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_sub_object_add_enable());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      std::string data_get(std::string key_)
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_data_get(efl::eolian::to_c(key_)));
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool box_append(std::string part_, evas::object child_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_box_append(efl::eolian::to_c(part_), efl::eolian::to_c(child_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void * signal_callback_del(std::string emission_, std::string source_, Edje_Signal_Cb func_)
      {
         void * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_signal_callback_del(efl::eolian::to_c(emission_), efl::eolian::to_c(source_), func_));
            return _tmp_ret;
      }

      int thaw()
      {
         int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_thaw());
            return _tmp_ret;
      }

      bool box_prepend(std::string part_, evas::object child_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_box_prepend(efl::eolian::to_c(part_), efl::eolian::to_c(child_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void signal_emit(std::string emission_, std::string source_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_layout_signal_emit(efl::eolian::to_c(emission_), efl::eolian::to_c(source_)));
      }

      bool table_pack(std::string part_, evas::object child_, unsigned short col_, unsigned short row_, unsigned short colspan_, unsigned short rowspan_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_table_pack(efl::eolian::to_c(part_), efl::eolian::to_c(child_), col_, row_, colspan_, rowspan_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool part_cursor_unset(std::string part_name_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_part_cursor_unset(efl::eolian::to_c(part_name_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool table_clear(std::string part_, bool clear_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_table_clear(efl::eolian::to_c(part_), efl::eolian::to_c(clear_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool edje_object_can_access_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_edje_object_can_access_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool edje_object_can_access_set(bool can_access_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_edje_object_can_access_set(efl::eolian::to_c(can_access_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool file_set(std::string file_, std::string group_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_file_set(efl::eolian::to_c(file_), efl::eolian::to_c(group_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool theme_set(std::string klass_, std::string group_, std::string style_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_theme_set(efl::eolian::to_c(klass_), efl::eolian::to_c(group_), efl::eolian::to_c(style_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      const Elm_Layout_Part_Alias_Description * text_aliases_get()
      {
         const Elm_Layout_Part_Alias_Description * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_text_aliases_get());
            return _tmp_ret;
      }

      const Elm_Layout_Part_Alias_Description * content_aliases_get()
      {
         const Elm_Layout_Part_Alias_Description * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_content_aliases_get());
            return _tmp_ret;
      }

      evas::object edje_get()
      {
         Evas_Object * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_layout_edje_get());
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_theme_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LAYOUT_EVENT_THEME_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_layout, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_layout, function_type>,
         ELM_LAYOUT_EVENT_THEME_CHANGED );
   }

   template <typename T>
   void
   callback_theme_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_LAYOUT_EVENT_THEME_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LAYOUT_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_layout, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_layout, function_type>,
         ELM_LAYOUT_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_LAYOUT_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LAYOUT_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_layout, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_layout, function_type>,
         ELM_LAYOUT_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_LAYOUT_EVENT_UNFOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LAYOUT_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_layout, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_layout, function_type>,
         ELM_LAYOUT_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_LAYOUT_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LAYOUT_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_layout, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_layout, function_type>,
         ELM_LAYOUT_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_LAYOUT_EVENT_ACCESS_CHANGED, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_layout>)
{
   return (ELM_LAYOUT_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_LAYOUT_HH

