#ifndef EFL_GENERATED_ELM_LIST_HH
#define EFL_GENERATED_ELM_LIST_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_list.eo.h"
}

#include "elm_layout.eo.hh"
#include "elm_interface_scrollable.eo.hh"
#include "elm_interface_atspi_widget_action.eo.hh"
#include <canvas/evas_object.eo.hh>
#include <string>

struct elm_list
      : elm_layout,
      efl::eo::detail::extension_inheritance<elm_interface_scrollable>::template type< ::elm_list>,
      efl::eo::detail::extension_inheritance<elm_interface_atspi_widget_action>::template type< ::elm_list>

{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_list(Eo* eo)
      : elm_layout(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_list(std::nullptr_t)
      : elm_layout(nullptr)
   {}

   elm_list(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_list(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_list(elm_list const& other)
      : elm_layout(eo_ref(other._eo_ptr()))
   {}

   ~elm_list() {}

   /// @brief Insert a new item into the list object before item @p before.
   ///
   /// @return The created item or @c NULL upon failure.
   ///
   /// A new item will be created and added to the list. Its position in
   /// this list will be just before item @p before.
   ///
   /// Items created with this method can be deleted with elm_object_item_del().
   ///
   /// Associated @p data can be properly freed when item is deleted if a
   /// callback function is set with elm_object_item_del_cb_set().
   ///
   /// If a function is passed as argument, it will be called every time this item
   /// is selected, i.e., the user clicks over an unselected item.
   /// If always select is enabled it will call this function every time
   /// user clicks over an item (already selected or not).
   /// If such function isn't needed, just passing
   /// @c NULL as @p func is enough. The same should be done for @p data.
   ///
   /// @note Remember that the label parameter is copied inside the list. So if an
   /// application dynamically allocated the label, the application should free the
   /// label after this call.
   ///
   /// @see elm_list_item_append() for a simple code example.
   /// @see elm_list_select_mode_set()
   /// @see elm_object_item_del()
   /// @see elm_object_item_del_cb_set()
   /// @see elm_list_clear()
   /// @see elm_icon_add()
   ///
   /// @ingroup List
   ///
   /// @param before The list item to insert before.
   /// @param label The label of the list item.
   /// @param icon The icon object to use for the left side of the item. An
   /// icon can be any Evas object, but usually it is an icon created
   /// with elm_icon_add().
   /// @param end The icon object to use for the right side of the item. An
   /// icon can be any Evas object.
   /// @param func The function to call when the item is clicked.
   /// @param data The data to associate with the item for related callbacks.
   ///
   Elm_Object_Item * item_insert_before(Elm_Object_Item * before_, std::string label_, evas::object icon_, evas::object end_, Evas_Smart_Cb func_, const void * data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_list_item_insert_before(before_, efl::eolian::to_c(label_), efl::eolian::to_c(icon_), efl::eolian::to_c(end_), func_, data_));
      return _tmp_ret;
   }

   /// @brief Starts the list.
   ///
   /// @note Call before running show() on the list object.
   /// @warning If not called, it won't display the list properly.
   ///
   /// @code
   /// li = elm_list_add(win);
   /// elm_list_item_append(li, "First", NULL, NULL, NULL, NULL);
   /// elm_list_item_append(li, "Second", NULL, NULL, NULL, NULL);
   /// elm_list_go(li);
   /// evas_object_show(li);
   /// @endcode
   ///
   /// @ingroup List
   ///
   void go() const
   {
      eo_do(_eo_ptr(), ::elm_obj_list_go());
   }

   /// @brief Insert a new item into the list object after item @p after.
   ///
   /// @return The created item or @c NULL upon failure.
   ///
   /// A new item will be created and added to the list. Its position in
   /// this list will be just after item @p after.
   ///
   /// Items created with this method can be deleted with elm_object_item_del().
   ///
   /// Associated @p data can be properly freed when item is deleted if a
   /// callback function is set with elm_object_item_del_cb_set().
   ///
   /// If a function is passed as argument, it will be called every time this item
   /// is selected, i.e., the user clicks over an unselected item.
   /// If always select is enabled it will call this function every time
   /// user clicks over an item (already selected or not).
   /// If such function isn't needed, just passing
   /// @c NULL as @p func is enough. The same should be done for @p data.
   ///
   /// @note Remember that the label parameter is copied inside the list. So if an
   /// application dynamically allocated the label, the application should free the
   /// label after this call.
   ///
   /// @see elm_list_item_append() for a simple code example.
   /// @see elm_list_select_mode_set()
   /// @see elm_object_item_del()
   /// @see elm_object_item_del_cb_set()
   /// @see elm_list_clear()
   /// @see elm_icon_add()
   ///
   /// @ingroup List
   ///
   /// @param after The list item to insert after.
   /// @param label The label of the list item.
   /// @param icon The icon object to use for the left side of the item. An
   /// icon can be any Evas object, but usually it is an icon created
   /// with elm_icon_add().
   /// @param end The icon object to use for the right side of the item. An
   /// icon can be any Evas object.
   /// @param func The function to call when the item is clicked.
   /// @param data The data to associate with the item for related callbacks.
   ///
   Elm_Object_Item * item_insert_after(Elm_Object_Item * after_, std::string label_, evas::object icon_, evas::object end_, Evas_Smart_Cb func_, const void * data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_list_item_insert_after(after_, efl::eolian::to_c(label_), efl::eolian::to_c(icon_), efl::eolian::to_c(end_), func_, data_));
      return _tmp_ret;
   }

   /// @brief Get the item that is at the x, y canvas coords.
   ///
   /// @return The item at the coordinates or NULL if none
   ///
   /// This returns the item at the given coordinates (which are canvas
   /// relative, not object-relative). If an item is at that coordinate,
   /// that item handle is returned, and if @p posret is not NULL, the
   /// integer pointed to is set to a value of -1, 0 or 1, depending if
   /// the coordinate is on the upper portion of that item (-1), on the
   /// middle section (0) or on the lower part (1). If NULL is returned as
   /// an item (no item found there), then posret may indicate -1 or 1
   /// based if the coordinate is above or below all items respectively in
   /// the list.
   ///
   ///
   /// @ingroup List
   ///
   /// @param x The input x coordinate
   /// @param y The input y coordinate
   /// @param[out] posret The position relative to the item returned here
   ///
   Elm_Object_Item * at_xy_item_get(Evas_Coord x_, Evas_Coord y_, int* posret_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_list_at_xy_item_get(x_, y_, posret_));
      return _tmp_ret;
   }

   /// @brief Append a new item to the list object.
   ///
   /// @return The created item or @c NULL upon failure.
   ///
   /// A new item will be created and appended to the list, i.e., will
   /// be set as @b last item.
   ///
   /// Items created with this method can be deleted with elm_object_item_del().
   ///
   /// Associated @p data can be properly freed when item is deleted if a
   /// callback function is set with elm_object_item_del_cb_set().
   ///
   /// If a function is passed as argument, it will be called every time this item
   /// is selected, i.e., the user clicks over an unselected item.
   /// If always select is enabled it will call this function every time
   /// user clicks over an item (already selected or not).
   /// If such function isn't needed, just passing
   /// @c NULL as @p func is enough. The same should be done for @p data.
   ///
   /// @note Remember that the label parameter is copied inside the list. So if an
   /// application dynamically allocated the label, the application should free the
   /// label after this call.
   ///
   /// Simple example (with no function callback or data associated):
   /// @code
   /// li = elm_list_add(win);
   /// ic = elm_icon_add(win);
   /// elm_image_file_set(ic, "path/to/image", NULL);
   /// elm_icon_resizable_set(ic, EINA_TRUE, EINA_TRUE);
   /// elm_list_item_append(li, "label", ic, NULL, NULL, NULL);
   /// elm_list_go(li);
   /// evas_object_show(li);
   /// @endcode
   ///
   /// @see elm_list_select_mode_set()
   /// @see elm_object_item_del()
   /// @see elm_object_item_del_cb_set()
   /// @see elm_list_clear()
   /// @see elm_icon_add()
   ///
   /// @ingroup List
   ///
   /// @param label The label of the list item.
   /// @param icon The icon object to use for the left side of the item. An
   /// icon can be any Evas object, but usually it is an icon created
   /// with elm_icon_add().
   /// @param end The icon object to use for the right side of the item. An
   /// icon can be any Evas object.
   /// @param func The function to call when the item is clicked.
   /// @param data The data to associate with the item for related callbacks.
   ///
   Elm_Object_Item * item_append(std::string label_, evas::object icon_, evas::object end_, Evas_Smart_Cb func_, const void * data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_list_item_append(efl::eolian::to_c(label_), efl::eolian::to_c(icon_), efl::eolian::to_c(end_), func_, data_));
      return _tmp_ret;
   }

   /// @brief Prepend a new item to the list object.
   ///
   /// @return The created item or @c NULL upon failure.
   ///
   /// A new item will be created and prepended to the list, i.e., will
   /// be set as @b first item.
   ///
   /// Items created with this method can be deleted with elm_object_item_del().
   ///
   /// Associated @p data can be properly freed when item is deleted if a
   /// callback function is set with elm_object_item_del_cb_set().
   ///
   /// If a function is passed as argument, it will be called every time this item
   /// is selected, i.e., the user clicks over an unselected item.
   /// If always select is enabled it will call this function every time
   /// user clicks over an item (already selected or not).
   /// If such function isn't needed, just passing
   /// @c NULL as @p func is enough. The same should be done for @p data.
   ///
   /// @note Remember that the label parameter is copied inside the list. So if an
   /// application dynamically allocated the label, the application should free the
   /// label after this call.
   ///
   /// @see elm_list_item_append() for a simple code example.
   /// @see elm_list_select_mode_set()
   /// @see elm_object_item_del()
   /// @see elm_object_item_del_cb_set()
   /// @see elm_list_clear()
   /// @see elm_icon_add()
   ///
   /// @ingroup List
   ///
   /// @param label The label of the list item.
   /// @param icon The icon object to use for the left side of the item. An
   /// icon can be any Evas object, but usually it is an icon created
   /// with elm_icon_add().
   /// @param end The icon object to use for the right side of the item. An
   /// icon can be any Evas object.
   /// @param func The function to call when the item is clicked.
   /// @param data The data to associate with the item for related callbacks.
   ///
   Elm_Object_Item * item_prepend(std::string label_, evas::object icon_, evas::object end_, Evas_Smart_Cb func_, const void * data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_list_item_prepend(efl::eolian::to_c(label_), efl::eolian::to_c(icon_), efl::eolian::to_c(end_), func_, data_));
      return _tmp_ret;
   }

   /// @brief Remove all list's items.
   ///
   /// @see elm_object_item_del()
   /// @see elm_list_item_append()
   ///
   /// @ingroup List
   ///
   void clear() const
   {
      eo_do(_eo_ptr(), ::elm_obj_list_clear());
   }

   /// @brief Insert a new item into the sorted list object.
   ///
   /// @return The created item or @c NULL upon failure.
   ///
   /// @note This function inserts values into a list object assuming it was
   /// sorted and the result will be sorted.
   ///
   /// A new item will be created and added to the list. Its position in
   /// this list will be found comparing the new item with previously inserted
   /// items using function @p cmp_func.
   ///
   /// Items created with this method can be deleted with elm_object_item_del().
   ///
   /// Associated @p data can be properly freed when item is deleted if a
   /// callback function is set with elm_object_item_del_cb_set().
   ///
   /// If a function is passed as argument, it will be called every time this item
   /// is selected, i.e., the user clicks over an unselected item.
   /// If always select is enabled it will call this function every time
   /// user clicks over an item (already selected or not).
   /// If such function isn't needed, just passing
   /// @c NULL as @p func is enough. The same should be done for @p data.
   ///
   /// @note Remember that the label parameter is copied inside the list. So if an
   /// application dynamically allocated the label, the application should free the
   /// label after this call.
   ///
   /// @see elm_list_item_append() for a simple code example.
   /// @see elm_list_select_mode_set()
   /// @see elm_object_item_del()
   /// @see elm_object_item_del_cb_set()
   /// @see elm_list_clear()
   /// @see elm_icon_add()
   ///
   /// @ingroup List
   ///
   /// @param label The label of the list item.
   /// @param icon The icon object to use for the left side of the item. An
   /// icon can be any Evas object, but usually it is an icon created
   /// with elm_icon_add().
   /// @param end The icon object to use for the right side of the item. An
   /// icon can be any Evas object.
   /// @param func The function to call when the item is clicked.
   /// @param data The data to associate with the item for related callbacks.
   /// @param cmp_func The comparing function to be used to sort list
   /// items <b>by #Elm_Object_Item item handles</b>. This function will
   /// receive two items and compare them, returning a non-negative integer
   /// if the second item should be place after the first, or negative value
   /// if should be placed before.
   ///
   Elm_Object_Item * item_sorted_insert(std::string label_, evas::object icon_, evas::object end_, Evas_Smart_Cb func_, const void * data_, Eina_Compare_Cb cmp_func_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_list_item_sorted_insert(efl::eolian::to_c(label_), efl::eolian::to_c(icon_), efl::eolian::to_c(end_), func_, data_, cmp_func_));
      return _tmp_ret;
   }

   /// @param horizontal @c EINA_TRUE to enable horizontal or @c EINA_FALSE to
   /// disable it, i.e., to enable vertical mode.
   ///
   bool horizontal_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_list_horizontal_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param horizontal @c EINA_TRUE to enable horizontal or @c EINA_FALSE to
   /// disable it, i.e., to enable vertical mode.
   ///
   void horizontal_set(bool horizontal_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_list_horizontal_set(efl::eolian::to_c(horizontal_)));
   }

   /// @param mode The select mode
   ///
   Elm_Object_Select_Mode select_mode_get() const
   {
      Elm_Object_Select_Mode _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_list_select_mode_get());
      return _tmp_ret;
   }

   /// @param mode The select mode
   ///
   void select_mode_set(Elm_Object_Select_Mode mode_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_list_select_mode_set(mode_));
   }

   /// @param enabled The tree effect status
   /// (EINA_TRUE = enabled, EINA_FALSE = disabled)
   ///
   bool focus_on_selection_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_list_focus_on_selection_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param enabled The tree effect status
   /// (EINA_TRUE = enabled, EINA_FALSE = disabled)
   ///
   void focus_on_selection_set(bool enabled_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_list_focus_on_selection_set(efl::eolian::to_c(enabled_)));
   }

   /// @param multi @c EINA_TRUE to enable multi selection or @c EINA_FALSE to
   /// disable it.
   ///
   bool multi_select_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_list_multi_select_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param multi @c EINA_TRUE to enable multi selection or @c EINA_FALSE to
   /// disable it.
   ///
   void multi_select_set(bool multi_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_list_multi_select_set(efl::eolian::to_c(multi_)));
   }

   /// @param mode The multi select mode
   ///
   Elm_Object_Multi_Select_Mode multi_select_mode_get() const
   {
      Elm_Object_Multi_Select_Mode _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_list_multi_select_mode_get());
      return _tmp_ret;
   }

   /// @param mode The multi select mode
   ///
   void multi_select_mode_set(Elm_Object_Multi_Select_Mode mode_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_list_multi_select_mode_set(mode_));
   }

   /// @param mode One of #Elm_List_Mode: #ELM_LIST_COMPRESS,
   /// #ELM_LIST_SCROLL, #ELM_LIST_LIMIT or #ELM_LIST_EXPAND.
   ///
   Elm_List_Mode mode_get() const
   {
      Elm_List_Mode _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_list_mode_get());
      return _tmp_ret;
   }

   /// @param mode One of #Elm_List_Mode: #ELM_LIST_COMPRESS,
   /// #ELM_LIST_SCROLL, #ELM_LIST_LIMIT or #ELM_LIST_EXPAND.
   ///
   void mode_set(Elm_List_Mode mode_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_list_mode_set(mode_));
   }

   Elm_Object_Item * selected_item_get() const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_list_selected_item_get());
      return _tmp_ret;
   }

   const Eina_List * items_get() const
   {
      const Eina_List * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_list_items_get());
      return _tmp_ret;
   }

   Elm_Object_Item * first_item_get() const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_list_first_item_get());
      return _tmp_ret;
   }

   const Eina_List * selected_items_get() const
   {
      const Eina_List * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_list_selected_items_get());
      return _tmp_ret;
   }

   Elm_Object_Item * last_item_get() const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_list_last_item_get());
      return _tmp_ret;
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_activated_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_ACTIVATED, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_ACTIVATED );
   }

   template <typename T>
   void
   callback_activated_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_ACTIVATED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_clicked_double_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_CLICKED_DOUBLE, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_CLICKED_DOUBLE );
   }

   template <typename T>
   void
   callback_clicked_double_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_CLICKED_DOUBLE, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_selected_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_SELECTED, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_SELECTED );
   }

   template <typename T>
   void
   callback_selected_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_SELECTED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unselected_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_UNSELECTED, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_UNSELECTED );
   }

   template <typename T>
   void
   callback_unselected_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_UNSELECTED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_longpressed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_LONGPRESSED, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_LONGPRESSED );
   }

   template <typename T>
   void
   callback_longpressed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_LONGPRESSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_edge_top_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_EDGE_TOP, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_EDGE_TOP );
   }

   template <typename T>
   void
   callback_edge_top_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_EDGE_TOP, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_edge_bottom_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_EDGE_BOTTOM, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_EDGE_BOTTOM );
   }

   template <typename T>
   void
   callback_edge_bottom_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_EDGE_BOTTOM, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_edge_left_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_EDGE_LEFT, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_EDGE_LEFT );
   }

   template <typename T>
   void
   callback_edge_left_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_EDGE_LEFT, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_edge_right_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_EDGE_RIGHT, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_EDGE_RIGHT );
   }

   template <typename T>
   void
   callback_edge_right_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_EDGE_RIGHT, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_swipe_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_SWIPE, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_SWIPE );
   }

   template <typename T>
   void
   callback_swipe_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_SWIPE, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_highlighted_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_HIGHLIGHTED, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_HIGHLIGHTED );
   }

   template <typename T>
   void
   callback_highlighted_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_HIGHLIGHTED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unhighlighted_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_UNHIGHLIGHTED, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_UNHIGHLIGHTED );
   }

   template <typename T>
   void
   callback_unhighlighted_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_UNHIGHLIGHTED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_item_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_ITEM_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_ITEM_FOCUSED );
   }

   template <typename T>
   void
   callback_item_focused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_ITEM_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_item_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_ITEM_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_ITEM_UNFOCUSED );
   }

   template <typename T>
   void
   callback_item_unfocused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_ITEM_UNFOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_UNFOCUSED, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_LIST_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_LIST_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
Elm_Object_Item * _elm_list_item_insert_before_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Object_Item * before_, const char * label_, Evas_Object * icon_, Evas_Object * end_, Evas_Smart_Cb func_, const void * data_)
{
   return static_cast<T*>(self->this_)->item_insert_before(before_, efl::eolian::to_cxx<std::string>(label_, std::tuple<std::false_type>()), efl::eolian::to_cxx<evas::object>(icon_, std::tuple<std::false_type>()), efl::eolian::to_cxx<evas::object>(end_, std::tuple<std::false_type>()), func_, data_);
}

template <typename T>
void _elm_list_go_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->go();
}

template <typename T>
Elm_Object_Item * _elm_list_item_insert_after_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Object_Item * after_, const char * label_, Evas_Object * icon_, Evas_Object * end_, Evas_Smart_Cb func_, const void * data_)
{
   return static_cast<T*>(self->this_)->item_insert_after(after_, efl::eolian::to_cxx<std::string>(label_, std::tuple<std::false_type>()), efl::eolian::to_cxx<evas::object>(icon_, std::tuple<std::false_type>()), efl::eolian::to_cxx<evas::object>(end_, std::tuple<std::false_type>()), func_, data_);
}

template <typename T>
Elm_Object_Item * _elm_list_at_xy_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord x_, Evas_Coord y_, int* posret_)
{
   return static_cast<T*>(self->this_)->at_xy_item_get(x_, y_, posret_);
}

template <typename T>
Elm_Object_Item * _elm_list_item_append_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * label_, Evas_Object * icon_, Evas_Object * end_, Evas_Smart_Cb func_, const void * data_)
{
   return static_cast<T*>(self->this_)->item_append(efl::eolian::to_cxx<std::string>(label_, std::tuple<std::false_type>()), efl::eolian::to_cxx<evas::object>(icon_, std::tuple<std::false_type>()), efl::eolian::to_cxx<evas::object>(end_, std::tuple<std::false_type>()), func_, data_);
}

template <typename T>
Elm_Object_Item * _elm_list_item_prepend_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * label_, Evas_Object * icon_, Evas_Object * end_, Evas_Smart_Cb func_, const void * data_)
{
   return static_cast<T*>(self->this_)->item_prepend(efl::eolian::to_cxx<std::string>(label_, std::tuple<std::false_type>()), efl::eolian::to_cxx<evas::object>(icon_, std::tuple<std::false_type>()), efl::eolian::to_cxx<evas::object>(end_, std::tuple<std::false_type>()), func_, data_);
}

template <typename T>
void _elm_list_clear_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->clear();
}

template <typename T>
Elm_Object_Item * _elm_list_item_sorted_insert_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * label_, Evas_Object * icon_, Evas_Object * end_, Evas_Smart_Cb func_, const void * data_, Eina_Compare_Cb cmp_func_)
{
   return static_cast<T*>(self->this_)->item_sorted_insert(efl::eolian::to_cxx<std::string>(label_, std::tuple<std::false_type>()), efl::eolian::to_cxx<evas::object>(icon_, std::tuple<std::false_type>()), efl::eolian::to_cxx<evas::object>(end_, std::tuple<std::false_type>()), func_, data_, cmp_func_);
}

template <typename T>
bool _elm_list_horizontal_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->horizontal_get();
}

template <typename T>
void _elm_list_horizontal_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool horizontal_)
{
   static_cast<T*>(self->this_)->horizontal_set(efl::eolian::to_cxx<bool>(horizontal_, std::tuple<std::false_type>()));
}

template <typename T>
Elm_Object_Select_Mode _elm_list_select_mode_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->select_mode_get();
}

template <typename T>
void _elm_list_select_mode_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Object_Select_Mode mode_)
{
   static_cast<T*>(self->this_)->select_mode_set(mode_);
}

template <typename T>
bool _elm_list_focus_on_selection_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->focus_on_selection_get();
}

template <typename T>
void _elm_list_focus_on_selection_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool enabled_)
{
   static_cast<T*>(self->this_)->focus_on_selection_set(efl::eolian::to_cxx<bool>(enabled_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_list_multi_select_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->multi_select_get();
}

template <typename T>
void _elm_list_multi_select_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool multi_)
{
   static_cast<T*>(self->this_)->multi_select_set(efl::eolian::to_cxx<bool>(multi_, std::tuple<std::false_type>()));
}

template <typename T>
Elm_Object_Multi_Select_Mode _elm_list_multi_select_mode_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->multi_select_mode_get();
}

template <typename T>
void _elm_list_multi_select_mode_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Object_Multi_Select_Mode mode_)
{
   static_cast<T*>(self->this_)->multi_select_mode_set(mode_);
}

template <typename T>
Elm_List_Mode _elm_list_mode_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->mode_get();
}

template <typename T>
void _elm_list_mode_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_List_Mode mode_)
{
   static_cast<T*>(self->this_)->mode_set(mode_);
}

template <typename T>
Elm_Object_Item * _elm_list_selected_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->selected_item_get();
}

template <typename T>
const Eina_List * _elm_list_items_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->items_get();
}

template <typename T>
Elm_Object_Item * _elm_list_first_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->first_item_get();
}

template <typename T>
const Eina_List * _elm_list_selected_items_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->selected_items_get();
}

template <typename T>
Elm_Object_Item * _elm_list_last_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->last_item_get();
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_list >
{
   template <typename T>
   struct type
   {
      virtual Elm_Object_Item * item_insert_before(Elm_Object_Item * before_, std::string label_, evas::object icon_, evas::object end_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_list_item_insert_before(before_, efl::eolian::to_c(label_), efl::eolian::to_c(icon_), efl::eolian::to_c(end_), func_, data_));
            return _tmp_ret;
      }

      virtual void go()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_list_go());
      }

      virtual Elm_Object_Item * item_insert_after(Elm_Object_Item * after_, std::string label_, evas::object icon_, evas::object end_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_list_item_insert_after(after_, efl::eolian::to_c(label_), efl::eolian::to_c(icon_), efl::eolian::to_c(end_), func_, data_));
            return _tmp_ret;
      }

      virtual Elm_Object_Item * at_xy_item_get(Evas_Coord x_, Evas_Coord y_, int* posret_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_list_at_xy_item_get(x_, y_, posret_));
            return _tmp_ret;
      }

      virtual Elm_Object_Item * item_append(std::string label_, evas::object icon_, evas::object end_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_list_item_append(efl::eolian::to_c(label_), efl::eolian::to_c(icon_), efl::eolian::to_c(end_), func_, data_));
            return _tmp_ret;
      }

      virtual Elm_Object_Item * item_prepend(std::string label_, evas::object icon_, evas::object end_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_list_item_prepend(efl::eolian::to_c(label_), efl::eolian::to_c(icon_), efl::eolian::to_c(end_), func_, data_));
            return _tmp_ret;
      }

      virtual void clear()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_list_clear());
      }

      virtual Elm_Object_Item * item_sorted_insert(std::string label_, evas::object icon_, evas::object end_, Evas_Smart_Cb func_, const void * data_, Eina_Compare_Cb cmp_func_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_list_item_sorted_insert(efl::eolian::to_c(label_), efl::eolian::to_c(icon_), efl::eolian::to_c(end_), func_, data_, cmp_func_));
            return _tmp_ret;
      }

      virtual bool horizontal_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_list_horizontal_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void horizontal_set(bool horizontal_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_list_horizontal_set(efl::eolian::to_c(horizontal_)));
      }

      virtual Elm_Object_Select_Mode select_mode_get()
      {
         Elm_Object_Select_Mode _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_list_select_mode_get());
            return _tmp_ret;
      }

      virtual void select_mode_set(Elm_Object_Select_Mode mode_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_list_select_mode_set(mode_));
      }

      virtual bool focus_on_selection_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_list_focus_on_selection_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void focus_on_selection_set(bool enabled_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_list_focus_on_selection_set(efl::eolian::to_c(enabled_)));
      }

      virtual bool multi_select_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_list_multi_select_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void multi_select_set(bool multi_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_list_multi_select_set(efl::eolian::to_c(multi_)));
      }

      virtual Elm_Object_Multi_Select_Mode multi_select_mode_get()
      {
         Elm_Object_Multi_Select_Mode _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_list_multi_select_mode_get());
            return _tmp_ret;
      }

      virtual void multi_select_mode_set(Elm_Object_Multi_Select_Mode mode_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_list_multi_select_mode_set(mode_));
      }

      virtual Elm_List_Mode mode_get()
      {
         Elm_List_Mode _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_list_mode_get());
            return _tmp_ret;
      }

      virtual void mode_set(Elm_List_Mode mode_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_list_mode_set(mode_));
      }

      virtual Elm_Object_Item * selected_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_list_selected_item_get());
            return _tmp_ret;
      }

      virtual const Eina_List * items_get()
      {
         const Eina_List * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_list_items_get());
            return _tmp_ret;
      }

      virtual Elm_Object_Item * first_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_list_first_item_get());
            return _tmp_ret;
      }

      virtual const Eina_List * selected_items_get()
      {
         const Eina_List * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_list_selected_items_get());
            return _tmp_ret;
      }

      virtual Elm_Object_Item * last_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_list_last_item_get());
            return _tmp_ret;
      }

   };
};


template<>
struct operation_description_class_size< ::elm_list >
{
   static const int value = 25;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_list>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_list_item_insert_before_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_list_item_insert_before);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_list_go_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_list_go);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_list_item_insert_after_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_list_item_insert_after);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_list_at_xy_item_get_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_list_at_xy_item_get);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_list_item_append_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_list_item_append);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_list_item_prepend_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_list_item_prepend);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_list_clear_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_list_clear);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_list_item_sorted_insert_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_list_item_sorted_insert);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_list_horizontal_get_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_list_horizontal_get);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_list_horizontal_set_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_list_horizontal_set);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::_elm_list_select_mode_get_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::elm_obj_list_select_mode_get);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::_elm_list_select_mode_set_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::elm_obj_list_select_mode_set);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::_elm_list_focus_on_selection_get_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::elm_obj_list_focus_on_selection_get);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::_elm_list_focus_on_selection_set_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::elm_obj_list_focus_on_selection_set);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::_elm_list_multi_select_get_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::elm_obj_list_multi_select_get);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::_elm_list_multi_select_set_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::elm_obj_list_multi_select_set);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   ops[16].func = reinterpret_cast<void*>(& ::_elm_list_multi_select_mode_get_wrapper<T>);
   ops[16].api_func = reinterpret_cast<void*>(& ::elm_obj_list_multi_select_mode_get);
   ops[16].op = EO_OP_OVERRIDE;
   ops[16].op_type = EO_OP_TYPE_REGULAR;
   ops[16].doc = NULL;

   ops[17].func = reinterpret_cast<void*>(& ::_elm_list_multi_select_mode_set_wrapper<T>);
   ops[17].api_func = reinterpret_cast<void*>(& ::elm_obj_list_multi_select_mode_set);
   ops[17].op = EO_OP_OVERRIDE;
   ops[17].op_type = EO_OP_TYPE_REGULAR;
   ops[17].doc = NULL;

   ops[18].func = reinterpret_cast<void*>(& ::_elm_list_mode_get_wrapper<T>);
   ops[18].api_func = reinterpret_cast<void*>(& ::elm_obj_list_mode_get);
   ops[18].op = EO_OP_OVERRIDE;
   ops[18].op_type = EO_OP_TYPE_REGULAR;
   ops[18].doc = NULL;

   ops[19].func = reinterpret_cast<void*>(& ::_elm_list_mode_set_wrapper<T>);
   ops[19].api_func = reinterpret_cast<void*>(& ::elm_obj_list_mode_set);
   ops[19].op = EO_OP_OVERRIDE;
   ops[19].op_type = EO_OP_TYPE_REGULAR;
   ops[19].doc = NULL;

   ops[20].func = reinterpret_cast<void*>(& ::_elm_list_selected_item_get_wrapper<T>);
   ops[20].api_func = reinterpret_cast<void*>(& ::elm_obj_list_selected_item_get);
   ops[20].op = EO_OP_OVERRIDE;
   ops[20].op_type = EO_OP_TYPE_REGULAR;
   ops[20].doc = NULL;

   ops[21].func = reinterpret_cast<void*>(& ::_elm_list_items_get_wrapper<T>);
   ops[21].api_func = reinterpret_cast<void*>(& ::elm_obj_list_items_get);
   ops[21].op = EO_OP_OVERRIDE;
   ops[21].op_type = EO_OP_TYPE_REGULAR;
   ops[21].doc = NULL;

   ops[22].func = reinterpret_cast<void*>(& ::_elm_list_first_item_get_wrapper<T>);
   ops[22].api_func = reinterpret_cast<void*>(& ::elm_obj_list_first_item_get);
   ops[22].op = EO_OP_OVERRIDE;
   ops[22].op_type = EO_OP_TYPE_REGULAR;
   ops[22].doc = NULL;

   ops[23].func = reinterpret_cast<void*>(& ::_elm_list_selected_items_get_wrapper<T>);
   ops[23].api_func = reinterpret_cast<void*>(& ::elm_obj_list_selected_items_get);
   ops[23].op = EO_OP_OVERRIDE;
   ops[23].op_type = EO_OP_TYPE_REGULAR;
   ops[23].doc = NULL;

   ops[24].func = reinterpret_cast<void*>(& ::_elm_list_last_item_get_wrapper<T>);
   ops[24].api_func = reinterpret_cast<void*>(& ::elm_obj_list_last_item_get);
   ops[24].op = EO_OP_OVERRIDE;
   ops[24].op_type = EO_OP_TYPE_REGULAR;
   ops[24].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_list >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_list, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_list >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_list, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_list>
{
   template <typename U>
   struct type
   {
      operator ::elm_list() const
      {
         return ::elm_list(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      Elm_Object_Item * item_insert_before(Elm_Object_Item * before_, std::string label_, evas::object icon_, evas::object end_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_list_item_insert_before(before_, efl::eolian::to_c(label_), efl::eolian::to_c(icon_), efl::eolian::to_c(end_), func_, data_));
            return _tmp_ret;
      }

      void go()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_list_go());
      }

      Elm_Object_Item * item_insert_after(Elm_Object_Item * after_, std::string label_, evas::object icon_, evas::object end_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_list_item_insert_after(after_, efl::eolian::to_c(label_), efl::eolian::to_c(icon_), efl::eolian::to_c(end_), func_, data_));
            return _tmp_ret;
      }

      Elm_Object_Item * at_xy_item_get(Evas_Coord x_, Evas_Coord y_, int* posret_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_list_at_xy_item_get(x_, y_, posret_));
            return _tmp_ret;
      }

      Elm_Object_Item * item_append(std::string label_, evas::object icon_, evas::object end_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_list_item_append(efl::eolian::to_c(label_), efl::eolian::to_c(icon_), efl::eolian::to_c(end_), func_, data_));
            return _tmp_ret;
      }

      Elm_Object_Item * item_prepend(std::string label_, evas::object icon_, evas::object end_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_list_item_prepend(efl::eolian::to_c(label_), efl::eolian::to_c(icon_), efl::eolian::to_c(end_), func_, data_));
            return _tmp_ret;
      }

      void clear()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_list_clear());
      }

      Elm_Object_Item * item_sorted_insert(std::string label_, evas::object icon_, evas::object end_, Evas_Smart_Cb func_, const void * data_, Eina_Compare_Cb cmp_func_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_list_item_sorted_insert(efl::eolian::to_c(label_), efl::eolian::to_c(icon_), efl::eolian::to_c(end_), func_, data_, cmp_func_));
            return _tmp_ret;
      }

      bool horizontal_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_list_horizontal_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void horizontal_set(bool horizontal_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_list_horizontal_set(efl::eolian::to_c(horizontal_)));
      }

      Elm_Object_Select_Mode select_mode_get()
      {
         Elm_Object_Select_Mode _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_list_select_mode_get());
            return _tmp_ret;
      }

      void select_mode_set(Elm_Object_Select_Mode mode_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_list_select_mode_set(mode_));
      }

      bool focus_on_selection_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_list_focus_on_selection_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void focus_on_selection_set(bool enabled_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_list_focus_on_selection_set(efl::eolian::to_c(enabled_)));
      }

      bool multi_select_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_list_multi_select_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void multi_select_set(bool multi_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_list_multi_select_set(efl::eolian::to_c(multi_)));
      }

      Elm_Object_Multi_Select_Mode multi_select_mode_get()
      {
         Elm_Object_Multi_Select_Mode _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_list_multi_select_mode_get());
            return _tmp_ret;
      }

      void multi_select_mode_set(Elm_Object_Multi_Select_Mode mode_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_list_multi_select_mode_set(mode_));
      }

      Elm_List_Mode mode_get()
      {
         Elm_List_Mode _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_list_mode_get());
            return _tmp_ret;
      }

      void mode_set(Elm_List_Mode mode_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_list_mode_set(mode_));
      }

      Elm_Object_Item * selected_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_list_selected_item_get());
            return _tmp_ret;
      }

      const Eina_List * items_get()
      {
         const Eina_List * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_list_items_get());
            return _tmp_ret;
      }

      Elm_Object_Item * first_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_list_first_item_get());
            return _tmp_ret;
      }

      const Eina_List * selected_items_get()
      {
         const Eina_List * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_list_selected_items_get());
            return _tmp_ret;
      }

      Elm_Object_Item * last_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_list_last_item_get());
            return _tmp_ret;
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_activated_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_ACTIVATED, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_ACTIVATED );
   }

   template <typename T>
   void
   callback_activated_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_ACTIVATED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_clicked_double_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_CLICKED_DOUBLE, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_CLICKED_DOUBLE );
   }

   template <typename T>
   void
   callback_clicked_double_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_CLICKED_DOUBLE, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_selected_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_SELECTED, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_SELECTED );
   }

   template <typename T>
   void
   callback_selected_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_SELECTED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unselected_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_UNSELECTED, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_UNSELECTED );
   }

   template <typename T>
   void
   callback_unselected_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_UNSELECTED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_longpressed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_LONGPRESSED, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_LONGPRESSED );
   }

   template <typename T>
   void
   callback_longpressed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_LONGPRESSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_edge_top_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_EDGE_TOP, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_EDGE_TOP );
   }

   template <typename T>
   void
   callback_edge_top_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_EDGE_TOP, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_edge_bottom_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_EDGE_BOTTOM, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_EDGE_BOTTOM );
   }

   template <typename T>
   void
   callback_edge_bottom_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_EDGE_BOTTOM, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_edge_left_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_EDGE_LEFT, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_EDGE_LEFT );
   }

   template <typename T>
   void
   callback_edge_left_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_EDGE_LEFT, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_edge_right_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_EDGE_RIGHT, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_EDGE_RIGHT );
   }

   template <typename T>
   void
   callback_edge_right_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_EDGE_RIGHT, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_swipe_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_SWIPE, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_SWIPE );
   }

   template <typename T>
   void
   callback_swipe_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_SWIPE, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_highlighted_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_HIGHLIGHTED, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_HIGHLIGHTED );
   }

   template <typename T>
   void
   callback_highlighted_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_HIGHLIGHTED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unhighlighted_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_UNHIGHLIGHTED, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_UNHIGHLIGHTED );
   }

   template <typename T>
   void
   callback_unhighlighted_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_UNHIGHLIGHTED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_item_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_ITEM_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_ITEM_FOCUSED );
   }

   template <typename T>
   void
   callback_item_focused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_ITEM_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_item_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_ITEM_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_ITEM_UNFOCUSED );
   }

   template <typename T>
   void
   callback_item_unfocused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_ITEM_UNFOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_LIST_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_list, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_list, function_type>,
         ELM_LIST_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_LIST_EVENT_UNFOCUSED, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_list>)
{
   return (ELM_LIST_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_LIST_HH

