#ifndef EFL_GENERATED_ELM_MAP_HH
#define EFL_GENERATED_ELM_MAP_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_map.eo.h"
}

#include "elm_widget.eo.hh"
#include "elm_interface_scrollable.eo.hh"
#include "elm_interface_atspi_widget_action.eo.hh"
#include <canvas/evas_object.eo.hh>
#include <string>

struct elm_map
      : elm_widget,
      efl::eo::detail::extension_inheritance<elm_interface_scrollable>::template type< ::elm_map>,
      efl::eo::detail::extension_inheritance<elm_interface_atspi_widget_action>::template type< ::elm_map>

{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_map(Eo* eo)
      : elm_widget(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_map(std::nullptr_t)
      : elm_widget(nullptr)
   {}

   elm_map(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_map(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_map(elm_map const& other)
      : elm_widget(eo_ref(other._eo_ptr()))
   {}

   ~elm_map() {}

   /// @brief Set the current source of the map for a specific type.
   ///
   /// Map widget retrieves tile images that composes the map from a web service.
   /// This web service can be set with this method
   /// for ELM_MAP_SOURCE_TYPE_TILE type.
   /// A different service can return a different maps with different
   /// information and it can use different zoom values.
   ///
   /// Map widget provides route data based on a external web service.
   /// This web service can be set with this method
   /// for ELM_MAP_SOURCE_TYPE_ROUTE type.
   ///
   /// Map widget also provide geoname data based on a external web service.
   /// This web service can be set with this method
   /// for ELM_MAP_SOURCE_TYPE_NAME type.
   ///
   /// The @p source_name need to match one of the names provided by
   /// elm_map_sources_get().
   ///
   /// The current source can be get using elm_map_source_get().
   ///
   /// @see elm_map_sources_get()
   /// @see elm_map_source_get()
   ///
   /// @ingroup Map
   ///
   /// @param type source type.
   /// @param source_name The source to be used.
   ///
   void source_set(Elm_Map_Source_Type type_, std::string source_name_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_map_source_set(type_, efl::eolian::to_c(source_name_)));
   }

   /// @brief Get the name of currently used source for a specific type.
   ///
   /// @return Returns the name of the source in use.
   ///
   /// @see elm_map_sources_get()
   /// @see elm_map_source_set()
   ///
   /// @ingroup Map
   ///
   /// @param type source type.
   ///
   std::string source_get(Elm_Map_Source_Type type_) const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_map_source_get(type_));
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Add a new route to the map object.
   ///
   /// @return The created route or @c NULL upon failure.
   ///
   /// A route will be traced by point on coordinates (@p flat, @p flon)
   /// to point on coordinates (@p tlat, @p tlon), using the route service
   /// set with elm_map_source_set().
   ///
   /// It will take @p type on consideration to define the route,
   /// depending if the user will be walking or driving, the route may vary.
   /// One of #ELM_MAP_ROUTE_TYPE_MOTOCAR, #ELM_MAP_ROUTE_TYPE_BICYCLE,
   /// or #ELM_MAP_ROUTE_TYPE_FOOT need to be used.
   ///
   /// Another parameter is what the route should prioritize, the minor distance
   /// or the less time to be spend on the route. So @p method should be one
   /// of #ELM_MAP_ROUTE_METHOD_SHORTEST or #ELM_MAP_ROUTE_METHOD_FASTEST.
   ///
   /// Routes created with this method can be deleted with
   /// elm_map_route_del(),
   /// and distance can be get with elm_map_route_distance_get().
   ///
   /// @see elm_map_route_del()
   /// @see elm_map_route_distance_get()
   /// @see elm_map_source_set()
   ///
   /// @ingroup Map
   ///
   /// @param type The type of transport to be considered when tracing a route.
   /// @param method The routing method, what should be prioritized.
   /// @param flon The start longitude.
   /// @param flat The start latitude.
   /// @param tlon The destination longitude.
   /// @param tlat The destination latitude.
   /// @param route_cb The route to be traced.
   /// @param data A pointer of user data.
   ///
   Elm_Map_Route * route_add(Elm_Map_Route_Type type_, Elm_Map_Route_Method method_, double flon_, double flat_, double tlon_, double tlat_, Elm_Map_Route_Cb route_cb_, void * data_) const
   {
      Elm_Map_Route * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_map_route_add(type_, method_, flon_, flat_, tlon_, tlat_, route_cb_, data_));
      return _tmp_ret;
   }

   /// @brief Add a track on the map
   ///
   /// @return The route object. This is an elm object of type Route.
   ///
   /// @see elm_route_add() for details.
   ///
   /// @ingroup Map
   ///
   /// @param emap The emap route object.
   ///
   evas::object track_add(void * emap_) const
   {
      Evas_Object * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_map_track_add(emap_));
      return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Convert geographic coordinates (longitude, latitude)
   /// into canvas coordinates.
   ///
   /// This gets canvas x, y coordinates from longitude and latitude. The canvas
   /// coordinates mean x, y coordinate from current viewport.
   ///
   /// see elm_map_canvas_to_region_convert()
   ///
   /// @ingroup Map
   ///
   /// @param lon The longitude to convert.
   /// @param lat The latitude to convert.
   /// @param[out] x A pointer to horizontal coordinate.
   /// @param[out] y A pointer to vertical coordinate.
   ///
   void region_to_canvas_convert(double lon_, double lat_, Evas_Coord* x_, Evas_Coord* y_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_map_region_to_canvas_convert(lon_, lat_, x_, y_));
   }

   /// @brief Add a new circle overlay to the map object.
   /// This overlay has a circle type.
   ///
   /// @return The created overlay or @c NULL upon failure.
   ///
   /// Overlay created with this method can be deleted with elm_map_overlay_del().
   ///
   /// @see elm_map_overlay_del()
   ///
   /// @ingroup Map
   ///
   /// @param lon The center longitude.
   /// @param lat The center latitude.
   /// @param radius The pixel length of radius.
   ///
   Elm_Map_Overlay * overlay_circle_add(double lon_, double lat_, double radius_) const
   {
      Elm_Map_Overlay * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_map_overlay_circle_add(lon_, lat_, radius_));
      return _tmp_ret;
   }

   /// @brief Add a new class overlay to the map object.
   /// This overlay has a class type.
   ///
   /// @return The created overlay or @c NULL upon failure.
   ///
   /// This overlay is not shown before overlay members are appended.
   /// if overlay members in the same class are close, group overlays
   /// are created. If they are far away, group overlays are hidden.
   /// When group overlays are shown, they have default style layouts at first.
   ///
   /// You can change the state (hidden, paused, etc.) or set the content
   /// or icon of the group overlays by chaning the state of the class overlay.
   /// Do not modify the group overlay itself.
   ///
   /// Also these changes have a influence on the overlays in the same class
   /// even if each overlay is alone and is not grouped.
   ///
   /// @see elm_map_overlay_del()
   /// @see elm_map_overlay_add()
   /// @see elm_map_overlay_bubble_add()
   ///
   /// @ingroup Map
   ///
   Elm_Map_Overlay * overlay_class_add() const
   {
      Elm_Map_Overlay * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_map_overlay_class_add());
      return _tmp_ret;
   }

   /// @brief Add a new bubble overlay to the map object.
   /// This overlay has a bubble type.
   ///
   /// @return The created overlay or @c NULL upon failure.
   ///
   /// A bubble will not be displayed before geographic coordinates are set or
   /// any other overlays are followed.
   ///
   /// This overlay has a bubble style layout and icon or content can not
   /// be set.
   ///
   /// Overlay created with this method can be deleted with elm_map_overlay_del().
   ///
   /// @see elm_map_overlay_del()
   /// @see elm_map_overlay_add()
   /// @see elm_map_overlay_class_add()
   /// @see elm_map_overlay_region_set()
   /// @see elm_map_overlay_bubble_follow()
   ///
   /// @ingroup Map
   ///
   Elm_Map_Overlay * overlay_bubble_add() const
   {
      Elm_Map_Overlay * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_map_overlay_bubble_add());
      return _tmp_ret;
   }

   /// @brief Get the names of available sources for a specific type.
   ///
   /// @return The char pointer array of source names.
   ///
   /// It will provide a list with all available sources.
   /// Current source can be set by elm_map_source_set(), or get with
   /// elm_map_source_get().
   ///
   /// At least available sources of tile type:
   /// @li "Mapnik"
   /// @li "Osmarender"
   /// @li "CycleMap"
   /// @li "Maplint"
   ///
   /// At least available sources of route type:
   /// @li "Yours"
   ///
   /// At least available sources of name type:
   /// @li "Nominatim"
   ///
   /// @see elm_map_source_set()
   /// @see elm_map_source_get()
   ///
   /// @ingroup Map
   ///
   /// @param type source type.
   ///
   const char ** sources_get(Elm_Map_Source_Type type_) const
   {
      const char ** _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_map_sources_get(type_));
      return _tmp_ret;
   }

   /// @brief Add a new polygon overlay to the map object.
   /// This overlay has a polygon type.
   ///
   /// @return The created overlay or @c NULL upon failure.
   ///
   /// At least 3 regions should be added to show the polygon overlay.
   ///
   /// Overlay created with this method can be deleted with elm_map_overlay_del().
   ///
   /// @see elm_map_overlay_polygon_region_add()
   /// @see elm_map_overlay_del()
   ///
   /// @ingroup Map
   ///
   Elm_Map_Overlay * overlay_polygon_add() const
   {
      Elm_Map_Overlay * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_map_overlay_polygon_add());
      return _tmp_ret;
   }

   /// @brief Add a new line overlay to the map object.
   /// This overlay has a line type.
   ///
   /// @return The created overlay or @c NULL upon failure.
   ///
   /// Overlay created with this method can be deleted with elm_map_overlay_del().
   ///
   /// @see elm_map_overlay_del()
   ///
   /// @ingroup Map
   ///
   /// @param flon The start longitude.
   /// @param flat The start latitude.
   /// @param tlon The destination longitude.
   /// @param tlat The destination latitude.
   ///
   Elm_Map_Overlay * overlay_line_add(double flon_, double flat_, double tlon_, double tlat_) const
   {
      Elm_Map_Overlay * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_map_overlay_line_add(flon_, flat_, tlon_, tlat_));
      return _tmp_ret;
   }

   /// @brief Show the given coordinates at the center of the map, @b immediately.
   ///
   /// This causes map to @b redraw its viewport's contents to the
   /// region containing the given @p lat and @p lon, that will be moved to the
   /// center of the map.
   ///
   /// @see elm_map_region_bring_in() for a function to move with animation.
   /// @see elm_map_region_get()
   ///
   /// @ingroup Map
   ///
   /// @param lon Longitude to center at.
   /// @param lat Latitude to center at.
   ///
   void region_show(double lon_, double lat_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_map_region_show(lon_, lat_));
   }

   /// @brief Request a address or geographic coordinates(longitude, latitude)
   /// from a given address or geographic coordinate(longitude, latitude).
   ///
   /// @return name A #Elm_Map_Name handle for this coordinate.
   ///
   /// If you want to get address from geographic coordinates, set input @p address
   /// as @c NULL and set @p lon, @p lat as you want to convert.
   /// If address is set except NULL, @p lon and @p lat are checked.
   ///
   /// To get the string for this address, elm_map_name_address_get()
   /// should be used after callback or "name,loaded" signal is called.
   ///
   /// To get the longitude and latitude, elm_map_name_region_get()
   /// should be used.
   ///
   /// @ingroup Map
   ///
   /// @param address The address.
   /// @param lon The longitude.
   /// @param lat The latitude.
   /// @param name_cb The callback function.
   /// @param data The user callback data.
   ///
   Elm_Map_Name * name_add(std::string address_, double lon_, double lat_, Elm_Map_Name_Cb name_cb_, void * data_) const
   {
      Elm_Map_Name * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_map_name_add(efl::eolian::to_c(address_), lon_, lat_, name_cb_, data_));
      return _tmp_ret;
   }

   /// @brief @brief Requests a list of addresses corresponding to a given name.
   ///
   /// @since 1.8
   ///
   /// @remarks This is used if you want to search the address from a name.
   ///
   /// @internal
   /// @ingroup Map
   ///
   /// @param address The address.
   /// @param name_cb The callback function.
   /// @param data The user callback data.
   ///
   void name_search(std::string address_, Elm_Map_Name_List_Cb name_cb_, void * data_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_map_name_search(efl::eolian::to_c(address_), name_cb_, data_));
   }

   /// @brief Animatedly bring in given coordinates to the center of the map.
   ///
   /// This causes map to jump to the given @p lat and @p lon coordinates
   /// and show it (by scrolling) in the center of the viewport, if it is not
   /// already centered. This will use animation to do so and take a period
   /// of time to complete.
   ///
   /// @see elm_map_region_show() for a function to avoid animation.
   /// @see elm_map_region_get()
   ///
   /// @ingroup Map
   ///
   /// @param lon Longitude to center at.
   /// @param lat Latitude to center at.
   ///
   void region_bring_in(double lon_, double lat_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_map_region_bring_in(lon_, lat_));
   }

   /// @brief Animatedly set the zoom level of the map and bring in given coordinates
   /// to the center of the map.
   ///
   /// This causes map to zoom into specific zoom level and also move to the
   /// given @p lat and @p lon coordinates and show it (by scrolling) in the
   /// center of the viewport concurrently.
   ///
   /// @since 1.11
   ///
   /// @see elm_map_region_bring_in()
   /// @see elm_map_zoom_set()
   ///
   /// @ingroup Map
   ///
   /// @param zoom The zoom level to set.
   /// @param lon Longitude to center at.
   /// @param lat Latitude to center at.
   ///
   void region_zoom_bring_in(int zoom_, double lon_, double lat_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_map_region_zoom_bring_in(zoom_, lon_, lat_));
   }

   /// @brief Remove a track from the map
   ///
   /// @ingroup Map
   ///
   /// @param route The track to remove.
   ///
   void track_remove(evas::object route_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_map_track_remove(efl::eolian::to_c(route_)));
   }

   /// @brief Add a new route overlay to the map object.
   /// This overlay has a route type.
   ///
   /// @return The created overlay or @c NULL upon failure.
   ///
   /// This overlay has a route style layout and icon or content can not
   /// be set.
   ///
   /// The color scheme can be changed by elm_map_overlay_content_set().
   ///
   /// Overlay created with this method can be deleted with elm_map_overlay_del().
   ///
   /// @see elm_map_overlay_del()
   /// @see elm_map_overlay_class_add()
   /// @see elm_map_overlay_content_set()
   /// @see elm_map_overlay_content_get()
   ///
   /// @ingroup Map
   ///
   /// @param route The route object to make a overlay.
   ///
   Elm_Map_Overlay * overlay_route_add(const Elm_Map_Route * route_) const
   {
      Elm_Map_Overlay * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_map_overlay_route_add(route_));
      return _tmp_ret;
   }

   /// @brief Add a new scale overlay to the map object.
   /// This overlay has a scale type.
   ///
   /// @return The created overlay or @c NULL upon failure.
   ///
   /// The scale overlay shows the ratio of a distance on the map to the corresponding distance.
   ///
   /// Overlay created with this method can be deleted with elm_map_overlay_del().
   ///
   /// @see elm_map_overlay_del()
   ///
   /// @ingroup Map
   ///
   /// @param x horizontal pixel coordinate.
   /// @param y vertical pixel coordinate
   ///
   Elm_Map_Overlay * overlay_scale_add(Evas_Coord x_, Evas_Coord y_) const
   {
      Elm_Map_Overlay * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_map_overlay_scale_add(x_, y_));
      return _tmp_ret;
   }

   /// @brief Add a new overlay to the map object. This overlay has a default type.
   ///
   /// @return The created overlay or @c NULL upon failure.
   ///
   /// A overlay will be created and shown in a specific point of the map, defined
   /// by @p lon and @p lat.
   ///
   /// The created overlay has a default style layout before content or
   /// icon is set.
   /// If content or icon is set, those are displayed instead of default style
   /// layout.
   /// You can set by using elm_map_overlay_content_set() or
   /// elm_map_overlay_icon_set(). If NULL is set, default style
   /// is shown again.
   ///
   /// Overlay created with this method can be deleted by elm_map_overlay_del().
   ///
   /// @see elm_map_overlay_del()
   /// @see elm_map_overlay_class_add()
   /// @see elm_map_overlay_bubble_add()
   /// @see elm_map_overlay_content_set()
   /// @see elm_map_overlay_icon_set()
   ///
   /// @ingroup Map
   ///
   /// @param lon The longitude of the overlay.
   /// @param lat The latitude of the overlay.
   ///
   Elm_Map_Overlay * overlay_add(double lon_, double lat_) const
   {
      Elm_Map_Overlay * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_map_overlay_add(lon_, lat_));
      return _tmp_ret;
   }

   /// @brief Convert canvas coordinates into geographic coordinates
   /// (longitude, latitude).
   ///
   /// This gets longitude and latitude from canvas x, y coordinates. The canvas
   /// coordinates mean x, y coordinate from current viewport.
   ///
   /// see elm_map_region_to_canvas_convert()
   ///
   /// @ingroup Map
   ///
   /// @param x horizontal coordinate of the point to convert.
   /// @param y vertical coordinate of the point to convert.
   /// @param[out] lon A pointer to the longitude.
   /// @param[out] lat A pointer to the latitude.
   ///
   void canvas_to_region_convert(Evas_Coord x_, Evas_Coord y_, double* lon_, double* lat_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_map_canvas_to_region_convert(x_, y_, lon_, lat_));
   }

   /// @param zoom The zoom level to set.
   ///
   int zoom_get() const
   {
      int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_map_zoom_get());
      return _tmp_ret;
   }

   /// @param zoom The zoom level to set.
   ///
   void zoom_set(int zoom_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_map_zoom_set(zoom_));
   }

   /// @param paused Use @c EINA_TRUE to pause the map @p obj or @c EINA_FALSE
   /// to unpause it.
   ///
   bool paused_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_map_paused_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param paused Use @c EINA_TRUE to pause the map @p obj or @c EINA_FALSE
   /// to unpause it.
   ///
   void paused_set(bool paused_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_map_paused_set(efl::eolian::to_c(paused_)));
   }

   /// @param disabled Use @c EINA_TRUE to disable mouse wheel or @c EINA_FALSE
   /// to enable it.
   ///
   bool wheel_disabled_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_map_wheel_disabled_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param disabled Use @c EINA_TRUE to disable mouse wheel or @c EINA_FALSE
   /// to enable it.
   ///
   void wheel_disabled_set(bool disabled_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_map_wheel_disabled_set(efl::eolian::to_c(disabled_)));
   }

   /// @param zoom New minimum zoom value to be used.
   ///
   int zoom_min_get() const
   {
      int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_map_zoom_min_get());
      return _tmp_ret;
   }

   /// @param zoom New minimum zoom value to be used.
   ///
   void zoom_min_set(int zoom_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_map_zoom_min_set(zoom_));
   }

   /// @param degree Angle from 0.0 to 360.0 to rotate around Z axis.
   /// @param cx Rotation's center horizontal position.
   /// @param cy Rotation's center vertical position.
   ///
   void rotate_get(double* degree_, Evas_Coord* cx_, Evas_Coord* cy_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_map_rotate_get(degree_, cx_, cy_));
   }

   /// @param degree Angle from 0.0 to 360.0 to rotate around Z axis.
   /// @param cx Rotation's center horizontal position.
   /// @param cy Rotation's center vertical position.
   ///
   void rotate_set(double degree_, Evas_Coord cx_, Evas_Coord cy_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_map_rotate_set(degree_, cx_, cy_));
   }

   /// @param user_agent The user agent to be used by the map.
   ///
   std::string user_agent_get() const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_map_user_agent_get());
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param user_agent The user agent to be used by the map.
   ///
   void user_agent_set(std::string user_agent_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_map_user_agent_set(efl::eolian::to_c(user_agent_)));
   }

   /// @param zoom New maximum zoom value to be used.
   ///
   int zoom_max_get() const
   {
      int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_map_zoom_max_get());
      return _tmp_ret;
   }

   /// @param zoom New maximum zoom value to be used.
   ///
   void zoom_max_set(int zoom_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_map_zoom_max_set(zoom_));
   }

   /// @param mode The zoom mode of the map, being it one of #ELM_MAP_ZOOM_MODE_MANUAL
   /// (default), #ELM_MAP_ZOOM_MODE_AUTO_FIT, or #ELM_MAP_ZOOM_MODE_AUTO_FILL.
   ///
   Elm_Map_Zoom_Mode zoom_mode_get() const
   {
      Elm_Map_Zoom_Mode _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_map_zoom_mode_get());
      return _tmp_ret;
   }

   /// @param mode The zoom mode of the map, being it one of #ELM_MAP_ZOOM_MODE_MANUAL
   /// (default), #ELM_MAP_ZOOM_MODE_AUTO_FIT, or #ELM_MAP_ZOOM_MODE_AUTO_FILL.
   ///
   void zoom_mode_set(Elm_Map_Zoom_Mode mode_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_map_zoom_mode_set(mode_));
   }

   /// @param lon Pointer to store longitude.
   /// @param lat Pointer to store latitude.
   ///
   void region_get(double* lon_, double* lat_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_map_region_get(lon_, lat_));
   }

   Eina_List * overlays_get() const
   {
      Eina_List * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_map_overlays_get());
      return _tmp_ret;
   }

   /// @param try_num Pointer to store number of tiles download requested.
   /// @param finish_num Pointer to store number of tiles successfully downloaded.
   ///
   void tile_load_status_get(int* try_num_, int* finish_num_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_map_tile_load_status_get(try_num_, finish_num_));
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_clicked_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_CLICKED, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_CLICKED );
   }

   template <typename T>
   void
   callback_clicked_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_CLICKED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_clicked_double_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_CLICKED_DOUBLE, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_CLICKED_DOUBLE );
   }

   template <typename T>
   void
   callback_clicked_double_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_CLICKED_DOUBLE, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_press_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_PRESS, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_PRESS );
   }

   template <typename T>
   void
   callback_press_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_PRESS, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_longpressed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_LONGPRESSED, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_LONGPRESSED );
   }

   template <typename T>
   void
   callback_longpressed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_LONGPRESSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_SCROLL, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_SCROLL );
   }

   template <typename T>
   void
   callback_scroll_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_SCROLL, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_drag_start_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_SCROLL_DRAG_START, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_SCROLL_DRAG_START );
   }

   template <typename T>
   void
   callback_scroll_drag_start_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_SCROLL_DRAG_START, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_drag_stop_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_SCROLL_DRAG_STOP, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_SCROLL_DRAG_STOP );
   }

   template <typename T>
   void
   callback_scroll_drag_stop_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_SCROLL_DRAG_STOP, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_anim_start_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_SCROLL_ANIM_START, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_SCROLL_ANIM_START );
   }

   template <typename T>
   void
   callback_scroll_anim_start_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_SCROLL_ANIM_START, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_anim_stop_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_SCROLL_ANIM_STOP, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_SCROLL_ANIM_STOP );
   }

   template <typename T>
   void
   callback_scroll_anim_stop_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_SCROLL_ANIM_STOP, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_zoom_start_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_ZOOM_START, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_ZOOM_START );
   }

   template <typename T>
   void
   callback_zoom_start_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_ZOOM_START, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_zoom_stop_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_ZOOM_STOP, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_ZOOM_STOP );
   }

   template <typename T>
   void
   callback_zoom_stop_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_ZOOM_STOP, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_zoom_change_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_ZOOM_CHANGE, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_ZOOM_CHANGE );
   }

   template <typename T>
   void
   callback_zoom_change_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_ZOOM_CHANGE, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_loaded_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_LOADED, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_LOADED );
   }

   template <typename T>
   void
   callback_loaded_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_LOADED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_tile_load_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_TILE_LOAD, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_TILE_LOAD );
   }

   template <typename T>
   void
   callback_tile_load_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_TILE_LOAD, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_tile_loaded_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_TILE_LOADED, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_TILE_LOADED );
   }

   template <typename T>
   void
   callback_tile_loaded_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_TILE_LOADED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_tile_loaded_fail_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_TILE_LOADED_FAIL, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_TILE_LOADED_FAIL );
   }

   template <typename T>
   void
   callback_tile_loaded_fail_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_TILE_LOADED_FAIL, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_route_load_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_ROUTE_LOAD, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_ROUTE_LOAD );
   }

   template <typename T>
   void
   callback_route_load_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_ROUTE_LOAD, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_route_loaded_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_ROUTE_LOADED, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_ROUTE_LOADED );
   }

   template <typename T>
   void
   callback_route_loaded_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_ROUTE_LOADED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_route_loaded_fail_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_ROUTE_LOADED_FAIL, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_ROUTE_LOADED_FAIL );
   }

   template <typename T>
   void
   callback_route_loaded_fail_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_ROUTE_LOADED_FAIL, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_name_load_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_NAME_LOAD, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_NAME_LOAD );
   }

   template <typename T>
   void
   callback_name_load_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_NAME_LOAD, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_name_loaded_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_NAME_LOADED, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_NAME_LOADED );
   }

   template <typename T>
   void
   callback_name_loaded_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_NAME_LOADED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_name_loaded_fail_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_NAME_LOADED_FAIL, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_NAME_LOADED_FAIL );
   }

   template <typename T>
   void
   callback_name_loaded_fail_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_NAME_LOADED_FAIL, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_overlay_clicked_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_OVERLAY_CLICKED, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_OVERLAY_CLICKED );
   }

   template <typename T>
   void
   callback_overlay_clicked_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_OVERLAY_CLICKED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_overlay_del_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_OVERLAY_DEL, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_OVERLAY_DEL );
   }

   template <typename T>
   void
   callback_overlay_del_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_OVERLAY_DEL, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_UNFOCUSED, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_MAP_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_MAP_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
void _elm_map_source_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Map_Source_Type type_, const char * source_name_)
{
   static_cast<T*>(self->this_)->source_set(type_, efl::eolian::to_cxx<std::string>(source_name_, std::tuple<std::false_type>()));
}

template <typename T>
std::string _elm_map_source_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Map_Source_Type type_)
{
   return static_cast<T*>(self->this_)->source_get(type_);
}

template <typename T>
Elm_Map_Route * _elm_map_route_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Map_Route_Type type_, Elm_Map_Route_Method method_, double flon_, double flat_, double tlon_, double tlat_, Elm_Map_Route_Cb route_cb_, void * data_)
{
   return static_cast<T*>(self->this_)->route_add(type_, method_, flon_, flat_, tlon_, tlat_, route_cb_, data_);
}

template <typename T>
evas::object _elm_map_track_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, void * emap_)
{
   return static_cast<T*>(self->this_)->track_add(emap_);
}

template <typename T>
void _elm_map_region_to_canvas_convert_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double lon_, double lat_, Evas_Coord* x_, Evas_Coord* y_)
{
   static_cast<T*>(self->this_)->region_to_canvas_convert(lon_, lat_, x_, y_);
}

template <typename T>
Elm_Map_Overlay * _elm_map_overlay_circle_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double lon_, double lat_, double radius_)
{
   return static_cast<T*>(self->this_)->overlay_circle_add(lon_, lat_, radius_);
}

template <typename T>
Elm_Map_Overlay * _elm_map_overlay_class_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->overlay_class_add();
}

template <typename T>
Elm_Map_Overlay * _elm_map_overlay_bubble_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->overlay_bubble_add();
}

template <typename T>
const char ** _elm_map_sources_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Map_Source_Type type_)
{
   return static_cast<T*>(self->this_)->sources_get(type_);
}

template <typename T>
Elm_Map_Overlay * _elm_map_overlay_polygon_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->overlay_polygon_add();
}

template <typename T>
Elm_Map_Overlay * _elm_map_overlay_line_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double flon_, double flat_, double tlon_, double tlat_)
{
   return static_cast<T*>(self->this_)->overlay_line_add(flon_, flat_, tlon_, tlat_);
}

template <typename T>
void _elm_map_region_show_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double lon_, double lat_)
{
   static_cast<T*>(self->this_)->region_show(lon_, lat_);
}

template <typename T>
Elm_Map_Name * _elm_map_name_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * address_, double lon_, double lat_, Elm_Map_Name_Cb name_cb_, void * data_)
{
   return static_cast<T*>(self->this_)->name_add(efl::eolian::to_cxx<std::string>(address_, std::tuple<std::false_type>()), lon_, lat_, name_cb_, data_);
}

template <typename T>
void _elm_map_name_search_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * address_, Elm_Map_Name_List_Cb name_cb_, void * data_)
{
   static_cast<T*>(self->this_)->name_search(efl::eolian::to_cxx<std::string>(address_, std::tuple<std::false_type>()), name_cb_, data_);
}

template <typename T>
void _elm_map_region_bring_in_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double lon_, double lat_)
{
   static_cast<T*>(self->this_)->region_bring_in(lon_, lat_);
}

template <typename T>
void _elm_map_region_zoom_bring_in_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int zoom_, double lon_, double lat_)
{
   static_cast<T*>(self->this_)->region_zoom_bring_in(zoom_, lon_, lat_);
}

template <typename T>
void _elm_map_track_remove_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * route_)
{
   static_cast<T*>(self->this_)->track_remove(efl::eolian::to_cxx<evas::object>(route_, std::tuple<std::false_type>()));
}

template <typename T>
Elm_Map_Overlay * _elm_map_overlay_route_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const Elm_Map_Route * route_)
{
   return static_cast<T*>(self->this_)->overlay_route_add(route_);
}

template <typename T>
Elm_Map_Overlay * _elm_map_overlay_scale_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord x_, Evas_Coord y_)
{
   return static_cast<T*>(self->this_)->overlay_scale_add(x_, y_);
}

template <typename T>
Elm_Map_Overlay * _elm_map_overlay_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double lon_, double lat_)
{
   return static_cast<T*>(self->this_)->overlay_add(lon_, lat_);
}

template <typename T>
void _elm_map_canvas_to_region_convert_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord x_, Evas_Coord y_, double* lon_, double* lat_)
{
   static_cast<T*>(self->this_)->canvas_to_region_convert(x_, y_, lon_, lat_);
}

template <typename T>
int _elm_map_zoom_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->zoom_get();
}

template <typename T>
void _elm_map_zoom_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int zoom_)
{
   static_cast<T*>(self->this_)->zoom_set(zoom_);
}

template <typename T>
bool _elm_map_paused_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->paused_get();
}

template <typename T>
void _elm_map_paused_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool paused_)
{
   static_cast<T*>(self->this_)->paused_set(efl::eolian::to_cxx<bool>(paused_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_map_wheel_disabled_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->wheel_disabled_get();
}

template <typename T>
void _elm_map_wheel_disabled_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool disabled_)
{
   static_cast<T*>(self->this_)->wheel_disabled_set(efl::eolian::to_cxx<bool>(disabled_, std::tuple<std::false_type>()));
}

template <typename T>
int _elm_map_zoom_min_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->zoom_min_get();
}

template <typename T>
void _elm_map_zoom_min_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int zoom_)
{
   static_cast<T*>(self->this_)->zoom_min_set(zoom_);
}

template <typename T>
void _elm_map_rotate_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double* degree_, Evas_Coord* cx_, Evas_Coord* cy_)
{
   static_cast<T*>(self->this_)->rotate_get(degree_, cx_, cy_);
}

template <typename T>
void _elm_map_rotate_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double degree_, Evas_Coord cx_, Evas_Coord cy_)
{
   static_cast<T*>(self->this_)->rotate_set(degree_, cx_, cy_);
}

template <typename T>
std::string _elm_map_user_agent_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->user_agent_get();
}

template <typename T>
void _elm_map_user_agent_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * user_agent_)
{
   static_cast<T*>(self->this_)->user_agent_set(efl::eolian::to_cxx<std::string>(user_agent_, std::tuple<std::false_type>()));
}

template <typename T>
int _elm_map_zoom_max_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->zoom_max_get();
}

template <typename T>
void _elm_map_zoom_max_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int zoom_)
{
   static_cast<T*>(self->this_)->zoom_max_set(zoom_);
}

template <typename T>
Elm_Map_Zoom_Mode _elm_map_zoom_mode_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->zoom_mode_get();
}

template <typename T>
void _elm_map_zoom_mode_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Map_Zoom_Mode mode_)
{
   static_cast<T*>(self->this_)->zoom_mode_set(mode_);
}

template <typename T>
void _elm_map_region_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double* lon_, double* lat_)
{
   static_cast<T*>(self->this_)->region_get(lon_, lat_);
}

template <typename T>
Eina_List * _elm_map_overlays_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->overlays_get();
}

template <typename T>
void _elm_map_tile_load_status_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int* try_num_, int* finish_num_)
{
   static_cast<T*>(self->this_)->tile_load_status_get(try_num_, finish_num_);
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_map >
{
   template <typename T>
   struct type
   {
      virtual void source_set(Elm_Map_Source_Type type_, std::string source_name_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_map_source_set(type_, efl::eolian::to_c(source_name_)));
      }

      virtual std::string source_get(Elm_Map_Source_Type type_)
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_map_source_get(type_));
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual Elm_Map_Route * route_add(Elm_Map_Route_Type type_, Elm_Map_Route_Method method_, double flon_, double flat_, double tlon_, double tlat_, Elm_Map_Route_Cb route_cb_, void * data_)
      {
         Elm_Map_Route * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_map_route_add(type_, method_, flon_, flat_, tlon_, tlat_, route_cb_, data_));
            return _tmp_ret;
      }

      virtual evas::object track_add(void * emap_)
      {
         Evas_Object * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_map_track_add(emap_));
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void region_to_canvas_convert(double lon_, double lat_, Evas_Coord* x_, Evas_Coord* y_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_map_region_to_canvas_convert(lon_, lat_, x_, y_));
      }

      virtual Elm_Map_Overlay * overlay_circle_add(double lon_, double lat_, double radius_)
      {
         Elm_Map_Overlay * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_map_overlay_circle_add(lon_, lat_, radius_));
            return _tmp_ret;
      }

      virtual Elm_Map_Overlay * overlay_class_add()
      {
         Elm_Map_Overlay * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_map_overlay_class_add());
            return _tmp_ret;
      }

      virtual Elm_Map_Overlay * overlay_bubble_add()
      {
         Elm_Map_Overlay * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_map_overlay_bubble_add());
            return _tmp_ret;
      }

      virtual const char ** sources_get(Elm_Map_Source_Type type_)
      {
         const char ** _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_map_sources_get(type_));
            return _tmp_ret;
      }

      virtual Elm_Map_Overlay * overlay_polygon_add()
      {
         Elm_Map_Overlay * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_map_overlay_polygon_add());
            return _tmp_ret;
      }

      virtual Elm_Map_Overlay * overlay_line_add(double flon_, double flat_, double tlon_, double tlat_)
      {
         Elm_Map_Overlay * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_map_overlay_line_add(flon_, flat_, tlon_, tlat_));
            return _tmp_ret;
      }

      virtual void region_show(double lon_, double lat_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_map_region_show(lon_, lat_));
      }

      virtual Elm_Map_Name * name_add(std::string address_, double lon_, double lat_, Elm_Map_Name_Cb name_cb_, void * data_)
      {
         Elm_Map_Name * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_map_name_add(efl::eolian::to_c(address_), lon_, lat_, name_cb_, data_));
            return _tmp_ret;
      }

      virtual void name_search(std::string address_, Elm_Map_Name_List_Cb name_cb_, void * data_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_map_name_search(efl::eolian::to_c(address_), name_cb_, data_));
      }

      virtual void region_bring_in(double lon_, double lat_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_map_region_bring_in(lon_, lat_));
      }

      virtual void region_zoom_bring_in(int zoom_, double lon_, double lat_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_map_region_zoom_bring_in(zoom_, lon_, lat_));
      }

      virtual void track_remove(evas::object route_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_map_track_remove(efl::eolian::to_c(route_)));
      }

      virtual Elm_Map_Overlay * overlay_route_add(const Elm_Map_Route * route_)
      {
         Elm_Map_Overlay * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_map_overlay_route_add(route_));
            return _tmp_ret;
      }

      virtual Elm_Map_Overlay * overlay_scale_add(Evas_Coord x_, Evas_Coord y_)
      {
         Elm_Map_Overlay * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_map_overlay_scale_add(x_, y_));
            return _tmp_ret;
      }

      virtual Elm_Map_Overlay * overlay_add(double lon_, double lat_)
      {
         Elm_Map_Overlay * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_map_overlay_add(lon_, lat_));
            return _tmp_ret;
      }

      virtual void canvas_to_region_convert(Evas_Coord x_, Evas_Coord y_, double* lon_, double* lat_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_map_canvas_to_region_convert(x_, y_, lon_, lat_));
      }

      virtual int zoom_get()
      {
         int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_map_zoom_get());
            return _tmp_ret;
      }

      virtual void zoom_set(int zoom_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_map_zoom_set(zoom_));
      }

      virtual bool paused_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_map_paused_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void paused_set(bool paused_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_map_paused_set(efl::eolian::to_c(paused_)));
      }

      virtual bool wheel_disabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_map_wheel_disabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void wheel_disabled_set(bool disabled_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_map_wheel_disabled_set(efl::eolian::to_c(disabled_)));
      }

      virtual int zoom_min_get()
      {
         int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_map_zoom_min_get());
            return _tmp_ret;
      }

      virtual void zoom_min_set(int zoom_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_map_zoom_min_set(zoom_));
      }

      virtual void rotate_get(double* degree_, Evas_Coord* cx_, Evas_Coord* cy_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_map_rotate_get(degree_, cx_, cy_));
      }

      virtual void rotate_set(double degree_, Evas_Coord cx_, Evas_Coord cy_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_map_rotate_set(degree_, cx_, cy_));
      }

      virtual std::string user_agent_get()
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_map_user_agent_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void user_agent_set(std::string user_agent_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_map_user_agent_set(efl::eolian::to_c(user_agent_)));
      }

      virtual int zoom_max_get()
      {
         int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_map_zoom_max_get());
            return _tmp_ret;
      }

      virtual void zoom_max_set(int zoom_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_map_zoom_max_set(zoom_));
      }

      virtual Elm_Map_Zoom_Mode zoom_mode_get()
      {
         Elm_Map_Zoom_Mode _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_map_zoom_mode_get());
            return _tmp_ret;
      }

      virtual void zoom_mode_set(Elm_Map_Zoom_Mode mode_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_map_zoom_mode_set(mode_));
      }

      virtual void region_get(double* lon_, double* lat_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_map_region_get(lon_, lat_));
      }

      virtual Eina_List * overlays_get()
      {
         Eina_List * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_map_overlays_get());
            return _tmp_ret;
      }

      virtual void tile_load_status_get(int* try_num_, int* finish_num_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_map_tile_load_status_get(try_num_, finish_num_));
      }

   };
};


template<>
struct operation_description_class_size< ::elm_map >
{
   static const int value = 40;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_map>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_map_source_set_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_map_source_set);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_map_source_get_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_map_source_get);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_map_route_add_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_map_route_add);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_map_track_add_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_map_track_add);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_map_region_to_canvas_convert_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_map_region_to_canvas_convert);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_map_overlay_circle_add_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_map_overlay_circle_add);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_map_overlay_class_add_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_map_overlay_class_add);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_map_overlay_bubble_add_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_map_overlay_bubble_add);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_map_sources_get_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_map_sources_get);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_map_overlay_polygon_add_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_map_overlay_polygon_add);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::_elm_map_overlay_line_add_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::elm_obj_map_overlay_line_add);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::_elm_map_region_show_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::elm_obj_map_region_show);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::_elm_map_name_add_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::elm_obj_map_name_add);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::_elm_map_name_search_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::elm_obj_map_name_search);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::_elm_map_region_bring_in_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::elm_obj_map_region_bring_in);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::_elm_map_region_zoom_bring_in_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::elm_obj_map_region_zoom_bring_in);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   ops[16].func = reinterpret_cast<void*>(& ::_elm_map_track_remove_wrapper<T>);
   ops[16].api_func = reinterpret_cast<void*>(& ::elm_obj_map_track_remove);
   ops[16].op = EO_OP_OVERRIDE;
   ops[16].op_type = EO_OP_TYPE_REGULAR;
   ops[16].doc = NULL;

   ops[17].func = reinterpret_cast<void*>(& ::_elm_map_overlay_route_add_wrapper<T>);
   ops[17].api_func = reinterpret_cast<void*>(& ::elm_obj_map_overlay_route_add);
   ops[17].op = EO_OP_OVERRIDE;
   ops[17].op_type = EO_OP_TYPE_REGULAR;
   ops[17].doc = NULL;

   ops[18].func = reinterpret_cast<void*>(& ::_elm_map_overlay_scale_add_wrapper<T>);
   ops[18].api_func = reinterpret_cast<void*>(& ::elm_obj_map_overlay_scale_add);
   ops[18].op = EO_OP_OVERRIDE;
   ops[18].op_type = EO_OP_TYPE_REGULAR;
   ops[18].doc = NULL;

   ops[19].func = reinterpret_cast<void*>(& ::_elm_map_overlay_add_wrapper<T>);
   ops[19].api_func = reinterpret_cast<void*>(& ::elm_obj_map_overlay_add);
   ops[19].op = EO_OP_OVERRIDE;
   ops[19].op_type = EO_OP_TYPE_REGULAR;
   ops[19].doc = NULL;

   ops[20].func = reinterpret_cast<void*>(& ::_elm_map_canvas_to_region_convert_wrapper<T>);
   ops[20].api_func = reinterpret_cast<void*>(& ::elm_obj_map_canvas_to_region_convert);
   ops[20].op = EO_OP_OVERRIDE;
   ops[20].op_type = EO_OP_TYPE_REGULAR;
   ops[20].doc = NULL;

   ops[21].func = reinterpret_cast<void*>(& ::_elm_map_zoom_get_wrapper<T>);
   ops[21].api_func = reinterpret_cast<void*>(& ::elm_obj_map_zoom_get);
   ops[21].op = EO_OP_OVERRIDE;
   ops[21].op_type = EO_OP_TYPE_REGULAR;
   ops[21].doc = NULL;

   ops[22].func = reinterpret_cast<void*>(& ::_elm_map_zoom_set_wrapper<T>);
   ops[22].api_func = reinterpret_cast<void*>(& ::elm_obj_map_zoom_set);
   ops[22].op = EO_OP_OVERRIDE;
   ops[22].op_type = EO_OP_TYPE_REGULAR;
   ops[22].doc = NULL;

   ops[23].func = reinterpret_cast<void*>(& ::_elm_map_paused_get_wrapper<T>);
   ops[23].api_func = reinterpret_cast<void*>(& ::elm_obj_map_paused_get);
   ops[23].op = EO_OP_OVERRIDE;
   ops[23].op_type = EO_OP_TYPE_REGULAR;
   ops[23].doc = NULL;

   ops[24].func = reinterpret_cast<void*>(& ::_elm_map_paused_set_wrapper<T>);
   ops[24].api_func = reinterpret_cast<void*>(& ::elm_obj_map_paused_set);
   ops[24].op = EO_OP_OVERRIDE;
   ops[24].op_type = EO_OP_TYPE_REGULAR;
   ops[24].doc = NULL;

   ops[25].func = reinterpret_cast<void*>(& ::_elm_map_wheel_disabled_get_wrapper<T>);
   ops[25].api_func = reinterpret_cast<void*>(& ::elm_obj_map_wheel_disabled_get);
   ops[25].op = EO_OP_OVERRIDE;
   ops[25].op_type = EO_OP_TYPE_REGULAR;
   ops[25].doc = NULL;

   ops[26].func = reinterpret_cast<void*>(& ::_elm_map_wheel_disabled_set_wrapper<T>);
   ops[26].api_func = reinterpret_cast<void*>(& ::elm_obj_map_wheel_disabled_set);
   ops[26].op = EO_OP_OVERRIDE;
   ops[26].op_type = EO_OP_TYPE_REGULAR;
   ops[26].doc = NULL;

   ops[27].func = reinterpret_cast<void*>(& ::_elm_map_zoom_min_get_wrapper<T>);
   ops[27].api_func = reinterpret_cast<void*>(& ::elm_obj_map_zoom_min_get);
   ops[27].op = EO_OP_OVERRIDE;
   ops[27].op_type = EO_OP_TYPE_REGULAR;
   ops[27].doc = NULL;

   ops[28].func = reinterpret_cast<void*>(& ::_elm_map_zoom_min_set_wrapper<T>);
   ops[28].api_func = reinterpret_cast<void*>(& ::elm_obj_map_zoom_min_set);
   ops[28].op = EO_OP_OVERRIDE;
   ops[28].op_type = EO_OP_TYPE_REGULAR;
   ops[28].doc = NULL;

   ops[29].func = reinterpret_cast<void*>(& ::_elm_map_rotate_get_wrapper<T>);
   ops[29].api_func = reinterpret_cast<void*>(& ::elm_obj_map_rotate_get);
   ops[29].op = EO_OP_OVERRIDE;
   ops[29].op_type = EO_OP_TYPE_REGULAR;
   ops[29].doc = NULL;

   ops[30].func = reinterpret_cast<void*>(& ::_elm_map_rotate_set_wrapper<T>);
   ops[30].api_func = reinterpret_cast<void*>(& ::elm_obj_map_rotate_set);
   ops[30].op = EO_OP_OVERRIDE;
   ops[30].op_type = EO_OP_TYPE_REGULAR;
   ops[30].doc = NULL;

   ops[31].func = reinterpret_cast<void*>(& ::_elm_map_user_agent_get_wrapper<T>);
   ops[31].api_func = reinterpret_cast<void*>(& ::elm_obj_map_user_agent_get);
   ops[31].op = EO_OP_OVERRIDE;
   ops[31].op_type = EO_OP_TYPE_REGULAR;
   ops[31].doc = NULL;

   ops[32].func = reinterpret_cast<void*>(& ::_elm_map_user_agent_set_wrapper<T>);
   ops[32].api_func = reinterpret_cast<void*>(& ::elm_obj_map_user_agent_set);
   ops[32].op = EO_OP_OVERRIDE;
   ops[32].op_type = EO_OP_TYPE_REGULAR;
   ops[32].doc = NULL;

   ops[33].func = reinterpret_cast<void*>(& ::_elm_map_zoom_max_get_wrapper<T>);
   ops[33].api_func = reinterpret_cast<void*>(& ::elm_obj_map_zoom_max_get);
   ops[33].op = EO_OP_OVERRIDE;
   ops[33].op_type = EO_OP_TYPE_REGULAR;
   ops[33].doc = NULL;

   ops[34].func = reinterpret_cast<void*>(& ::_elm_map_zoom_max_set_wrapper<T>);
   ops[34].api_func = reinterpret_cast<void*>(& ::elm_obj_map_zoom_max_set);
   ops[34].op = EO_OP_OVERRIDE;
   ops[34].op_type = EO_OP_TYPE_REGULAR;
   ops[34].doc = NULL;

   ops[35].func = reinterpret_cast<void*>(& ::_elm_map_zoom_mode_get_wrapper<T>);
   ops[35].api_func = reinterpret_cast<void*>(& ::elm_obj_map_zoom_mode_get);
   ops[35].op = EO_OP_OVERRIDE;
   ops[35].op_type = EO_OP_TYPE_REGULAR;
   ops[35].doc = NULL;

   ops[36].func = reinterpret_cast<void*>(& ::_elm_map_zoom_mode_set_wrapper<T>);
   ops[36].api_func = reinterpret_cast<void*>(& ::elm_obj_map_zoom_mode_set);
   ops[36].op = EO_OP_OVERRIDE;
   ops[36].op_type = EO_OP_TYPE_REGULAR;
   ops[36].doc = NULL;

   ops[37].func = reinterpret_cast<void*>(& ::_elm_map_region_get_wrapper<T>);
   ops[37].api_func = reinterpret_cast<void*>(& ::elm_obj_map_region_get);
   ops[37].op = EO_OP_OVERRIDE;
   ops[37].op_type = EO_OP_TYPE_REGULAR;
   ops[37].doc = NULL;

   ops[38].func = reinterpret_cast<void*>(& ::_elm_map_overlays_get_wrapper<T>);
   ops[38].api_func = reinterpret_cast<void*>(& ::elm_obj_map_overlays_get);
   ops[38].op = EO_OP_OVERRIDE;
   ops[38].op_type = EO_OP_TYPE_REGULAR;
   ops[38].doc = NULL;

   ops[39].func = reinterpret_cast<void*>(& ::_elm_map_tile_load_status_get_wrapper<T>);
   ops[39].api_func = reinterpret_cast<void*>(& ::elm_obj_map_tile_load_status_get);
   ops[39].op = EO_OP_OVERRIDE;
   ops[39].op_type = EO_OP_TYPE_REGULAR;
   ops[39].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_map >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_map, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_map >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_map, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_map>
{
   template <typename U>
   struct type
   {
      operator ::elm_map() const
      {
         return ::elm_map(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      void source_set(Elm_Map_Source_Type type_, std::string source_name_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_map_source_set(type_, efl::eolian::to_c(source_name_)));
      }

      std::string source_get(Elm_Map_Source_Type type_)
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_map_source_get(type_));
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      Elm_Map_Route * route_add(Elm_Map_Route_Type type_, Elm_Map_Route_Method method_, double flon_, double flat_, double tlon_, double tlat_, Elm_Map_Route_Cb route_cb_, void * data_)
      {
         Elm_Map_Route * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_map_route_add(type_, method_, flon_, flat_, tlon_, tlat_, route_cb_, data_));
            return _tmp_ret;
      }

      evas::object track_add(void * emap_)
      {
         Evas_Object * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_map_track_add(emap_));
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      void region_to_canvas_convert(double lon_, double lat_, Evas_Coord* x_, Evas_Coord* y_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_map_region_to_canvas_convert(lon_, lat_, x_, y_));
      }

      Elm_Map_Overlay * overlay_circle_add(double lon_, double lat_, double radius_)
      {
         Elm_Map_Overlay * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_map_overlay_circle_add(lon_, lat_, radius_));
            return _tmp_ret;
      }

      Elm_Map_Overlay * overlay_class_add()
      {
         Elm_Map_Overlay * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_map_overlay_class_add());
            return _tmp_ret;
      }

      Elm_Map_Overlay * overlay_bubble_add()
      {
         Elm_Map_Overlay * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_map_overlay_bubble_add());
            return _tmp_ret;
      }

      const char ** sources_get(Elm_Map_Source_Type type_)
      {
         const char ** _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_map_sources_get(type_));
            return _tmp_ret;
      }

      Elm_Map_Overlay * overlay_polygon_add()
      {
         Elm_Map_Overlay * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_map_overlay_polygon_add());
            return _tmp_ret;
      }

      Elm_Map_Overlay * overlay_line_add(double flon_, double flat_, double tlon_, double tlat_)
      {
         Elm_Map_Overlay * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_map_overlay_line_add(flon_, flat_, tlon_, tlat_));
            return _tmp_ret;
      }

      void region_show(double lon_, double lat_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_map_region_show(lon_, lat_));
      }

      Elm_Map_Name * name_add(std::string address_, double lon_, double lat_, Elm_Map_Name_Cb name_cb_, void * data_)
      {
         Elm_Map_Name * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_map_name_add(efl::eolian::to_c(address_), lon_, lat_, name_cb_, data_));
            return _tmp_ret;
      }

      void name_search(std::string address_, Elm_Map_Name_List_Cb name_cb_, void * data_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_map_name_search(efl::eolian::to_c(address_), name_cb_, data_));
      }

      void region_bring_in(double lon_, double lat_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_map_region_bring_in(lon_, lat_));
      }

      void region_zoom_bring_in(int zoom_, double lon_, double lat_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_map_region_zoom_bring_in(zoom_, lon_, lat_));
      }

      void track_remove(evas::object route_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_map_track_remove(efl::eolian::to_c(route_)));
      }

      Elm_Map_Overlay * overlay_route_add(const Elm_Map_Route * route_)
      {
         Elm_Map_Overlay * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_map_overlay_route_add(route_));
            return _tmp_ret;
      }

      Elm_Map_Overlay * overlay_scale_add(Evas_Coord x_, Evas_Coord y_)
      {
         Elm_Map_Overlay * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_map_overlay_scale_add(x_, y_));
            return _tmp_ret;
      }

      Elm_Map_Overlay * overlay_add(double lon_, double lat_)
      {
         Elm_Map_Overlay * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_map_overlay_add(lon_, lat_));
            return _tmp_ret;
      }

      void canvas_to_region_convert(Evas_Coord x_, Evas_Coord y_, double* lon_, double* lat_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_map_canvas_to_region_convert(x_, y_, lon_, lat_));
      }

      int zoom_get()
      {
         int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_map_zoom_get());
            return _tmp_ret;
      }

      void zoom_set(int zoom_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_map_zoom_set(zoom_));
      }

      bool paused_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_map_paused_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void paused_set(bool paused_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_map_paused_set(efl::eolian::to_c(paused_)));
      }

      bool wheel_disabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_map_wheel_disabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void wheel_disabled_set(bool disabled_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_map_wheel_disabled_set(efl::eolian::to_c(disabled_)));
      }

      int zoom_min_get()
      {
         int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_map_zoom_min_get());
            return _tmp_ret;
      }

      void zoom_min_set(int zoom_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_map_zoom_min_set(zoom_));
      }

      void rotate_get(double* degree_, Evas_Coord* cx_, Evas_Coord* cy_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_map_rotate_get(degree_, cx_, cy_));
      }

      void rotate_set(double degree_, Evas_Coord cx_, Evas_Coord cy_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_map_rotate_set(degree_, cx_, cy_));
      }

      std::string user_agent_get()
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_map_user_agent_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      void user_agent_set(std::string user_agent_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_map_user_agent_set(efl::eolian::to_c(user_agent_)));
      }

      int zoom_max_get()
      {
         int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_map_zoom_max_get());
            return _tmp_ret;
      }

      void zoom_max_set(int zoom_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_map_zoom_max_set(zoom_));
      }

      Elm_Map_Zoom_Mode zoom_mode_get()
      {
         Elm_Map_Zoom_Mode _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_map_zoom_mode_get());
            return _tmp_ret;
      }

      void zoom_mode_set(Elm_Map_Zoom_Mode mode_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_map_zoom_mode_set(mode_));
      }

      void region_get(double* lon_, double* lat_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_map_region_get(lon_, lat_));
      }

      Eina_List * overlays_get()
      {
         Eina_List * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_map_overlays_get());
            return _tmp_ret;
      }

      void tile_load_status_get(int* try_num_, int* finish_num_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_map_tile_load_status_get(try_num_, finish_num_));
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_clicked_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_CLICKED, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_CLICKED );
   }

   template <typename T>
   void
   callback_clicked_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_CLICKED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_clicked_double_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_CLICKED_DOUBLE, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_CLICKED_DOUBLE );
   }

   template <typename T>
   void
   callback_clicked_double_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_CLICKED_DOUBLE, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_press_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_PRESS, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_PRESS );
   }

   template <typename T>
   void
   callback_press_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_PRESS, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_longpressed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_LONGPRESSED, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_LONGPRESSED );
   }

   template <typename T>
   void
   callback_longpressed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_LONGPRESSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_SCROLL, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_SCROLL );
   }

   template <typename T>
   void
   callback_scroll_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_SCROLL, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_drag_start_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_SCROLL_DRAG_START, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_SCROLL_DRAG_START );
   }

   template <typename T>
   void
   callback_scroll_drag_start_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_SCROLL_DRAG_START, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_drag_stop_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_SCROLL_DRAG_STOP, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_SCROLL_DRAG_STOP );
   }

   template <typename T>
   void
   callback_scroll_drag_stop_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_SCROLL_DRAG_STOP, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_anim_start_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_SCROLL_ANIM_START, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_SCROLL_ANIM_START );
   }

   template <typename T>
   void
   callback_scroll_anim_start_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_SCROLL_ANIM_START, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_anim_stop_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_SCROLL_ANIM_STOP, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_SCROLL_ANIM_STOP );
   }

   template <typename T>
   void
   callback_scroll_anim_stop_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_SCROLL_ANIM_STOP, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_zoom_start_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_ZOOM_START, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_ZOOM_START );
   }

   template <typename T>
   void
   callback_zoom_start_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_ZOOM_START, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_zoom_stop_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_ZOOM_STOP, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_ZOOM_STOP );
   }

   template <typename T>
   void
   callback_zoom_stop_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_ZOOM_STOP, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_zoom_change_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_ZOOM_CHANGE, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_ZOOM_CHANGE );
   }

   template <typename T>
   void
   callback_zoom_change_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_ZOOM_CHANGE, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_loaded_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_LOADED, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_LOADED );
   }

   template <typename T>
   void
   callback_loaded_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_LOADED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_tile_load_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_TILE_LOAD, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_TILE_LOAD );
   }

   template <typename T>
   void
   callback_tile_load_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_TILE_LOAD, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_tile_loaded_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_TILE_LOADED, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_TILE_LOADED );
   }

   template <typename T>
   void
   callback_tile_loaded_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_TILE_LOADED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_tile_loaded_fail_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_TILE_LOADED_FAIL, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_TILE_LOADED_FAIL );
   }

   template <typename T>
   void
   callback_tile_loaded_fail_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_TILE_LOADED_FAIL, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_route_load_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_ROUTE_LOAD, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_ROUTE_LOAD );
   }

   template <typename T>
   void
   callback_route_load_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_ROUTE_LOAD, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_route_loaded_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_ROUTE_LOADED, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_ROUTE_LOADED );
   }

   template <typename T>
   void
   callback_route_loaded_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_ROUTE_LOADED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_route_loaded_fail_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_ROUTE_LOADED_FAIL, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_ROUTE_LOADED_FAIL );
   }

   template <typename T>
   void
   callback_route_loaded_fail_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_ROUTE_LOADED_FAIL, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_name_load_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_NAME_LOAD, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_NAME_LOAD );
   }

   template <typename T>
   void
   callback_name_load_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_NAME_LOAD, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_name_loaded_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_NAME_LOADED, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_NAME_LOADED );
   }

   template <typename T>
   void
   callback_name_loaded_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_NAME_LOADED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_name_loaded_fail_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_NAME_LOADED_FAIL, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_NAME_LOADED_FAIL );
   }

   template <typename T>
   void
   callback_name_loaded_fail_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_NAME_LOADED_FAIL, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_overlay_clicked_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_OVERLAY_CLICKED, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_OVERLAY_CLICKED );
   }

   template <typename T>
   void
   callback_overlay_clicked_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_OVERLAY_CLICKED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_overlay_del_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_OVERLAY_DEL, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_OVERLAY_DEL );
   }

   template <typename T>
   void
   callback_overlay_del_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_OVERLAY_DEL, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MAP_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_map, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_map, function_type>,
         ELM_MAP_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MAP_EVENT_UNFOCUSED, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_map>)
{
   return (ELM_MAP_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_MAP_HH

