#ifndef EFL_GENERATED_ELM_MAPBUF_HH
#define EFL_GENERATED_ELM_MAPBUF_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_mapbuf.eo.h"
}

#include "elm_container.eo.hh"

struct elm_mapbuf
      : elm_container
{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_mapbuf(Eo* eo)
      : elm_container(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_mapbuf(std::nullptr_t)
      : elm_container(nullptr)
   {}

   elm_mapbuf(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_mapbuf(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_mapbuf(elm_mapbuf const& other)
      : elm_container(eo_ref(other._eo_ptr()))
   {}

   ~elm_mapbuf() {}

   /// @brief Set the color of a vertex in the mapbuf
   ///
   /// This sets the color of the vertex in the mapbuf. Colors will be linearly
   /// interpolated between vertex points through the mapbuf. Color will multiply
   /// the "texture" pixels (like GL_MODULATE in OpenGL). The default color of
   /// a vertex in a mapbuf is white solid (255, 255, 255, 255) which means it will
   /// have no affect on modifying the texture pixels.
   ///
   /// @see evas_object_map_set()
   /// @since 1.9
   ///
   /// @param idx index of point to change. Must be smaller than mapbuf size.
   /// @param r red (0 - 255)
   /// @param g green (0 - 255)
   /// @param b blue (0 - 255)
   /// @param a alpha (0 - 255)
   ///
   void point_color_set(int idx_, int r_, int g_, int b_, int a_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_mapbuf_point_color_set(idx_, r_, g_, b_, a_));
   }

   /// @brief Get the color set on a vertex in the mapbuf
   ///
   /// This gets the color set by elm_mapbuf_point_color_set() on the given vertex
   /// of the mapbuf.
   ///
   /// @see elm_mapbuf_point_color_set()
   ///
   /// @since 1.9
   ///
   /// @param idx index of point get. Must be smaller than map size.
   /// @param[out] r pointer to red return
   /// @param[out] g pointer to green return
   /// @param[out] b pointer to blue return
   /// @param[out] a pointer to alpha return
   ///
   void point_color_get(int idx_, int* r_, int* g_, int* b_, int* a_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_mapbuf_point_color_get(idx_, r_, g_, b_, a_));
   }

   /// @param on @c EINA_TRUE to enable auto mode or @c EINA_FALSE
   /// to disable it.
   ///
   bool auto__get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_mapbuf_auto_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param on @c EINA_TRUE to enable auto mode or @c EINA_FALSE
   /// to disable it.
   ///
   void auto__set(bool on_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_mapbuf_auto_set(efl::eolian::to_c(on_)));
   }

   /// @param smooth @c EINA_TRUE to enable smooth map rendering or @c EINA_FALSE
   /// to disable it.
   ///
   bool smooth_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_mapbuf_smooth_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param smooth @c EINA_TRUE to enable smooth map rendering or @c EINA_FALSE
   /// to disable it.
   ///
   void smooth_set(bool smooth_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_mapbuf_smooth_set(efl::eolian::to_c(smooth_)));
   }

   /// @param alpha @c EINA_TRUE to enable alpha blending or @c EINA_FALSE
   /// to disable it.
   ///
   bool alpha_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_mapbuf_alpha_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param alpha @c EINA_TRUE to enable alpha blending or @c EINA_FALSE
   /// to disable it.
   ///
   void alpha_set(bool alpha_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_mapbuf_alpha_set(efl::eolian::to_c(alpha_)));
   }

   /// @param enabled @c EINA_TRUE to enable map or @c EINA_FALSE to disable it.
   ///
   bool enabled_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_mapbuf_enabled_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param enabled @c EINA_TRUE to enable map or @c EINA_FALSE to disable it.
   ///
   void enabled_set(bool enabled_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_mapbuf_enabled_set(efl::eolian::to_c(enabled_)));
   }

   static Eo_Class const* _eo_class()
   {
      return(ELM_MAPBUF_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_MAPBUF_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
void _elm_mapbuf_point_color_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int idx_, int r_, int g_, int b_, int a_)
{
   static_cast<T*>(self->this_)->point_color_set(idx_, r_, g_, b_, a_);
}

template <typename T>
void _elm_mapbuf_point_color_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int idx_, int* r_, int* g_, int* b_, int* a_)
{
   static_cast<T*>(self->this_)->point_color_get(idx_, r_, g_, b_, a_);
}

template <typename T>
bool _elm_mapbuf_auto__get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->auto__get();
}

template <typename T>
void _elm_mapbuf_auto__set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool on_)
{
   static_cast<T*>(self->this_)->auto__set(efl::eolian::to_cxx<bool>(on_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_mapbuf_smooth_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->smooth_get();
}

template <typename T>
void _elm_mapbuf_smooth_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool smooth_)
{
   static_cast<T*>(self->this_)->smooth_set(efl::eolian::to_cxx<bool>(smooth_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_mapbuf_alpha_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->alpha_get();
}

template <typename T>
void _elm_mapbuf_alpha_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool alpha_)
{
   static_cast<T*>(self->this_)->alpha_set(efl::eolian::to_cxx<bool>(alpha_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_mapbuf_enabled_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->enabled_get();
}

template <typename T>
void _elm_mapbuf_enabled_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool enabled_)
{
   static_cast<T*>(self->this_)->enabled_set(efl::eolian::to_cxx<bool>(enabled_, std::tuple<std::false_type>()));
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_mapbuf >
{
   template <typename T>
   struct type
   {
      virtual void point_color_set(int idx_, int r_, int g_, int b_, int a_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_mapbuf_point_color_set(idx_, r_, g_, b_, a_));
      }

      virtual void point_color_get(int idx_, int* r_, int* g_, int* b_, int* a_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_mapbuf_point_color_get(idx_, r_, g_, b_, a_));
      }

      virtual bool auto__get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_mapbuf_auto_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void auto__set(bool on_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_mapbuf_auto_set(efl::eolian::to_c(on_)));
      }

      virtual bool smooth_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_mapbuf_smooth_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void smooth_set(bool smooth_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_mapbuf_smooth_set(efl::eolian::to_c(smooth_)));
      }

      virtual bool alpha_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_mapbuf_alpha_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void alpha_set(bool alpha_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_mapbuf_alpha_set(efl::eolian::to_c(alpha_)));
      }

      virtual bool enabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_mapbuf_enabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void enabled_set(bool enabled_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_mapbuf_enabled_set(efl::eolian::to_c(enabled_)));
      }

   };
};


template<>
struct operation_description_class_size< ::elm_mapbuf >
{
   static const int value = 10;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_mapbuf>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_mapbuf_point_color_set_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_mapbuf_point_color_set);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_mapbuf_point_color_get_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_mapbuf_point_color_get);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_mapbuf_auto__get_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_mapbuf_auto_get);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_mapbuf_auto__set_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_mapbuf_auto_set);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_mapbuf_smooth_get_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_mapbuf_smooth_get);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_mapbuf_smooth_set_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_mapbuf_smooth_set);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_mapbuf_alpha_get_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_mapbuf_alpha_get);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_mapbuf_alpha_set_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_mapbuf_alpha_set);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_mapbuf_enabled_get_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_mapbuf_enabled_get);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_mapbuf_enabled_set_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_mapbuf_enabled_set);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_mapbuf >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_mapbuf, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_mapbuf >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_mapbuf, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_mapbuf>
{
   template <typename U>
   struct type
   {
      operator ::elm_mapbuf() const
      {
         return ::elm_mapbuf(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      void point_color_set(int idx_, int r_, int g_, int b_, int a_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_mapbuf_point_color_set(idx_, r_, g_, b_, a_));
      }

      void point_color_get(int idx_, int* r_, int* g_, int* b_, int* a_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_mapbuf_point_color_get(idx_, r_, g_, b_, a_));
      }

      bool auto__get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_mapbuf_auto_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void auto__set(bool on_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_mapbuf_auto_set(efl::eolian::to_c(on_)));
      }

      bool smooth_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_mapbuf_smooth_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void smooth_set(bool smooth_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_mapbuf_smooth_set(efl::eolian::to_c(smooth_)));
      }

      bool alpha_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_mapbuf_alpha_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void alpha_set(bool alpha_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_mapbuf_alpha_set(efl::eolian::to_c(alpha_)));
      }

      bool enabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_mapbuf_enabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void enabled_set(bool enabled_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_mapbuf_enabled_set(efl::eolian::to_c(enabled_)));
      }

   };
};

inline Eo_Class const* get_eo_class(tag<::elm_mapbuf>)
{
   return (ELM_MAPBUF_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_MAPBUF_HH

