#ifndef EFL_GENERATED_ELM_MENU_HH
#define EFL_GENERATED_ELM_MENU_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_menu.eo.h"
}

#include "elm_widget.eo.hh"
#include "evas_clickable_interface.eo.hh"
#include <string>

struct elm_menu
      : elm_widget,
      efl::eo::detail::extension_inheritance<evas::clickable_interface>::template type< ::elm_menu>

{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_menu(Eo* eo)
      : elm_widget(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_menu(std::nullptr_t)
      : elm_widget(nullptr)
   {}

   elm_menu(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_menu(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_menu(elm_menu const& other)
      : elm_widget(eo_ref(other._eo_ptr()))
   {}

   ~elm_menu() {}

   /// @brief @brief Move the menu to a new position
   ///
   /// Sets the top-left position of the menu to (@p x,@p y).
   ///
   /// @note @p x and @p y coordinates are relative to parent.
   ///
   /// @ingroup Menu
   ///
   /// @param x The new position.
   /// @param y The new position.
   ///
   void move(Evas_Coord x_, Evas_Coord y_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_menu_move(x_, y_));
   }

   /// @brief @brief Add an item at the end of the given menu widget
   ///
   /// @return Returns the new item.
   ///
   /// @note This function does not accept relative icon path.
   ///
   /// @ingroup Menu
   ///
   /// @param parent The parent menu item (optional)
   /// @param icon An icon display on the item. The icon will be destroyed by the menu.
   /// @param label The label of the item.
   /// @param func Function called when the user select the item.
   /// @param data Data sent by the callback.
   ///
   Elm_Object_Item * item_add(Elm_Object_Item * parent_, std::string icon_, std::string label_, Evas_Smart_Cb func_, const void * data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_menu_item_add(parent_, efl::eolian::to_c(icon_), efl::eolian::to_c(label_), func_, data_));
      return _tmp_ret;
   }

   /// @brief @brief Close a opened menu
   ///
   /// @return void
   ///
   /// Hides the menu and all it's sub-menus.
   ///
   /// @ingroup Menu
   ///
   void close() const
   {
      eo_do(_eo_ptr(), ::elm_obj_menu_close());
   }

   /// @brief @brief Add a separator item to menu @p obj under @p parent.
   ///
   /// @return The created item or NULL on failure
   ///
   /// This is item is a @ref Separator.
   ///
   /// @ingroup Menu
   ///
   /// @param parent The item to add the separator under
   ///
   Elm_Object_Item * item_separator_add(Elm_Object_Item * parent_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_menu_item_separator_add(parent_));
      return _tmp_ret;
   }

   Elm_Object_Item * selected_item_get() const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_menu_selected_item_get());
      return _tmp_ret;
   }

   const Eina_List * items_get() const
   {
      const Eina_List * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_menu_items_get());
      return _tmp_ret;
   }

   Elm_Object_Item * first_item_get() const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_menu_first_item_get());
      return _tmp_ret;
   }

   Elm_Object_Item * last_item_get() const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_menu_last_item_get());
      return _tmp_ret;
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MENU_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_menu, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_menu, function_type>,
         ELM_MENU_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MENU_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MENU_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_menu, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_menu, function_type>,
         ELM_MENU_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_MENU_EVENT_ACCESS_CHANGED, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_MENU_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_MENU_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
void _elm_menu_move_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord x_, Evas_Coord y_)
{
   static_cast<T*>(self->this_)->move(x_, y_);
}

template <typename T>
Elm_Object_Item * _elm_menu_item_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Object_Item * parent_, const char * icon_, const char * label_, Evas_Smart_Cb func_, const void * data_)
{
   return static_cast<T*>(self->this_)->item_add(parent_, efl::eolian::to_cxx<std::string>(icon_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(label_, std::tuple<std::false_type>()), func_, data_);
}

template <typename T>
void _elm_menu_close_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->close();
}

template <typename T>
Elm_Object_Item * _elm_menu_item_separator_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Object_Item * parent_)
{
   return static_cast<T*>(self->this_)->item_separator_add(parent_);
}

template <typename T>
Elm_Object_Item * _elm_menu_selected_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->selected_item_get();
}

template <typename T>
const Eina_List * _elm_menu_items_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->items_get();
}

template <typename T>
Elm_Object_Item * _elm_menu_first_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->first_item_get();
}

template <typename T>
Elm_Object_Item * _elm_menu_last_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->last_item_get();
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_menu >
{
   template <typename T>
   struct type
   {
      virtual void move(Evas_Coord x_, Evas_Coord y_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_menu_move(x_, y_));
      }

      virtual Elm_Object_Item * item_add(Elm_Object_Item * parent_, std::string icon_, std::string label_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_menu_item_add(parent_, efl::eolian::to_c(icon_), efl::eolian::to_c(label_), func_, data_));
            return _tmp_ret;
      }

      virtual void close()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_menu_close());
      }

      virtual Elm_Object_Item * item_separator_add(Elm_Object_Item * parent_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_menu_item_separator_add(parent_));
            return _tmp_ret;
      }

      virtual Elm_Object_Item * selected_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_menu_selected_item_get());
            return _tmp_ret;
      }

      virtual const Eina_List * items_get()
      {
         const Eina_List * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_menu_items_get());
            return _tmp_ret;
      }

      virtual Elm_Object_Item * first_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_menu_first_item_get());
            return _tmp_ret;
      }

      virtual Elm_Object_Item * last_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_menu_last_item_get());
            return _tmp_ret;
      }

   };
};


template<>
struct operation_description_class_size< ::elm_menu >
{
   static const int value = 8;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_menu>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_menu_move_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_menu_move);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_menu_item_add_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_menu_item_add);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_menu_close_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_menu_close);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_menu_item_separator_add_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_menu_item_separator_add);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_menu_selected_item_get_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_menu_selected_item_get);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_menu_items_get_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_menu_items_get);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_menu_first_item_get_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_menu_first_item_get);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_menu_last_item_get_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_menu_last_item_get);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_menu >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_menu, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_menu >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_menu, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_menu>
{
   template <typename U>
   struct type
   {
      operator ::elm_menu() const
      {
         return ::elm_menu(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      void move(Evas_Coord x_, Evas_Coord y_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_menu_move(x_, y_));
      }

      Elm_Object_Item * item_add(Elm_Object_Item * parent_, std::string icon_, std::string label_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_menu_item_add(parent_, efl::eolian::to_c(icon_), efl::eolian::to_c(label_), func_, data_));
            return _tmp_ret;
      }

      void close()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_menu_close());
      }

      Elm_Object_Item * item_separator_add(Elm_Object_Item * parent_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_menu_item_separator_add(parent_));
            return _tmp_ret;
      }

      Elm_Object_Item * selected_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_menu_selected_item_get());
            return _tmp_ret;
      }

      const Eina_List * items_get()
      {
         const Eina_List * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_menu_items_get());
            return _tmp_ret;
      }

      Elm_Object_Item * first_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_menu_first_item_get());
            return _tmp_ret;
      }

      Elm_Object_Item * last_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_menu_last_item_get());
            return _tmp_ret;
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MENU_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_menu, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_menu, function_type>,
         ELM_MENU_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MENU_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_MENU_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_menu, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_menu, function_type>,
         ELM_MENU_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_MENU_EVENT_ACCESS_CHANGED, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_menu>)
{
   return (ELM_MENU_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_MENU_HH

