#ifndef EFL_GENERATED_ELM_PHOTO_HH
#define EFL_GENERATED_ELM_PHOTO_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_photo.eo.h"
}

#include "elm_widget.eo.hh"
#include "evas_clickable_interface.eo.hh"
#include "evas_draggable_interface.eo.hh"
#include <string>

struct elm_photo
      : elm_widget,
      efl::eo::detail::extension_inheritance<evas::clickable_interface>::template type< ::elm_photo>,
      efl::eo::detail::extension_inheritance<evas::draggable_interface>::template type< ::elm_photo>

{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_photo(Eo* eo)
      : elm_widget(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_photo(std::nullptr_t)
      : elm_widget(nullptr)
   {}

   elm_photo(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_photo(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_photo(elm_photo const& other)
      : elm_widget(eo_ref(other._eo_ptr()))
   {}

   ~elm_photo() {}

   /// @brief Set the file that will be used as thumbnail in the photo.
   ///
   /// @ingroup Photo
   ///
   /// @param file The path to file that will be used as thumbnail.
   /// @param group The key used in case of an EET file.
   ///
   void thumb_set(std::string file_, std::string group_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_photo_thumb_set(efl::eolian::to_c(file_), efl::eolian::to_c(group_)));
   }

   /// @param set To set of clear editability.
   ///
   bool editable_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_photo_editable_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param set To set of clear editability.
   ///
   void editable_set(bool set_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_photo_editable_set(efl::eolian::to_c(set_)));
   }

   /// @param fill if true the photo will be completely visible
   ///
   bool fill_inside_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_photo_fill_inside_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param fill if true the photo will be completely visible
   ///
   void fill_inside_set(bool fill_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_photo_fill_inside_set(efl::eolian::to_c(fill_)));
   }

   /// @param fixed @c EINA_TRUE if the photo should fix the aspect,
   /// @c EINA_FALSE otherwise.
   ///
   bool aspect_fixed_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_photo_aspect_fixed_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param fixed @c EINA_TRUE if the photo should fix the aspect,
   /// @c EINA_FALSE otherwise.
   ///
   void aspect_fixed_set(bool fixed_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_photo_aspect_fixed_set(efl::eolian::to_c(fixed_)));
   }

   /// @param size The size of the photo
   ///
   int size_get() const
   {
      int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_photo_size_get());
      return _tmp_ret;
   }

   /// @param size The size of the photo
   ///
   void size_set(int size_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_photo_size_set(size_));
   }

   /// @param file The path to file that will be used as @a obj's image.
   ///
   bool file_set(std::string file_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_photo_file_set(efl::eolian::to_c(file_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_clicked_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PHOTO_EVENT_CLICKED, priority_,
            &efl::eo::_detail::event_callback<::elm_photo, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_photo, function_type>,
         ELM_PHOTO_EVENT_CLICKED );
   }

   template <typename T>
   void
   callback_clicked_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_PHOTO_EVENT_CLICKED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_drag_start_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PHOTO_EVENT_DRAG_START, priority_,
            &efl::eo::_detail::event_callback<::elm_photo, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_photo, function_type>,
         ELM_PHOTO_EVENT_DRAG_START );
   }

   template <typename T>
   void
   callback_drag_start_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_PHOTO_EVENT_DRAG_START, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_drag_end_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PHOTO_EVENT_DRAG_END, priority_,
            &efl::eo::_detail::event_callback<::elm_photo, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_photo, function_type>,
         ELM_PHOTO_EVENT_DRAG_END );
   }

   template <typename T>
   void
   callback_drag_end_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_PHOTO_EVENT_DRAG_END, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_PHOTO_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_PHOTO_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
void _elm_photo_thumb_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * file_, const char * group_)
{
   static_cast<T*>(self->this_)->thumb_set(efl::eolian::to_cxx<std::string>(file_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(group_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_photo_editable_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->editable_get();
}

template <typename T>
void _elm_photo_editable_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool set_)
{
   static_cast<T*>(self->this_)->editable_set(efl::eolian::to_cxx<bool>(set_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_photo_fill_inside_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->fill_inside_get();
}

template <typename T>
void _elm_photo_fill_inside_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool fill_)
{
   static_cast<T*>(self->this_)->fill_inside_set(efl::eolian::to_cxx<bool>(fill_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_photo_aspect_fixed_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->aspect_fixed_get();
}

template <typename T>
void _elm_photo_aspect_fixed_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool fixed_)
{
   static_cast<T*>(self->this_)->aspect_fixed_set(efl::eolian::to_cxx<bool>(fixed_, std::tuple<std::false_type>()));
}

template <typename T>
int _elm_photo_size_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->size_get();
}

template <typename T>
void _elm_photo_size_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int size_)
{
   static_cast<T*>(self->this_)->size_set(size_);
}

template <typename T>
bool _elm_photo_file_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * file_)
{
   return static_cast<T*>(self->this_)->file_set(efl::eolian::to_cxx<std::string>(file_, std::tuple<std::false_type>()));
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_photo >
{
   template <typename T>
   struct type
   {
      virtual void thumb_set(std::string file_, std::string group_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_photo_thumb_set(efl::eolian::to_c(file_), efl::eolian::to_c(group_)));
      }

      virtual bool editable_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_photo_editable_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void editable_set(bool set_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_photo_editable_set(efl::eolian::to_c(set_)));
      }

      virtual bool fill_inside_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_photo_fill_inside_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void fill_inside_set(bool fill_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_photo_fill_inside_set(efl::eolian::to_c(fill_)));
      }

      virtual bool aspect_fixed_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_photo_aspect_fixed_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void aspect_fixed_set(bool fixed_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_photo_aspect_fixed_set(efl::eolian::to_c(fixed_)));
      }

      virtual int size_get()
      {
         int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_photo_size_get());
            return _tmp_ret;
      }

      virtual void size_set(int size_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_photo_size_set(size_));
      }

      virtual bool file_set(std::string file_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_photo_file_set(efl::eolian::to_c(file_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

   };
};


template<>
struct operation_description_class_size< ::elm_photo >
{
   static const int value = 10;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_photo>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_photo_thumb_set_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_photo_thumb_set);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_photo_editable_get_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_photo_editable_get);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_photo_editable_set_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_photo_editable_set);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_photo_fill_inside_get_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_photo_fill_inside_get);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_photo_fill_inside_set_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_photo_fill_inside_set);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_photo_aspect_fixed_get_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_photo_aspect_fixed_get);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_photo_aspect_fixed_set_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_photo_aspect_fixed_set);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_photo_size_get_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_photo_size_get);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_photo_size_set_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_photo_size_set);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_photo_file_set_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_photo_file_set);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_photo >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_photo, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_photo >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_photo, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_photo>
{
   template <typename U>
   struct type
   {
      operator ::elm_photo() const
      {
         return ::elm_photo(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      void thumb_set(std::string file_, std::string group_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_photo_thumb_set(efl::eolian::to_c(file_), efl::eolian::to_c(group_)));
      }

      bool editable_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_photo_editable_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void editable_set(bool set_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_photo_editable_set(efl::eolian::to_c(set_)));
      }

      bool fill_inside_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_photo_fill_inside_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void fill_inside_set(bool fill_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_photo_fill_inside_set(efl::eolian::to_c(fill_)));
      }

      bool aspect_fixed_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_photo_aspect_fixed_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void aspect_fixed_set(bool fixed_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_photo_aspect_fixed_set(efl::eolian::to_c(fixed_)));
      }

      int size_get()
      {
         int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_photo_size_get());
            return _tmp_ret;
      }

      void size_set(int size_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_photo_size_set(size_));
      }

      bool file_set(std::string file_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_photo_file_set(efl::eolian::to_c(file_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_clicked_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PHOTO_EVENT_CLICKED, priority_,
            &efl::eo::_detail::event_callback<::elm_photo, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_photo, function_type>,
         ELM_PHOTO_EVENT_CLICKED );
   }

   template <typename T>
   void
   callback_clicked_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_PHOTO_EVENT_CLICKED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_drag_start_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PHOTO_EVENT_DRAG_START, priority_,
            &efl::eo::_detail::event_callback<::elm_photo, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_photo, function_type>,
         ELM_PHOTO_EVENT_DRAG_START );
   }

   template <typename T>
   void
   callback_drag_start_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_PHOTO_EVENT_DRAG_START, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_drag_end_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PHOTO_EVENT_DRAG_END, priority_,
            &efl::eo::_detail::event_callback<::elm_photo, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_photo, function_type>,
         ELM_PHOTO_EVENT_DRAG_END );
   }

   template <typename T>
   void
   callback_drag_end_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_PHOTO_EVENT_DRAG_END, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_photo>)
{
   return (ELM_PHOTO_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_PHOTO_HH

