#ifndef EFL_GENERATED_ELM_PLUG_HH
#define EFL_GENERATED_ELM_PLUG_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_plug.eo.h"
}

#include "elm_widget.eo.hh"
#include <string>

struct elm_plug
      : elm_widget
{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_plug(Eo* eo)
      : elm_widget(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_plug(std::nullptr_t)
      : elm_widget(nullptr)
   {}

   elm_plug(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_plug(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_plug(elm_plug const& other)
      : elm_widget(eo_ref(other._eo_ptr()))
   {}

   ~elm_plug() {}

   /// @brief Connect a plug widget to service provided by socket image.
   ///
   /// @return (@c EINA_TRUE = success, @c EINA_FALSE = error)
   ///
   /// @ingroup Plug
   ///
   /// @param svcname The service name to connect to set up by the socket.
   /// @param svcnum The service number to connect to (set up by socket).
   /// @param svcsys Boolean to set if the service is a system one or not (set up by socket).
   ///
   bool connect(std::string svcname_, int svcnum_, bool svcsys_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_plug_connect(efl::eolian::to_c(svcname_), svcnum_, efl::eolian::to_c(svcsys_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   evas::object image_object_get() const
   {
      Evas_Object * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_plug_image_object_get());
      return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_clicked_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PLUG_EVENT_CLICKED, priority_,
            &efl::eo::_detail::event_callback<::elm_plug, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_plug, function_type>,
         ELM_PLUG_EVENT_CLICKED );
   }

   template <typename T>
   void
   callback_clicked_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_PLUG_EVENT_CLICKED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_image_deleted_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PLUG_EVENT_IMAGE_DELETED, priority_,
            &efl::eo::_detail::event_callback<::elm_plug, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_plug, function_type>,
         ELM_PLUG_EVENT_IMAGE_DELETED );
   }

   template <typename T>
   void
   callback_image_deleted_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_PLUG_EVENT_IMAGE_DELETED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_image_resized_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PLUG_EVENT_IMAGE_RESIZED, priority_,
            &efl::eo::_detail::event_callback<::elm_plug, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_plug, function_type>,
         ELM_PLUG_EVENT_IMAGE_RESIZED );
   }

   template <typename T>
   void
   callback_image_resized_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_PLUG_EVENT_IMAGE_RESIZED, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_PLUG_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_PLUG_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
bool _elm_plug_connect_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * svcname_, int svcnum_, Eina_Bool svcsys_)
{
   return static_cast<T*>(self->this_)->connect(efl::eolian::to_cxx<std::string>(svcname_, std::tuple<std::false_type>()), svcnum_, efl::eolian::to_cxx<bool>(svcsys_, std::tuple<std::false_type>()));
}

template <typename T>
evas::object _elm_plug_image_object_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->image_object_get();
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_plug >
{
   template <typename T>
   struct type
   {
      virtual bool connect(std::string svcname_, int svcnum_, bool svcsys_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_plug_connect(efl::eolian::to_c(svcname_), svcnum_, efl::eolian::to_c(svcsys_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual evas::object image_object_get()
      {
         Evas_Object * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_plug_image_object_get());
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

   };
};


template<>
struct operation_description_class_size< ::elm_plug >
{
   static const int value = 2;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_plug>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_plug_connect_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_plug_connect);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_plug_image_object_get_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_plug_image_object_get);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_plug >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_plug, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_plug >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_plug, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_plug>
{
   template <typename U>
   struct type
   {
      operator ::elm_plug() const
      {
         return ::elm_plug(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      bool connect(std::string svcname_, int svcnum_, bool svcsys_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_plug_connect(efl::eolian::to_c(svcname_), svcnum_, efl::eolian::to_c(svcsys_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      evas::object image_object_get()
      {
         Evas_Object * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_plug_image_object_get());
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_clicked_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PLUG_EVENT_CLICKED, priority_,
            &efl::eo::_detail::event_callback<::elm_plug, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_plug, function_type>,
         ELM_PLUG_EVENT_CLICKED );
   }

   template <typename T>
   void
   callback_clicked_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_PLUG_EVENT_CLICKED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_image_deleted_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PLUG_EVENT_IMAGE_DELETED, priority_,
            &efl::eo::_detail::event_callback<::elm_plug, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_plug, function_type>,
         ELM_PLUG_EVENT_IMAGE_DELETED );
   }

   template <typename T>
   void
   callback_image_deleted_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_PLUG_EVENT_IMAGE_DELETED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_image_resized_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PLUG_EVENT_IMAGE_RESIZED, priority_,
            &efl::eo::_detail::event_callback<::elm_plug, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_plug, function_type>,
         ELM_PLUG_EVENT_IMAGE_RESIZED );
   }

   template <typename T>
   void
   callback_image_resized_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_PLUG_EVENT_IMAGE_RESIZED, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_plug>)
{
   return (ELM_PLUG_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_PLUG_HH

