#ifndef EFL_GENERATED_ELM_PREFS_HH
#define EFL_GENERATED_ELM_PREFS_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_prefs.eo.h"
}

#include "elm_widget.eo.hh"
#include <canvas/evas_object.eo.hh>
#include <string>

struct elm_prefs
      : elm_widget
{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_prefs(Eo* eo)
      : elm_widget(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_prefs(std::nullptr_t)
      : elm_widget(nullptr)
   {}

   elm_prefs(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_prefs(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_prefs(elm_prefs const& other)
      : elm_widget(eo_ref(other._eo_ptr()))
   {}

   ~elm_prefs() {}

   /// @brief Reset the values of a given prefs widget to a previous state.
   ///
   /// As can be seen on #Elm_Prefs_Reset_Mode, there are two possible
   /// actions to be taken by this call -- either to reset @a prefs'
   /// values to the defaults (declared on the @c .epb file it is bound
   /// to) or to reset to the state they were before the last modification
   /// it got.
   ///
   /// @since 1.8
   ///
   /// @param mode The reset mode to apply on @a prefs
   ///
   void reset(Elm_Prefs_Reset_Mode mode_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_prefs_reset(mode_));
   }

   /// @brief Set the value on a given prefs widget's item.
   ///
   /// @return @c EINA_TRUE, on success, @c EINA_FALSE otherwise
   ///
   /// This will change the value of item named @a name programatically.
   ///
   /// @see elm_prefs_item_value_get()
   ///
   /// @since 1.8
   ///
   /// @param name The name of the item (as declared in the prefs
   /// collection)
   /// @param value The value to set on the item. It should be typed as
   /// the item expects, preferably, or a conversion will
   /// take place
   ///
   bool item_value_set(std::string name_, const Eina_Value * value_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_prefs_item_value_set(efl::eolian::to_c(name_), value_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Retrieve the value of a given prefs widget's item.
   ///
   /// @return @c EINA_TRUE, on success, @c EINA_FALSE otherwise
   ///
   /// This will retrieve the value of item named @a name.
   ///
   /// @see elm_prefs_item_value_set()
   ///
   /// @since 1.8
   ///
   /// @param name The name of the item (as declared in the prefs
   /// collection) to get value from
   /// @param[out] value Where to store the value of the item. It will be
   /// overwritten and setup with the type the item
   /// is bound to
   ///
   bool item_value_get(std::string name_, Eina_Value* value_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_prefs_item_value_get(efl::eolian::to_c(name_), value_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Retrieve the Elementary widget bound to a given prefs widget's
   /// item.
   ///
   /// @return A valid widget handle, on success, or @c NULL, otherwise
   ///
   /// This will retrieve a handle to the real widget implementing a given
   /// item of @a prefs, <b>for read-only</b> actions.
   ///
   /// @warning You should @b never modify the state of the returned
   /// widget, because it's meant to be managed by @a prefs, solely.
   ///
   /// @see elm_prefs_item_value_set()
   ///
   /// @since 1.8
   ///
   /// @param name The name of the item (as declared in the prefs
   /// collection) to get object from
   ///
   const Evas_Object * item_object_get(std::string name_) const
   {
      const Evas_Object * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_prefs_item_object_get(efl::eolian::to_c(name_)));
      return _tmp_ret;
   }

   /// @brief Set whether the widget bound to a given prefs widget's item is
   /// disabled or not.
   ///
   /// @see elm_prefs_item_disabled_get()
   ///
   /// @since 1.8
   ///
   /// @param name The name of the item (as declared in the prefs
   /// collection) to act on
   /// @param disabled @c EINA_TRUE, to make it disabled, @c EINA_FALSE
   /// otherwise
   ///
   void item_disabled_set(std::string name_, bool disabled_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_prefs_item_disabled_set(efl::eolian::to_c(name_), efl::eolian::to_c(disabled_)));
   }

   /// @brief Retrieve whether the widget bound to a given prefs widget's item is
   /// disabled or not.
   ///
   /// @return @c EINA_TRUE, if it is disabled, @c EINA_FALSE
   /// otherwise
   ///
   /// @see elm_prefs_item_disabled_set()
   ///
   /// @since 1.8
   ///
   /// @param name The name of the item (as declared in the prefs
   /// collection) to get disabled state from
   ///
   bool item_disabled_get(std::string name_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_prefs_item_disabled_get(efl::eolian::to_c(name_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief "Swallows" an object into a SWALLOW item of a prefs widget.
   ///
   /// @return @c EINA_TRUE, on success, @c EINA_FALSE otherwise
   ///
   /// @see elm_prefs_item_swallow() for more details
   ///
   /// @since 1.8
   ///
   /// @param name the name of the SWALLOW item (as declared in the prefs
   /// collection)
   /// @param child The object to occupy the item
   ///
   bool item_swallow(std::string name_, evas::object child_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_prefs_item_swallow(efl::eolian::to_c(name_), efl::eolian::to_c(child_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Set whether the widget bound to a given prefs widget's item is
   /// editable or not.
   ///
   /// @note Only @c TEXT or @c TEXTAREA items' default widgets implement
   /// the 'editable' property. Custom registered widgets may as well
   /// implement them.
   ///
   /// @see elm_prefs_item_editable_get()
   ///
   /// @since 1.8
   ///
   /// @param name The name of the item (as declared in the prefs
   /// collection) to act on
   /// @param editable @c EINA_TRUE, to make it editable, @c EINA_FALSE
   /// otherwise
   ///
   void item_editable_set(std::string name_, bool editable_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_prefs_item_editable_set(efl::eolian::to_c(name_), efl::eolian::to_c(editable_)));
   }

   /// @brief Retrieve whether the widget bound to a given prefs widget's item is
   /// editable or not.
   ///
   /// @return @c EINA_TRUE, if it is editable, @c EINA_FALSE
   /// otherwise
   ///
   /// @see elm_prefs_item_editable_set() for more details
   ///
   /// @since 1.8
   ///
   /// @param name The name of the item (as declared in the prefs
   /// collection) to get editable state from
   ///
   bool item_editable_get(std::string name_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_prefs_item_editable_get(efl::eolian::to_c(name_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Unswallow an object from a SWALLOW item of a prefs widget.
   ///
   /// @return The unswallowed object, or NULL on errors
   ///
   /// @see elm_prefs_item_unswallow() for more details
   ///
   /// @since 1.8
   ///
   /// @param name the name of the SWALLOW item (as declared in the prefs
   /// collection)
   ///
   evas::object item_unswallow(std::string name_) const
   {
      Evas_Object * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_prefs_item_unswallow(efl::eolian::to_c(name_)));
      return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Set whether the widget bound to given prefs widget's item should be
   /// visible or not.
   ///
   /// Each prefs item may have a default visibility state, declared on
   /// the @c .epb @a prefs it was loaded with. By this call one may alter
   /// that state, programatically.
   ///
   /// @see elm_prefs_item_visible_get()
   ///
   /// @since 1.8
   ///
   /// @param name The name of the item (as declared in the prefs
   /// collection) to change visibility of
   /// @param visible @c EINA_TRUE, to make it visible, @c EINA_FALSE
   /// otherwise
   ///
   void item_visible_set(std::string name_, bool visible_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_prefs_item_visible_set(efl::eolian::to_c(name_), efl::eolian::to_c(visible_)));
   }

   /// @brief Retrieve whether the widget bound to a given prefs widget's item is
   /// visible or not.
   ///
   /// @return @c EINA_TRUE, if it is visible, @c EINA_FALSE
   /// otherwise
   ///
   /// @see elm_prefs_item_visible_set() for more details
   ///
   /// @since 1.8
   ///
   /// @param name The name of the item (as declared in the prefs
   /// collection) to get visibility state from
   ///
   bool item_visible_get(std::string name_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_prefs_item_visible_get(efl::eolian::to_c(name_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param data A valid prefs_data handle
   ///
   Elm_Prefs_Data * data_get() const
   {
      Elm_Prefs_Data * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_prefs_data_get());
      return _tmp_ret;
   }

   /// @param data A valid prefs_data handle
   ///
   bool data_set(Elm_Prefs_Data * data_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_prefs_data_set(data_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param file The @b .epb (binary) file to get contents from
   /// @param page The page, inside @a file, where to get item contents from
   ///
   bool file_get(const char ** file_, const char ** page_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_prefs_file_get(file_, page_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param file The @b .epb (binary) file to get contents from
   /// @param page The page, inside @a file, where to get item contents from
   ///
   bool file_set(std::string file_, std::string page_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_prefs_file_set(efl::eolian::to_c(file_), efl::eolian::to_c(page_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param autosave @c EINA_TRUE to save automatically, @c EINA_FALSE
   /// otherwise.
   ///
   bool autosave_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_prefs_autosave_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param autosave @c EINA_TRUE to save automatically, @c EINA_FALSE
   /// otherwise.
   ///
   void autosave_set(bool autosave_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_prefs_autosave_set(efl::eolian::to_c(autosave_)));
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_page_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PREFS_EVENT_PAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_prefs, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_prefs, function_type>,
         ELM_PREFS_EVENT_PAGE_CHANGED );
   }

   template <typename T>
   void
   callback_page_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_PREFS_EVENT_PAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_page_saved_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PREFS_EVENT_PAGE_SAVED, priority_,
            &efl::eo::_detail::event_callback<::elm_prefs, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_prefs, function_type>,
         ELM_PREFS_EVENT_PAGE_SAVED );
   }

   template <typename T>
   void
   callback_page_saved_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_PREFS_EVENT_PAGE_SAVED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_page_reset_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PREFS_EVENT_PAGE_RESET, priority_,
            &efl::eo::_detail::event_callback<::elm_prefs, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_prefs, function_type>,
         ELM_PREFS_EVENT_PAGE_RESET );
   }

   template <typename T>
   void
   callback_page_reset_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_PREFS_EVENT_PAGE_RESET, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_page_loaded_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PREFS_EVENT_PAGE_LOADED, priority_,
            &efl::eo::_detail::event_callback<::elm_prefs, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_prefs, function_type>,
         ELM_PREFS_EVENT_PAGE_LOADED );
   }

   template <typename T>
   void
   callback_page_loaded_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_PREFS_EVENT_PAGE_LOADED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_item_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PREFS_EVENT_ITEM_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_prefs, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_prefs, function_type>,
         ELM_PREFS_EVENT_ITEM_CHANGED );
   }

   template <typename T>
   void
   callback_item_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_PREFS_EVENT_ITEM_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_action_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PREFS_EVENT_ACTION, priority_,
            &efl::eo::_detail::event_callback<::elm_prefs, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_prefs, function_type>,
         ELM_PREFS_EVENT_ACTION );
   }

   template <typename T>
   void
   callback_action_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_PREFS_EVENT_ACTION, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_PREFS_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_PREFS_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
void _elm_prefs_reset_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Prefs_Reset_Mode mode_)
{
   static_cast<T*>(self->this_)->reset(mode_);
}

template <typename T>
bool _elm_prefs_item_value_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * name_, const Eina_Value * value_)
{
   return static_cast<T*>(self->this_)->item_value_set(efl::eolian::to_cxx<std::string>(name_, std::tuple<std::false_type>()), value_);
}

template <typename T>
bool _elm_prefs_item_value_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * name_, Eina_Value* value_)
{
   return static_cast<T*>(self->this_)->item_value_get(efl::eolian::to_cxx<std::string>(name_, std::tuple<std::false_type>()), value_);
}

template <typename T>
const Evas_Object * _elm_prefs_item_object_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * name_)
{
   return static_cast<T*>(self->this_)->item_object_get(efl::eolian::to_cxx<std::string>(name_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_prefs_item_disabled_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * name_, Eina_Bool disabled_)
{
   static_cast<T*>(self->this_)->item_disabled_set(efl::eolian::to_cxx<std::string>(name_, std::tuple<std::false_type>()), efl::eolian::to_cxx<bool>(disabled_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_prefs_item_disabled_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * name_)
{
   return static_cast<T*>(self->this_)->item_disabled_get(efl::eolian::to_cxx<std::string>(name_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_prefs_item_swallow_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * name_, Evas_Object * child_)
{
   return static_cast<T*>(self->this_)->item_swallow(efl::eolian::to_cxx<std::string>(name_, std::tuple<std::false_type>()), efl::eolian::to_cxx<evas::object>(child_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_prefs_item_editable_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * name_, Eina_Bool editable_)
{
   static_cast<T*>(self->this_)->item_editable_set(efl::eolian::to_cxx<std::string>(name_, std::tuple<std::false_type>()), efl::eolian::to_cxx<bool>(editable_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_prefs_item_editable_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * name_)
{
   return static_cast<T*>(self->this_)->item_editable_get(efl::eolian::to_cxx<std::string>(name_, std::tuple<std::false_type>()));
}

template <typename T>
evas::object _elm_prefs_item_unswallow_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * name_)
{
   return static_cast<T*>(self->this_)->item_unswallow(efl::eolian::to_cxx<std::string>(name_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_prefs_item_visible_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * name_, Eina_Bool visible_)
{
   static_cast<T*>(self->this_)->item_visible_set(efl::eolian::to_cxx<std::string>(name_, std::tuple<std::false_type>()), efl::eolian::to_cxx<bool>(visible_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_prefs_item_visible_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * name_)
{
   return static_cast<T*>(self->this_)->item_visible_get(efl::eolian::to_cxx<std::string>(name_, std::tuple<std::false_type>()));
}

template <typename T>
Elm_Prefs_Data * _elm_prefs_data_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->data_get();
}

template <typename T>
bool _elm_prefs_data_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Prefs_Data * data_)
{
   return static_cast<T*>(self->this_)->data_set(data_);
}

template <typename T>
bool _elm_prefs_file_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char ** file_, const char ** page_)
{
   return static_cast<T*>(self->this_)->file_get(file_, page_);
}

template <typename T>
bool _elm_prefs_file_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * file_, const char * page_)
{
   return static_cast<T*>(self->this_)->file_set(efl::eolian::to_cxx<std::string>(file_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(page_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_prefs_autosave_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->autosave_get();
}

template <typename T>
void _elm_prefs_autosave_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool autosave_)
{
   static_cast<T*>(self->this_)->autosave_set(efl::eolian::to_cxx<bool>(autosave_, std::tuple<std::false_type>()));
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_prefs >
{
   template <typename T>
   struct type
   {
      virtual void reset(Elm_Prefs_Reset_Mode mode_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_prefs_reset(mode_));
      }

      virtual bool item_value_set(std::string name_, const Eina_Value * value_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_prefs_item_value_set(efl::eolian::to_c(name_), value_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool item_value_get(std::string name_, Eina_Value* value_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_prefs_item_value_get(efl::eolian::to_c(name_), value_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual const Evas_Object * item_object_get(std::string name_)
      {
         const Evas_Object * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_prefs_item_object_get(efl::eolian::to_c(name_)));
            return _tmp_ret;
      }

      virtual void item_disabled_set(std::string name_, bool disabled_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_prefs_item_disabled_set(efl::eolian::to_c(name_), efl::eolian::to_c(disabled_)));
      }

      virtual bool item_disabled_get(std::string name_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_prefs_item_disabled_get(efl::eolian::to_c(name_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool item_swallow(std::string name_, evas::object child_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_prefs_item_swallow(efl::eolian::to_c(name_), efl::eolian::to_c(child_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void item_editable_set(std::string name_, bool editable_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_prefs_item_editable_set(efl::eolian::to_c(name_), efl::eolian::to_c(editable_)));
      }

      virtual bool item_editable_get(std::string name_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_prefs_item_editable_get(efl::eolian::to_c(name_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual evas::object item_unswallow(std::string name_)
      {
         Evas_Object * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_prefs_item_unswallow(efl::eolian::to_c(name_)));
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void item_visible_set(std::string name_, bool visible_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_prefs_item_visible_set(efl::eolian::to_c(name_), efl::eolian::to_c(visible_)));
      }

      virtual bool item_visible_get(std::string name_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_prefs_item_visible_get(efl::eolian::to_c(name_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual Elm_Prefs_Data * data_get()
      {
         Elm_Prefs_Data * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_prefs_data_get());
            return _tmp_ret;
      }

      virtual bool data_set(Elm_Prefs_Data * data_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_prefs_data_set(data_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool file_get(const char ** file_, const char ** page_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_prefs_file_get(file_, page_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool file_set(std::string file_, std::string page_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_prefs_file_set(efl::eolian::to_c(file_), efl::eolian::to_c(page_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool autosave_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_prefs_autosave_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void autosave_set(bool autosave_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_prefs_autosave_set(efl::eolian::to_c(autosave_)));
      }

   };
};


template<>
struct operation_description_class_size< ::elm_prefs >
{
   static const int value = 18;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_prefs>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_prefs_reset_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_prefs_reset);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_prefs_item_value_set_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_prefs_item_value_set);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_prefs_item_value_get_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_prefs_item_value_get);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_prefs_item_object_get_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_prefs_item_object_get);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_prefs_item_disabled_set_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_prefs_item_disabled_set);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_prefs_item_disabled_get_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_prefs_item_disabled_get);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_prefs_item_swallow_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_prefs_item_swallow);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_prefs_item_editable_set_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_prefs_item_editable_set);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_prefs_item_editable_get_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_prefs_item_editable_get);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_prefs_item_unswallow_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_prefs_item_unswallow);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::_elm_prefs_item_visible_set_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::elm_obj_prefs_item_visible_set);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::_elm_prefs_item_visible_get_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::elm_obj_prefs_item_visible_get);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::_elm_prefs_data_get_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::elm_obj_prefs_data_get);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::_elm_prefs_data_set_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::elm_obj_prefs_data_set);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::_elm_prefs_file_get_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::elm_obj_prefs_file_get);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::_elm_prefs_file_set_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::elm_obj_prefs_file_set);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   ops[16].func = reinterpret_cast<void*>(& ::_elm_prefs_autosave_get_wrapper<T>);
   ops[16].api_func = reinterpret_cast<void*>(& ::elm_obj_prefs_autosave_get);
   ops[16].op = EO_OP_OVERRIDE;
   ops[16].op_type = EO_OP_TYPE_REGULAR;
   ops[16].doc = NULL;

   ops[17].func = reinterpret_cast<void*>(& ::_elm_prefs_autosave_set_wrapper<T>);
   ops[17].api_func = reinterpret_cast<void*>(& ::elm_obj_prefs_autosave_set);
   ops[17].op = EO_OP_OVERRIDE;
   ops[17].op_type = EO_OP_TYPE_REGULAR;
   ops[17].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_prefs >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_prefs, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_prefs >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_prefs, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_prefs>
{
   template <typename U>
   struct type
   {
      operator ::elm_prefs() const
      {
         return ::elm_prefs(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      void reset(Elm_Prefs_Reset_Mode mode_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_prefs_reset(mode_));
      }

      bool item_value_set(std::string name_, const Eina_Value * value_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_prefs_item_value_set(efl::eolian::to_c(name_), value_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool item_value_get(std::string name_, Eina_Value* value_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_prefs_item_value_get(efl::eolian::to_c(name_), value_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      const Evas_Object * item_object_get(std::string name_)
      {
         const Evas_Object * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_prefs_item_object_get(efl::eolian::to_c(name_)));
            return _tmp_ret;
      }

      void item_disabled_set(std::string name_, bool disabled_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_prefs_item_disabled_set(efl::eolian::to_c(name_), efl::eolian::to_c(disabled_)));
      }

      bool item_disabled_get(std::string name_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_prefs_item_disabled_get(efl::eolian::to_c(name_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool item_swallow(std::string name_, evas::object child_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_prefs_item_swallow(efl::eolian::to_c(name_), efl::eolian::to_c(child_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void item_editable_set(std::string name_, bool editable_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_prefs_item_editable_set(efl::eolian::to_c(name_), efl::eolian::to_c(editable_)));
      }

      bool item_editable_get(std::string name_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_prefs_item_editable_get(efl::eolian::to_c(name_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      evas::object item_unswallow(std::string name_)
      {
         Evas_Object * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_prefs_item_unswallow(efl::eolian::to_c(name_)));
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      void item_visible_set(std::string name_, bool visible_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_prefs_item_visible_set(efl::eolian::to_c(name_), efl::eolian::to_c(visible_)));
      }

      bool item_visible_get(std::string name_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_prefs_item_visible_get(efl::eolian::to_c(name_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      Elm_Prefs_Data * data_get()
      {
         Elm_Prefs_Data * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_prefs_data_get());
            return _tmp_ret;
      }

      bool data_set(Elm_Prefs_Data * data_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_prefs_data_set(data_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool file_get(const char ** file_, const char ** page_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_prefs_file_get(file_, page_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool file_set(std::string file_, std::string page_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_prefs_file_set(efl::eolian::to_c(file_), efl::eolian::to_c(page_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool autosave_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_prefs_autosave_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void autosave_set(bool autosave_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_prefs_autosave_set(efl::eolian::to_c(autosave_)));
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_page_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PREFS_EVENT_PAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_prefs, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_prefs, function_type>,
         ELM_PREFS_EVENT_PAGE_CHANGED );
   }

   template <typename T>
   void
   callback_page_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_PREFS_EVENT_PAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_page_saved_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PREFS_EVENT_PAGE_SAVED, priority_,
            &efl::eo::_detail::event_callback<::elm_prefs, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_prefs, function_type>,
         ELM_PREFS_EVENT_PAGE_SAVED );
   }

   template <typename T>
   void
   callback_page_saved_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_PREFS_EVENT_PAGE_SAVED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_page_reset_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PREFS_EVENT_PAGE_RESET, priority_,
            &efl::eo::_detail::event_callback<::elm_prefs, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_prefs, function_type>,
         ELM_PREFS_EVENT_PAGE_RESET );
   }

   template <typename T>
   void
   callback_page_reset_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_PREFS_EVENT_PAGE_RESET, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_page_loaded_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PREFS_EVENT_PAGE_LOADED, priority_,
            &efl::eo::_detail::event_callback<::elm_prefs, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_prefs, function_type>,
         ELM_PREFS_EVENT_PAGE_LOADED );
   }

   template <typename T>
   void
   callback_page_loaded_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_PREFS_EVENT_PAGE_LOADED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_item_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PREFS_EVENT_ITEM_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_prefs, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_prefs, function_type>,
         ELM_PREFS_EVENT_ITEM_CHANGED );
   }

   template <typename T>
   void
   callback_item_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_PREFS_EVENT_ITEM_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_action_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PREFS_EVENT_ACTION, priority_,
            &efl::eo::_detail::event_callback<::elm_prefs, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_prefs, function_type>,
         ELM_PREFS_EVENT_ACTION );
   }

   template <typename T>
   void
   callback_action_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_PREFS_EVENT_ACTION, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_prefs>)
{
   return (ELM_PREFS_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_PREFS_HH

