#ifndef EFL_GENERATED_ELM_PROGRESSBAR_HH
#define EFL_GENERATED_ELM_PROGRESSBAR_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_progressbar.eo.h"
}

#include "elm_layout.eo.hh"
#include <string>

struct elm_progressbar
      : elm_layout
{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_progressbar(Eo* eo)
      : elm_layout(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_progressbar(std::nullptr_t)
      : elm_layout(nullptr)
   {}

   elm_progressbar(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_progressbar(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_progressbar(elm_progressbar const& other)
      : elm_layout(eo_ref(other._eo_ptr()))
   {}

   ~elm_progressbar() {}

   /// @brief Set the progress value (in percentage) on a given progress bar
   /// widget for the given part name
   ///
   /// @since 1.8
   ///
   /// Use this call to set progress bar status for more than one progress status .
   ///
   /// @ingroup Progressbar
   ///
   /// @param part The partname to which val have to set
   /// @param val The progress value (@b must be between @c 0.0 and @c
   /// 1.0)
   ///
   void part_value_set(std::string part_, double val_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_progressbar_part_value_set(efl::eolian::to_c(part_), val_));
   }

   /// @brief Get the progress value (in percentage) on a given progress bar
   /// widget for a particular part
   ///
   /// @since 1.8
   ///
   /// @return The value of the progressbar
   ///
   /// @see elm_progressbar_value_set() for more details
   ///
   /// @ingroup Progressbar
   ///
   /// @param part The part name of the progress bar
   ///
   double part_value_get(std::string part_) const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_progressbar_part_value_get(efl::eolian::to_c(part_)));
      return _tmp_ret;
   }

   /// @brief Start/stop a given progress bar "pulsing" animation, if its
   /// under that mode
   ///
   /// @note This call won't do anything if @p obj is not under "pulsing mode".
   ///
   /// @see elm_progressbar_pulse_set() for more details.
   ///
   /// @ingroup Progressbar
   ///
   /// @param state @c EINA_TRUE, to @b start the pulsing animation,
   /// @c EINA_FALSE to @b stop it
   ///
   void pulse(bool state_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_progressbar_pulse(efl::eolian::to_c(state_)));
   }

   /// @param size The length of the progress bar's bar region
   ///
   Evas_Coord span_size_get() const
   {
      Evas_Coord _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_progressbar_span_size_get());
      return _tmp_ret;
   }

   /// @param size The length of the progress bar's bar region
   ///
   void span_size_set(Evas_Coord size_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_progressbar_span_size_set(size_));
   }

   /// @param pulse @c EINA_TRUE to put @p obj in pulsing mode,
   /// @c EINA_FALSE to put it back to its default one
   ///
   bool pulse_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_progressbar_pulse_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param pulse @c EINA_TRUE to put @p obj in pulsing mode,
   /// @c EINA_FALSE to put it back to its default one
   ///
   void pulse_set(bool pulse_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_progressbar_pulse_set(efl::eolian::to_c(pulse_)));
   }

   /// @param val The progress value (@b must be between @c 0.0 and @c
   /// 1.0)
   ///
   double value_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_progressbar_value_get());
      return _tmp_ret;
   }

   /// @param val The progress value (@b must be between @c 0.0 and @c
   /// 1.0)
   ///
   void value_set(double val_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_progressbar_value_set(val_));
   }

   /// @param inverted Use @c EINA_TRUE to make @p obj inverted,
   /// @c EINA_FALSE to bring it back to default, non-inverted values.
   ///
   bool inverted_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_progressbar_inverted_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param inverted Use @c EINA_TRUE to make @p obj inverted,
   /// @c EINA_FALSE to bring it back to default, non-inverted values.
   ///
   void inverted_set(bool inverted_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_progressbar_inverted_set(efl::eolian::to_c(inverted_)));
   }

   /// @param horizontal Use @c EINA_TRUE to make @p obj to be
   /// @b horizontal, @c EINA_FALSE to make it @b vertical
   ///
   bool horizontal_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_progressbar_horizontal_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param horizontal Use @c EINA_TRUE to make @p obj to be
   /// @b horizontal, @c EINA_FALSE to make it @b vertical
   ///
   void horizontal_set(bool horizontal_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_progressbar_horizontal_set(efl::eolian::to_c(horizontal_)));
   }

   /// @param units The format string for @p obj's units label
   ///
   std::string unit_format_get() const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_progressbar_unit_format_get());
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param units The format string for @p obj's units label
   ///
   void unit_format_set(std::string units_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_progressbar_unit_format_set(efl::eolian::to_c(units_)));
   }

   /// @param func The unit format function
   /// @param free_func The freeing function for the format string.
   ///
   void unit_format_function_set(progressbar_func_type func_, progressbar_freefunc_type free_func_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_progressbar_unit_format_function_set(func_, free_func_));
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PROGRESSBAR_EVENT_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_progressbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_progressbar, function_type>,
         ELM_PROGRESSBAR_EVENT_CHANGED );
   }

   template <typename T>
   void
   callback_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_PROGRESSBAR_EVENT_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PROGRESSBAR_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_progressbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_progressbar, function_type>,
         ELM_PROGRESSBAR_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_PROGRESSBAR_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PROGRESSBAR_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_progressbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_progressbar, function_type>,
         ELM_PROGRESSBAR_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_PROGRESSBAR_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PROGRESSBAR_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_progressbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_progressbar, function_type>,
         ELM_PROGRESSBAR_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_PROGRESSBAR_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PROGRESSBAR_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_progressbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_progressbar, function_type>,
         ELM_PROGRESSBAR_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_PROGRESSBAR_EVENT_UNFOCUSED, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_PROGRESSBAR_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_PROGRESSBAR_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
void _elm_progressbar_part_value_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * part_, double val_)
{
   static_cast<T*>(self->this_)->part_value_set(efl::eolian::to_cxx<std::string>(part_, std::tuple<std::false_type>()), val_);
}

template <typename T>
double _elm_progressbar_part_value_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * part_)
{
   return static_cast<T*>(self->this_)->part_value_get(efl::eolian::to_cxx<std::string>(part_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_progressbar_pulse_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool state_)
{
   static_cast<T*>(self->this_)->pulse(efl::eolian::to_cxx<bool>(state_, std::tuple<std::false_type>()));
}

template <typename T>
Evas_Coord _elm_progressbar_span_size_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->span_size_get();
}

template <typename T>
void _elm_progressbar_span_size_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord size_)
{
   static_cast<T*>(self->this_)->span_size_set(size_);
}

template <typename T>
bool _elm_progressbar_pulse_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->pulse_get();
}

template <typename T>
void _elm_progressbar_pulse_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool pulse_)
{
   static_cast<T*>(self->this_)->pulse_set(efl::eolian::to_cxx<bool>(pulse_, std::tuple<std::false_type>()));
}

template <typename T>
double _elm_progressbar_value_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->value_get();
}

template <typename T>
void _elm_progressbar_value_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double val_)
{
   static_cast<T*>(self->this_)->value_set(val_);
}

template <typename T>
bool _elm_progressbar_inverted_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->inverted_get();
}

template <typename T>
void _elm_progressbar_inverted_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool inverted_)
{
   static_cast<T*>(self->this_)->inverted_set(efl::eolian::to_cxx<bool>(inverted_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_progressbar_horizontal_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->horizontal_get();
}

template <typename T>
void _elm_progressbar_horizontal_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool horizontal_)
{
   static_cast<T*>(self->this_)->horizontal_set(efl::eolian::to_cxx<bool>(horizontal_, std::tuple<std::false_type>()));
}

template <typename T>
std::string _elm_progressbar_unit_format_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->unit_format_get();
}

template <typename T>
void _elm_progressbar_unit_format_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * units_)
{
   static_cast<T*>(self->this_)->unit_format_set(efl::eolian::to_cxx<std::string>(units_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_progressbar_unit_format_function_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, progressbar_func_type func_, progressbar_freefunc_type free_func_)
{
   static_cast<T*>(self->this_)->unit_format_function_set(func_, free_func_);
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_progressbar >
{
   template <typename T>
   struct type
   {
      virtual void part_value_set(std::string part_, double val_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_progressbar_part_value_set(efl::eolian::to_c(part_), val_));
      }

      virtual double part_value_get(std::string part_)
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_progressbar_part_value_get(efl::eolian::to_c(part_)));
            return _tmp_ret;
      }

      virtual void pulse(bool state_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_progressbar_pulse(efl::eolian::to_c(state_)));
      }

      virtual Evas_Coord span_size_get()
      {
         Evas_Coord _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_progressbar_span_size_get());
            return _tmp_ret;
      }

      virtual void span_size_set(Evas_Coord size_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_progressbar_span_size_set(size_));
      }

      virtual bool pulse_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_progressbar_pulse_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void pulse_set(bool pulse_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_progressbar_pulse_set(efl::eolian::to_c(pulse_)));
      }

      virtual double value_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_progressbar_value_get());
            return _tmp_ret;
      }

      virtual void value_set(double val_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_progressbar_value_set(val_));
      }

      virtual bool inverted_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_progressbar_inverted_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void inverted_set(bool inverted_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_progressbar_inverted_set(efl::eolian::to_c(inverted_)));
      }

      virtual bool horizontal_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_progressbar_horizontal_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void horizontal_set(bool horizontal_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_progressbar_horizontal_set(efl::eolian::to_c(horizontal_)));
      }

      virtual std::string unit_format_get()
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_progressbar_unit_format_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void unit_format_set(std::string units_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_progressbar_unit_format_set(efl::eolian::to_c(units_)));
      }

      virtual void unit_format_function_set(progressbar_func_type func_, progressbar_freefunc_type free_func_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_progressbar_unit_format_function_set(func_, free_func_));
      }

   };
};


template<>
struct operation_description_class_size< ::elm_progressbar >
{
   static const int value = 16;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_progressbar>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_progressbar_part_value_set_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_progressbar_part_value_set);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_progressbar_part_value_get_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_progressbar_part_value_get);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_progressbar_pulse_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_progressbar_pulse);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_progressbar_span_size_get_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_progressbar_span_size_get);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_progressbar_span_size_set_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_progressbar_span_size_set);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_progressbar_pulse_get_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_progressbar_pulse_get);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_progressbar_pulse_set_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_progressbar_pulse_set);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_progressbar_value_get_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_progressbar_value_get);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_progressbar_value_set_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_progressbar_value_set);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_progressbar_inverted_get_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_progressbar_inverted_get);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::_elm_progressbar_inverted_set_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::elm_obj_progressbar_inverted_set);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::_elm_progressbar_horizontal_get_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::elm_obj_progressbar_horizontal_get);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::_elm_progressbar_horizontal_set_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::elm_obj_progressbar_horizontal_set);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::_elm_progressbar_unit_format_get_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::elm_obj_progressbar_unit_format_get);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::_elm_progressbar_unit_format_set_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::elm_obj_progressbar_unit_format_set);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::_elm_progressbar_unit_format_function_set_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::elm_obj_progressbar_unit_format_function_set);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_progressbar >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_progressbar, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_progressbar >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_progressbar, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_progressbar>
{
   template <typename U>
   struct type
   {
      operator ::elm_progressbar() const
      {
         return ::elm_progressbar(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      void part_value_set(std::string part_, double val_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_progressbar_part_value_set(efl::eolian::to_c(part_), val_));
      }

      double part_value_get(std::string part_)
      {
         double _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_progressbar_part_value_get(efl::eolian::to_c(part_)));
            return _tmp_ret;
      }

      void pulse(bool state_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_progressbar_pulse(efl::eolian::to_c(state_)));
      }

      Evas_Coord span_size_get()
      {
         Evas_Coord _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_progressbar_span_size_get());
            return _tmp_ret;
      }

      void span_size_set(Evas_Coord size_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_progressbar_span_size_set(size_));
      }

      bool pulse_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_progressbar_pulse_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void pulse_set(bool pulse_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_progressbar_pulse_set(efl::eolian::to_c(pulse_)));
      }

      double value_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_progressbar_value_get());
            return _tmp_ret;
      }

      void value_set(double val_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_progressbar_value_set(val_));
      }

      bool inverted_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_progressbar_inverted_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void inverted_set(bool inverted_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_progressbar_inverted_set(efl::eolian::to_c(inverted_)));
      }

      bool horizontal_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_progressbar_horizontal_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void horizontal_set(bool horizontal_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_progressbar_horizontal_set(efl::eolian::to_c(horizontal_)));
      }

      std::string unit_format_get()
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_progressbar_unit_format_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      void unit_format_set(std::string units_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_progressbar_unit_format_set(efl::eolian::to_c(units_)));
      }

      void unit_format_function_set(progressbar_func_type func_, progressbar_freefunc_type free_func_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_progressbar_unit_format_function_set(func_, free_func_));
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PROGRESSBAR_EVENT_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_progressbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_progressbar, function_type>,
         ELM_PROGRESSBAR_EVENT_CHANGED );
   }

   template <typename T>
   void
   callback_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_PROGRESSBAR_EVENT_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PROGRESSBAR_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_progressbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_progressbar, function_type>,
         ELM_PROGRESSBAR_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_PROGRESSBAR_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PROGRESSBAR_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_progressbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_progressbar, function_type>,
         ELM_PROGRESSBAR_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_PROGRESSBAR_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PROGRESSBAR_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_progressbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_progressbar, function_type>,
         ELM_PROGRESSBAR_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_PROGRESSBAR_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_PROGRESSBAR_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_progressbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_progressbar, function_type>,
         ELM_PROGRESSBAR_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_PROGRESSBAR_EVENT_UNFOCUSED, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_progressbar>)
{
   return (ELM_PROGRESSBAR_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_PROGRESSBAR_HH

