#ifndef EFL_GENERATED_ELM_SEGMENT_CONTROL_HH
#define EFL_GENERATED_ELM_SEGMENT_CONTROL_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_segment_control.eo.h"
}

#include "elm_layout.eo.hh"
#include <canvas/evas_object.eo.hh>
#include <string>

struct elm_segment_control
      : elm_layout
{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_segment_control(Eo* eo)
      : elm_layout(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_segment_control(std::nullptr_t)
      : elm_layout(nullptr)
   {}

   elm_segment_control(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_segment_control(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_segment_control(elm_segment_control const& other)
      : elm_layout(eo_ref(other._eo_ptr()))
   {}

   ~elm_segment_control() {}

   /// @brief Get the label of item.
   ///
   /// @return The label of the item at @p index.
   ///
   /// The return value is a pointer to the label associated to the item when
   /// it was created, with function elm_segment_control_item_add(), or later
   /// with function elm_object_item_text_set. If no label
   /// was passed as argument, it will return @c NULL.
   ///
   /// @see elm_object_item_text_set() for more details.
   /// @see elm_segment_control_item_add()
   ///
   /// @ingroup SegmentControl
   ///
   /// @param idx The index of the segment item.
   ///
   std::string item_label_get(int idx_) const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_segment_control_item_label_get(idx_));
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Insert a new item to the segment control object at specified position.
   ///
   /// @return The created item or @c NULL upon failure.
   ///
   /// Index values must be between @c 0, when item will be prepended to
   /// segment control, and items count, that can be get with
   /// elm_segment_control_item_count_get(), case when item will be appended
   /// to segment control, just like elm_segment_control_item_add().
   ///
   /// Items created with this function can be deleted with function
   /// elm_object_item_del() or elm_segment_control_item_del_at().
   ///
   /// @note @p label set to @c NULL is different from empty string "".
   /// If an item
   /// only has icon, it will be displayed bigger and centered. If it has
   /// icon and label, even that an empty string, icon will be smaller and
   /// positioned at left.
   ///
   /// @see elm_segment_control_item_add()
   /// @see elm_segment_control_item_count_get()
   /// @see elm_object_item_del()
   ///
   /// @ingroup SegmentControl
   ///
   /// @param icon The icon object to use for the left side of the item. An
   /// icon can be any Evas object, but usually it is an icon created
   /// with elm_icon_add().
   /// @param label The label of the item.
   /// @param idx Item position. Value should be between 0 and items count.
   ///
   Elm_Object_Item * item_insert_at(evas::object icon_, std::string label_, int idx_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_segment_control_item_insert_at(efl::eolian::to_c(icon_), efl::eolian::to_c(label_), idx_));
      return _tmp_ret;
   }

   /// @brief Get the item placed at specified index.
   ///
   /// @return The segment control item or @c NULL on failure.
   ///
   /// Index is the position of an item in segment control widget. Its
   /// range is from @c 0 to <tt> count - 1 </tt>.
   /// Count is the number of items, that can be get with
   /// elm_segment_control_item_count_get().
   ///
   /// @ingroup SegmentControl
   ///
   /// @param idx The index of the segment item.
   ///
   Elm_Object_Item * item_get(int idx_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_segment_control_item_get(idx_));
      return _tmp_ret;
   }

   /// @brief Remove a segment control item at given index from its parent,
   /// deleting it.
   ///
   /// Items can be added with elm_segment_control_item_add() or
   /// elm_segment_control_item_insert_at().
   ///
   /// @ingroup SegmentControl
   ///
   /// @param idx The position of the segment control item to be deleted.
   ///
   void item_del_at(int idx_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_segment_control_item_del_at(idx_));
   }

   /// @brief Append a new item to the segment control object.
   ///
   /// @return The created item or @c NULL upon failure.
   ///
   /// A new item will be created and appended to the segment control, i.e., will
   /// be set as @b last item.
   ///
   /// If it should be inserted at another position,
   /// elm_segment_control_item_insert_at() should be used instead.
   ///
   /// Items created with this function can be deleted with function
   /// elm_object_item_del() or elm_object_item_del_at().
   ///
   /// @note @p label set to @c NULL is different from empty string "".
   /// If an item
   /// only has icon, it will be displayed bigger and centered. If it has
   /// icon and label, even that an empty string, icon will be smaller and
   /// positioned at left.
   ///
   /// Simple example:
   /// @code
   /// sc = elm_segment_control_add(win);
   /// ic = elm_icon_add(win);
   /// elm_image_file_set(ic, "path/to/image", NULL);
   /// elm_icon_resizable_set(ic, EINA_TRUE, EINA_TRUE);
   /// elm_segment_control_item_add(sc, ic, "label");
   /// evas_object_show(sc);
   /// @endcode
   ///
   /// @see elm_segment_control_item_insert_at()
   /// @see elm_object_item_del()
   ///
   /// @ingroup SegmentControl
   ///
   /// @param icon The icon object to use for the left side of the item. An
   /// icon can be any Evas object, but usually it is an icon created
   /// with elm_icon_add().
   /// @param label The label of the item.
   /// Note that, NULL is different from empty string "".
   ///
   Elm_Object_Item * item_add(evas::object icon_, std::string label_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_segment_control_item_add(efl::eolian::to_c(icon_), efl::eolian::to_c(label_)));
      return _tmp_ret;
   }

   /// @brief Get the icon associated to the item.
   ///
   /// @return The left side icon associated to the item at @p index.
   ///
   /// The return value is a pointer to the icon associated to the item when
   /// it was created, with function elm_segment_control_item_add(), or later
   /// with function elm_object_item_part_content_set(). If no icon
   /// was passed as argument, it will return @c NULL.
   ///
   /// @see elm_segment_control_item_add()
   /// @see elm_object_item_part_content_set()
   ///
   /// @ingroup SegmentControl
   ///
   /// @param idx The index of the segment item.
   ///
   evas::object item_icon_get(int idx_) const
   {
      Evas_Object * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_segment_control_item_icon_get(idx_));
      return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
   }

   int item_count_get() const
   {
      int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_segment_control_item_count_get());
      return _tmp_ret;
   }

   Elm_Object_Item * item_selected_get() const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_segment_control_item_selected_get());
      return _tmp_ret;
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SEGMENT_CONTROL_EVENT_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_segment_control, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_segment_control, function_type>,
         ELM_SEGMENT_CONTROL_EVENT_CHANGED );
   }

   template <typename T>
   void
   callback_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_SEGMENT_CONTROL_EVENT_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SEGMENT_CONTROL_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_segment_control, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_segment_control, function_type>,
         ELM_SEGMENT_CONTROL_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_SEGMENT_CONTROL_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SEGMENT_CONTROL_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_segment_control, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_segment_control, function_type>,
         ELM_SEGMENT_CONTROL_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_SEGMENT_CONTROL_EVENT_ACCESS_CHANGED, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_SEGMENT_CONTROL_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_SEGMENT_CONTROL_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
std::string _elm_segment_control_item_label_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int idx_)
{
   return static_cast<T*>(self->this_)->item_label_get(idx_);
}

template <typename T>
Elm_Object_Item * _elm_segment_control_item_insert_at_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * icon_, const char * label_, int idx_)
{
   return static_cast<T*>(self->this_)->item_insert_at(efl::eolian::to_cxx<evas::object>(icon_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(label_, std::tuple<std::false_type>()), idx_);
}

template <typename T>
Elm_Object_Item * _elm_segment_control_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int idx_)
{
   return static_cast<T*>(self->this_)->item_get(idx_);
}

template <typename T>
void _elm_segment_control_item_del_at_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int idx_)
{
   static_cast<T*>(self->this_)->item_del_at(idx_);
}

template <typename T>
Elm_Object_Item * _elm_segment_control_item_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * icon_, const char * label_)
{
   return static_cast<T*>(self->this_)->item_add(efl::eolian::to_cxx<evas::object>(icon_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(label_, std::tuple<std::false_type>()));
}

template <typename T>
evas::object _elm_segment_control_item_icon_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int idx_)
{
   return static_cast<T*>(self->this_)->item_icon_get(idx_);
}

template <typename T>
int _elm_segment_control_item_count_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->item_count_get();
}

template <typename T>
Elm_Object_Item * _elm_segment_control_item_selected_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->item_selected_get();
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_segment_control >
{
   template <typename T>
   struct type
   {
      virtual std::string item_label_get(int idx_)
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_segment_control_item_label_get(idx_));
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual Elm_Object_Item * item_insert_at(evas::object icon_, std::string label_, int idx_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_segment_control_item_insert_at(efl::eolian::to_c(icon_), efl::eolian::to_c(label_), idx_));
            return _tmp_ret;
      }

      virtual Elm_Object_Item * item_get(int idx_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_segment_control_item_get(idx_));
            return _tmp_ret;
      }

      virtual void item_del_at(int idx_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_segment_control_item_del_at(idx_));
      }

      virtual Elm_Object_Item * item_add(evas::object icon_, std::string label_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_segment_control_item_add(efl::eolian::to_c(icon_), efl::eolian::to_c(label_)));
            return _tmp_ret;
      }

      virtual evas::object item_icon_get(int idx_)
      {
         Evas_Object * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_segment_control_item_icon_get(idx_));
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual int item_count_get()
      {
         int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_segment_control_item_count_get());
            return _tmp_ret;
      }

      virtual Elm_Object_Item * item_selected_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_segment_control_item_selected_get());
            return _tmp_ret;
      }

   };
};


template<>
struct operation_description_class_size< ::elm_segment_control >
{
   static const int value = 8;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_segment_control>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_segment_control_item_label_get_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_segment_control_item_label_get);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_segment_control_item_insert_at_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_segment_control_item_insert_at);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_segment_control_item_get_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_segment_control_item_get);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_segment_control_item_del_at_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_segment_control_item_del_at);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_segment_control_item_add_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_segment_control_item_add);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_segment_control_item_icon_get_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_segment_control_item_icon_get);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_segment_control_item_count_get_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_segment_control_item_count_get);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_segment_control_item_selected_get_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_segment_control_item_selected_get);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_segment_control >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_segment_control, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_segment_control >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_segment_control, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_segment_control>
{
   template <typename U>
   struct type
   {
      operator ::elm_segment_control() const
      {
         return ::elm_segment_control(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      std::string item_label_get(int idx_)
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_segment_control_item_label_get(idx_));
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      Elm_Object_Item * item_insert_at(evas::object icon_, std::string label_, int idx_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_segment_control_item_insert_at(efl::eolian::to_c(icon_), efl::eolian::to_c(label_), idx_));
            return _tmp_ret;
      }

      Elm_Object_Item * item_get(int idx_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_segment_control_item_get(idx_));
            return _tmp_ret;
      }

      void item_del_at(int idx_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_segment_control_item_del_at(idx_));
      }

      Elm_Object_Item * item_add(evas::object icon_, std::string label_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_segment_control_item_add(efl::eolian::to_c(icon_), efl::eolian::to_c(label_)));
            return _tmp_ret;
      }

      evas::object item_icon_get(int idx_)
      {
         Evas_Object * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_segment_control_item_icon_get(idx_));
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      int item_count_get()
      {
         int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_segment_control_item_count_get());
            return _tmp_ret;
      }

      Elm_Object_Item * item_selected_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_segment_control_item_selected_get());
            return _tmp_ret;
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SEGMENT_CONTROL_EVENT_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_segment_control, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_segment_control, function_type>,
         ELM_SEGMENT_CONTROL_EVENT_CHANGED );
   }

   template <typename T>
   void
   callback_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_SEGMENT_CONTROL_EVENT_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SEGMENT_CONTROL_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_segment_control, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_segment_control, function_type>,
         ELM_SEGMENT_CONTROL_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_SEGMENT_CONTROL_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SEGMENT_CONTROL_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_segment_control, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_segment_control, function_type>,
         ELM_SEGMENT_CONTROL_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_SEGMENT_CONTROL_EVENT_ACCESS_CHANGED, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_segment_control>)
{
   return (ELM_SEGMENT_CONTROL_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_SEGMENT_CONTROL_HH

