#ifndef EFL_GENERATED_ELM_SLIDESHOW_HH
#define EFL_GENERATED_ELM_SLIDESHOW_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_slideshow.eo.h"
}

#include "elm_layout.eo.hh"
#include "elm_interface_atspi_widget_action.eo.hh"
#include <string>

struct elm_slideshow
      : elm_layout,
      efl::eo::detail::extension_inheritance<elm_interface_atspi_widget_action>::template type< ::elm_slideshow>

{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_slideshow(Eo* eo)
      : elm_layout(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_slideshow(std::nullptr_t)
      : elm_layout(nullptr)
   {}

   elm_slideshow(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_slideshow(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_slideshow(elm_slideshow const& other)
      : elm_layout(eo_ref(other._eo_ptr()))
   {}

   ~elm_slideshow() {}

   /// @brief Slide to the @b previous item, in a given slideshow widget
   ///
   /// The sliding animation @p obj is set to use will be the
   /// transition effect used, after this call is issued.
   ///
   /// @note If the beginning of the slideshow's internal list of items
   /// is reached, it'll wrap around to the list's end, again.
   ///
   /// @ingroup Slideshow
   ///
   void previous() const
   {
      eo_do(_eo_ptr(), ::elm_obj_slideshow_previous());
   }

   /// @brief Get the the item, in a given slideshow widget, placed at
   /// position @p nth, in its internal items list
   ///
   /// @return The item stored in @p obj at position @p nth or @c NULL,
   /// if there's no item with that index (and on errors)
   ///
   /// @ingroup Slideshow
   ///
   /// @param nth The number of the item to grab a handle to (0 being
   /// the first)
   ///
   Elm_Object_Item * item_nth_get(unsigned int nth_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_item_nth_get(nth_));
      return _tmp_ret;
   }

   /// @brief Slide to the @b next item, in a given slideshow widget
   ///
   /// The sliding animation @p obj is set to use will be the
   /// transition effect used, after this call is issued.
   ///
   /// @note If the end of the slideshow's internal list of items is
   /// reached, it'll wrap around to the list's beginning, again.
   ///
   /// @ingroup Slideshow
   ///
   void next() const
   {
      eo_do(_eo_ptr(), ::elm_obj_slideshow_next());
   }

   /// @brief Remove all items from a given slideshow widget
   ///
   /// This removes (and deletes) all items in @p obj, leaving it
   /// empty.
   ///
   /// @see elm_object_item_del(), to remove just one item.
   ///
   /// @ingroup Slideshow
   ///
   void clear() const
   {
      eo_do(_eo_ptr(), ::elm_obj_slideshow_clear());
   }

   /// @brief Add (append) a new item in a given slideshow widget.
   ///
   /// @return A handle to the item added or @c NULL, on errors
   ///
   /// Add a new item to @p obj's internal list of items, appending it.
   /// The item's class must contain the function really fetching the
   /// image object to show for this item, which could be an Evas image
   /// object or an Elementary photo, for example. The @p data
   /// parameter is going to be passed to both class functions of the
   /// item.
   ///
   /// @see #Elm_Slideshow_Item_Class
   /// @see elm_slideshow_item_sorted_insert()
   /// @see elm_object_item_data_set()
   ///
   /// @ingroup Slideshow
   ///
   /// @param itc The item class for the item
   /// @param data The item's data
   ///
   Elm_Object_Item * item_add(const Elm_Slideshow_Item_Class * itc_, const void * data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_item_add(itc_, data_));
      return _tmp_ret;
   }

   /// @brief Insert a new item into the given slideshow widget, using the @p func
   /// function to sort items (by item handles).
   ///
   /// @return Returns The slideshow item handle, on success, or
   /// @c NULL, on errors
   ///
   /// Add a new item to @p obj's internal list of items, in a position
   /// determined by the @p func comparing function. The item's class
   /// must contain the function really fetching the image object to
   /// show for this item, which could be an Evas image object or an
   /// Elementary photo, for example. The @p data parameter is going to
   /// be passed to both class functions of the item.
   ///
   /// @see #Elm_Slideshow_Item_Class
   /// @see elm_slideshow_item_add()
   ///
   /// @ingroup Slideshow
   ///
   /// @param itc The item class for the item
   /// @param data The item's data
   /// @param func The comparing function to be used to sort slideshow
   /// items <b>by #Elm_Slideshow_Item_Class item handles</b>
   ///
   Elm_Object_Item * item_sorted_insert(const Elm_Slideshow_Item_Class * itc_, const void * data_, Eina_Compare_Cb func_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_item_sorted_insert(itc_, data_, func_));
      return _tmp_ret;
   }

   /// @param count Number of items to cache after the current one
   ///
   int cache_after_get() const
   {
      int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_cache_after_get());
      return _tmp_ret;
   }

   /// @param count Number of items to cache after the current one
   ///
   void cache_after_set(int count_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_slideshow_cache_after_set(count_));
   }

   /// @param count Number of items to cache before the current one
   ///
   int cache_before_get() const
   {
      int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_cache_before_get());
      return _tmp_ret;
   }

   /// @param count Number of items to cache before the current one
   ///
   void cache_before_set(int count_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_slideshow_cache_before_set(count_));
   }

   /// @param layout The new layout's name string
   ///
   std::string layout_get() const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_layout_get());
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param layout The new layout's name string
   ///
   void layout_set(std::string layout_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_slideshow_layout_set(efl::eolian::to_c(layout_)));
   }

   /// @param transition The new transition's name string
   ///
   std::string transition_get() const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_transition_get());
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param transition The new transition's name string
   ///
   void transition_set(std::string transition_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_slideshow_transition_set(efl::eolian::to_c(transition_)));
   }

   /// @param loop Use @c EINA_TRUE to make it cycle through items or
   /// @c EINA_FALSE for it to stop at the end of @p obj's internal
   /// list of items
   ///
   bool loop_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_loop_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param loop Use @c EINA_TRUE to make it cycle through items or
   /// @c EINA_FALSE for it to stop at the end of @p obj's internal
   /// list of items
   ///
   void loop_set(bool loop_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_slideshow_loop_set(efl::eolian::to_c(loop_)));
   }

   /// @param timeout The new displaying timeout for images
   ///
   double timeout_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_timeout_get());
      return _tmp_ret;
   }

   /// @param timeout The new displaying timeout for images
   ///
   void timeout_set(double timeout_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_slideshow_timeout_set(timeout_));
   }

   const Eina_List * items_get() const
   {
      const Eina_List * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_items_get());
      return _tmp_ret;
   }

   const Eina_List * transitions_get() const
   {
      const Eina_List * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_transitions_get());
      return _tmp_ret;
   }

   unsigned int count_get() const
   {
      unsigned int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_count_get());
      return _tmp_ret;
   }

   Elm_Object_Item * item_current_get() const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_item_current_get());
      return _tmp_ret;
   }

   const Eina_List * layouts_get() const
   {
      const Eina_List * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_layouts_get());
      return _tmp_ret;
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SLIDESHOW_EVENT_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_slideshow, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_slideshow, function_type>,
         ELM_SLIDESHOW_EVENT_CHANGED );
   }

   template <typename T>
   void
   callback_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_SLIDESHOW_EVENT_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_transition_end_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SLIDESHOW_EVENT_TRANSITION_END, priority_,
            &efl::eo::_detail::event_callback<::elm_slideshow, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_slideshow, function_type>,
         ELM_SLIDESHOW_EVENT_TRANSITION_END );
   }

   template <typename T>
   void
   callback_transition_end_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_SLIDESHOW_EVENT_TRANSITION_END, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SLIDESHOW_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_slideshow, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_slideshow, function_type>,
         ELM_SLIDESHOW_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_SLIDESHOW_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SLIDESHOW_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_slideshow, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_slideshow, function_type>,
         ELM_SLIDESHOW_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_SLIDESHOW_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SLIDESHOW_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_slideshow, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_slideshow, function_type>,
         ELM_SLIDESHOW_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_SLIDESHOW_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SLIDESHOW_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_slideshow, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_slideshow, function_type>,
         ELM_SLIDESHOW_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_SLIDESHOW_EVENT_UNFOCUSED, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_SLIDESHOW_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_SLIDESHOW_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
void _elm_slideshow_previous_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->previous();
}

template <typename T>
Elm_Object_Item * _elm_slideshow_item_nth_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, unsigned int nth_)
{
   return static_cast<T*>(self->this_)->item_nth_get(nth_);
}

template <typename T>
void _elm_slideshow_next_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->next();
}

template <typename T>
void _elm_slideshow_clear_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->clear();
}

template <typename T>
Elm_Object_Item * _elm_slideshow_item_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const Elm_Slideshow_Item_Class * itc_, const void * data_)
{
   return static_cast<T*>(self->this_)->item_add(itc_, data_);
}

template <typename T>
Elm_Object_Item * _elm_slideshow_item_sorted_insert_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const Elm_Slideshow_Item_Class * itc_, const void * data_, Eina_Compare_Cb func_)
{
   return static_cast<T*>(self->this_)->item_sorted_insert(itc_, data_, func_);
}

template <typename T>
int _elm_slideshow_cache_after_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->cache_after_get();
}

template <typename T>
void _elm_slideshow_cache_after_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int count_)
{
   static_cast<T*>(self->this_)->cache_after_set(count_);
}

template <typename T>
int _elm_slideshow_cache_before_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->cache_before_get();
}

template <typename T>
void _elm_slideshow_cache_before_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int count_)
{
   static_cast<T*>(self->this_)->cache_before_set(count_);
}

template <typename T>
std::string _elm_slideshow_layout_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->layout_get();
}

template <typename T>
void _elm_slideshow_layout_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * layout_)
{
   static_cast<T*>(self->this_)->layout_set(efl::eolian::to_cxx<std::string>(layout_, std::tuple<std::false_type>()));
}

template <typename T>
std::string _elm_slideshow_transition_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->transition_get();
}

template <typename T>
void _elm_slideshow_transition_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * transition_)
{
   static_cast<T*>(self->this_)->transition_set(efl::eolian::to_cxx<std::string>(transition_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_slideshow_loop_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->loop_get();
}

template <typename T>
void _elm_slideshow_loop_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool loop_)
{
   static_cast<T*>(self->this_)->loop_set(efl::eolian::to_cxx<bool>(loop_, std::tuple<std::false_type>()));
}

template <typename T>
double _elm_slideshow_timeout_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->timeout_get();
}

template <typename T>
void _elm_slideshow_timeout_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double timeout_)
{
   static_cast<T*>(self->this_)->timeout_set(timeout_);
}

template <typename T>
const Eina_List * _elm_slideshow_items_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->items_get();
}

template <typename T>
const Eina_List * _elm_slideshow_transitions_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->transitions_get();
}

template <typename T>
unsigned int _elm_slideshow_count_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->count_get();
}

template <typename T>
Elm_Object_Item * _elm_slideshow_item_current_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->item_current_get();
}

template <typename T>
const Eina_List * _elm_slideshow_layouts_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->layouts_get();
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_slideshow >
{
   template <typename T>
   struct type
   {
      virtual void previous()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_slideshow_previous());
      }

      virtual Elm_Object_Item * item_nth_get(unsigned int nth_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_slideshow_item_nth_get(nth_));
            return _tmp_ret;
      }

      virtual void next()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_slideshow_next());
      }

      virtual void clear()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_slideshow_clear());
      }

      virtual Elm_Object_Item * item_add(const Elm_Slideshow_Item_Class * itc_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_slideshow_item_add(itc_, data_));
            return _tmp_ret;
      }

      virtual Elm_Object_Item * item_sorted_insert(const Elm_Slideshow_Item_Class * itc_, const void * data_, Eina_Compare_Cb func_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_slideshow_item_sorted_insert(itc_, data_, func_));
            return _tmp_ret;
      }

      virtual int cache_after_get()
      {
         int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_slideshow_cache_after_get());
            return _tmp_ret;
      }

      virtual void cache_after_set(int count_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_slideshow_cache_after_set(count_));
      }

      virtual int cache_before_get()
      {
         int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_slideshow_cache_before_get());
            return _tmp_ret;
      }

      virtual void cache_before_set(int count_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_slideshow_cache_before_set(count_));
      }

      virtual std::string layout_get()
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_slideshow_layout_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void layout_set(std::string layout_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_slideshow_layout_set(efl::eolian::to_c(layout_)));
      }

      virtual std::string transition_get()
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_slideshow_transition_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void transition_set(std::string transition_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_slideshow_transition_set(efl::eolian::to_c(transition_)));
      }

      virtual bool loop_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_slideshow_loop_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void loop_set(bool loop_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_slideshow_loop_set(efl::eolian::to_c(loop_)));
      }

      virtual double timeout_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_slideshow_timeout_get());
            return _tmp_ret;
      }

      virtual void timeout_set(double timeout_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_slideshow_timeout_set(timeout_));
      }

      virtual const Eina_List * items_get()
      {
         const Eina_List * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_slideshow_items_get());
            return _tmp_ret;
      }

      virtual const Eina_List * transitions_get()
      {
         const Eina_List * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_slideshow_transitions_get());
            return _tmp_ret;
      }

      virtual unsigned int count_get()
      {
         unsigned int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_slideshow_count_get());
            return _tmp_ret;
      }

      virtual Elm_Object_Item * item_current_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_slideshow_item_current_get());
            return _tmp_ret;
      }

      virtual const Eina_List * layouts_get()
      {
         const Eina_List * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_slideshow_layouts_get());
            return _tmp_ret;
      }

   };
};


template<>
struct operation_description_class_size< ::elm_slideshow >
{
   static const int value = 23;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_slideshow>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_slideshow_previous_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_slideshow_previous);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_slideshow_item_nth_get_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_slideshow_item_nth_get);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_slideshow_next_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_slideshow_next);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_slideshow_clear_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_slideshow_clear);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_slideshow_item_add_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_slideshow_item_add);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_slideshow_item_sorted_insert_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_slideshow_item_sorted_insert);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_slideshow_cache_after_get_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_slideshow_cache_after_get);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_slideshow_cache_after_set_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_slideshow_cache_after_set);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_slideshow_cache_before_get_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_slideshow_cache_before_get);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_slideshow_cache_before_set_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_slideshow_cache_before_set);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::_elm_slideshow_layout_get_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::elm_obj_slideshow_layout_get);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::_elm_slideshow_layout_set_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::elm_obj_slideshow_layout_set);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::_elm_slideshow_transition_get_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::elm_obj_slideshow_transition_get);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::_elm_slideshow_transition_set_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::elm_obj_slideshow_transition_set);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::_elm_slideshow_loop_get_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::elm_obj_slideshow_loop_get);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::_elm_slideshow_loop_set_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::elm_obj_slideshow_loop_set);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   ops[16].func = reinterpret_cast<void*>(& ::_elm_slideshow_timeout_get_wrapper<T>);
   ops[16].api_func = reinterpret_cast<void*>(& ::elm_obj_slideshow_timeout_get);
   ops[16].op = EO_OP_OVERRIDE;
   ops[16].op_type = EO_OP_TYPE_REGULAR;
   ops[16].doc = NULL;

   ops[17].func = reinterpret_cast<void*>(& ::_elm_slideshow_timeout_set_wrapper<T>);
   ops[17].api_func = reinterpret_cast<void*>(& ::elm_obj_slideshow_timeout_set);
   ops[17].op = EO_OP_OVERRIDE;
   ops[17].op_type = EO_OP_TYPE_REGULAR;
   ops[17].doc = NULL;

   ops[18].func = reinterpret_cast<void*>(& ::_elm_slideshow_items_get_wrapper<T>);
   ops[18].api_func = reinterpret_cast<void*>(& ::elm_obj_slideshow_items_get);
   ops[18].op = EO_OP_OVERRIDE;
   ops[18].op_type = EO_OP_TYPE_REGULAR;
   ops[18].doc = NULL;

   ops[19].func = reinterpret_cast<void*>(& ::_elm_slideshow_transitions_get_wrapper<T>);
   ops[19].api_func = reinterpret_cast<void*>(& ::elm_obj_slideshow_transitions_get);
   ops[19].op = EO_OP_OVERRIDE;
   ops[19].op_type = EO_OP_TYPE_REGULAR;
   ops[19].doc = NULL;

   ops[20].func = reinterpret_cast<void*>(& ::_elm_slideshow_count_get_wrapper<T>);
   ops[20].api_func = reinterpret_cast<void*>(& ::elm_obj_slideshow_count_get);
   ops[20].op = EO_OP_OVERRIDE;
   ops[20].op_type = EO_OP_TYPE_REGULAR;
   ops[20].doc = NULL;

   ops[21].func = reinterpret_cast<void*>(& ::_elm_slideshow_item_current_get_wrapper<T>);
   ops[21].api_func = reinterpret_cast<void*>(& ::elm_obj_slideshow_item_current_get);
   ops[21].op = EO_OP_OVERRIDE;
   ops[21].op_type = EO_OP_TYPE_REGULAR;
   ops[21].doc = NULL;

   ops[22].func = reinterpret_cast<void*>(& ::_elm_slideshow_layouts_get_wrapper<T>);
   ops[22].api_func = reinterpret_cast<void*>(& ::elm_obj_slideshow_layouts_get);
   ops[22].op = EO_OP_OVERRIDE;
   ops[22].op_type = EO_OP_TYPE_REGULAR;
   ops[22].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_slideshow >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_slideshow, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_slideshow >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_slideshow, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_slideshow>
{
   template <typename U>
   struct type
   {
      operator ::elm_slideshow() const
      {
         return ::elm_slideshow(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      void previous()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_slideshow_previous());
      }

      Elm_Object_Item * item_nth_get(unsigned int nth_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_item_nth_get(nth_));
            return _tmp_ret;
      }

      void next()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_slideshow_next());
      }

      void clear()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_slideshow_clear());
      }

      Elm_Object_Item * item_add(const Elm_Slideshow_Item_Class * itc_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_item_add(itc_, data_));
            return _tmp_ret;
      }

      Elm_Object_Item * item_sorted_insert(const Elm_Slideshow_Item_Class * itc_, const void * data_, Eina_Compare_Cb func_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_item_sorted_insert(itc_, data_, func_));
            return _tmp_ret;
      }

      int cache_after_get()
      {
         int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_cache_after_get());
            return _tmp_ret;
      }

      void cache_after_set(int count_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_slideshow_cache_after_set(count_));
      }

      int cache_before_get()
      {
         int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_cache_before_get());
            return _tmp_ret;
      }

      void cache_before_set(int count_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_slideshow_cache_before_set(count_));
      }

      std::string layout_get()
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_layout_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      void layout_set(std::string layout_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_slideshow_layout_set(efl::eolian::to_c(layout_)));
      }

      std::string transition_get()
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_transition_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      void transition_set(std::string transition_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_slideshow_transition_set(efl::eolian::to_c(transition_)));
      }

      bool loop_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_loop_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void loop_set(bool loop_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_slideshow_loop_set(efl::eolian::to_c(loop_)));
      }

      double timeout_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_timeout_get());
            return _tmp_ret;
      }

      void timeout_set(double timeout_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_slideshow_timeout_set(timeout_));
      }

      const Eina_List * items_get()
      {
         const Eina_List * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_items_get());
            return _tmp_ret;
      }

      const Eina_List * transitions_get()
      {
         const Eina_List * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_transitions_get());
            return _tmp_ret;
      }

      unsigned int count_get()
      {
         unsigned int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_count_get());
            return _tmp_ret;
      }

      Elm_Object_Item * item_current_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_item_current_get());
            return _tmp_ret;
      }

      const Eina_List * layouts_get()
      {
         const Eina_List * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_slideshow_layouts_get());
            return _tmp_ret;
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SLIDESHOW_EVENT_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_slideshow, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_slideshow, function_type>,
         ELM_SLIDESHOW_EVENT_CHANGED );
   }

   template <typename T>
   void
   callback_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_SLIDESHOW_EVENT_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_transition_end_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SLIDESHOW_EVENT_TRANSITION_END, priority_,
            &efl::eo::_detail::event_callback<::elm_slideshow, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_slideshow, function_type>,
         ELM_SLIDESHOW_EVENT_TRANSITION_END );
   }

   template <typename T>
   void
   callback_transition_end_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_SLIDESHOW_EVENT_TRANSITION_END, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SLIDESHOW_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_slideshow, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_slideshow, function_type>,
         ELM_SLIDESHOW_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_SLIDESHOW_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SLIDESHOW_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_slideshow, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_slideshow, function_type>,
         ELM_SLIDESHOW_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_SLIDESHOW_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SLIDESHOW_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_slideshow, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_slideshow, function_type>,
         ELM_SLIDESHOW_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_SLIDESHOW_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SLIDESHOW_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_slideshow, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_slideshow, function_type>,
         ELM_SLIDESHOW_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_SLIDESHOW_EVENT_UNFOCUSED, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_slideshow>)
{
   return (ELM_SLIDESHOW_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_SLIDESHOW_HH

