#ifndef EFL_GENERATED_ELM_SPINNER_HH
#define EFL_GENERATED_ELM_SPINNER_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_spinner.eo.h"
}

#include "elm_layout.eo.hh"
#include "elm_interface_atspi_value.eo.hh"
#include "elm_interface_atspi_widget_action.eo.hh"
#include <string>

struct elm_spinner
      : elm_layout,
      efl::eo::detail::extension_inheritance<elm_interface_atspi_value>::template type< ::elm_spinner>,
      efl::eo::detail::extension_inheritance<elm_interface_atspi_widget_action>::template type< ::elm_spinner>

{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_spinner(Eo* eo)
      : elm_layout(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_spinner(std::nullptr_t)
      : elm_layout(nullptr)
   {}

   elm_spinner(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_spinner(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_spinner(elm_spinner const& other)
      : elm_layout(eo_ref(other._eo_ptr()))
   {}

   ~elm_spinner() {}

   /// @brief Set a special string to display in the place of the numerical value.
   ///
   /// It's useful for cases when a user should select an item that is
   /// better indicated by a label than a value. For example, weekdays or months.
   ///
   /// E.g.:
   /// @code
   /// sp = elm_spinner_add(win);
   /// elm_spinner_min_max_set(sp, 1, 3);
   /// elm_spinner_special_value_add(sp, 1, "January");
   /// elm_spinner_special_value_add(sp, 2, "February");
   /// elm_spinner_special_value_add(sp, 3, "March");
   /// evas_object_show(sp);
   /// @endcode
   ///
   /// @note If another label was previously set to @p value, it will be replaced
   /// by the new label.
   ///
   /// @see elm_spinner_special_value_get().
   /// @see elm_spinner_special_value_del().
   ///
   /// @ingroup Spinner
   ///
   /// @param value The value to be replaced.
   /// @param label The label to be used.
   ///
   void special_value_add(double value_, std::string label_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_spinner_special_value_add(value_, efl::eolian::to_c(label_)));
   }

   /// @param min The minimum value.
   /// @param max The maximum value.
   ///
   void min_max_get(double* min_, double* max_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_spinner_min_max_get(min_, max_));
   }

   /// @param min The minimum value.
   /// @param max The maximum value.
   ///
   void min_max_set(double min_, double max_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_spinner_min_max_set(min_, max_));
   }

   /// @param step The step value.
   ///
   double step_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_spinner_step_get());
      return _tmp_ret;
   }

   /// @param step The step value.
   ///
   void step_set(double step_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_spinner_step_set(step_));
   }

   /// @param wrap @c EINA_TRUE to enable wrap or @c EINA_FALSE to
   /// disable it.
   ///
   bool wrap_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_spinner_wrap_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param wrap @c EINA_TRUE to enable wrap or @c EINA_FALSE to
   /// disable it.
   ///
   void wrap_set(bool wrap_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_spinner_wrap_set(efl::eolian::to_c(wrap_)));
   }

   /// @param interval The (first) interval value in seconds.
   ///
   double interval_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_spinner_interval_get());
      return _tmp_ret;
   }

   /// @param interval The (first) interval value in seconds.
   ///
   void interval_set(double interval_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_spinner_interval_set(interval_));
   }

   /// @param rnd The rounding value
   ///
   int round_get() const
   {
      int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_spinner_round_get());
      return _tmp_ret;
   }

   /// @param rnd The rounding value
   ///
   void round_set(int rnd_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_spinner_round_set(rnd_));
   }

   /// @param editable @c EINA_TRUE to allow users to edit it or @c EINA_FALSE to
   /// don't allow users to edit it directly.
   ///
   bool editable_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_spinner_editable_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param editable @c EINA_TRUE to allow users to edit it or @c EINA_FALSE to
   /// don't allow users to edit it directly.
   ///
   void editable_set(bool editable_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_spinner_editable_set(efl::eolian::to_c(editable_)));
   }

   /// @param base The base value
   ///
   double base_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_spinner_base_get());
      return _tmp_ret;
   }

   /// @param base The base value
   ///
   void base_set(double base_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_spinner_base_set(base_));
   }

   /// @param val The value to be displayed.
   ///
   double value_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_spinner_value_get());
      return _tmp_ret;
   }

   /// @param val The value to be displayed.
   ///
   void value_set(double val_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_spinner_value_set(val_));
   }

   /// @param fmt The format string for the label display.
   ///
   std::string label_format_get() const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_spinner_label_format_get());
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param fmt The format string for the label display.
   ///
   void label_format_set(std::string fmt_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_spinner_label_format_set(efl::eolian::to_c(fmt_)));
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SPINNER_EVENT_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_spinner, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_spinner, function_type>,
         ELM_SPINNER_EVENT_CHANGED );
   }

   template <typename T>
   void
   callback_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_SPINNER_EVENT_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_delay_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SPINNER_EVENT_DELAY_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_spinner, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_spinner, function_type>,
         ELM_SPINNER_EVENT_DELAY_CHANGED );
   }

   template <typename T>
   void
   callback_delay_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_SPINNER_EVENT_DELAY_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_spinner_drag_start_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SPINNER_EVENT_SPINNER_DRAG_START, priority_,
            &efl::eo::_detail::event_callback<::elm_spinner, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_spinner, function_type>,
         ELM_SPINNER_EVENT_SPINNER_DRAG_START );
   }

   template <typename T>
   void
   callback_spinner_drag_start_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_SPINNER_EVENT_SPINNER_DRAG_START, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_spinner_drag_stop_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SPINNER_EVENT_SPINNER_DRAG_STOP, priority_,
            &efl::eo::_detail::event_callback<::elm_spinner, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_spinner, function_type>,
         ELM_SPINNER_EVENT_SPINNER_DRAG_STOP );
   }

   template <typename T>
   void
   callback_spinner_drag_stop_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_SPINNER_EVENT_SPINNER_DRAG_STOP, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SPINNER_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_spinner, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_spinner, function_type>,
         ELM_SPINNER_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_SPINNER_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SPINNER_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_spinner, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_spinner, function_type>,
         ELM_SPINNER_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_SPINNER_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SPINNER_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_spinner, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_spinner, function_type>,
         ELM_SPINNER_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_SPINNER_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SPINNER_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_spinner, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_spinner, function_type>,
         ELM_SPINNER_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_SPINNER_EVENT_UNFOCUSED, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_SPINNER_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_SPINNER_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
void _elm_spinner_special_value_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double value_, const char * label_)
{
   static_cast<T*>(self->this_)->special_value_add(value_, efl::eolian::to_cxx<std::string>(label_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_spinner_min_max_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double* min_, double* max_)
{
   static_cast<T*>(self->this_)->min_max_get(min_, max_);
}

template <typename T>
void _elm_spinner_min_max_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double min_, double max_)
{
   static_cast<T*>(self->this_)->min_max_set(min_, max_);
}

template <typename T>
double _elm_spinner_step_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->step_get();
}

template <typename T>
void _elm_spinner_step_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double step_)
{
   static_cast<T*>(self->this_)->step_set(step_);
}

template <typename T>
bool _elm_spinner_wrap_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->wrap_get();
}

template <typename T>
void _elm_spinner_wrap_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool wrap_)
{
   static_cast<T*>(self->this_)->wrap_set(efl::eolian::to_cxx<bool>(wrap_, std::tuple<std::false_type>()));
}

template <typename T>
double _elm_spinner_interval_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->interval_get();
}

template <typename T>
void _elm_spinner_interval_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double interval_)
{
   static_cast<T*>(self->this_)->interval_set(interval_);
}

template <typename T>
int _elm_spinner_round_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->round_get();
}

template <typename T>
void _elm_spinner_round_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int rnd_)
{
   static_cast<T*>(self->this_)->round_set(rnd_);
}

template <typename T>
bool _elm_spinner_editable_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->editable_get();
}

template <typename T>
void _elm_spinner_editable_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool editable_)
{
   static_cast<T*>(self->this_)->editable_set(efl::eolian::to_cxx<bool>(editable_, std::tuple<std::false_type>()));
}

template <typename T>
double _elm_spinner_base_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->base_get();
}

template <typename T>
void _elm_spinner_base_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double base_)
{
   static_cast<T*>(self->this_)->base_set(base_);
}

template <typename T>
double _elm_spinner_value_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->value_get();
}

template <typename T>
void _elm_spinner_value_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double val_)
{
   static_cast<T*>(self->this_)->value_set(val_);
}

template <typename T>
std::string _elm_spinner_label_format_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->label_format_get();
}

template <typename T>
void _elm_spinner_label_format_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * fmt_)
{
   static_cast<T*>(self->this_)->label_format_set(efl::eolian::to_cxx<std::string>(fmt_, std::tuple<std::false_type>()));
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_spinner >
{
   template <typename T>
   struct type
   {
      virtual void special_value_add(double value_, std::string label_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_spinner_special_value_add(value_, efl::eolian::to_c(label_)));
      }

      virtual void min_max_get(double* min_, double* max_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_spinner_min_max_get(min_, max_));
      }

      virtual void min_max_set(double min_, double max_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_spinner_min_max_set(min_, max_));
      }

      virtual double step_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_spinner_step_get());
            return _tmp_ret;
      }

      virtual void step_set(double step_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_spinner_step_set(step_));
      }

      virtual bool wrap_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_spinner_wrap_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void wrap_set(bool wrap_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_spinner_wrap_set(efl::eolian::to_c(wrap_)));
      }

      virtual double interval_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_spinner_interval_get());
            return _tmp_ret;
      }

      virtual void interval_set(double interval_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_spinner_interval_set(interval_));
      }

      virtual int round_get()
      {
         int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_spinner_round_get());
            return _tmp_ret;
      }

      virtual void round_set(int rnd_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_spinner_round_set(rnd_));
      }

      virtual bool editable_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_spinner_editable_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void editable_set(bool editable_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_spinner_editable_set(efl::eolian::to_c(editable_)));
      }

      virtual double base_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_spinner_base_get());
            return _tmp_ret;
      }

      virtual void base_set(double base_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_spinner_base_set(base_));
      }

      virtual double value_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_spinner_value_get());
            return _tmp_ret;
      }

      virtual void value_set(double val_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_spinner_value_set(val_));
      }

      virtual std::string label_format_get()
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_spinner_label_format_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void label_format_set(std::string fmt_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_spinner_label_format_set(efl::eolian::to_c(fmt_)));
      }

   };
};


template<>
struct operation_description_class_size< ::elm_spinner >
{
   static const int value = 19;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_spinner>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_spinner_special_value_add_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_spinner_special_value_add);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_spinner_min_max_get_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_spinner_min_max_get);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_spinner_min_max_set_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_spinner_min_max_set);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_spinner_step_get_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_spinner_step_get);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_spinner_step_set_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_spinner_step_set);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_spinner_wrap_get_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_spinner_wrap_get);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_spinner_wrap_set_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_spinner_wrap_set);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_spinner_interval_get_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_spinner_interval_get);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_spinner_interval_set_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_spinner_interval_set);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_spinner_round_get_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_spinner_round_get);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::_elm_spinner_round_set_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::elm_obj_spinner_round_set);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::_elm_spinner_editable_get_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::elm_obj_spinner_editable_get);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::_elm_spinner_editable_set_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::elm_obj_spinner_editable_set);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::_elm_spinner_base_get_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::elm_obj_spinner_base_get);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::_elm_spinner_base_set_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::elm_obj_spinner_base_set);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::_elm_spinner_value_get_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::elm_obj_spinner_value_get);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   ops[16].func = reinterpret_cast<void*>(& ::_elm_spinner_value_set_wrapper<T>);
   ops[16].api_func = reinterpret_cast<void*>(& ::elm_obj_spinner_value_set);
   ops[16].op = EO_OP_OVERRIDE;
   ops[16].op_type = EO_OP_TYPE_REGULAR;
   ops[16].doc = NULL;

   ops[17].func = reinterpret_cast<void*>(& ::_elm_spinner_label_format_get_wrapper<T>);
   ops[17].api_func = reinterpret_cast<void*>(& ::elm_obj_spinner_label_format_get);
   ops[17].op = EO_OP_OVERRIDE;
   ops[17].op_type = EO_OP_TYPE_REGULAR;
   ops[17].doc = NULL;

   ops[18].func = reinterpret_cast<void*>(& ::_elm_spinner_label_format_set_wrapper<T>);
   ops[18].api_func = reinterpret_cast<void*>(& ::elm_obj_spinner_label_format_set);
   ops[18].op = EO_OP_OVERRIDE;
   ops[18].op_type = EO_OP_TYPE_REGULAR;
   ops[18].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_spinner >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_spinner, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_spinner >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_spinner, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_spinner>
{
   template <typename U>
   struct type
   {
      operator ::elm_spinner() const
      {
         return ::elm_spinner(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      void special_value_add(double value_, std::string label_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_spinner_special_value_add(value_, efl::eolian::to_c(label_)));
      }

      void min_max_get(double* min_, double* max_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_spinner_min_max_get(min_, max_));
      }

      void min_max_set(double min_, double max_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_spinner_min_max_set(min_, max_));
      }

      double step_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_spinner_step_get());
            return _tmp_ret;
      }

      void step_set(double step_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_spinner_step_set(step_));
      }

      bool wrap_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_spinner_wrap_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void wrap_set(bool wrap_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_spinner_wrap_set(efl::eolian::to_c(wrap_)));
      }

      double interval_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_spinner_interval_get());
            return _tmp_ret;
      }

      void interval_set(double interval_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_spinner_interval_set(interval_));
      }

      int round_get()
      {
         int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_spinner_round_get());
            return _tmp_ret;
      }

      void round_set(int rnd_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_spinner_round_set(rnd_));
      }

      bool editable_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_spinner_editable_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void editable_set(bool editable_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_spinner_editable_set(efl::eolian::to_c(editable_)));
      }

      double base_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_spinner_base_get());
            return _tmp_ret;
      }

      void base_set(double base_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_spinner_base_set(base_));
      }

      double value_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_spinner_value_get());
            return _tmp_ret;
      }

      void value_set(double val_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_spinner_value_set(val_));
      }

      std::string label_format_get()
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_spinner_label_format_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      void label_format_set(std::string fmt_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_spinner_label_format_set(efl::eolian::to_c(fmt_)));
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SPINNER_EVENT_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_spinner, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_spinner, function_type>,
         ELM_SPINNER_EVENT_CHANGED );
   }

   template <typename T>
   void
   callback_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_SPINNER_EVENT_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_delay_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SPINNER_EVENT_DELAY_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_spinner, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_spinner, function_type>,
         ELM_SPINNER_EVENT_DELAY_CHANGED );
   }

   template <typename T>
   void
   callback_delay_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_SPINNER_EVENT_DELAY_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_spinner_drag_start_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SPINNER_EVENT_SPINNER_DRAG_START, priority_,
            &efl::eo::_detail::event_callback<::elm_spinner, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_spinner, function_type>,
         ELM_SPINNER_EVENT_SPINNER_DRAG_START );
   }

   template <typename T>
   void
   callback_spinner_drag_start_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_SPINNER_EVENT_SPINNER_DRAG_START, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_spinner_drag_stop_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SPINNER_EVENT_SPINNER_DRAG_STOP, priority_,
            &efl::eo::_detail::event_callback<::elm_spinner, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_spinner, function_type>,
         ELM_SPINNER_EVENT_SPINNER_DRAG_STOP );
   }

   template <typename T>
   void
   callback_spinner_drag_stop_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_SPINNER_EVENT_SPINNER_DRAG_STOP, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SPINNER_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_spinner, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_spinner, function_type>,
         ELM_SPINNER_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_SPINNER_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SPINNER_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_spinner, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_spinner, function_type>,
         ELM_SPINNER_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_SPINNER_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SPINNER_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_spinner, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_spinner, function_type>,
         ELM_SPINNER_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_SPINNER_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_SPINNER_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_spinner, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_spinner, function_type>,
         ELM_SPINNER_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_SPINNER_EVENT_UNFOCUSED, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_spinner>)
{
   return (ELM_SPINNER_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_SPINNER_HH

