#ifndef EFL_GENERATED_ELM_TABLE_HH
#define EFL_GENERATED_ELM_TABLE_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_table.eo.h"
}

#include "elm_widget.eo.hh"
#include <canvas/evas_object.eo.hh>

struct elm_table
      : elm_widget
{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_table(Eo* eo)
      : elm_widget(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_table(std::nullptr_t)
      : elm_widget(nullptr)
   {}

   elm_table(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_table(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_table(elm_table const& other)
      : elm_widget(eo_ref(other._eo_ptr()))
   {}

   ~elm_table() {}

   /// @brief @brief Faster way to remove all child objects from a table object.
   ///
   /// @ingroup Table
   ///
   /// @param clear If true, will delete children, else just remove from table.
   ///
   void clear(bool clear_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_table_clear(efl::eolian::to_c(clear_)));
   }

   /// @brief @brief Get child object of table at given coordinates.
   ///
   /// @return Child of object if find if not return NULL.
   ///
   /// @param col Column number of child object
   /// @param row Row number of child object
   ///
   evas::object child_get(int col_, int row_) const
   {
      Evas_Object * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_table_child_get(col_, row_));
      return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief @brief Set the packing location of an existing child of the table
   ///
   /// Modifies the position of an object already in the table.
   ///
   /// @note All positioning inside the table is relative to rows and columns, so
   /// a value of 0 for col and row, means the top left cell of the table, and a
   /// value of 1 for colspan and rowspan means @p subobj only takes that 1 cell.
   ///
   /// @ingroup Table
   ///
   /// @param subobj The subobject to be modified in the table
   /// @param column Column number
   /// @param row Row number
   /// @param colspan colspan
   /// @param rowspan rowspan
   ///
   void pack_set(evas::object subobj_, int column_, int row_, int colspan_, int rowspan_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_table_pack_set(efl::eolian::to_c(subobj_), column_, row_, colspan_, rowspan_));
   }

   /// @brief @brief Get the packing location of an existing child of the table
   ///
   /// @see elm_table_pack_set()
   ///
   /// @ingroup Table
   ///
   /// @param subobj The subobject to be modified in the table
   /// @param[out] column Column number
   /// @param[out] row Row number
   /// @param[out] colspan colspan
   /// @param[out] rowspan rowspan
   ///
   void pack_get(evas::object subobj_, int* column_, int* row_, int* colspan_, int* rowspan_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_table_pack_get(efl::eolian::to_c(subobj_), column_, row_, colspan_, rowspan_));
   }

   /// @brief @brief Remove child from table.
   ///
   /// @ingroup Table
   ///
   /// @param subobj The subobject
   ///
   void unpack(evas::object subobj_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_table_unpack(efl::eolian::to_c(subobj_)));
   }

   /// @brief @brief Add a subobject on the table with the coordinates passed
   ///
   /// @note All positioning inside the table is relative to rows and columns, so
   /// a value of 0 for x and y, means the top left cell of the table, and a
   /// value of 1 for w and h means @p subobj only takes that 1 cell.
   ///
   /// Note that columns and rows only guarantee 16bit unsigned values at best.
   /// That means that col + colspan AND row + rowspan must fit inside 16bit
   /// unsigned values cleanly. You will be warned once values exceed 15bit
   /// storage, and attempting to use values not able to fit in 16bits will
   /// result in failure.
   ///
   /// @ingroup Table
   ///
   /// @param subobj The subobject to be added to the table
   /// @param column Column number
   /// @param row Row number
   /// @param colspan colspan
   /// @param rowspan rowspan
   ///
   void pack(evas::object subobj_, int column_, int row_, int colspan_, int rowspan_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_table_pack(efl::eolian::to_c(subobj_), column_, row_, colspan_, rowspan_));
   }

   /// @param homogeneous A boolean to set if the layout is homogeneous in the
   /// table (EINA_TRUE = homogeneous, EINA_FALSE = no homogeneous)
   ///
   bool homogeneous_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_table_homogeneous_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param homogeneous A boolean to set if the layout is homogeneous in the
   /// table (EINA_TRUE = homogeneous, EINA_FALSE = no homogeneous)
   ///
   void homogeneous_set(bool homogeneous_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_table_homogeneous_set(efl::eolian::to_c(homogeneous_)));
   }

   /// @param horizontal set the horizontal padding.
   /// @param vertical set the vertical padding.
   ///
   void padding_get(Evas_Coord* horizontal_, Evas_Coord* vertical_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_table_padding_get(horizontal_, vertical_));
   }

   /// @param horizontal set the horizontal padding.
   /// @param vertical set the vertical padding.
   ///
   void padding_set(Evas_Coord horizontal_, Evas_Coord vertical_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_table_padding_set(horizontal_, vertical_));
   }

   static Eo_Class const* _eo_class()
   {
      return(ELM_TABLE_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_TABLE_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
void _elm_table_clear_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool clear_)
{
   static_cast<T*>(self->this_)->clear(efl::eolian::to_cxx<bool>(clear_, std::tuple<std::false_type>()));
}

template <typename T>
evas::object _elm_table_child_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int col_, int row_)
{
   return static_cast<T*>(self->this_)->child_get(col_, row_);
}

template <typename T>
void _elm_table_pack_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * subobj_, int column_, int row_, int colspan_, int rowspan_)
{
   static_cast<T*>(self->this_)->pack_set(efl::eolian::to_cxx<evas::object>(subobj_, std::tuple<std::false_type>()), column_, row_, colspan_, rowspan_);
}

template <typename T>
void _elm_table_pack_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * subobj_, int* column_, int* row_, int* colspan_, int* rowspan_)
{
   static_cast<T*>(self->this_)->pack_get(efl::eolian::to_cxx<evas::object>(subobj_, std::tuple<std::false_type>()), column_, row_, colspan_, rowspan_);
}

template <typename T>
void _elm_table_unpack_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * subobj_)
{
   static_cast<T*>(self->this_)->unpack(efl::eolian::to_cxx<evas::object>(subobj_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_table_pack_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * subobj_, int column_, int row_, int colspan_, int rowspan_)
{
   static_cast<T*>(self->this_)->pack(efl::eolian::to_cxx<evas::object>(subobj_, std::tuple<std::false_type>()), column_, row_, colspan_, rowspan_);
}

template <typename T>
bool _elm_table_homogeneous_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->homogeneous_get();
}

template <typename T>
void _elm_table_homogeneous_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool homogeneous_)
{
   static_cast<T*>(self->this_)->homogeneous_set(efl::eolian::to_cxx<bool>(homogeneous_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_table_padding_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord* horizontal_, Evas_Coord* vertical_)
{
   static_cast<T*>(self->this_)->padding_get(horizontal_, vertical_);
}

template <typename T>
void _elm_table_padding_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Coord horizontal_, Evas_Coord vertical_)
{
   static_cast<T*>(self->this_)->padding_set(horizontal_, vertical_);
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_table >
{
   template <typename T>
   struct type
   {
      virtual void clear(bool clear_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_table_clear(efl::eolian::to_c(clear_)));
      }

      virtual evas::object child_get(int col_, int row_)
      {
         Evas_Object * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_table_child_get(col_, row_));
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void pack_set(evas::object subobj_, int column_, int row_, int colspan_, int rowspan_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_table_pack_set(efl::eolian::to_c(subobj_), column_, row_, colspan_, rowspan_));
      }

      virtual void pack_get(evas::object subobj_, int* column_, int* row_, int* colspan_, int* rowspan_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_table_pack_get(efl::eolian::to_c(subobj_), column_, row_, colspan_, rowspan_));
      }

      virtual void unpack(evas::object subobj_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_table_unpack(efl::eolian::to_c(subobj_)));
      }

      virtual void pack(evas::object subobj_, int column_, int row_, int colspan_, int rowspan_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_table_pack(efl::eolian::to_c(subobj_), column_, row_, colspan_, rowspan_));
      }

      virtual bool homogeneous_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_table_homogeneous_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void homogeneous_set(bool homogeneous_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_table_homogeneous_set(efl::eolian::to_c(homogeneous_)));
      }

      virtual void padding_get(Evas_Coord* horizontal_, Evas_Coord* vertical_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_table_padding_get(horizontal_, vertical_));
      }

      virtual void padding_set(Evas_Coord horizontal_, Evas_Coord vertical_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_table_padding_set(horizontal_, vertical_));
      }

   };
};


template<>
struct operation_description_class_size< ::elm_table >
{
   static const int value = 10;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_table>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_table_clear_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_table_clear);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_table_child_get_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_table_child_get);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_table_pack_set_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_table_pack_set);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_table_pack_get_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_table_pack_get);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_table_unpack_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_table_unpack);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_table_pack_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_table_pack);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_table_homogeneous_get_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_table_homogeneous_get);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_table_homogeneous_set_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_table_homogeneous_set);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_table_padding_get_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_table_padding_get);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_table_padding_set_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_table_padding_set);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_table >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_table, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_table >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_table, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_table>
{
   template <typename U>
   struct type
   {
      operator ::elm_table() const
      {
         return ::elm_table(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      void clear(bool clear_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_table_clear(efl::eolian::to_c(clear_)));
      }

      evas::object child_get(int col_, int row_)
      {
         Evas_Object * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_table_child_get(col_, row_));
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      void pack_set(evas::object subobj_, int column_, int row_, int colspan_, int rowspan_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_table_pack_set(efl::eolian::to_c(subobj_), column_, row_, colspan_, rowspan_));
      }

      void pack_get(evas::object subobj_, int* column_, int* row_, int* colspan_, int* rowspan_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_table_pack_get(efl::eolian::to_c(subobj_), column_, row_, colspan_, rowspan_));
      }

      void unpack(evas::object subobj_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_table_unpack(efl::eolian::to_c(subobj_)));
      }

      void pack(evas::object subobj_, int column_, int row_, int colspan_, int rowspan_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_table_pack(efl::eolian::to_c(subobj_), column_, row_, colspan_, rowspan_));
      }

      bool homogeneous_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_table_homogeneous_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void homogeneous_set(bool homogeneous_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_table_homogeneous_set(efl::eolian::to_c(homogeneous_)));
      }

      void padding_get(Evas_Coord* horizontal_, Evas_Coord* vertical_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_table_padding_get(horizontal_, vertical_));
      }

      void padding_set(Evas_Coord horizontal_, Evas_Coord vertical_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_table_padding_set(horizontal_, vertical_));
      }

   };
};

inline Eo_Class const* get_eo_class(tag<::elm_table>)
{
   return (ELM_TABLE_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_TABLE_HH

