#ifndef EFL_GENERATED_ELM_TOOLBAR_HH
#define EFL_GENERATED_ELM_TOOLBAR_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_toolbar.eo.h"
}

#include "elm_widget.eo.hh"
#include "elm_interface_scrollable.eo.hh"
#include "elm_interface_atspi_widget_action.eo.hh"
#include <canvas/evas_object.eo.hh>
#include <string>

struct elm_toolbar
      : elm_widget,
      efl::eo::detail::extension_inheritance<elm_interface_scrollable>::template type< ::elm_toolbar>,
      efl::eo::detail::extension_inheritance<elm_interface_atspi_widget_action>::template type< ::elm_toolbar>

{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_toolbar(Eo* eo)
      : elm_widget(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_toolbar(std::nullptr_t)
      : elm_widget(nullptr)
   {}

   elm_toolbar(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_toolbar(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_toolbar(elm_toolbar const& other)
      : elm_widget(eo_ref(other._eo_ptr()))
   {}

   ~elm_toolbar() {}

   /// @brief Insert a new item into the toolbar object before item @p before.
   ///
   /// @return The created item or @c NULL upon failure.
   ///
   /// A new item will be created and added to the toolbar. Its position in
   /// this toolbar will be just before item @p before.
   ///
   /// Items created with this method can be deleted with
   /// elm_object_item_del().
   ///
   /// Associated @p data can be properly freed when item is deleted if a
   /// callback function is set with elm_object_item_del_cb_set().
   ///
   /// If a function is passed as argument, it will be called every time this item
   /// is selected, i.e., the user clicks over an unselected item.
   /// If such function isn't needed, just passing
   /// @c NULL as @p func is enough. The same should be done for @p data.
   ///
   /// Toolbar will load icon image from fdo or current theme.
   /// This behavior can be set by elm_toolbar_icon_order_lookup_set() function.
   /// If an absolute path is provided it will load it direct from a file.
   ///
   /// @note This function does not accept relative icon path.
   ///
   /// @see elm_toolbar_item_icon_set()
   /// @see elm_object_item_del()
   ///
   /// @ingroup Toolbar
   ///
   /// @param before The toolbar item to insert before.
   /// @param icon A string with icon name or the absolute path of an image file.
   /// @param label The label of the item.
   /// @param func The function to call when the item is clicked.
   /// @param data The data to associate with the item for related callbacks.
   ///
   Elm_Object_Item * item_insert_before(Elm_Object_Item * before_, std::string icon_, std::string label_, Evas_Smart_Cb func_, const void * data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_item_insert_before(before_, efl::eolian::to_c(icon_), efl::eolian::to_c(label_), func_, data_));
      return _tmp_ret;
   }

   /// @brief Insert a new item into the toolbar object after item @p after.
   ///
   /// @return The created item or @c NULL upon failure.
   ///
   /// A new item will be created and added to the toolbar. Its position in
   /// this toolbar will be just after item @p after.
   ///
   /// Items created with this method can be deleted with
   /// elm_object_item_del().
   ///
   /// Associated @p data can be properly freed when item is deleted if a
   /// callback function is set with elm_object_item_del_cb_set().
   ///
   /// If a function is passed as argument, it will be called every time this item
   /// is selected, i.e., the user clicks over an unselected item.
   /// If such function isn't needed, just passing
   /// @c NULL as @p func is enough. The same should be done for @p data.
   ///
   /// Toolbar will load icon image from fdo or current theme.
   /// This behavior can be set by elm_toolbar_icon_order_lookup_set() function.
   /// If an absolute path is provided it will load it direct from a file.
   ///
   /// @note This function does not accept relative icon path.
   ///
   /// @see elm_toolbar_item_icon_set()
   /// @see elm_object_item_del()
   ///
   /// @ingroup Toolbar
   ///
   /// @param after The toolbar item to insert after.
   /// @param icon A string with icon name or the absolute path of an image file.
   /// @param label The label of the item.
   /// @param func The function to call when the item is clicked.
   /// @param data The data to associate with the item for related callbacks.
   ///
   Elm_Object_Item * item_insert_after(Elm_Object_Item * after_, std::string icon_, std::string label_, Evas_Smart_Cb func_, const void * data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_item_insert_after(after_, efl::eolian::to_c(icon_), efl::eolian::to_c(label_), func_, data_));
      return _tmp_ret;
   }

   /// @brief Append item to the toolbar.
   ///
   /// @return The created item or @c NULL upon failure.
   ///
   /// A new item will be created and appended to the toolbar, i.e., will
   /// be set as @b last item.
   ///
   /// Items created with this method can be deleted with
   /// elm_object_item_del().
   ///
   /// Associated @p data can be properly freed when item is deleted if a
   /// callback function is set with elm_object_item_del_cb_set().
   ///
   /// If a function is passed as argument, it will be called every time this item
   /// is selected, i.e., the user clicks over an unselected item.
   /// If such function isn't needed, just passing
   /// @c NULL as @p func is enough. The same should be done for @p data.
   ///
   /// Toolbar will load icon image from fdo or current theme.
   /// This behavior can be set by elm_toolbar_icon_order_lookup_set() function.
   /// If an absolute path is provided it will load it direct from a file.
   ///
   /// @note This function does not accept relative icon path.
   ///
   /// @see elm_toolbar_item_icon_set()
   /// @see elm_object_item_del()
   ///
   /// @ingroup Toolbar
   ///
   /// @param icon A string with icon name or the absolute path of an image file.
   /// @param label The label of the item.
   /// @param func The function to call when the item is clicked.
   /// @param data The data to associate with the item for related callbacks.
   ///
   Elm_Object_Item * item_append(std::string icon_, std::string label_, Evas_Smart_Cb func_, const void * data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_item_append(efl::eolian::to_c(icon_), efl::eolian::to_c(label_), func_, data_));
      return _tmp_ret;
   }

   /// @brief Get the number of items in a toolbar
   /// @return The number of items in @p obj toolbar
   /// @ingroup Toolbar
   ///
   unsigned int items_count() const
   {
      unsigned int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_items_count());
      return _tmp_ret;
   }

   /// @brief Prepend item to the toolbar.
   ///
   /// @return The created item or @c NULL upon failure.
   ///
   /// A new item will be created and prepended to the toolbar, i.e., will
   /// be set as @b first item.
   ///
   /// Items created with this method can be deleted with
   /// elm_object_item_del().
   ///
   /// Associated @p data can be properly freed when item is deleted if a
   /// callback function is set with elm_object_item_del_cb_set().
   ///
   /// If a function is passed as argument, it will be called every time this item
   /// is selected, i.e., the user clicks over an unselected item.
   /// If such function isn't needed, just passing
   /// @c NULL as @p func is enough. The same should be done for @p data.
   ///
   /// Toolbar will load icon image from fdo or current theme.
   /// This behavior can be set by elm_toolbar_icon_order_lookup_set() function.
   /// If an absolute path is provided it will load it direct from a file.
   ///
   /// @note This function does not accept relative icon path.
   ///
   /// @see elm_toolbar_item_icon_set()
   /// @see elm_object_item_del()
   ///
   /// @ingroup Toolbar
   ///
   /// @param icon A string with icon name or the absolute path of an image file.
   /// @param label The label of the item.
   /// @param func The function to call when the item is clicked.
   /// @param data The data to associate with the item for related callbacks.
   ///
   Elm_Object_Item * item_prepend(std::string icon_, std::string label_, Evas_Smart_Cb func_, const void * data_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_item_prepend(efl::eolian::to_c(icon_), efl::eolian::to_c(label_), func_, data_));
      return _tmp_ret;
   }

   /// @brief Returns a pointer to a toolbar item by its label.
   ///
   /// @return The pointer to the toolbar item matching @p label or @c NULL
   /// on failure.
   ///
   /// @ingroup Toolbar
   ///
   /// @param label The label of the item to find.
   ///
   Elm_Object_Item * item_find_by_label(std::string label_) const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_item_find_by_label(efl::eolian::to_c(label_)));
      return _tmp_ret;
   }

   /// @param homogeneous Assume the items within the toolbar are of the
   /// same size (EINA_TRUE = on, EINA_FALSE = off). Default is @c EINA_FALSE.
   ///
   bool homogeneous_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_homogeneous_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param homogeneous Assume the items within the toolbar are of the
   /// same size (EINA_TRUE = on, EINA_FALSE = off). Default is @c EINA_FALSE.
   ///
   void homogeneous_set(bool homogeneous_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_toolbar_homogeneous_set(efl::eolian::to_c(homogeneous_)));
   }

   /// @param align The new alignment, a float between <tt> 0.0 </tt>
   /// and <tt> 1.0 </tt>.
   ///
   double align_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_align_get());
      return _tmp_ret;
   }

   /// @param align The new alignment, a float between <tt> 0.0 </tt>
   /// and <tt> 1.0 </tt>.
   ///
   void align_set(double align_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_toolbar_align_set(align_));
   }

   /// @param mode The select mode
   ///
   Elm_Object_Select_Mode select_mode_get() const
   {
      Elm_Object_Select_Mode _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_select_mode_get());
      return _tmp_ret;
   }

   /// @param mode The select mode
   ///
   void select_mode_set(Elm_Object_Select_Mode mode_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_toolbar_select_mode_set(mode_));
   }

   /// @param icon_size The icon size in pixels
   ///
   int icon_size_get() const
   {
      int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_icon_size_get());
      return _tmp_ret;
   }

   /// @param icon_size The icon size in pixels
   ///
   void icon_size_set(int icon_size_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_toolbar_icon_size_set(icon_size_));
   }

   /// @param horizontal If @c EINA_TRUE, the toolbar is horizontal
   ///
   bool horizontal_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_horizontal_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param horizontal If @c EINA_TRUE, the toolbar is horizontal
   ///
   void horizontal_set(bool horizontal_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_toolbar_horizontal_set(efl::eolian::to_c(horizontal_)));
   }

   /// @param order The icon lookup order.
   ///
   Elm_Icon_Lookup_Order icon_order_lookup_get() const
   {
      Elm_Icon_Lookup_Order _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_icon_order_lookup_get());
      return _tmp_ret;
   }

   /// @param order The icon lookup order.
   ///
   void icon_order_lookup_set(Elm_Icon_Lookup_Order order_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_toolbar_icon_order_lookup_set(order_));
   }

   /// @param shrink_mode Toolbar's items display behavior
   ///
   Elm_Toolbar_Shrink_Mode shrink_mode_get() const
   {
      Elm_Toolbar_Shrink_Mode _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_shrink_mode_get());
      return _tmp_ret;
   }

   /// @param shrink_mode Toolbar's items display behavior
   ///
   void shrink_mode_set(Elm_Toolbar_Shrink_Mode shrink_mode_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_toolbar_shrink_mode_set(shrink_mode_));
   }

   /// @param parent The parent of the menu objects.
   ///
   evas::object menu_parent_get() const
   {
      Evas_Object * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_menu_parent_get());
      return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param parent The parent of the menu objects.
   ///
   void menu_parent_set(evas::object parent_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_toolbar_menu_parent_set(efl::eolian::to_c(parent_)));
   }

   /// @param priority The standard_priority of visible items
   ///
   int standard_priority_get() const
   {
      int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_standard_priority_get());
      return _tmp_ret;
   }

   /// @param priority The standard_priority of visible items
   ///
   void standard_priority_set(int priority_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_toolbar_standard_priority_set(priority_));
   }

   Elm_Object_Item * selected_item_get() const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_selected_item_get());
      return _tmp_ret;
   }

   Elm_Object_Item * first_item_get() const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_first_item_get());
      return _tmp_ret;
   }

   Elm_Object_Item * more_item_get() const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_more_item_get());
      return _tmp_ret;
   }

   Elm_Object_Item * last_item_get() const
   {
      Elm_Object_Item * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_last_item_get());
      return _tmp_ret;
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_SCROLL, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_SCROLL );
   }

   template <typename T>
   void
   callback_scroll_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_SCROLL, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_anim_start_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_SCROLL_ANIM_START, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_SCROLL_ANIM_START );
   }

   template <typename T>
   void
   callback_scroll_anim_start_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_SCROLL_ANIM_START, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_anim_stop_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_SCROLL_ANIM_STOP, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_SCROLL_ANIM_STOP );
   }

   template <typename T>
   void
   callback_scroll_anim_stop_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_SCROLL_ANIM_STOP, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_drag_start_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_SCROLL_DRAG_START, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_SCROLL_DRAG_START );
   }

   template <typename T>
   void
   callback_scroll_drag_start_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_SCROLL_DRAG_START, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_drag_stop_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_SCROLL_DRAG_STOP, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_SCROLL_DRAG_STOP );
   }

   template <typename T>
   void
   callback_scroll_drag_stop_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_SCROLL_DRAG_STOP, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_clicked_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_CLICKED, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_CLICKED );
   }

   template <typename T>
   void
   callback_clicked_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_CLICKED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_selected_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_SELECTED, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_SELECTED );
   }

   template <typename T>
   void
   callback_selected_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_SELECTED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unselected_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_UNSELECTED, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_UNSELECTED );
   }

   template <typename T>
   void
   callback_unselected_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_UNSELECTED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_longpressed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_LONGPRESSED, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_LONGPRESSED );
   }

   template <typename T>
   void
   callback_longpressed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_LONGPRESSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_clicked_double_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_CLICKED_DOUBLE, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_CLICKED_DOUBLE );
   }

   template <typename T>
   void
   callback_clicked_double_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_CLICKED_DOUBLE, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_UNFOCUSED, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_TOOLBAR_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_TOOLBAR_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
Elm_Object_Item * _elm_toolbar_item_insert_before_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Object_Item * before_, const char * icon_, const char * label_, Evas_Smart_Cb func_, const void * data_)
{
   return static_cast<T*>(self->this_)->item_insert_before(before_, efl::eolian::to_cxx<std::string>(icon_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(label_, std::tuple<std::false_type>()), func_, data_);
}

template <typename T>
Elm_Object_Item * _elm_toolbar_item_insert_after_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Object_Item * after_, const char * icon_, const char * label_, Evas_Smart_Cb func_, const void * data_)
{
   return static_cast<T*>(self->this_)->item_insert_after(after_, efl::eolian::to_cxx<std::string>(icon_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(label_, std::tuple<std::false_type>()), func_, data_);
}

template <typename T>
Elm_Object_Item * _elm_toolbar_item_append_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * icon_, const char * label_, Evas_Smart_Cb func_, const void * data_)
{
   return static_cast<T*>(self->this_)->item_append(efl::eolian::to_cxx<std::string>(icon_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(label_, std::tuple<std::false_type>()), func_, data_);
}

template <typename T>
unsigned int _elm_toolbar_items_count_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->items_count();
}

template <typename T>
Elm_Object_Item * _elm_toolbar_item_prepend_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * icon_, const char * label_, Evas_Smart_Cb func_, const void * data_)
{
   return static_cast<T*>(self->this_)->item_prepend(efl::eolian::to_cxx<std::string>(icon_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(label_, std::tuple<std::false_type>()), func_, data_);
}

template <typename T>
Elm_Object_Item * _elm_toolbar_item_find_by_label_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * label_)
{
   return static_cast<T*>(self->this_)->item_find_by_label(efl::eolian::to_cxx<std::string>(label_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_toolbar_homogeneous_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->homogeneous_get();
}

template <typename T>
void _elm_toolbar_homogeneous_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool homogeneous_)
{
   static_cast<T*>(self->this_)->homogeneous_set(efl::eolian::to_cxx<bool>(homogeneous_, std::tuple<std::false_type>()));
}

template <typename T>
double _elm_toolbar_align_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->align_get();
}

template <typename T>
void _elm_toolbar_align_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double align_)
{
   static_cast<T*>(self->this_)->align_set(align_);
}

template <typename T>
Elm_Object_Select_Mode _elm_toolbar_select_mode_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->select_mode_get();
}

template <typename T>
void _elm_toolbar_select_mode_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Object_Select_Mode mode_)
{
   static_cast<T*>(self->this_)->select_mode_set(mode_);
}

template <typename T>
int _elm_toolbar_icon_size_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->icon_size_get();
}

template <typename T>
void _elm_toolbar_icon_size_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int icon_size_)
{
   static_cast<T*>(self->this_)->icon_size_set(icon_size_);
}

template <typename T>
bool _elm_toolbar_horizontal_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->horizontal_get();
}

template <typename T>
void _elm_toolbar_horizontal_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool horizontal_)
{
   static_cast<T*>(self->this_)->horizontal_set(efl::eolian::to_cxx<bool>(horizontal_, std::tuple<std::false_type>()));
}

template <typename T>
Elm_Icon_Lookup_Order _elm_toolbar_icon_order_lookup_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->icon_order_lookup_get();
}

template <typename T>
void _elm_toolbar_icon_order_lookup_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Icon_Lookup_Order order_)
{
   static_cast<T*>(self->this_)->icon_order_lookup_set(order_);
}

template <typename T>
Elm_Toolbar_Shrink_Mode _elm_toolbar_shrink_mode_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->shrink_mode_get();
}

template <typename T>
void _elm_toolbar_shrink_mode_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Toolbar_Shrink_Mode shrink_mode_)
{
   static_cast<T*>(self->this_)->shrink_mode_set(shrink_mode_);
}

template <typename T>
evas::object _elm_toolbar_menu_parent_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->menu_parent_get();
}

template <typename T>
void _elm_toolbar_menu_parent_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * parent_)
{
   static_cast<T*>(self->this_)->menu_parent_set(efl::eolian::to_cxx<evas::object>(parent_, std::tuple<std::false_type>()));
}

template <typename T>
int _elm_toolbar_standard_priority_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->standard_priority_get();
}

template <typename T>
void _elm_toolbar_standard_priority_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int priority_)
{
   static_cast<T*>(self->this_)->standard_priority_set(priority_);
}

template <typename T>
Elm_Object_Item * _elm_toolbar_selected_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->selected_item_get();
}

template <typename T>
Elm_Object_Item * _elm_toolbar_first_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->first_item_get();
}

template <typename T>
Elm_Object_Item * _elm_toolbar_more_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->more_item_get();
}

template <typename T>
Elm_Object_Item * _elm_toolbar_last_item_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->last_item_get();
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_toolbar >
{
   template <typename T>
   struct type
   {
      virtual Elm_Object_Item * item_insert_before(Elm_Object_Item * before_, std::string icon_, std::string label_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_toolbar_item_insert_before(before_, efl::eolian::to_c(icon_), efl::eolian::to_c(label_), func_, data_));
            return _tmp_ret;
      }

      virtual Elm_Object_Item * item_insert_after(Elm_Object_Item * after_, std::string icon_, std::string label_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_toolbar_item_insert_after(after_, efl::eolian::to_c(icon_), efl::eolian::to_c(label_), func_, data_));
            return _tmp_ret;
      }

      virtual Elm_Object_Item * item_append(std::string icon_, std::string label_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_toolbar_item_append(efl::eolian::to_c(icon_), efl::eolian::to_c(label_), func_, data_));
            return _tmp_ret;
      }

      virtual unsigned int items_count()
      {
         unsigned int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_toolbar_items_count());
            return _tmp_ret;
      }

      virtual Elm_Object_Item * item_prepend(std::string icon_, std::string label_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_toolbar_item_prepend(efl::eolian::to_c(icon_), efl::eolian::to_c(label_), func_, data_));
            return _tmp_ret;
      }

      virtual Elm_Object_Item * item_find_by_label(std::string label_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_toolbar_item_find_by_label(efl::eolian::to_c(label_)));
            return _tmp_ret;
      }

      virtual bool homogeneous_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_toolbar_homogeneous_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void homogeneous_set(bool homogeneous_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_toolbar_homogeneous_set(efl::eolian::to_c(homogeneous_)));
      }

      virtual double align_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_toolbar_align_get());
            return _tmp_ret;
      }

      virtual void align_set(double align_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_toolbar_align_set(align_));
      }

      virtual Elm_Object_Select_Mode select_mode_get()
      {
         Elm_Object_Select_Mode _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_toolbar_select_mode_get());
            return _tmp_ret;
      }

      virtual void select_mode_set(Elm_Object_Select_Mode mode_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_toolbar_select_mode_set(mode_));
      }

      virtual int icon_size_get()
      {
         int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_toolbar_icon_size_get());
            return _tmp_ret;
      }

      virtual void icon_size_set(int icon_size_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_toolbar_icon_size_set(icon_size_));
      }

      virtual bool horizontal_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_toolbar_horizontal_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void horizontal_set(bool horizontal_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_toolbar_horizontal_set(efl::eolian::to_c(horizontal_)));
      }

      virtual Elm_Icon_Lookup_Order icon_order_lookup_get()
      {
         Elm_Icon_Lookup_Order _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_toolbar_icon_order_lookup_get());
            return _tmp_ret;
      }

      virtual void icon_order_lookup_set(Elm_Icon_Lookup_Order order_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_toolbar_icon_order_lookup_set(order_));
      }

      virtual Elm_Toolbar_Shrink_Mode shrink_mode_get()
      {
         Elm_Toolbar_Shrink_Mode _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_toolbar_shrink_mode_get());
            return _tmp_ret;
      }

      virtual void shrink_mode_set(Elm_Toolbar_Shrink_Mode shrink_mode_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_toolbar_shrink_mode_set(shrink_mode_));
      }

      virtual evas::object menu_parent_get()
      {
         Evas_Object * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_toolbar_menu_parent_get());
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void menu_parent_set(evas::object parent_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_toolbar_menu_parent_set(efl::eolian::to_c(parent_)));
      }

      virtual int standard_priority_get()
      {
         int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_toolbar_standard_priority_get());
            return _tmp_ret;
      }

      virtual void standard_priority_set(int priority_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_toolbar_standard_priority_set(priority_));
      }

      virtual Elm_Object_Item * selected_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_toolbar_selected_item_get());
            return _tmp_ret;
      }

      virtual Elm_Object_Item * first_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_toolbar_first_item_get());
            return _tmp_ret;
      }

      virtual Elm_Object_Item * more_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_toolbar_more_item_get());
            return _tmp_ret;
      }

      virtual Elm_Object_Item * last_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_toolbar_last_item_get());
            return _tmp_ret;
      }

   };
};


template<>
struct operation_description_class_size< ::elm_toolbar >
{
   static const int value = 28;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_toolbar>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_toolbar_item_insert_before_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_item_insert_before);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_toolbar_item_insert_after_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_item_insert_after);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_toolbar_item_append_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_item_append);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_toolbar_items_count_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_items_count);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_toolbar_item_prepend_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_item_prepend);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_toolbar_item_find_by_label_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_item_find_by_label);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_toolbar_homogeneous_get_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_homogeneous_get);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_toolbar_homogeneous_set_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_homogeneous_set);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_toolbar_align_get_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_align_get);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_toolbar_align_set_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_align_set);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::_elm_toolbar_select_mode_get_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_select_mode_get);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::_elm_toolbar_select_mode_set_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_select_mode_set);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::_elm_toolbar_icon_size_get_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_icon_size_get);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::_elm_toolbar_icon_size_set_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_icon_size_set);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::_elm_toolbar_horizontal_get_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_horizontal_get);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::_elm_toolbar_horizontal_set_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_horizontal_set);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   ops[16].func = reinterpret_cast<void*>(& ::_elm_toolbar_icon_order_lookup_get_wrapper<T>);
   ops[16].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_icon_order_lookup_get);
   ops[16].op = EO_OP_OVERRIDE;
   ops[16].op_type = EO_OP_TYPE_REGULAR;
   ops[16].doc = NULL;

   ops[17].func = reinterpret_cast<void*>(& ::_elm_toolbar_icon_order_lookup_set_wrapper<T>);
   ops[17].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_icon_order_lookup_set);
   ops[17].op = EO_OP_OVERRIDE;
   ops[17].op_type = EO_OP_TYPE_REGULAR;
   ops[17].doc = NULL;

   ops[18].func = reinterpret_cast<void*>(& ::_elm_toolbar_shrink_mode_get_wrapper<T>);
   ops[18].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_shrink_mode_get);
   ops[18].op = EO_OP_OVERRIDE;
   ops[18].op_type = EO_OP_TYPE_REGULAR;
   ops[18].doc = NULL;

   ops[19].func = reinterpret_cast<void*>(& ::_elm_toolbar_shrink_mode_set_wrapper<T>);
   ops[19].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_shrink_mode_set);
   ops[19].op = EO_OP_OVERRIDE;
   ops[19].op_type = EO_OP_TYPE_REGULAR;
   ops[19].doc = NULL;

   ops[20].func = reinterpret_cast<void*>(& ::_elm_toolbar_menu_parent_get_wrapper<T>);
   ops[20].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_menu_parent_get);
   ops[20].op = EO_OP_OVERRIDE;
   ops[20].op_type = EO_OP_TYPE_REGULAR;
   ops[20].doc = NULL;

   ops[21].func = reinterpret_cast<void*>(& ::_elm_toolbar_menu_parent_set_wrapper<T>);
   ops[21].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_menu_parent_set);
   ops[21].op = EO_OP_OVERRIDE;
   ops[21].op_type = EO_OP_TYPE_REGULAR;
   ops[21].doc = NULL;

   ops[22].func = reinterpret_cast<void*>(& ::_elm_toolbar_standard_priority_get_wrapper<T>);
   ops[22].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_standard_priority_get);
   ops[22].op = EO_OP_OVERRIDE;
   ops[22].op_type = EO_OP_TYPE_REGULAR;
   ops[22].doc = NULL;

   ops[23].func = reinterpret_cast<void*>(& ::_elm_toolbar_standard_priority_set_wrapper<T>);
   ops[23].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_standard_priority_set);
   ops[23].op = EO_OP_OVERRIDE;
   ops[23].op_type = EO_OP_TYPE_REGULAR;
   ops[23].doc = NULL;

   ops[24].func = reinterpret_cast<void*>(& ::_elm_toolbar_selected_item_get_wrapper<T>);
   ops[24].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_selected_item_get);
   ops[24].op = EO_OP_OVERRIDE;
   ops[24].op_type = EO_OP_TYPE_REGULAR;
   ops[24].doc = NULL;

   ops[25].func = reinterpret_cast<void*>(& ::_elm_toolbar_first_item_get_wrapper<T>);
   ops[25].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_first_item_get);
   ops[25].op = EO_OP_OVERRIDE;
   ops[25].op_type = EO_OP_TYPE_REGULAR;
   ops[25].doc = NULL;

   ops[26].func = reinterpret_cast<void*>(& ::_elm_toolbar_more_item_get_wrapper<T>);
   ops[26].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_more_item_get);
   ops[26].op = EO_OP_OVERRIDE;
   ops[26].op_type = EO_OP_TYPE_REGULAR;
   ops[26].doc = NULL;

   ops[27].func = reinterpret_cast<void*>(& ::_elm_toolbar_last_item_get_wrapper<T>);
   ops[27].api_func = reinterpret_cast<void*>(& ::elm_obj_toolbar_last_item_get);
   ops[27].op = EO_OP_OVERRIDE;
   ops[27].op_type = EO_OP_TYPE_REGULAR;
   ops[27].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_toolbar >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_toolbar, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_toolbar >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_toolbar, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_toolbar>
{
   template <typename U>
   struct type
   {
      operator ::elm_toolbar() const
      {
         return ::elm_toolbar(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      Elm_Object_Item * item_insert_before(Elm_Object_Item * before_, std::string icon_, std::string label_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_item_insert_before(before_, efl::eolian::to_c(icon_), efl::eolian::to_c(label_), func_, data_));
            return _tmp_ret;
      }

      Elm_Object_Item * item_insert_after(Elm_Object_Item * after_, std::string icon_, std::string label_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_item_insert_after(after_, efl::eolian::to_c(icon_), efl::eolian::to_c(label_), func_, data_));
            return _tmp_ret;
      }

      Elm_Object_Item * item_append(std::string icon_, std::string label_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_item_append(efl::eolian::to_c(icon_), efl::eolian::to_c(label_), func_, data_));
            return _tmp_ret;
      }

      unsigned int items_count()
      {
         unsigned int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_items_count());
            return _tmp_ret;
      }

      Elm_Object_Item * item_prepend(std::string icon_, std::string label_, Evas_Smart_Cb func_, const void * data_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_item_prepend(efl::eolian::to_c(icon_), efl::eolian::to_c(label_), func_, data_));
            return _tmp_ret;
      }

      Elm_Object_Item * item_find_by_label(std::string label_)
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_item_find_by_label(efl::eolian::to_c(label_)));
            return _tmp_ret;
      }

      bool homogeneous_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_homogeneous_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void homogeneous_set(bool homogeneous_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_toolbar_homogeneous_set(efl::eolian::to_c(homogeneous_)));
      }

      double align_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_align_get());
            return _tmp_ret;
      }

      void align_set(double align_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_toolbar_align_set(align_));
      }

      Elm_Object_Select_Mode select_mode_get()
      {
         Elm_Object_Select_Mode _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_select_mode_get());
            return _tmp_ret;
      }

      void select_mode_set(Elm_Object_Select_Mode mode_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_toolbar_select_mode_set(mode_));
      }

      int icon_size_get()
      {
         int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_icon_size_get());
            return _tmp_ret;
      }

      void icon_size_set(int icon_size_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_toolbar_icon_size_set(icon_size_));
      }

      bool horizontal_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_horizontal_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void horizontal_set(bool horizontal_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_toolbar_horizontal_set(efl::eolian::to_c(horizontal_)));
      }

      Elm_Icon_Lookup_Order icon_order_lookup_get()
      {
         Elm_Icon_Lookup_Order _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_icon_order_lookup_get());
            return _tmp_ret;
      }

      void icon_order_lookup_set(Elm_Icon_Lookup_Order order_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_toolbar_icon_order_lookup_set(order_));
      }

      Elm_Toolbar_Shrink_Mode shrink_mode_get()
      {
         Elm_Toolbar_Shrink_Mode _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_shrink_mode_get());
            return _tmp_ret;
      }

      void shrink_mode_set(Elm_Toolbar_Shrink_Mode shrink_mode_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_toolbar_shrink_mode_set(shrink_mode_));
      }

      evas::object menu_parent_get()
      {
         Evas_Object * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_menu_parent_get());
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      void menu_parent_set(evas::object parent_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_toolbar_menu_parent_set(efl::eolian::to_c(parent_)));
      }

      int standard_priority_get()
      {
         int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_standard_priority_get());
            return _tmp_ret;
      }

      void standard_priority_set(int priority_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_toolbar_standard_priority_set(priority_));
      }

      Elm_Object_Item * selected_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_selected_item_get());
            return _tmp_ret;
      }

      Elm_Object_Item * first_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_first_item_get());
            return _tmp_ret;
      }

      Elm_Object_Item * more_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_more_item_get());
            return _tmp_ret;
      }

      Elm_Object_Item * last_item_get()
      {
         Elm_Object_Item * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_toolbar_last_item_get());
            return _tmp_ret;
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_SCROLL, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_SCROLL );
   }

   template <typename T>
   void
   callback_scroll_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_SCROLL, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_anim_start_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_SCROLL_ANIM_START, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_SCROLL_ANIM_START );
   }

   template <typename T>
   void
   callback_scroll_anim_start_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_SCROLL_ANIM_START, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_anim_stop_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_SCROLL_ANIM_STOP, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_SCROLL_ANIM_STOP );
   }

   template <typename T>
   void
   callback_scroll_anim_stop_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_SCROLL_ANIM_STOP, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_drag_start_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_SCROLL_DRAG_START, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_SCROLL_DRAG_START );
   }

   template <typename T>
   void
   callback_scroll_drag_start_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_SCROLL_DRAG_START, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_scroll_drag_stop_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_SCROLL_DRAG_STOP, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_SCROLL_DRAG_STOP );
   }

   template <typename T>
   void
   callback_scroll_drag_stop_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_SCROLL_DRAG_STOP, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_clicked_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_CLICKED, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_CLICKED );
   }

   template <typename T>
   void
   callback_clicked_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_CLICKED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_selected_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_SELECTED, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_SELECTED );
   }

   template <typename T>
   void
   callback_selected_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_SELECTED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unselected_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_UNSELECTED, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_UNSELECTED );
   }

   template <typename T>
   void
   callback_unselected_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_UNSELECTED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_longpressed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_LONGPRESSED, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_LONGPRESSED );
   }

   template <typename T>
   void
   callback_longpressed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_LONGPRESSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_clicked_double_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_CLICKED_DOUBLE, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_CLICKED_DOUBLE );
   }

   template <typename T>
   void
   callback_clicked_double_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_CLICKED_DOUBLE, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_language_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_LANGUAGE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_LANGUAGE_CHANGED );
   }

   template <typename T>
   void
   callback_language_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_LANGUAGE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_access_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_ACCESS_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_ACCESS_CHANGED );
   }

   template <typename T>
   void
   callback_access_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_ACCESS_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_TOOLBAR_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_toolbar, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_toolbar, function_type>,
         ELM_TOOLBAR_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_TOOLBAR_EVENT_UNFOCUSED, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_toolbar>)
{
   return (ELM_TOOLBAR_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_TOOLBAR_HH

