#ifndef EFL_GENERATED_ELM_VIDEO_HH
#define EFL_GENERATED_ELM_VIDEO_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_video.eo.h"
}

#include "elm_layout.eo.hh"
#include "elm_interface_atspi_widget_action.eo.hh"
#include <string>

struct elm_video
      : elm_layout,
      efl::eo::detail::extension_inheritance<elm_interface_atspi_widget_action>::template type< ::elm_video>

{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_video(Eo* eo)
      : elm_layout(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_video(std::nullptr_t)
      : elm_layout(nullptr)
   {}

   elm_video(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_video(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_video(elm_video const& other)
      : elm_layout(eo_ref(other._eo_ptr()))
   {}

   ~elm_video() {}

   /// @brief @brief Start to play the video
   ///
   /// Start to play the video and cancel all suspend state.
   ///
   /// @ingroup Video
   ///
   void play() const
   {
      eo_do(_eo_ptr(), ::elm_obj_video_play());
   }

   /// @brief @brief Pause the video
   ///
   /// Pause the video and start a timer to trigger suspend mode.
   ///
   /// @ingroup Video
   ///
   void pause() const
   {
      eo_do(_eo_ptr(), ::elm_obj_video_pause());
   }

   /// @brief @brief Stop the video
   ///
   /// Stop the video and put the emotion in deep sleep mode.
   ///
   /// @ingroup Video
   ///
   void stop() const
   {
      eo_do(_eo_ptr(), ::elm_obj_video_stop());
   }

   /// @param volume The new audio volume.
   ///
   double audio_level_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_video_audio_level_get());
      return _tmp_ret;
   }

   /// @param volume The new audio volume.
   ///
   void audio_level_set(double volume_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_video_audio_level_set(volume_));
   }

   /// @param remember the last played position of the Elm_Video object.
   ///
   bool remember_position_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_video_remember_position_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param remember the last played position of the Elm_Video object.
   ///
   void remember_position_set(bool remember_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_video_remember_position_set(efl::eolian::to_c(remember_)));
   }

   /// @param position The time (in seconds) since the beginning of the media file.
   ///
   double play_position_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_video_play_position_get());
      return _tmp_ret;
   }

   /// @param position The time (in seconds) since the beginning of the media file.
   ///
   void play_position_set(double position_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_video_play_position_set(position_));
   }

   /// @param mute The new mute state.
   ///
   bool audio_mute_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_video_audio_mute_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param mute The new mute state.
   ///
   void audio_mute_set(bool mute_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_video_audio_mute_set(efl::eolian::to_c(mute_)));
   }

   /// @param filename The file or URI to target.
   /// Local files can be specified using file:// or by using full file paths.
   /// URI could be remote source of video, like http:// or local source like
   /// WebCam (v4l2://). (You can use Emotion API to request and list
   /// the available Webcam on your system).
   ///
   bool file_set(std::string filename_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_video_file_set(efl::eolian::to_c(filename_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   bool is_playing_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_video_is_playing_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   double play_length_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_video_play_length_get());
      return _tmp_ret;
   }

   evas::object emotion_get() const
   {
      Evas_Object * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_video_emotion_get());
      return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
   }

   bool is_seekable_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_video_is_seekable_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   std::string title_get() const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_video_title_get());
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_VIDEO_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_video, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_video, function_type>,
         ELM_VIDEO_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_VIDEO_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_VIDEO_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_video, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_video, function_type>,
         ELM_VIDEO_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_VIDEO_EVENT_UNFOCUSED, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_VIDEO_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_VIDEO_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
void _elm_video_play_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->play();
}

template <typename T>
void _elm_video_pause_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->pause();
}

template <typename T>
void _elm_video_stop_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->stop();
}

template <typename T>
double _elm_video_audio_level_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->audio_level_get();
}

template <typename T>
void _elm_video_audio_level_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double volume_)
{
   static_cast<T*>(self->this_)->audio_level_set(volume_);
}

template <typename T>
bool _elm_video_remember_position_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->remember_position_get();
}

template <typename T>
void _elm_video_remember_position_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool remember_)
{
   static_cast<T*>(self->this_)->remember_position_set(efl::eolian::to_cxx<bool>(remember_, std::tuple<std::false_type>()));
}

template <typename T>
double _elm_video_play_position_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->play_position_get();
}

template <typename T>
void _elm_video_play_position_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double position_)
{
   static_cast<T*>(self->this_)->play_position_set(position_);
}

template <typename T>
bool _elm_video_audio_mute_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->audio_mute_get();
}

template <typename T>
void _elm_video_audio_mute_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool mute_)
{
   static_cast<T*>(self->this_)->audio_mute_set(efl::eolian::to_cxx<bool>(mute_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_video_file_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * filename_)
{
   return static_cast<T*>(self->this_)->file_set(efl::eolian::to_cxx<std::string>(filename_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_video_is_playing_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->is_playing_get();
}

template <typename T>
double _elm_video_play_length_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->play_length_get();
}

template <typename T>
evas::object _elm_video_emotion_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->emotion_get();
}

template <typename T>
bool _elm_video_is_seekable_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->is_seekable_get();
}

template <typename T>
std::string _elm_video_title_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->title_get();
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_video >
{
   template <typename T>
   struct type
   {
      virtual void play()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_video_play());
      }

      virtual void pause()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_video_pause());
      }

      virtual void stop()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_video_stop());
      }

      virtual double audio_level_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_video_audio_level_get());
            return _tmp_ret;
      }

      virtual void audio_level_set(double volume_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_video_audio_level_set(volume_));
      }

      virtual bool remember_position_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_video_remember_position_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void remember_position_set(bool remember_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_video_remember_position_set(efl::eolian::to_c(remember_)));
      }

      virtual double play_position_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_video_play_position_get());
            return _tmp_ret;
      }

      virtual void play_position_set(double position_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_video_play_position_set(position_));
      }

      virtual bool audio_mute_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_video_audio_mute_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void audio_mute_set(bool mute_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_video_audio_mute_set(efl::eolian::to_c(mute_)));
      }

      virtual bool file_set(std::string filename_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_video_file_set(efl::eolian::to_c(filename_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool is_playing_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_video_is_playing_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual double play_length_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_video_play_length_get());
            return _tmp_ret;
      }

      virtual evas::object emotion_get()
      {
         Evas_Object * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_video_emotion_get());
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool is_seekable_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_video_is_seekable_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual std::string title_get()
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_video_title_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

   };
};


template<>
struct operation_description_class_size< ::elm_video >
{
   static const int value = 17;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_video>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_video_play_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_video_play);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_video_pause_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_video_pause);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_video_stop_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_video_stop);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_video_audio_level_get_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_video_audio_level_get);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_video_audio_level_set_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_video_audio_level_set);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_video_remember_position_get_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_video_remember_position_get);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_video_remember_position_set_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_video_remember_position_set);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_video_play_position_get_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_video_play_position_get);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_video_play_position_set_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_video_play_position_set);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_video_audio_mute_get_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_video_audio_mute_get);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::_elm_video_audio_mute_set_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::elm_obj_video_audio_mute_set);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::_elm_video_file_set_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::elm_obj_video_file_set);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::_elm_video_is_playing_get_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::elm_obj_video_is_playing_get);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::_elm_video_play_length_get_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::elm_obj_video_play_length_get);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::_elm_video_emotion_get_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::elm_obj_video_emotion_get);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::_elm_video_is_seekable_get_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::elm_obj_video_is_seekable_get);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   ops[16].func = reinterpret_cast<void*>(& ::_elm_video_title_get_wrapper<T>);
   ops[16].api_func = reinterpret_cast<void*>(& ::elm_obj_video_title_get);
   ops[16].op = EO_OP_OVERRIDE;
   ops[16].op_type = EO_OP_TYPE_REGULAR;
   ops[16].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_video >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_video, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_video >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_video, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_video>
{
   template <typename U>
   struct type
   {
      operator ::elm_video() const
      {
         return ::elm_video(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      void play()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_video_play());
      }

      void pause()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_video_pause());
      }

      void stop()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_video_stop());
      }

      double audio_level_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_video_audio_level_get());
            return _tmp_ret;
      }

      void audio_level_set(double volume_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_video_audio_level_set(volume_));
      }

      bool remember_position_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_video_remember_position_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void remember_position_set(bool remember_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_video_remember_position_set(efl::eolian::to_c(remember_)));
      }

      double play_position_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_video_play_position_get());
            return _tmp_ret;
      }

      void play_position_set(double position_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_video_play_position_set(position_));
      }

      bool audio_mute_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_video_audio_mute_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void audio_mute_set(bool mute_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_video_audio_mute_set(efl::eolian::to_c(mute_)));
      }

      bool file_set(std::string filename_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_video_file_set(efl::eolian::to_c(filename_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool is_playing_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_video_is_playing_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      double play_length_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_video_play_length_get());
            return _tmp_ret;
      }

      evas::object emotion_get()
      {
         Evas_Object * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_video_emotion_get());
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool is_seekable_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_video_is_seekable_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      std::string title_get()
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_video_title_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_VIDEO_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_video, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_video, function_type>,
         ELM_VIDEO_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_VIDEO_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_VIDEO_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_video, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_video, function_type>,
         ELM_VIDEO_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_VIDEO_EVENT_UNFOCUSED, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_video>)
{
   return (ELM_VIDEO_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_VIDEO_HH

