#ifndef EFL_GENERATED_ELM_WEB_HH
#define EFL_GENERATED_ELM_WEB_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_web.eo.h"
}

#include "elm_widget.eo.hh"
#include <string>

struct elm_web
      : elm_widget
{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_web(Eo* eo)
      : elm_widget(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_web(std::nullptr_t)
      : elm_widget(nullptr)
   {}

   elm_web(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_web(_c0(_p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_web(elm_web const& other)
      : elm_widget(eo_ref(other._eo_ptr()))
   {}

   ~elm_web() {}

   /// @brief Jumps the given number of steps in the browsing history
   ///
   /// The @p steps value can be a negative integer to back in history, or a
   /// positive to move forward.
   ///
   /// @return @c EINA_TRUE on success, @c EINA_FALSE on error or if not enough
   /// history exists to jump the given number of steps
   ///
   /// @see elm_web_history_enabled_set()
   /// @see elm_web_back()
   /// @see elm_web_forward()
   ///
   /// @ingroup Web
   ///
   /// @param steps The number of steps to jump
   ///
   bool navigate(int steps_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_navigate(steps_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Goes back one step in the browsing history
   ///
   /// This is equivalent to calling elm_web_object_navigate(obj, -1);
   ///
   /// @return @c EINA_TRUE on success, @c EINA_FALSE otherwise
   ///
   /// @see elm_web_history_enabled_set()
   /// @see elm_web_back_possible()
   /// @see elm_web_forward()
   /// @see elm_web_navigate()
   ///
   /// @ingroup Web
   ///
   bool back() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_back());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Loads the specified @a html string as the content of the web object
   ///
   /// @return @c EINA_TRUE if it the HTML was successfully loaded, @c EINA_FALSE otherwise
   ///
   /// External objects such as stylesheets or images referenced in the HTML
   /// document are located relative to @a base_url.
   ///
   /// If an @a unreachable_url is passed it is used as the url for the loaded
   /// content. This is typically used to display error pages for a failed
   /// load.
   ///
   /// @since 1.9
   /// @ingroup Web
   ///
   /// @param html HTML data to load
   /// @param base_url Base URL used for relative paths to external objects (optional)
   /// @param unreachable_url URL that could not be reached (optional)
   ///
   bool html_string_load(std::string html_, std::string base_url_, std::string unreachable_url_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_html_string_load(efl::eolian::to_c(html_), efl::eolian::to_c(base_url_), efl::eolian::to_c(unreachable_url_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Searches the given string in a document.
   ///
   /// @return @c EINA_TRUE if the given string was found, @c EINA_FALSE if not
   /// or failure
   ///
   /// @ingroup Web
   ///
   /// @param string String to search
   /// @param case_sensitive If search should be case sensitive or not
   /// @param forward If search is from cursor and on or backwards
   /// @param wrap If search should wrap at the end
   ///
   bool text_search(std::string string_, bool case_sensitive_, bool forward_, bool wrap_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_text_search(efl::eolian::to_c(string_), efl::eolian::to_c(case_sensitive_), efl::eolian::to_c(forward_), efl::eolian::to_c(wrap_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Dismisses an open dropdown popup
   ///
   /// When the popup from a dropdown widget is to be dismissed, either after
   /// selecting an option or to cancel it, this function must be called, which
   /// will later emit an "popup,willdelete" signal to notify the user that
   /// any memory and objects related to this popup can be freed.
   ///
   /// @return @c EINA_TRUE if the menu was successfully destroyed, or @c EINA_FALSE
   /// if there was no menu to destroy
   ///
   /// @ingroup Web
   ///
   bool popup_destroy() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_popup_destroy());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Shows the given region in the web object
   ///
   /// @ingroup Web
   ///
   /// @param x The x coordinate of the region to show
   /// @param y The y coordinate of the region to show
   /// @param w The width of the region to show
   /// @param h The height of the region to show
   ///
   void region_show(int x_, int y_, int w_, int h_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_web_region_show(x_, y_, w_, h_));
   }

   /// @brief Goes forward one step in the browsing history
   ///
   /// This is equivalent to calling elm_web_object_navigate(obj, 1);
   ///
   /// @return @c EINA_TRUE on success, @c EINA_FALSE otherwise
   ///
   /// @see elm_web_history_enabled_set()
   /// @see elm_web_forward_possible_get()
   /// @see elm_web_back()
   /// @see elm_web_navigate()
   ///
   /// @ingroup Web
   ///
   bool forward() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_forward());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Marks matches of the given string in a document.
   ///
   /// @return number of matched @a string
   ///
   /// @ingroup Web
   ///
   /// @param string String to match
   /// @param case_sensitive If match should be case sensitive or not
   /// @param highlight If matches should be highlighted
   /// @param limit Maximum amount of matches, or zero to unlimited
   ///
   unsigned int text_matches_mark(std::string string_, bool case_sensitive_, bool highlight_, unsigned int limit_) const
   {
      unsigned int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_text_matches_mark(efl::eolian::to_c(string_), efl::eolian::to_c(case_sensitive_), efl::eolian::to_c(highlight_), limit_));
      return _tmp_ret;
   }

   /// @brief Brings in the region to the visible area
   ///
   /// Like elm_web_region_show(), but it animates the scrolling of the object
   /// to show the area
   ///
   /// @ingroup Web
   ///
   /// @param x The x coordinate of the region to show
   /// @param y The y coordinate of the region to show
   /// @param w The width of the region to show
   /// @param h The height of the region to show
   ///
   void region_bring_in(int x_, int y_, int w_, int h_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_web_region_bring_in(x_, y_, w_, h_));
   }

   /// @brief Stops loading the current page
   ///
   /// Cancels the loading of the current page in the web object. This will
   /// cause a "load,error" signal to be emitted, with the is_cancellation
   /// flag set to @c EINA_TRUE.
   ///
   /// @return @c EINA_TRUE if the cancel was successful, @c EINA_FALSE otherwise
   ///
   /// @ingroup Web
   ///
   bool stop() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_stop());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Queries whether it's possible to jump the given number of steps
   ///
   /// The @p steps value can be a negative integer to back in history, or a
   /// positive to move forward.
   ///
   /// @return @c EINA_TRUE if enough history exists to perform the given jump,
   /// @c EINA_FALSE otherwise
   ///
   /// @ingroup Web
   ///
   /// @param steps The number of steps to check for
   ///
   bool navigate_possible_get(int steps_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_navigate_possible_get(steps_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Requests a reload of the current document, avoiding any existing caches
   ///
   /// @return @c EINA_TRUE on success, @c EINA_FALSE otherwise
   ///
   /// @ingroup Web
   ///
   bool reload_full() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_reload_full());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Clears all marked matches in the document
   ///
   /// @return @c EINA_TRUE on success, @c EINA_FALSE otherwise
   ///
   /// @ingroup Web
   ///
   bool text_matches_unmark_all() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_text_matches_unmark_all());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Requests a reload of the current document in the object
   ///
   /// @return @c EINA_TRUE on success, @c EINA_FALSE otherwise
   ///
   /// @ingroup Web
   ///
   bool reload() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_reload());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param highlight Whether to highlight the marks or not
   ///
   bool text_matches_highlight_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_text_matches_highlight_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param highlight Whether to highlight the marks or not
   ///
   bool text_matches_highlight_set(bool highlight_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_text_matches_highlight_set(efl::eolian::to_c(highlight_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param user_agent String for useragent
   ///
   std::string useragent_get() const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_useragent_get());
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param user_agent String for useragent
   ///
   void useragent_set(std::string user_agent_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_web_useragent_set(efl::eolian::to_c(user_agent_)));
   }

   /// @param url The URL to set
   ///
   std::string url_get() const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_url_get());
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param url The URL to set
   ///
   bool url_set(std::string url_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_url_set(efl::eolian::to_c(url_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param r Red component
   /// @param g Green component
   /// @param b Blue component
   /// @param a Alpha component
   ///
   void bg_color_get(int* r_, int* g_, int* b_, int* a_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_web_bg_color_get(r_, g_, b_, a_));
   }

   /// @param r Red component
   /// @param g Green component
   /// @param b Blue component
   /// @param a Alpha component
   ///
   void bg_color_set(int r_, int g_, int b_, int a_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_web_bg_color_set(r_, g_, b_, a_));
   }

   /// @param value @c EINA_TRUE to use Inwin, @c EINA_FALSE to use a normal window
   ///
   bool inwin_mode_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_inwin_mode_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param value @c EINA_TRUE to use Inwin, @c EINA_FALSE to use a normal window
   ///
   void inwin_mode_set(bool value_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_web_inwin_mode_set(efl::eolian::to_c(value_)));
   }

   /// @param propagate Whether to propagate Tab keys to Elementary or not
   ///
   bool tab_propagate_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_tab_propagate_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param propagate Whether to propagate Tab keys to Elementary or not
   ///
   void tab_propagate_set(bool propagate_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_web_tab_propagate_set(efl::eolian::to_c(propagate_)));
   }

   /// @param enable Whether to enable or disable the browsing history
   ///
   bool history_enabled_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_history_enabled_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param enable Whether to enable or disable the browsing history
   ///
   void history_enabled_set(bool enable_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_web_history_enabled_set(efl::eolian::to_c(enable_)));
   }

   /// @param mode The mode to set
   ///
   Elm_Web_Zoom_Mode zoom_mode_get() const
   {
      Elm_Web_Zoom_Mode _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_zoom_mode_get());
      return _tmp_ret;
   }

   /// @param mode The mode to set
   ///
   void zoom_mode_set(Elm_Web_Zoom_Mode mode_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_web_zoom_mode_set(mode_));
   }

   /// @param zoom The zoom level to set
   ///
   double zoom_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_zoom_get());
      return _tmp_ret;
   }

   /// @param zoom The zoom level to set
   ///
   void zoom_set(double zoom_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_web_zoom_set(zoom_));
   }

   /// @param func The callback function to be used
   /// @param data User data
   ///
   void console_message_hook_set(Elm_Web_Console_Message func_, void * data_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_web_console_message_hook_set(func_, data_));
   }

   /// @param func The hook function to be called when a window is requested
   /// @param data User data
   ///
   void window_create_hook_set(Elm_Web_Window_Open func_, void * data_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_web_window_create_hook_set(func_, data_));
   }

   /// @param func The callback function to be used
   /// @param data User data
   ///
   void dialog_file_selector_hook_set(Elm_Web_Dialog_File_Selector func_, void * data_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_web_dialog_file_selector_hook_set(func_, data_));
   }

   /// @param func The callback function to be used
   /// @param data User data
   ///
   void dialog_confirm_hook_set(Elm_Web_Dialog_Confirm func_, void * data_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_web_dialog_confirm_hook_set(func_, data_));
   }

   /// @param idx The index selected
   ///
   void popup_selected_set(int idx_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_web_popup_selected_set(idx_));
   }

   /// @param func The callback function to be used
   /// @param data User data
   ///
   void dialog_prompt_hook_set(Elm_Web_Dialog_Prompt func_, void * data_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_web_dialog_prompt_hook_set(func_, data_));
   }

   /// @param func The callback function to be used
   /// @param data User data
   ///
   void dialog_alert_hook_set(Elm_Web_Dialog_Alert func_, void * data_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_web_dialog_alert_hook_set(func_, data_));
   }

   bool forward_possible_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_forward_possible_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   evas::object webkit_view_get() const
   {
      Evas_Object * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_webkit_view_get());
      return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
   }

   bool back_possible_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_back_possible_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   double load_progress_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_load_progress_get());
      return _tmp_ret;
   }

   std::string selection_get() const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_selection_get());
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   std::string title_get() const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_web_title_get());
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_uri_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WEB_EVENT_URI_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_web, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_web, function_type>,
         ELM_WEB_EVENT_URI_CHANGED );
   }

   template <typename T>
   void
   callback_uri_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_WEB_EVENT_URI_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_url_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WEB_EVENT_URL_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_web, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_web, function_type>,
         ELM_WEB_EVENT_URL_CHANGED );
   }

   template <typename T>
   void
   callback_url_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_WEB_EVENT_URL_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WEB_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_web, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_web, function_type>,
         ELM_WEB_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_WEB_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WEB_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_web, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_web, function_type>,
         ELM_WEB_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_WEB_EVENT_UNFOCUSED, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_WEB_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_WEB_CLASS, _p._eo_raw, eo_constructor());
   }

};
template <typename T>
bool _elm_web_navigate_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int steps_)
{
   return static_cast<T*>(self->this_)->navigate(steps_);
}

template <typename T>
bool _elm_web_back_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->back();
}

template <typename T>
bool _elm_web_html_string_load_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * html_, const char * base_url_, const char * unreachable_url_)
{
   return static_cast<T*>(self->this_)->html_string_load(efl::eolian::to_cxx<std::string>(html_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(base_url_, std::tuple<std::false_type>()), efl::eolian::to_cxx<std::string>(unreachable_url_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_web_text_search_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * string_, Eina_Bool case_sensitive_, Eina_Bool forward_, Eina_Bool wrap_)
{
   return static_cast<T*>(self->this_)->text_search(efl::eolian::to_cxx<std::string>(string_, std::tuple<std::false_type>()), efl::eolian::to_cxx<bool>(case_sensitive_, std::tuple<std::false_type>()), efl::eolian::to_cxx<bool>(forward_, std::tuple<std::false_type>()), efl::eolian::to_cxx<bool>(wrap_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_web_popup_destroy_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->popup_destroy();
}

template <typename T>
void _elm_web_region_show_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int x_, int y_, int w_, int h_)
{
   static_cast<T*>(self->this_)->region_show(x_, y_, w_, h_);
}

template <typename T>
bool _elm_web_forward_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->forward();
}

template <typename T>
unsigned int _elm_web_text_matches_mark_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * string_, Eina_Bool case_sensitive_, Eina_Bool highlight_, unsigned int limit_)
{
   return static_cast<T*>(self->this_)->text_matches_mark(efl::eolian::to_cxx<std::string>(string_, std::tuple<std::false_type>()), efl::eolian::to_cxx<bool>(case_sensitive_, std::tuple<std::false_type>()), efl::eolian::to_cxx<bool>(highlight_, std::tuple<std::false_type>()), limit_);
}

template <typename T>
void _elm_web_region_bring_in_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int x_, int y_, int w_, int h_)
{
   static_cast<T*>(self->this_)->region_bring_in(x_, y_, w_, h_);
}

template <typename T>
bool _elm_web_stop_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->stop();
}

template <typename T>
bool _elm_web_navigate_possible_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int steps_)
{
   return static_cast<T*>(self->this_)->navigate_possible_get(steps_);
}

template <typename T>
bool _elm_web_reload_full_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->reload_full();
}

template <typename T>
bool _elm_web_text_matches_unmark_all_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->text_matches_unmark_all();
}

template <typename T>
bool _elm_web_reload_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->reload();
}

template <typename T>
bool _elm_web_text_matches_highlight_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->text_matches_highlight_get();
}

template <typename T>
bool _elm_web_text_matches_highlight_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool highlight_)
{
   return static_cast<T*>(self->this_)->text_matches_highlight_set(efl::eolian::to_cxx<bool>(highlight_, std::tuple<std::false_type>()));
}

template <typename T>
std::string _elm_web_useragent_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->useragent_get();
}

template <typename T>
void _elm_web_useragent_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * user_agent_)
{
   static_cast<T*>(self->this_)->useragent_set(efl::eolian::to_cxx<std::string>(user_agent_, std::tuple<std::false_type>()));
}

template <typename T>
std::string _elm_web_url_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->url_get();
}

template <typename T>
bool _elm_web_url_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * url_)
{
   return static_cast<T*>(self->this_)->url_set(efl::eolian::to_cxx<std::string>(url_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_web_bg_color_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int* r_, int* g_, int* b_, int* a_)
{
   static_cast<T*>(self->this_)->bg_color_get(r_, g_, b_, a_);
}

template <typename T>
void _elm_web_bg_color_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int r_, int g_, int b_, int a_)
{
   static_cast<T*>(self->this_)->bg_color_set(r_, g_, b_, a_);
}

template <typename T>
bool _elm_web_inwin_mode_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->inwin_mode_get();
}

template <typename T>
void _elm_web_inwin_mode_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool value_)
{
   static_cast<T*>(self->this_)->inwin_mode_set(efl::eolian::to_cxx<bool>(value_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_web_tab_propagate_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->tab_propagate_get();
}

template <typename T>
void _elm_web_tab_propagate_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool propagate_)
{
   static_cast<T*>(self->this_)->tab_propagate_set(efl::eolian::to_cxx<bool>(propagate_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_web_history_enabled_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->history_enabled_get();
}

template <typename T>
void _elm_web_history_enabled_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool enable_)
{
   static_cast<T*>(self->this_)->history_enabled_set(efl::eolian::to_cxx<bool>(enable_, std::tuple<std::false_type>()));
}

template <typename T>
Elm_Web_Zoom_Mode _elm_web_zoom_mode_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->zoom_mode_get();
}

template <typename T>
void _elm_web_zoom_mode_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Web_Zoom_Mode mode_)
{
   static_cast<T*>(self->this_)->zoom_mode_set(mode_);
}

template <typename T>
double _elm_web_zoom_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->zoom_get();
}

template <typename T>
void _elm_web_zoom_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double zoom_)
{
   static_cast<T*>(self->this_)->zoom_set(zoom_);
}

template <typename T>
void _elm_web_console_message_hook_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Web_Console_Message func_, void * data_)
{
   static_cast<T*>(self->this_)->console_message_hook_set(func_, data_);
}

template <typename T>
void _elm_web_window_create_hook_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Web_Window_Open func_, void * data_)
{
   static_cast<T*>(self->this_)->window_create_hook_set(func_, data_);
}

template <typename T>
void _elm_web_dialog_file_selector_hook_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Web_Dialog_File_Selector func_, void * data_)
{
   static_cast<T*>(self->this_)->dialog_file_selector_hook_set(func_, data_);
}

template <typename T>
void _elm_web_dialog_confirm_hook_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Web_Dialog_Confirm func_, void * data_)
{
   static_cast<T*>(self->this_)->dialog_confirm_hook_set(func_, data_);
}

template <typename T>
void _elm_web_popup_selected_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int idx_)
{
   static_cast<T*>(self->this_)->popup_selected_set(idx_);
}

template <typename T>
void _elm_web_dialog_prompt_hook_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Web_Dialog_Prompt func_, void * data_)
{
   static_cast<T*>(self->this_)->dialog_prompt_hook_set(func_, data_);
}

template <typename T>
void _elm_web_dialog_alert_hook_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Web_Dialog_Alert func_, void * data_)
{
   static_cast<T*>(self->this_)->dialog_alert_hook_set(func_, data_);
}

template <typename T>
bool _elm_web_forward_possible_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->forward_possible_get();
}

template <typename T>
evas::object _elm_web_webkit_view_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->webkit_view_get();
}

template <typename T>
bool _elm_web_back_possible_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->back_possible_get();
}

template <typename T>
double _elm_web_load_progress_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->load_progress_get();
}

template <typename T>
std::string _elm_web_selection_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->selection_get();
}

template <typename T>
std::string _elm_web_title_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->title_get();
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_web >
{
   template <typename T>
   struct type
   {
      virtual bool navigate(int steps_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_navigate(steps_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool back()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_back());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool html_string_load(std::string html_, std::string base_url_, std::string unreachable_url_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_html_string_load(efl::eolian::to_c(html_), efl::eolian::to_c(base_url_), efl::eolian::to_c(unreachable_url_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool text_search(std::string string_, bool case_sensitive_, bool forward_, bool wrap_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_text_search(efl::eolian::to_c(string_), efl::eolian::to_c(case_sensitive_), efl::eolian::to_c(forward_), efl::eolian::to_c(wrap_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool popup_destroy()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_popup_destroy());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void region_show(int x_, int y_, int w_, int h_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_web_region_show(x_, y_, w_, h_));
      }

      virtual bool forward()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_forward());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual unsigned int text_matches_mark(std::string string_, bool case_sensitive_, bool highlight_, unsigned int limit_)
      {
         unsigned int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_text_matches_mark(efl::eolian::to_c(string_), efl::eolian::to_c(case_sensitive_), efl::eolian::to_c(highlight_), limit_));
            return _tmp_ret;
      }

      virtual void region_bring_in(int x_, int y_, int w_, int h_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_web_region_bring_in(x_, y_, w_, h_));
      }

      virtual bool stop()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_stop());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool navigate_possible_get(int steps_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_navigate_possible_get(steps_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool reload_full()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_reload_full());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool text_matches_unmark_all()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_text_matches_unmark_all());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool reload()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_reload());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool text_matches_highlight_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_text_matches_highlight_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool text_matches_highlight_set(bool highlight_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_text_matches_highlight_set(efl::eolian::to_c(highlight_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual std::string useragent_get()
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_useragent_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void useragent_set(std::string user_agent_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_web_useragent_set(efl::eolian::to_c(user_agent_)));
      }

      virtual std::string url_get()
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_url_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool url_set(std::string url_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_url_set(efl::eolian::to_c(url_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void bg_color_get(int* r_, int* g_, int* b_, int* a_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_web_bg_color_get(r_, g_, b_, a_));
      }

      virtual void bg_color_set(int r_, int g_, int b_, int a_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_web_bg_color_set(r_, g_, b_, a_));
      }

      virtual bool inwin_mode_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_inwin_mode_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void inwin_mode_set(bool value_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_web_inwin_mode_set(efl::eolian::to_c(value_)));
      }

      virtual bool tab_propagate_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_tab_propagate_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void tab_propagate_set(bool propagate_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_web_tab_propagate_set(efl::eolian::to_c(propagate_)));
      }

      virtual bool history_enabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_history_enabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void history_enabled_set(bool enable_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_web_history_enabled_set(efl::eolian::to_c(enable_)));
      }

      virtual Elm_Web_Zoom_Mode zoom_mode_get()
      {
         Elm_Web_Zoom_Mode _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_zoom_mode_get());
            return _tmp_ret;
      }

      virtual void zoom_mode_set(Elm_Web_Zoom_Mode mode_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_web_zoom_mode_set(mode_));
      }

      virtual double zoom_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_zoom_get());
            return _tmp_ret;
      }

      virtual void zoom_set(double zoom_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_web_zoom_set(zoom_));
      }

      virtual void console_message_hook_set(Elm_Web_Console_Message func_, void * data_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_web_console_message_hook_set(func_, data_));
      }

      virtual void window_create_hook_set(Elm_Web_Window_Open func_, void * data_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_web_window_create_hook_set(func_, data_));
      }

      virtual void dialog_file_selector_hook_set(Elm_Web_Dialog_File_Selector func_, void * data_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_web_dialog_file_selector_hook_set(func_, data_));
      }

      virtual void dialog_confirm_hook_set(Elm_Web_Dialog_Confirm func_, void * data_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_web_dialog_confirm_hook_set(func_, data_));
      }

      virtual void popup_selected_set(int idx_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_web_popup_selected_set(idx_));
      }

      virtual void dialog_prompt_hook_set(Elm_Web_Dialog_Prompt func_, void * data_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_web_dialog_prompt_hook_set(func_, data_));
      }

      virtual void dialog_alert_hook_set(Elm_Web_Dialog_Alert func_, void * data_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_web_dialog_alert_hook_set(func_, data_));
      }

      virtual bool forward_possible_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_forward_possible_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual evas::object webkit_view_get()
      {
         Evas_Object * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_webkit_view_get());
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual bool back_possible_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_back_possible_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual double load_progress_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_load_progress_get());
            return _tmp_ret;
      }

      virtual std::string selection_get()
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_selection_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual std::string title_get()
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_web_title_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

   };
};


template<>
struct operation_description_class_size< ::elm_web >
{
   static const int value = 45;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_web>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_web_navigate_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_web_navigate);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_web_back_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_web_back);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_web_html_string_load_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_web_html_string_load);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_web_text_search_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_web_text_search);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_web_popup_destroy_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_web_popup_destroy);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_web_region_show_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_web_region_show);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_web_forward_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_web_forward);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_web_text_matches_mark_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_web_text_matches_mark);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_web_region_bring_in_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_web_region_bring_in);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_web_stop_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_web_stop);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::_elm_web_navigate_possible_get_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::elm_obj_web_navigate_possible_get);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::_elm_web_reload_full_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::elm_obj_web_reload_full);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::_elm_web_text_matches_unmark_all_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::elm_obj_web_text_matches_unmark_all);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::_elm_web_reload_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::elm_obj_web_reload);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::_elm_web_text_matches_highlight_get_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::elm_obj_web_text_matches_highlight_get);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::_elm_web_text_matches_highlight_set_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::elm_obj_web_text_matches_highlight_set);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   ops[16].func = reinterpret_cast<void*>(& ::_elm_web_useragent_get_wrapper<T>);
   ops[16].api_func = reinterpret_cast<void*>(& ::elm_obj_web_useragent_get);
   ops[16].op = EO_OP_OVERRIDE;
   ops[16].op_type = EO_OP_TYPE_REGULAR;
   ops[16].doc = NULL;

   ops[17].func = reinterpret_cast<void*>(& ::_elm_web_useragent_set_wrapper<T>);
   ops[17].api_func = reinterpret_cast<void*>(& ::elm_obj_web_useragent_set);
   ops[17].op = EO_OP_OVERRIDE;
   ops[17].op_type = EO_OP_TYPE_REGULAR;
   ops[17].doc = NULL;

   ops[18].func = reinterpret_cast<void*>(& ::_elm_web_url_get_wrapper<T>);
   ops[18].api_func = reinterpret_cast<void*>(& ::elm_obj_web_url_get);
   ops[18].op = EO_OP_OVERRIDE;
   ops[18].op_type = EO_OP_TYPE_REGULAR;
   ops[18].doc = NULL;

   ops[19].func = reinterpret_cast<void*>(& ::_elm_web_url_set_wrapper<T>);
   ops[19].api_func = reinterpret_cast<void*>(& ::elm_obj_web_url_set);
   ops[19].op = EO_OP_OVERRIDE;
   ops[19].op_type = EO_OP_TYPE_REGULAR;
   ops[19].doc = NULL;

   ops[20].func = reinterpret_cast<void*>(& ::_elm_web_bg_color_get_wrapper<T>);
   ops[20].api_func = reinterpret_cast<void*>(& ::elm_obj_web_bg_color_get);
   ops[20].op = EO_OP_OVERRIDE;
   ops[20].op_type = EO_OP_TYPE_REGULAR;
   ops[20].doc = NULL;

   ops[21].func = reinterpret_cast<void*>(& ::_elm_web_bg_color_set_wrapper<T>);
   ops[21].api_func = reinterpret_cast<void*>(& ::elm_obj_web_bg_color_set);
   ops[21].op = EO_OP_OVERRIDE;
   ops[21].op_type = EO_OP_TYPE_REGULAR;
   ops[21].doc = NULL;

   ops[22].func = reinterpret_cast<void*>(& ::_elm_web_inwin_mode_get_wrapper<T>);
   ops[22].api_func = reinterpret_cast<void*>(& ::elm_obj_web_inwin_mode_get);
   ops[22].op = EO_OP_OVERRIDE;
   ops[22].op_type = EO_OP_TYPE_REGULAR;
   ops[22].doc = NULL;

   ops[23].func = reinterpret_cast<void*>(& ::_elm_web_inwin_mode_set_wrapper<T>);
   ops[23].api_func = reinterpret_cast<void*>(& ::elm_obj_web_inwin_mode_set);
   ops[23].op = EO_OP_OVERRIDE;
   ops[23].op_type = EO_OP_TYPE_REGULAR;
   ops[23].doc = NULL;

   ops[24].func = reinterpret_cast<void*>(& ::_elm_web_tab_propagate_get_wrapper<T>);
   ops[24].api_func = reinterpret_cast<void*>(& ::elm_obj_web_tab_propagate_get);
   ops[24].op = EO_OP_OVERRIDE;
   ops[24].op_type = EO_OP_TYPE_REGULAR;
   ops[24].doc = NULL;

   ops[25].func = reinterpret_cast<void*>(& ::_elm_web_tab_propagate_set_wrapper<T>);
   ops[25].api_func = reinterpret_cast<void*>(& ::elm_obj_web_tab_propagate_set);
   ops[25].op = EO_OP_OVERRIDE;
   ops[25].op_type = EO_OP_TYPE_REGULAR;
   ops[25].doc = NULL;

   ops[26].func = reinterpret_cast<void*>(& ::_elm_web_history_enabled_get_wrapper<T>);
   ops[26].api_func = reinterpret_cast<void*>(& ::elm_obj_web_history_enabled_get);
   ops[26].op = EO_OP_OVERRIDE;
   ops[26].op_type = EO_OP_TYPE_REGULAR;
   ops[26].doc = NULL;

   ops[27].func = reinterpret_cast<void*>(& ::_elm_web_history_enabled_set_wrapper<T>);
   ops[27].api_func = reinterpret_cast<void*>(& ::elm_obj_web_history_enabled_set);
   ops[27].op = EO_OP_OVERRIDE;
   ops[27].op_type = EO_OP_TYPE_REGULAR;
   ops[27].doc = NULL;

   ops[28].func = reinterpret_cast<void*>(& ::_elm_web_zoom_mode_get_wrapper<T>);
   ops[28].api_func = reinterpret_cast<void*>(& ::elm_obj_web_zoom_mode_get);
   ops[28].op = EO_OP_OVERRIDE;
   ops[28].op_type = EO_OP_TYPE_REGULAR;
   ops[28].doc = NULL;

   ops[29].func = reinterpret_cast<void*>(& ::_elm_web_zoom_mode_set_wrapper<T>);
   ops[29].api_func = reinterpret_cast<void*>(& ::elm_obj_web_zoom_mode_set);
   ops[29].op = EO_OP_OVERRIDE;
   ops[29].op_type = EO_OP_TYPE_REGULAR;
   ops[29].doc = NULL;

   ops[30].func = reinterpret_cast<void*>(& ::_elm_web_zoom_get_wrapper<T>);
   ops[30].api_func = reinterpret_cast<void*>(& ::elm_obj_web_zoom_get);
   ops[30].op = EO_OP_OVERRIDE;
   ops[30].op_type = EO_OP_TYPE_REGULAR;
   ops[30].doc = NULL;

   ops[31].func = reinterpret_cast<void*>(& ::_elm_web_zoom_set_wrapper<T>);
   ops[31].api_func = reinterpret_cast<void*>(& ::elm_obj_web_zoom_set);
   ops[31].op = EO_OP_OVERRIDE;
   ops[31].op_type = EO_OP_TYPE_REGULAR;
   ops[31].doc = NULL;

   ops[32].func = reinterpret_cast<void*>(& ::_elm_web_console_message_hook_set_wrapper<T>);
   ops[32].api_func = reinterpret_cast<void*>(& ::elm_obj_web_console_message_hook_set);
   ops[32].op = EO_OP_OVERRIDE;
   ops[32].op_type = EO_OP_TYPE_REGULAR;
   ops[32].doc = NULL;

   ops[33].func = reinterpret_cast<void*>(& ::_elm_web_window_create_hook_set_wrapper<T>);
   ops[33].api_func = reinterpret_cast<void*>(& ::elm_obj_web_window_create_hook_set);
   ops[33].op = EO_OP_OVERRIDE;
   ops[33].op_type = EO_OP_TYPE_REGULAR;
   ops[33].doc = NULL;

   ops[34].func = reinterpret_cast<void*>(& ::_elm_web_dialog_file_selector_hook_set_wrapper<T>);
   ops[34].api_func = reinterpret_cast<void*>(& ::elm_obj_web_dialog_file_selector_hook_set);
   ops[34].op = EO_OP_OVERRIDE;
   ops[34].op_type = EO_OP_TYPE_REGULAR;
   ops[34].doc = NULL;

   ops[35].func = reinterpret_cast<void*>(& ::_elm_web_dialog_confirm_hook_set_wrapper<T>);
   ops[35].api_func = reinterpret_cast<void*>(& ::elm_obj_web_dialog_confirm_hook_set);
   ops[35].op = EO_OP_OVERRIDE;
   ops[35].op_type = EO_OP_TYPE_REGULAR;
   ops[35].doc = NULL;

   ops[36].func = reinterpret_cast<void*>(& ::_elm_web_popup_selected_set_wrapper<T>);
   ops[36].api_func = reinterpret_cast<void*>(& ::elm_obj_web_popup_selected_set);
   ops[36].op = EO_OP_OVERRIDE;
   ops[36].op_type = EO_OP_TYPE_REGULAR;
   ops[36].doc = NULL;

   ops[37].func = reinterpret_cast<void*>(& ::_elm_web_dialog_prompt_hook_set_wrapper<T>);
   ops[37].api_func = reinterpret_cast<void*>(& ::elm_obj_web_dialog_prompt_hook_set);
   ops[37].op = EO_OP_OVERRIDE;
   ops[37].op_type = EO_OP_TYPE_REGULAR;
   ops[37].doc = NULL;

   ops[38].func = reinterpret_cast<void*>(& ::_elm_web_dialog_alert_hook_set_wrapper<T>);
   ops[38].api_func = reinterpret_cast<void*>(& ::elm_obj_web_dialog_alert_hook_set);
   ops[38].op = EO_OP_OVERRIDE;
   ops[38].op_type = EO_OP_TYPE_REGULAR;
   ops[38].doc = NULL;

   ops[39].func = reinterpret_cast<void*>(& ::_elm_web_forward_possible_get_wrapper<T>);
   ops[39].api_func = reinterpret_cast<void*>(& ::elm_obj_web_forward_possible_get);
   ops[39].op = EO_OP_OVERRIDE;
   ops[39].op_type = EO_OP_TYPE_REGULAR;
   ops[39].doc = NULL;

   ops[40].func = reinterpret_cast<void*>(& ::_elm_web_webkit_view_get_wrapper<T>);
   ops[40].api_func = reinterpret_cast<void*>(& ::elm_obj_web_webkit_view_get);
   ops[40].op = EO_OP_OVERRIDE;
   ops[40].op_type = EO_OP_TYPE_REGULAR;
   ops[40].doc = NULL;

   ops[41].func = reinterpret_cast<void*>(& ::_elm_web_back_possible_get_wrapper<T>);
   ops[41].api_func = reinterpret_cast<void*>(& ::elm_obj_web_back_possible_get);
   ops[41].op = EO_OP_OVERRIDE;
   ops[41].op_type = EO_OP_TYPE_REGULAR;
   ops[41].doc = NULL;

   ops[42].func = reinterpret_cast<void*>(& ::_elm_web_load_progress_get_wrapper<T>);
   ops[42].api_func = reinterpret_cast<void*>(& ::elm_obj_web_load_progress_get);
   ops[42].op = EO_OP_OVERRIDE;
   ops[42].op_type = EO_OP_TYPE_REGULAR;
   ops[42].doc = NULL;

   ops[43].func = reinterpret_cast<void*>(& ::_elm_web_selection_get_wrapper<T>);
   ops[43].api_func = reinterpret_cast<void*>(& ::elm_obj_web_selection_get);
   ops[43].op = EO_OP_OVERRIDE;
   ops[43].op_type = EO_OP_TYPE_REGULAR;
   ops[43].doc = NULL;

   ops[44].func = reinterpret_cast<void*>(& ::_elm_web_title_get_wrapper<T>);
   ops[44].api_func = reinterpret_cast<void*>(& ::elm_obj_web_title_get);
   ops[44].op = EO_OP_OVERRIDE;
   ops[44].op_type = EO_OP_TYPE_REGULAR;
   ops[44].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_web >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_web, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_web >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_web, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_web>
{
   template <typename U>
   struct type
   {
      operator ::elm_web() const
      {
         return ::elm_web(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      bool navigate(int steps_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_navigate(steps_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool back()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_back());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool html_string_load(std::string html_, std::string base_url_, std::string unreachable_url_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_html_string_load(efl::eolian::to_c(html_), efl::eolian::to_c(base_url_), efl::eolian::to_c(unreachable_url_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool text_search(std::string string_, bool case_sensitive_, bool forward_, bool wrap_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_text_search(efl::eolian::to_c(string_), efl::eolian::to_c(case_sensitive_), efl::eolian::to_c(forward_), efl::eolian::to_c(wrap_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool popup_destroy()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_popup_destroy());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void region_show(int x_, int y_, int w_, int h_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_web_region_show(x_, y_, w_, h_));
      }

      bool forward()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_forward());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      unsigned int text_matches_mark(std::string string_, bool case_sensitive_, bool highlight_, unsigned int limit_)
      {
         unsigned int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_text_matches_mark(efl::eolian::to_c(string_), efl::eolian::to_c(case_sensitive_), efl::eolian::to_c(highlight_), limit_));
            return _tmp_ret;
      }

      void region_bring_in(int x_, int y_, int w_, int h_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_web_region_bring_in(x_, y_, w_, h_));
      }

      bool stop()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_stop());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool navigate_possible_get(int steps_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_navigate_possible_get(steps_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool reload_full()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_reload_full());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool text_matches_unmark_all()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_text_matches_unmark_all());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool reload()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_reload());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool text_matches_highlight_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_text_matches_highlight_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool text_matches_highlight_set(bool highlight_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_text_matches_highlight_set(efl::eolian::to_c(highlight_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      std::string useragent_get()
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_useragent_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      void useragent_set(std::string user_agent_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_web_useragent_set(efl::eolian::to_c(user_agent_)));
      }

      std::string url_get()
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_url_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool url_set(std::string url_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_url_set(efl::eolian::to_c(url_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void bg_color_get(int* r_, int* g_, int* b_, int* a_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_web_bg_color_get(r_, g_, b_, a_));
      }

      void bg_color_set(int r_, int g_, int b_, int a_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_web_bg_color_set(r_, g_, b_, a_));
      }

      bool inwin_mode_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_inwin_mode_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void inwin_mode_set(bool value_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_web_inwin_mode_set(efl::eolian::to_c(value_)));
      }

      bool tab_propagate_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_tab_propagate_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void tab_propagate_set(bool propagate_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_web_tab_propagate_set(efl::eolian::to_c(propagate_)));
      }

      bool history_enabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_history_enabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void history_enabled_set(bool enable_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_web_history_enabled_set(efl::eolian::to_c(enable_)));
      }

      Elm_Web_Zoom_Mode zoom_mode_get()
      {
         Elm_Web_Zoom_Mode _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_zoom_mode_get());
            return _tmp_ret;
      }

      void zoom_mode_set(Elm_Web_Zoom_Mode mode_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_web_zoom_mode_set(mode_));
      }

      double zoom_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_zoom_get());
            return _tmp_ret;
      }

      void zoom_set(double zoom_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_web_zoom_set(zoom_));
      }

      void console_message_hook_set(Elm_Web_Console_Message func_, void * data_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_web_console_message_hook_set(func_, data_));
      }

      void window_create_hook_set(Elm_Web_Window_Open func_, void * data_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_web_window_create_hook_set(func_, data_));
      }

      void dialog_file_selector_hook_set(Elm_Web_Dialog_File_Selector func_, void * data_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_web_dialog_file_selector_hook_set(func_, data_));
      }

      void dialog_confirm_hook_set(Elm_Web_Dialog_Confirm func_, void * data_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_web_dialog_confirm_hook_set(func_, data_));
      }

      void popup_selected_set(int idx_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_web_popup_selected_set(idx_));
      }

      void dialog_prompt_hook_set(Elm_Web_Dialog_Prompt func_, void * data_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_web_dialog_prompt_hook_set(func_, data_));
      }

      void dialog_alert_hook_set(Elm_Web_Dialog_Alert func_, void * data_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_web_dialog_alert_hook_set(func_, data_));
      }

      bool forward_possible_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_forward_possible_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      evas::object webkit_view_get()
      {
         Evas_Object * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_webkit_view_get());
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      bool back_possible_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_back_possible_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      double load_progress_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_load_progress_get());
            return _tmp_ret;
      }

      std::string selection_get()
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_selection_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      std::string title_get()
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_web_title_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_uri_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WEB_EVENT_URI_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_web, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_web, function_type>,
         ELM_WEB_EVENT_URI_CHANGED );
   }

   template <typename T>
   void
   callback_uri_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_WEB_EVENT_URI_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_url_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WEB_EVENT_URL_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_web, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_web, function_type>,
         ELM_WEB_EVENT_URL_CHANGED );
   }

   template <typename T>
   void
   callback_url_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_WEB_EVENT_URL_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WEB_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_web, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_web, function_type>,
         ELM_WEB_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_WEB_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WEB_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_web, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_web, function_type>,
         ELM_WEB_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_WEB_EVENT_UNFOCUSED, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_web>)
{
   return (ELM_WEB_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_WEB_HH

