#ifndef EFL_GENERATED_ELM_WIN_HH
#define EFL_GENERATED_ELM_WIN_HH

#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "elm_win.eo.h"
}

#include "elm_widget.eo.hh"
#include "elm_interface_atspi_window.eo.hh"
#include "elm_interface_atspi_widget_action.eo.hh"
#include <canvas/evas_object.eo.hh>
#include <string>

struct elm_win
      : elm_widget,
      efl::eo::detail::extension_inheritance<elm_interface_atspi_window>::template type< ::elm_win>,
      efl::eo::detail::extension_inheritance<elm_interface_atspi_widget_action>::template type< ::elm_win>

{
   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit elm_win(Eo* eo)
      : elm_widget(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit elm_win(std::nullptr_t)
      : elm_widget(nullptr)
   {}

   elm_win(efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_win(_c0(_p))
   {}

   /// @param name 
   /// @param type 
   ///
   elm_win(std::string name_, Elm_Win_Type type_, efl::eo::parent_type _p = (efl::eo::parent = nullptr))
      : elm_win(_c1(name_, type_, _p))
   {}

   /// @brief Copy Constructor.
   ///
   elm_win(elm_win const& other)
      : elm_widget(eo_ref(other._eo_ptr()))
   {}

   ~elm_win() {}

   /// @brief To notify the rotation done to WM manually.
   ///
   /// This function is used to notify the rotation done to WM manually.
   ///
   /// @see elm_win_wm_rotation_manual_rotation_done_set()
   /// @see elm_win_wm_rotation_manual_rotation_done_get()
   ///
   /// ingroup Win
   /// @since 1.9
   ///
   void wm_manual_rotation_done() const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_wm_manual_rotation_done());
   }

   /// @brief Create a socket to provide the service for Plug widget
   ///
   /// @return If socket creation is successful
   ///
   /// @ingroup Win
   ///
   /// @param svcname The name of the service to be advertised. ensure that it is unique (when combined with @p svcnum) otherwise creation may fail.
   /// @param svcnum A number (any value, 0 being the common default) to differentiate multiple instances of services with the same name.
   /// @param svcsys A boolean that if true, specifies to create a system-wide service all users can connect to, otherwise the service is private to the user id that created the service.
   ///
   bool socket_listen(std::string svcname_, int svcnum_, bool svcsys_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_socket_listen(efl::eolian::to_c(svcname_), svcnum_, efl::eolian::to_c(svcsys_)));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @brief Send a command to the windowing environment
   ///
   /// This is intended to work in touchscreen or small screen device
   /// environments where there is a more simplistic window management policy in
   /// place. This uses the window object indicated to select which part of the
   /// environment to control (the part that this window lives in), and provides
   /// a command and an optional parameter structure (use NULL for this if not
   /// needed).
   ///
   /// @ingroup Win
   ///
   /// @param command The command to send
   /// @param params Optional parameters for the command
   ///
   void illume_command_send(Elm_Illume_Command command_, void * params_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_illume_command_send(command_, params_));
   }

   /// @brief Activate a window object.
   ///
   /// This function sends a request to the Window Manager to activate the
   /// window pointed by @p obj. If honored by the WM, the window will receive
   /// the keyboard focus.
   ///
   /// @note This is just a request that a Window Manager may ignore, so calling
   /// this function does not ensure in any way that the window will be the
   /// active one after it.
   ///
   /// @ingroup Win
   ///
   void activate() const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_activate());
   }

   /// @brief Add @p subobj as a resize object of window @p obj.
   ///
   ///
   /// Setting an object as a resize object of the window means that the
   /// @p subobj child's size and position will be controlled by the window
   /// directly. That is, the object will be resized to match the window size
   /// and should never be moved or resized manually by the developer.
   ///
   /// In addition, resize objects of the window control what the minimum size
   /// of it will be, as well as whether it can or not be resized by the user.
   ///
   /// For the end user to be able to resize a window by dragging the handles
   /// or borders provided by the Window Manager, or using any other similar
   /// mechanism, all of the resize objects in the window should have their
   /// evas_object_size_hint_weight_set() set to EVAS_HINT_EXPAND.
   ///
   /// Also notice that the window can get resized to the current size of the
   /// object if the EVAS_HINT_EXPAND is set @b after the call to
   /// elm_win_resize_object_add(). So if the object should get resized to the
   /// size of the window, set this hint @b before adding it as a resize object
   /// (this happens because the size of the window and the object are evaluated
   /// as soon as the object is added to the window).
   ///
   /// @ingroup Win
   ///
   /// @param subobj The resize object to add
   ///
   void resize_object_add(evas::object subobj_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_resize_object_add(efl::eolian::to_c(subobj_)));
   }

   /// @brief Raise a window object.
   ///
   /// Places the window pointed by @p obj at the top of the stack, so that it's
   /// not covered by any other window.
   ///
   /// If elm_win_override_set() is not set, the Window Manager may ignore this
   /// request.
   ///
   /// @ingroup Win
   ///
   void raise() const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_raise());
   }

   /// @brief Lower a window object.
   ///
   /// Places the window pointed by @p obj at the bottom of the stack, so that
   /// no other window is covered by it.
   ///
   /// If elm_win_override_set() is not set, the Window Manager may ignore this
   /// request.
   ///
   /// @ingroup Win
   ///
   void lower() const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_lower());
   }

   /// @brief Delete @p subobj as a resize object of window @p obj.
   ///
   /// This function removes the object @p subobj from the resize objects of
   /// the window @p obj. It will not delete the object itself, which will be
   /// left unmanaged and should be deleted by the developer, manually handled
   /// or set as child of some other container.
   ///
   /// @ingroup Win
   ///
   /// @param subobj The resize object to add
   ///
   void resize_object_del(evas::object subobj_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_resize_object_del(efl::eolian::to_c(subobj_)));
   }

   /// @brief Center a window on its screen
   ///
   /// This function centers window @p obj horizontally and/or vertically based on the values
   /// of @p h and @p v.
   /// @ingroup Win
   ///
   /// @param h If true, center horizontally. If false, do not change horizontal location.
   /// @param v If true, center vertically. If false, do not change vertical location.
   ///
   void center(bool h_, bool v_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_center(efl::eolian::to_c(h_), efl::eolian::to_c(v_)));
   }

   /// @param is_keyboard If true, the window is a virtual keyboard
   ///
   bool keyboard_win_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_keyboard_win_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param is_keyboard If true, the window is a virtual keyboard
   ///
   void keyboard_win_set(bool is_keyboard_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_keyboard_win_set(efl::eolian::to_c(is_keyboard_)));
   }

   /// @param autodel If true, the window will automatically delete itself when
   /// closed
   ///
   bool autodel_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_autodel_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param autodel If true, the window will automatically delete itself when
   /// closed
   ///
   void autodel_set(bool autodel_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_autodel_set(efl::eolian::to_c(autodel_)));
   }

   /// @param override If true, the window is overridden
   ///
   bool override_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_override_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param override If true, the window is overridden
   ///
   void override_set(bool override_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_override_set(efl::eolian::to_c(override_)));
   }

   /// @param iconified If true, the window is iconified
   ///
   bool iconified_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_iconified_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param iconified If true, the window is iconified
   ///
   void iconified_set(bool iconified_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_iconified_set(efl::eolian::to_c(iconified_)));
   }

   /// @param rotations The array of rotation value.
   /// @param count The number of array of rotations
   ///
   bool wm_available_rotations_get(int ** rotations_, unsigned int* count_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_wm_available_rotations_get(rotations_, count_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param rotations The array of rotation value.
   /// @param count The number of array of rotations
   ///
   void wm_available_rotations_set(const int * rotations_, unsigned int count_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_wm_available_rotations_set(rotations_, count_));
   }

   /// @param zone The requested zone for this quickpanel
   ///
   int quickpanel_zone_get() const
   {
      int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_quickpanel_zone_get());
      return _tmp_ret;
   }

   /// @param zone The requested zone for this quickpanel
   ///
   void quickpanel_zone_set(int zone_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_quickpanel_zone_set(zone_));
   }

   /// @param maximized If true, the window is maximized
   ///
   bool maximized_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_maximized_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param maximized If true, the window is maximized
   ///
   void maximized_set(bool maximized_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_maximized_set(efl::eolian::to_c(maximized_)));
   }

   /// @param modal If true, the window is modal
   ///
   bool modal_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_modal_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param modal If true, the window is modal
   ///
   void modal_set(bool modal_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_modal_set(efl::eolian::to_c(modal_)));
   }

   /// @param icon_name The icon name to set
   ///
   std::string icon_name_get() const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_icon_name_get());
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param icon_name The icon name to set
   ///
   void icon_name_set(std::string icon_name_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_icon_name_set(efl::eolian::to_c(icon_name_)));
   }

   /// @param withdrawn If true, the window is withdrawn
   ///
   bool withdrawn_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_withdrawn_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param withdrawn If true, the window is withdrawn
   ///
   void withdrawn_set(bool withdrawn_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_withdrawn_set(efl::eolian::to_c(withdrawn_)));
   }

   /// @param role The role to set
   ///
   std::string role_get() const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_role_get());
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param role The role to set
   ///
   void role_set(std::string role_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_role_set(efl::eolian::to_c(role_)));
   }

   /// @param w The stepping width (0 disables)
   /// @param h The stepping height (0 disables)
   ///
   void size_step_get(int* w_, int* h_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_size_step_get(w_, h_));
   }

   /// @param w The stepping width (0 disables)
   /// @param h The stepping height (0 disables)
   ///
   void size_step_set(int w_, int h_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_size_step_set(w_, h_));
   }

   /// @param style The style to set
   ///
   std::string focus_highlight_style_get() const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_focus_highlight_style_get());
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param style The style to set
   ///
   void focus_highlight_style_set(std::string style_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_focus_highlight_style_set(efl::eolian::to_c(style_)));
   }

   /// @param borderless If true, the window is borderless
   ///
   bool borderless_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_borderless_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param borderless If true, the window is borderless
   ///
   void borderless_set(bool borderless_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_borderless_set(efl::eolian::to_c(borderless_)));
   }

   /// @param constrain EINA_TRUE to restrict the window's maximum size, EINA_FALSE to disable restriction
   ///
   bool screen_constrain_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_screen_constrain_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param constrain EINA_TRUE to restrict the window's maximum size, EINA_FALSE to disable restriction
   ///
   void screen_constrain_set(bool constrain_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_screen_constrain_set(efl::eolian::to_c(constrain_)));
   }

   /// @param profiles The string array of available profiles
   /// @param count The number of members in profiles
   ///
   bool available_profiles_get(char *** profiles_, unsigned int* count_) const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_available_profiles_get(profiles_, count_));
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param profiles The string array of available profiles
   /// @param count The number of members in profiles
   ///
   void available_profiles_set(const char ** profiles_, unsigned int count_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_available_profiles_set(profiles_, count_));
   }

   /// @param enabled The enabled value for the highlight
   ///
   bool focus_highlight_enabled_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_focus_highlight_enabled_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param enabled The enabled value for the highlight
   ///
   void focus_highlight_enabled_set(bool enabled_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_focus_highlight_enabled_set(efl::eolian::to_c(enabled_)));
   }

   /// @param title The title to set
   ///
   std::string title_get() const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_title_get());
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param title The title to set
   ///
   void title_set(std::string title_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_title_set(efl::eolian::to_c(title_)));
   }

   /// @param alpha EINA_TRUE if the window alpha channel is enabled, EINA_FALSE otherwise
   ///
   bool alpha_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_alpha_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param alpha EINA_TRUE if the window alpha channel is enabled, EINA_FALSE otherwise
   ///
   void alpha_set(bool alpha_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_alpha_set(efl::eolian::to_c(alpha_)));
   }

   /// @param urgent If true, the window is urgent
   ///
   bool urgent_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_urgent_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param urgent If true, the window is urgent
   ///
   void urgent_set(bool urgent_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_urgent_set(efl::eolian::to_c(urgent_)));
   }

   /// @param rotation The rotation of the window, in degrees (0-360),
   /// counter-clockwise.
   ///
   int rotation_get() const
   {
      int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_rotation_get());
      return _tmp_ret;
   }

   /// @param rotation The rotation of the window, in degrees (0-360),
   /// counter-clockwise.
   ///
   void rotation_set(int rotation_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_rotation_set(rotation_));
   }

   /// @param icon The Evas image object to use for an icon
   ///
   const evas::object icon_object_get() const
   {
      const Evas_Object * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_icon_object_get());
      return efl::eolian::to_cxx<const evas::object>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param icon The Evas image object to use for an icon
   ///
   void icon_object_set(evas::object icon_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_icon_object_set(efl::eolian::to_c(icon_)));
   }

   /// @param priority The minor priority for this quickpanel
   ///
   int quickpanel_priority_minor_get() const
   {
      int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_quickpanel_priority_minor_get());
      return _tmp_ret;
   }

   /// @param priority The minor priority for this quickpanel
   ///
   void quickpanel_priority_minor_set(int priority_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_quickpanel_priority_minor_set(priority_));
   }

   /// @param sticky If true, the window's sticky state is enabled
   ///
   bool sticky_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_sticky_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param sticky If true, the window's sticky state is enabled
   ///
   void sticky_set(bool sticky_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_sticky_set(efl::eolian::to_c(sticky_)));
   }

   /// @param mode The mode to set, one of #Elm_Win_Keyboard_Mode
   ///
   Elm_Win_Keyboard_Mode keyboard_mode_get() const
   {
      Elm_Win_Keyboard_Mode _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_keyboard_mode_get());
      return _tmp_ret;
   }

   /// @param mode The mode to set, one of #Elm_Win_Keyboard_Mode
   ///
   void keyboard_mode_set(Elm_Win_Keyboard_Mode mode_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_keyboard_mode_set(mode_));
   }

   /// @param animate The enabled value for the highlight animation
   ///
   bool focus_highlight_animate_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_focus_highlight_animate_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param animate The enabled value for the highlight animation
   ///
   void focus_highlight_animate_set(bool animate_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_focus_highlight_animate_set(efl::eolian::to_c(animate_)));
   }

   /// @param aspect If 0, the window has no aspect limits, otherwise it is
   /// width divided by height
   ///
   double aspect_get() const
   {
      double _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_aspect_get());
      return _tmp_ret;
   }

   /// @param aspect If 0, the window has no aspect limits, otherwise it is
   /// width divided by height
   ///
   void aspect_set(double aspect_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_aspect_set(aspect_));
   }

   /// @param priority The major priority for this quickpanel
   ///
   int quickpanel_priority_major_get() const
   {
      int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_quickpanel_priority_major_get());
      return _tmp_ret;
   }

   /// @param priority The major priority for this quickpanel
   ///
   void quickpanel_priority_major_set(int priority_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_quickpanel_priority_major_set(priority_));
   }

   /// @param mode The mode to set, one of #Elm_Win_Indicator_Opacity_Mode
   ///
   Elm_Win_Indicator_Opacity_Mode indicator_opacity_get() const
   {
      Elm_Win_Indicator_Opacity_Mode _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_indicator_opacity_get());
      return _tmp_ret;
   }

   /// @param mode The mode to set, one of #Elm_Win_Indicator_Opacity_Mode
   ///
   void indicator_opacity_set(Elm_Win_Indicator_Opacity_Mode mode_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_indicator_opacity_set(mode_));
   }

   /// @param demand_attention If true, the window is demand_attention
   ///
   bool demand_attention_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_demand_attention_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param demand_attention If true, the window is demand_attention
   ///
   void demand_attention_set(bool demand_attention_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_demand_attention_set(efl::eolian::to_c(demand_attention_)));
   }

   /// @param rotation The preferred rotation of the window in degrees (0-360),
   /// counter-clockwise.
   ///
   int wm_preferred_rotation_get() const
   {
      int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_wm_preferred_rotation_get());
      return _tmp_ret;
   }

   /// @param rotation The preferred rotation of the window in degrees (0-360),
   /// counter-clockwise.
   ///
   void wm_preferred_rotation_set(int rotation_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_wm_preferred_rotation_set(rotation_));
   }

   /// @param layer The layer of the window
   ///
   int layer_get() const
   {
      int _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_layer_get());
      return _tmp_ret;
   }

   /// @param layer The layer of the window
   ///
   void layer_set(int layer_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_layer_set(layer_));
   }

   /// @param profile The string value of a window profile
   ///
   std::string profile_get() const
   {
      const char * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_profile_get());
      return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param profile The string value of a window profile
   ///
   void profile_set(std::string profile_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_profile_set(efl::eolian::to_c(profile_)));
   }

   /// @param shaped If true, the window is shaped
   ///
   bool shaped_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_shaped_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param shaped If true, the window is shaped
   ///
   void shaped_set(bool shaped_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_shaped_set(efl::eolian::to_c(shaped_)));
   }

   /// @param fullscreen If true, the window is fullscreen
   ///
   bool fullscreen_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_fullscreen_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param fullscreen If true, the window is fullscreen
   ///
   void fullscreen_set(bool fullscreen_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_fullscreen_set(efl::eolian::to_c(fullscreen_)));
   }

   /// @param set EINA_TRUE means to set manual rotation done mode EINA_FALSE otherwise.
   ///
   bool wm_manual_rotation_done_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_wm_manual_rotation_done_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param set EINA_TRUE means to set manual rotation done mode EINA_FALSE otherwise.
   ///
   void wm_manual_rotation_done_set(bool set_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_wm_manual_rotation_done_set(efl::eolian::to_c(set_)));
   }

   /// @param mode The mode to set, one of #Elm_Win_Indicator_Mode
   ///
   Elm_Win_Indicator_Mode indicator_mode_get() const
   {
      Elm_Win_Indicator_Mode _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_indicator_mode_get());
      return _tmp_ret;
   }

   /// @param mode The mode to set, one of #Elm_Win_Indicator_Mode
   ///
   void indicator_mode_set(Elm_Win_Indicator_Mode mode_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_indicator_mode_set(mode_));
   }

   /// @param conformant The conformant flag (1 = conformant, 0 = non-conformant)
   ///
   bool conformant_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_conformant_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param conformant The conformant flag (1 = conformant, 0 = non-conformant)
   ///
   void conformant_set(bool conformant_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_conformant_set(efl::eolian::to_c(conformant_)));
   }

   /// @param w The base width
   /// @param h The base height
   ///
   void size_base_get(int* w_, int* h_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_size_base_get(w_, h_));
   }

   /// @param w The base width
   /// @param h The base height
   ///
   void size_base_set(int w_, int h_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_size_base_set(w_, h_));
   }

   /// @param quickpanel The quickpanel flag (1 = quickpanel, 0 = normal window)
   ///
   bool quickpanel_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_quickpanel_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param quickpanel The quickpanel flag (1 = quickpanel, 0 = normal window)
   ///
   void quickpanel_set(bool quickpanel_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_quickpanel_set(efl::eolian::to_c(quickpanel_)));
   }

   /// @param rotation The rotation of the window in degrees (0-360),
   /// counter-clockwise.
   ///
   void rotation_with_resize_set(int rotation_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_rotation_with_resize_set(rotation_));
   }

   /// @param skip The skip flag state (EINA_TRUE if it is to be skipped)
   ///
   void prop_focus_skip_set(bool skip_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_prop_focus_skip_set(efl::eolian::to_c(skip_)));
   }

   /// @param x The int to store the x coordinate to
   /// @param y The int to store the y coordinate to
   ///
   void screen_position_get(int* x_, int* y_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_screen_position_get(x_, y_));
   }

   bool wm_rotation_supported_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_wm_rotation_supported_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   Ecore_X_Window xwindow_get() const
   {
      Ecore_X_Window _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_xwindow_get());
      return _tmp_ret;
   }

   bool focus_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_focus_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param x where to return the horizontal offset value. May be NULL.
   /// @param y where to return the vertical offset value. May be NULL.
   /// @param w where to return the width value. May be NULL.
   /// @param h where to return the height value. May be NULL.
   ///
   void screen_size_get(int* x_, int* y_, int* w_, int* h_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_screen_size_get(x_, y_, w_, h_));
   }

   evas::object main_menu_get() const
   {
      Evas_Object * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_main_menu_get());
      return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
   }

   Ecore_Wl_Window * wl_window_get() const
   {
      Ecore_Wl_Window * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_wl_window_get());
      return _tmp_ret;
   }

   Ecore_Window window_id_get() const
   {
      Ecore_Window _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_window_id_get());
      return _tmp_ret;
   }

   /// @param xdpi Pointer to value to store return horizontal dpi. May be NULL.
   /// @param ydpi Pointer to value to store return vertical dpi. May be NULL.
   ///
   void screen_dpi_get(int* xdpi_, int* ydpi_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_screen_dpi_get(xdpi_, ydpi_));
   }

   evas::object inlined_image_object_get() const
   {
      Evas_Object * _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_inlined_image_object_get());
      return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
   }

   Elm_Win_Type type_get() const
   {
      Elm_Win_Type _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_type_get());
      return _tmp_ret;
   }

   /// @param noblank If true, the window is set to noblank
   ///
   bool noblank_get() const
   {
      Eina_Bool _tmp_ret;
      eo_do(_eo_ptr(), _tmp_ret = ::elm_obj_win_noblank_get());
      return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
   }

   /// @param noblank If true, the window is set to noblank
   ///
   void noblank_set(bool noblank_) const
   {
      eo_do(_eo_ptr(), ::elm_obj_win_noblank_set(efl::eolian::to_c(noblank_)));
   }

   template <typename F>
   ::efl::eo::signal_connection
   callback_delete_request_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_DELETE_REQUEST, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_DELETE_REQUEST );
   }

   template <typename T>
   void
   callback_delete_request_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_DELETE_REQUEST, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focus_out_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_FOCUS_OUT, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_FOCUS_OUT );
   }

   template <typename T>
   void
   callback_focus_out_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_FOCUS_OUT, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focus_in_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_FOCUS_IN, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_FOCUS_IN );
   }

   template <typename T>
   void
   callback_focus_in_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_FOCUS_IN, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_moved_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_MOVED, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_MOVED );
   }

   template <typename T>
   void
   callback_moved_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_MOVED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_withdrawn_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_WITHDRAWN, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_WITHDRAWN );
   }

   template <typename T>
   void
   callback_withdrawn_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_WITHDRAWN, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_iconified_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_ICONIFIED, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_ICONIFIED );
   }

   template <typename T>
   void
   callback_iconified_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_ICONIFIED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_normal_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_NORMAL, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_NORMAL );
   }

   template <typename T>
   void
   callback_normal_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_NORMAL, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_stick_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_STICK, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_STICK );
   }

   template <typename T>
   void
   callback_stick_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_STICK, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unstick_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_UNSTICK, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_UNSTICK );
   }

   template <typename T>
   void
   callback_unstick_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_UNSTICK, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_fullscreen_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_FULLSCREEN, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_FULLSCREEN );
   }

   template <typename T>
   void
   callback_fullscreen_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_FULLSCREEN, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfullscreen_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_UNFULLSCREEN, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_UNFULLSCREEN );
   }

   template <typename T>
   void
   callback_unfullscreen_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_UNFULLSCREEN, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_maximized_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_MAXIMIZED, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_MAXIMIZED );
   }

   template <typename T>
   void
   callback_maximized_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_MAXIMIZED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unmaximized_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_UNMAXIMIZED, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_UNMAXIMIZED );
   }

   template <typename T>
   void
   callback_unmaximized_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_UNMAXIMIZED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_ioerr_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_IOERR, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_IOERR );
   }

   template <typename T>
   void
   callback_ioerr_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_IOERR, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_indicator_prop_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_INDICATOR_PROP_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_INDICATOR_PROP_CHANGED );
   }

   template <typename T>
   void
   callback_indicator_prop_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_INDICATOR_PROP_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_rotation_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_ROTATION_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_ROTATION_CHANGED );
   }

   template <typename T>
   void
   callback_rotation_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_ROTATION_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_profile_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_PROFILE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_PROFILE_CHANGED );
   }

   template <typename T>
   void
   callback_profile_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_PROFILE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_UNFOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_wm_rotation_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_WM_ROTATION_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, _eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_WM_ROTATION_CHANGED );
   }

   template <typename T>
   void
   callback_wm_rotation_changed_call(T* info)
   {
      eo_do(_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_WM_ROTATION_CHANGED, info));
   }
   static Eo_Class const* _eo_class()
   {
      return(ELM_WIN_CLASS);
   }

private:
   static Eo* _c0(efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_WIN_CLASS, _p._eo_raw, eo_constructor());
   }

   static Eo* _c1(std::string name_, Elm_Win_Type type_, efl::eo::parent_type _p)
   {
      return eo_add_custom(ELM_WIN_CLASS, _p._eo_raw, elm_obj_win_constructor(efl::eolian::to_c(name_), type_));
   }

};
template <typename T>
void _elm_win_wm_manual_rotation_done_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->wm_manual_rotation_done();
}

template <typename T>
bool _elm_win_socket_listen_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * svcname_, int svcnum_, Eina_Bool svcsys_)
{
   return static_cast<T*>(self->this_)->socket_listen(efl::eolian::to_cxx<std::string>(svcname_, std::tuple<std::false_type>()), svcnum_, efl::eolian::to_cxx<bool>(svcsys_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_win_illume_command_send_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Illume_Command command_, void * params_)
{
   static_cast<T*>(self->this_)->illume_command_send(command_, params_);
}

template <typename T>
void _elm_win_activate_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->activate();
}

template <typename T>
void _elm_win_resize_object_add_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * subobj_)
{
   static_cast<T*>(self->this_)->resize_object_add(efl::eolian::to_cxx<evas::object>(subobj_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_win_raise_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->raise();
}

template <typename T>
void _elm_win_lower_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   static_cast<T*>(self->this_)->lower();
}

template <typename T>
void _elm_win_resize_object_del_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * subobj_)
{
   static_cast<T*>(self->this_)->resize_object_del(efl::eolian::to_cxx<evas::object>(subobj_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_win_center_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool h_, Eina_Bool v_)
{
   static_cast<T*>(self->this_)->center(efl::eolian::to_cxx<bool>(h_, std::tuple<std::false_type>()), efl::eolian::to_cxx<bool>(v_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_win_keyboard_win_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->keyboard_win_get();
}

template <typename T>
void _elm_win_keyboard_win_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool is_keyboard_)
{
   static_cast<T*>(self->this_)->keyboard_win_set(efl::eolian::to_cxx<bool>(is_keyboard_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_win_autodel_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->autodel_get();
}

template <typename T>
void _elm_win_autodel_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool autodel_)
{
   static_cast<T*>(self->this_)->autodel_set(efl::eolian::to_cxx<bool>(autodel_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_win_override_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->override_get();
}

template <typename T>
void _elm_win_override_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool override_)
{
   static_cast<T*>(self->this_)->override_set(efl::eolian::to_cxx<bool>(override_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_win_iconified_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->iconified_get();
}

template <typename T>
void _elm_win_iconified_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool iconified_)
{
   static_cast<T*>(self->this_)->iconified_set(efl::eolian::to_cxx<bool>(iconified_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_win_wm_available_rotations_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int ** rotations_, unsigned int* count_)
{
   return static_cast<T*>(self->this_)->wm_available_rotations_get(rotations_, count_);
}

template <typename T>
void _elm_win_wm_available_rotations_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const int * rotations_, unsigned int count_)
{
   static_cast<T*>(self->this_)->wm_available_rotations_set(rotations_, count_);
}

template <typename T>
int _elm_win_quickpanel_zone_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->quickpanel_zone_get();
}

template <typename T>
void _elm_win_quickpanel_zone_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int zone_)
{
   static_cast<T*>(self->this_)->quickpanel_zone_set(zone_);
}

template <typename T>
bool _elm_win_maximized_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->maximized_get();
}

template <typename T>
void _elm_win_maximized_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool maximized_)
{
   static_cast<T*>(self->this_)->maximized_set(efl::eolian::to_cxx<bool>(maximized_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_win_modal_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->modal_get();
}

template <typename T>
void _elm_win_modal_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool modal_)
{
   static_cast<T*>(self->this_)->modal_set(efl::eolian::to_cxx<bool>(modal_, std::tuple<std::false_type>()));
}

template <typename T>
std::string _elm_win_icon_name_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->icon_name_get();
}

template <typename T>
void _elm_win_icon_name_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * icon_name_)
{
   static_cast<T*>(self->this_)->icon_name_set(efl::eolian::to_cxx<std::string>(icon_name_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_win_withdrawn_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->withdrawn_get();
}

template <typename T>
void _elm_win_withdrawn_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool withdrawn_)
{
   static_cast<T*>(self->this_)->withdrawn_set(efl::eolian::to_cxx<bool>(withdrawn_, std::tuple<std::false_type>()));
}

template <typename T>
std::string _elm_win_role_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->role_get();
}

template <typename T>
void _elm_win_role_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * role_)
{
   static_cast<T*>(self->this_)->role_set(efl::eolian::to_cxx<std::string>(role_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_win_size_step_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int* w_, int* h_)
{
   static_cast<T*>(self->this_)->size_step_get(w_, h_);
}

template <typename T>
void _elm_win_size_step_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int w_, int h_)
{
   static_cast<T*>(self->this_)->size_step_set(w_, h_);
}

template <typename T>
std::string _elm_win_focus_highlight_style_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->focus_highlight_style_get();
}

template <typename T>
void _elm_win_focus_highlight_style_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * style_)
{
   static_cast<T*>(self->this_)->focus_highlight_style_set(efl::eolian::to_cxx<std::string>(style_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_win_borderless_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->borderless_get();
}

template <typename T>
void _elm_win_borderless_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool borderless_)
{
   static_cast<T*>(self->this_)->borderless_set(efl::eolian::to_cxx<bool>(borderless_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_win_screen_constrain_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->screen_constrain_get();
}

template <typename T>
void _elm_win_screen_constrain_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool constrain_)
{
   static_cast<T*>(self->this_)->screen_constrain_set(efl::eolian::to_cxx<bool>(constrain_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_win_available_profiles_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, char *** profiles_, unsigned int* count_)
{
   return static_cast<T*>(self->this_)->available_profiles_get(profiles_, count_);
}

template <typename T>
void _elm_win_available_profiles_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char ** profiles_, unsigned int count_)
{
   static_cast<T*>(self->this_)->available_profiles_set(profiles_, count_);
}

template <typename T>
bool _elm_win_focus_highlight_enabled_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->focus_highlight_enabled_get();
}

template <typename T>
void _elm_win_focus_highlight_enabled_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool enabled_)
{
   static_cast<T*>(self->this_)->focus_highlight_enabled_set(efl::eolian::to_cxx<bool>(enabled_, std::tuple<std::false_type>()));
}

template <typename T>
std::string _elm_win_title_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->title_get();
}

template <typename T>
void _elm_win_title_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * title_)
{
   static_cast<T*>(self->this_)->title_set(efl::eolian::to_cxx<std::string>(title_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_win_alpha_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->alpha_get();
}

template <typename T>
void _elm_win_alpha_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool alpha_)
{
   static_cast<T*>(self->this_)->alpha_set(efl::eolian::to_cxx<bool>(alpha_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_win_urgent_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->urgent_get();
}

template <typename T>
void _elm_win_urgent_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool urgent_)
{
   static_cast<T*>(self->this_)->urgent_set(efl::eolian::to_cxx<bool>(urgent_, std::tuple<std::false_type>()));
}

template <typename T>
int _elm_win_rotation_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->rotation_get();
}

template <typename T>
void _elm_win_rotation_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int rotation_)
{
   static_cast<T*>(self->this_)->rotation_set(rotation_);
}

template <typename T>
const evas::object _elm_win_icon_object_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->icon_object_get();
}

template <typename T>
void _elm_win_icon_object_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Evas_Object * icon_)
{
   static_cast<T*>(self->this_)->icon_object_set(efl::eolian::to_cxx<evas::object>(icon_, std::tuple<std::false_type>()));
}

template <typename T>
int _elm_win_quickpanel_priority_minor_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->quickpanel_priority_minor_get();
}

template <typename T>
void _elm_win_quickpanel_priority_minor_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int priority_)
{
   static_cast<T*>(self->this_)->quickpanel_priority_minor_set(priority_);
}

template <typename T>
bool _elm_win_sticky_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->sticky_get();
}

template <typename T>
void _elm_win_sticky_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool sticky_)
{
   static_cast<T*>(self->this_)->sticky_set(efl::eolian::to_cxx<bool>(sticky_, std::tuple<std::false_type>()));
}

template <typename T>
Elm_Win_Keyboard_Mode _elm_win_keyboard_mode_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->keyboard_mode_get();
}

template <typename T>
void _elm_win_keyboard_mode_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Win_Keyboard_Mode mode_)
{
   static_cast<T*>(self->this_)->keyboard_mode_set(mode_);
}

template <typename T>
bool _elm_win_focus_highlight_animate_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->focus_highlight_animate_get();
}

template <typename T>
void _elm_win_focus_highlight_animate_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool animate_)
{
   static_cast<T*>(self->this_)->focus_highlight_animate_set(efl::eolian::to_cxx<bool>(animate_, std::tuple<std::false_type>()));
}

template <typename T>
double _elm_win_aspect_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->aspect_get();
}

template <typename T>
void _elm_win_aspect_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, double aspect_)
{
   static_cast<T*>(self->this_)->aspect_set(aspect_);
}

template <typename T>
int _elm_win_quickpanel_priority_major_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->quickpanel_priority_major_get();
}

template <typename T>
void _elm_win_quickpanel_priority_major_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int priority_)
{
   static_cast<T*>(self->this_)->quickpanel_priority_major_set(priority_);
}

template <typename T>
Elm_Win_Indicator_Opacity_Mode _elm_win_indicator_opacity_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->indicator_opacity_get();
}

template <typename T>
void _elm_win_indicator_opacity_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Win_Indicator_Opacity_Mode mode_)
{
   static_cast<T*>(self->this_)->indicator_opacity_set(mode_);
}

template <typename T>
bool _elm_win_demand_attention_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->demand_attention_get();
}

template <typename T>
void _elm_win_demand_attention_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool demand_attention_)
{
   static_cast<T*>(self->this_)->demand_attention_set(efl::eolian::to_cxx<bool>(demand_attention_, std::tuple<std::false_type>()));
}

template <typename T>
int _elm_win_wm_preferred_rotation_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->wm_preferred_rotation_get();
}

template <typename T>
void _elm_win_wm_preferred_rotation_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int rotation_)
{
   static_cast<T*>(self->this_)->wm_preferred_rotation_set(rotation_);
}

template <typename T>
int _elm_win_layer_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->layer_get();
}

template <typename T>
void _elm_win_layer_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int layer_)
{
   static_cast<T*>(self->this_)->layer_set(layer_);
}

template <typename T>
std::string _elm_win_profile_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->profile_get();
}

template <typename T>
void _elm_win_profile_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, const char * profile_)
{
   static_cast<T*>(self->this_)->profile_set(efl::eolian::to_cxx<std::string>(profile_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_win_shaped_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->shaped_get();
}

template <typename T>
void _elm_win_shaped_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool shaped_)
{
   static_cast<T*>(self->this_)->shaped_set(efl::eolian::to_cxx<bool>(shaped_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_win_fullscreen_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->fullscreen_get();
}

template <typename T>
void _elm_win_fullscreen_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool fullscreen_)
{
   static_cast<T*>(self->this_)->fullscreen_set(efl::eolian::to_cxx<bool>(fullscreen_, std::tuple<std::false_type>()));
}

template <typename T>
bool _elm_win_wm_manual_rotation_done_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->wm_manual_rotation_done_get();
}

template <typename T>
void _elm_win_wm_manual_rotation_done_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool set_)
{
   static_cast<T*>(self->this_)->wm_manual_rotation_done_set(efl::eolian::to_cxx<bool>(set_, std::tuple<std::false_type>()));
}

template <typename T>
Elm_Win_Indicator_Mode _elm_win_indicator_mode_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->indicator_mode_get();
}

template <typename T>
void _elm_win_indicator_mode_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Elm_Win_Indicator_Mode mode_)
{
   static_cast<T*>(self->this_)->indicator_mode_set(mode_);
}

template <typename T>
bool _elm_win_conformant_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->conformant_get();
}

template <typename T>
void _elm_win_conformant_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool conformant_)
{
   static_cast<T*>(self->this_)->conformant_set(efl::eolian::to_cxx<bool>(conformant_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_win_size_base_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int* w_, int* h_)
{
   static_cast<T*>(self->this_)->size_base_get(w_, h_);
}

template <typename T>
void _elm_win_size_base_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int w_, int h_)
{
   static_cast<T*>(self->this_)->size_base_set(w_, h_);
}

template <typename T>
bool _elm_win_quickpanel_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->quickpanel_get();
}

template <typename T>
void _elm_win_quickpanel_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool quickpanel_)
{
   static_cast<T*>(self->this_)->quickpanel_set(efl::eolian::to_cxx<bool>(quickpanel_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_win_rotation_with_resize_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int rotation_)
{
   static_cast<T*>(self->this_)->rotation_with_resize_set(rotation_);
}

template <typename T>
void _elm_win_prop_focus_skip_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool skip_)
{
   static_cast<T*>(self->this_)->prop_focus_skip_set(efl::eolian::to_cxx<bool>(skip_, std::tuple<std::false_type>()));
}

template <typename T>
void _elm_win_screen_position_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int* x_, int* y_)
{
   static_cast<T*>(self->this_)->screen_position_get(x_, y_);
}

template <typename T>
bool _elm_win_wm_rotation_supported_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->wm_rotation_supported_get();
}

template <typename T>
Ecore_X_Window _elm_win_xwindow_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->xwindow_get();
}

template <typename T>
bool _elm_win_focus_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->focus_get();
}

template <typename T>
void _elm_win_screen_size_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int* x_, int* y_, int* w_, int* h_)
{
   static_cast<T*>(self->this_)->screen_size_get(x_, y_, w_, h_);
}

template <typename T>
evas::object _elm_win_main_menu_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->main_menu_get();
}

template <typename T>
Ecore_Wl_Window * _elm_win_wl_window_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->wl_window_get();
}

template <typename T>
Ecore_Window _elm_win_window_id_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->window_id_get();
}

template <typename T>
void _elm_win_screen_dpi_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, int* xdpi_, int* ydpi_)
{
   static_cast<T*>(self->this_)->screen_dpi_get(xdpi_, ydpi_);
}

template <typename T>
evas::object _elm_win_inlined_image_object_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->inlined_image_object_get();
}

template <typename T>
Elm_Win_Type _elm_win_type_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->type_get();
}

template <typename T>
bool _elm_win_noblank_get_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self)
{
   return static_cast<T*>(self->this_)->noblank_get();
}

template <typename T>
void _elm_win_noblank_set_wrapper(Eo* objid EINA_UNUSED, efl::eo::detail::Inherit_Private_Data* self, Eina_Bool noblank_)
{
   static_cast<T*>(self->this_)->noblank_set(efl::eolian::to_cxx<bool>(noblank_, std::tuple<std::false_type>()));
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::elm_win >
{
   template <typename T>
   struct type
   {
      virtual void wm_manual_rotation_done()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_wm_manual_rotation_done());
      }

      virtual bool socket_listen(std::string svcname_, int svcnum_, bool svcsys_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_socket_listen(efl::eolian::to_c(svcname_), svcnum_, efl::eolian::to_c(svcsys_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void illume_command_send(Elm_Illume_Command command_, void * params_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_illume_command_send(command_, params_));
      }

      virtual void activate()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_activate());
      }

      virtual void resize_object_add(evas::object subobj_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_resize_object_add(efl::eolian::to_c(subobj_)));
      }

      virtual void raise()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_raise());
      }

      virtual void lower()
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_lower());
      }

      virtual void resize_object_del(evas::object subobj_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_resize_object_del(efl::eolian::to_c(subobj_)));
      }

      virtual void center(bool h_, bool v_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_center(efl::eolian::to_c(h_), efl::eolian::to_c(v_)));
      }

      virtual bool keyboard_win_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_keyboard_win_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void keyboard_win_set(bool is_keyboard_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_keyboard_win_set(efl::eolian::to_c(is_keyboard_)));
      }

      virtual bool autodel_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_autodel_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void autodel_set(bool autodel_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_autodel_set(efl::eolian::to_c(autodel_)));
      }

      virtual bool override_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_override_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void override_set(bool override_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_override_set(efl::eolian::to_c(override_)));
      }

      virtual bool iconified_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_iconified_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void iconified_set(bool iconified_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_iconified_set(efl::eolian::to_c(iconified_)));
      }

      virtual bool wm_available_rotations_get(int ** rotations_, unsigned int* count_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_wm_available_rotations_get(rotations_, count_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void wm_available_rotations_set(const int * rotations_, unsigned int count_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_wm_available_rotations_set(rotations_, count_));
      }

      virtual int quickpanel_zone_get()
      {
         int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_quickpanel_zone_get());
            return _tmp_ret;
      }

      virtual void quickpanel_zone_set(int zone_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_quickpanel_zone_set(zone_));
      }

      virtual bool maximized_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_maximized_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void maximized_set(bool maximized_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_maximized_set(efl::eolian::to_c(maximized_)));
      }

      virtual bool modal_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_modal_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void modal_set(bool modal_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_modal_set(efl::eolian::to_c(modal_)));
      }

      virtual std::string icon_name_get()
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_icon_name_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void icon_name_set(std::string icon_name_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_icon_name_set(efl::eolian::to_c(icon_name_)));
      }

      virtual bool withdrawn_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_withdrawn_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void withdrawn_set(bool withdrawn_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_withdrawn_set(efl::eolian::to_c(withdrawn_)));
      }

      virtual std::string role_get()
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_role_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void role_set(std::string role_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_role_set(efl::eolian::to_c(role_)));
      }

      virtual void size_step_get(int* w_, int* h_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_size_step_get(w_, h_));
      }

      virtual void size_step_set(int w_, int h_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_size_step_set(w_, h_));
      }

      virtual std::string focus_highlight_style_get()
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_focus_highlight_style_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void focus_highlight_style_set(std::string style_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_focus_highlight_style_set(efl::eolian::to_c(style_)));
      }

      virtual bool borderless_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_borderless_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void borderless_set(bool borderless_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_borderless_set(efl::eolian::to_c(borderless_)));
      }

      virtual bool screen_constrain_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_screen_constrain_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void screen_constrain_set(bool constrain_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_screen_constrain_set(efl::eolian::to_c(constrain_)));
      }

      virtual bool available_profiles_get(char *** profiles_, unsigned int* count_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_available_profiles_get(profiles_, count_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void available_profiles_set(const char ** profiles_, unsigned int count_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_available_profiles_set(profiles_, count_));
      }

      virtual bool focus_highlight_enabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_focus_highlight_enabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void focus_highlight_enabled_set(bool enabled_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_focus_highlight_enabled_set(efl::eolian::to_c(enabled_)));
      }

      virtual std::string title_get()
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_title_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void title_set(std::string title_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_title_set(efl::eolian::to_c(title_)));
      }

      virtual bool alpha_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_alpha_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void alpha_set(bool alpha_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_alpha_set(efl::eolian::to_c(alpha_)));
      }

      virtual bool urgent_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_urgent_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void urgent_set(bool urgent_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_urgent_set(efl::eolian::to_c(urgent_)));
      }

      virtual int rotation_get()
      {
         int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_rotation_get());
            return _tmp_ret;
      }

      virtual void rotation_set(int rotation_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_rotation_set(rotation_));
      }

      virtual const evas::object icon_object_get()
      {
         const Evas_Object * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_icon_object_get());
            return efl::eolian::to_cxx<const evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void icon_object_set(evas::object icon_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_icon_object_set(efl::eolian::to_c(icon_)));
      }

      virtual int quickpanel_priority_minor_get()
      {
         int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_quickpanel_priority_minor_get());
            return _tmp_ret;
      }

      virtual void quickpanel_priority_minor_set(int priority_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_quickpanel_priority_minor_set(priority_));
      }

      virtual bool sticky_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_sticky_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void sticky_set(bool sticky_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_sticky_set(efl::eolian::to_c(sticky_)));
      }

      virtual Elm_Win_Keyboard_Mode keyboard_mode_get()
      {
         Elm_Win_Keyboard_Mode _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_keyboard_mode_get());
            return _tmp_ret;
      }

      virtual void keyboard_mode_set(Elm_Win_Keyboard_Mode mode_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_keyboard_mode_set(mode_));
      }

      virtual bool focus_highlight_animate_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_focus_highlight_animate_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void focus_highlight_animate_set(bool animate_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_focus_highlight_animate_set(efl::eolian::to_c(animate_)));
      }

      virtual double aspect_get()
      {
         double _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_aspect_get());
            return _tmp_ret;
      }

      virtual void aspect_set(double aspect_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_aspect_set(aspect_));
      }

      virtual int quickpanel_priority_major_get()
      {
         int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_quickpanel_priority_major_get());
            return _tmp_ret;
      }

      virtual void quickpanel_priority_major_set(int priority_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_quickpanel_priority_major_set(priority_));
      }

      virtual Elm_Win_Indicator_Opacity_Mode indicator_opacity_get()
      {
         Elm_Win_Indicator_Opacity_Mode _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_indicator_opacity_get());
            return _tmp_ret;
      }

      virtual void indicator_opacity_set(Elm_Win_Indicator_Opacity_Mode mode_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_indicator_opacity_set(mode_));
      }

      virtual bool demand_attention_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_demand_attention_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void demand_attention_set(bool demand_attention_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_demand_attention_set(efl::eolian::to_c(demand_attention_)));
      }

      virtual int wm_preferred_rotation_get()
      {
         int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_wm_preferred_rotation_get());
            return _tmp_ret;
      }

      virtual void wm_preferred_rotation_set(int rotation_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_wm_preferred_rotation_set(rotation_));
      }

      virtual int layer_get()
      {
         int _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_layer_get());
            return _tmp_ret;
      }

      virtual void layer_set(int layer_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_layer_set(layer_));
      }

      virtual std::string profile_get()
      {
         const char * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_profile_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void profile_set(std::string profile_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_profile_set(efl::eolian::to_c(profile_)));
      }

      virtual bool shaped_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_shaped_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void shaped_set(bool shaped_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_shaped_set(efl::eolian::to_c(shaped_)));
      }

      virtual bool fullscreen_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_fullscreen_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void fullscreen_set(bool fullscreen_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_fullscreen_set(efl::eolian::to_c(fullscreen_)));
      }

      virtual bool wm_manual_rotation_done_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_wm_manual_rotation_done_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void wm_manual_rotation_done_set(bool set_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_wm_manual_rotation_done_set(efl::eolian::to_c(set_)));
      }

      virtual Elm_Win_Indicator_Mode indicator_mode_get()
      {
         Elm_Win_Indicator_Mode _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_indicator_mode_get());
            return _tmp_ret;
      }

      virtual void indicator_mode_set(Elm_Win_Indicator_Mode mode_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_indicator_mode_set(mode_));
      }

      virtual bool conformant_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_conformant_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void conformant_set(bool conformant_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_conformant_set(efl::eolian::to_c(conformant_)));
      }

      virtual void size_base_get(int* w_, int* h_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_size_base_get(w_, h_));
      }

      virtual void size_base_set(int w_, int h_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_size_base_set(w_, h_));
      }

      virtual bool quickpanel_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_quickpanel_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void quickpanel_set(bool quickpanel_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_quickpanel_set(efl::eolian::to_c(quickpanel_)));
      }

      virtual void rotation_with_resize_set(int rotation_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_rotation_with_resize_set(rotation_));
      }

      virtual void prop_focus_skip_set(bool skip_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_prop_focus_skip_set(efl::eolian::to_c(skip_)));
      }

      virtual void screen_position_get(int* x_, int* y_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_screen_position_get(x_, y_));
      }

      virtual bool wm_rotation_supported_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_wm_rotation_supported_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual Ecore_X_Window xwindow_get()
      {
         Ecore_X_Window _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_xwindow_get());
            return _tmp_ret;
      }

      virtual bool focus_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_focus_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void screen_size_get(int* x_, int* y_, int* w_, int* h_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_screen_size_get(x_, y_, w_, h_));
      }

      virtual evas::object main_menu_get()
      {
         Evas_Object * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_main_menu_get());
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual Ecore_Wl_Window * wl_window_get()
      {
         Ecore_Wl_Window * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_wl_window_get());
            return _tmp_ret;
      }

      virtual Ecore_Window window_id_get()
      {
         Ecore_Window _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_window_id_get());
            return _tmp_ret;
      }

      virtual void screen_dpi_get(int* xdpi_, int* ydpi_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_screen_dpi_get(xdpi_, ydpi_));
      }

      virtual evas::object inlined_image_object_get()
      {
         Evas_Object * _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_inlined_image_object_get());
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual Elm_Win_Type type_get()
      {
         Elm_Win_Type _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_type_get());
            return _tmp_ret;
      }

      virtual bool noblank_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::elm_obj_win_noblank_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void noblank_set(bool noblank_)
      {
         eo_do_super(static_cast<T*>(this)->_eo_ptr(),
               static_cast<T*>(this)->_eo_class(),
               ::elm_obj_win_noblank_set(efl::eolian::to_c(noblank_)));
      }

   };
};


template<>
struct operation_description_class_size< ::elm_win >
{
   static const int value = 104;
};

template <typename T>
int initialize_operation_description(efl::eo::detail::tag<::elm_win>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_elm_win_wm_manual_rotation_done_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::elm_obj_win_wm_manual_rotation_done);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_elm_win_socket_listen_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::elm_obj_win_socket_listen);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_elm_win_illume_command_send_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::elm_obj_win_illume_command_send);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_elm_win_activate_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::elm_obj_win_activate);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_elm_win_resize_object_add_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::elm_obj_win_resize_object_add);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_elm_win_raise_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::elm_obj_win_raise);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_elm_win_lower_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::elm_obj_win_lower);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_elm_win_resize_object_del_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::elm_obj_win_resize_object_del);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_elm_win_center_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::elm_obj_win_center);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_elm_win_keyboard_win_get_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::elm_obj_win_keyboard_win_get);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::_elm_win_keyboard_win_set_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::elm_obj_win_keyboard_win_set);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::_elm_win_autodel_get_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::elm_obj_win_autodel_get);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::_elm_win_autodel_set_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::elm_obj_win_autodel_set);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::_elm_win_override_get_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::elm_obj_win_override_get);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::_elm_win_override_set_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::elm_obj_win_override_set);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::_elm_win_iconified_get_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::elm_obj_win_iconified_get);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   ops[16].func = reinterpret_cast<void*>(& ::_elm_win_iconified_set_wrapper<T>);
   ops[16].api_func = reinterpret_cast<void*>(& ::elm_obj_win_iconified_set);
   ops[16].op = EO_OP_OVERRIDE;
   ops[16].op_type = EO_OP_TYPE_REGULAR;
   ops[16].doc = NULL;

   ops[17].func = reinterpret_cast<void*>(& ::_elm_win_wm_available_rotations_get_wrapper<T>);
   ops[17].api_func = reinterpret_cast<void*>(& ::elm_obj_win_wm_available_rotations_get);
   ops[17].op = EO_OP_OVERRIDE;
   ops[17].op_type = EO_OP_TYPE_REGULAR;
   ops[17].doc = NULL;

   ops[18].func = reinterpret_cast<void*>(& ::_elm_win_wm_available_rotations_set_wrapper<T>);
   ops[18].api_func = reinterpret_cast<void*>(& ::elm_obj_win_wm_available_rotations_set);
   ops[18].op = EO_OP_OVERRIDE;
   ops[18].op_type = EO_OP_TYPE_REGULAR;
   ops[18].doc = NULL;

   ops[19].func = reinterpret_cast<void*>(& ::_elm_win_quickpanel_zone_get_wrapper<T>);
   ops[19].api_func = reinterpret_cast<void*>(& ::elm_obj_win_quickpanel_zone_get);
   ops[19].op = EO_OP_OVERRIDE;
   ops[19].op_type = EO_OP_TYPE_REGULAR;
   ops[19].doc = NULL;

   ops[20].func = reinterpret_cast<void*>(& ::_elm_win_quickpanel_zone_set_wrapper<T>);
   ops[20].api_func = reinterpret_cast<void*>(& ::elm_obj_win_quickpanel_zone_set);
   ops[20].op = EO_OP_OVERRIDE;
   ops[20].op_type = EO_OP_TYPE_REGULAR;
   ops[20].doc = NULL;

   ops[21].func = reinterpret_cast<void*>(& ::_elm_win_maximized_get_wrapper<T>);
   ops[21].api_func = reinterpret_cast<void*>(& ::elm_obj_win_maximized_get);
   ops[21].op = EO_OP_OVERRIDE;
   ops[21].op_type = EO_OP_TYPE_REGULAR;
   ops[21].doc = NULL;

   ops[22].func = reinterpret_cast<void*>(& ::_elm_win_maximized_set_wrapper<T>);
   ops[22].api_func = reinterpret_cast<void*>(& ::elm_obj_win_maximized_set);
   ops[22].op = EO_OP_OVERRIDE;
   ops[22].op_type = EO_OP_TYPE_REGULAR;
   ops[22].doc = NULL;

   ops[23].func = reinterpret_cast<void*>(& ::_elm_win_modal_get_wrapper<T>);
   ops[23].api_func = reinterpret_cast<void*>(& ::elm_obj_win_modal_get);
   ops[23].op = EO_OP_OVERRIDE;
   ops[23].op_type = EO_OP_TYPE_REGULAR;
   ops[23].doc = NULL;

   ops[24].func = reinterpret_cast<void*>(& ::_elm_win_modal_set_wrapper<T>);
   ops[24].api_func = reinterpret_cast<void*>(& ::elm_obj_win_modal_set);
   ops[24].op = EO_OP_OVERRIDE;
   ops[24].op_type = EO_OP_TYPE_REGULAR;
   ops[24].doc = NULL;

   ops[25].func = reinterpret_cast<void*>(& ::_elm_win_icon_name_get_wrapper<T>);
   ops[25].api_func = reinterpret_cast<void*>(& ::elm_obj_win_icon_name_get);
   ops[25].op = EO_OP_OVERRIDE;
   ops[25].op_type = EO_OP_TYPE_REGULAR;
   ops[25].doc = NULL;

   ops[26].func = reinterpret_cast<void*>(& ::_elm_win_icon_name_set_wrapper<T>);
   ops[26].api_func = reinterpret_cast<void*>(& ::elm_obj_win_icon_name_set);
   ops[26].op = EO_OP_OVERRIDE;
   ops[26].op_type = EO_OP_TYPE_REGULAR;
   ops[26].doc = NULL;

   ops[27].func = reinterpret_cast<void*>(& ::_elm_win_withdrawn_get_wrapper<T>);
   ops[27].api_func = reinterpret_cast<void*>(& ::elm_obj_win_withdrawn_get);
   ops[27].op = EO_OP_OVERRIDE;
   ops[27].op_type = EO_OP_TYPE_REGULAR;
   ops[27].doc = NULL;

   ops[28].func = reinterpret_cast<void*>(& ::_elm_win_withdrawn_set_wrapper<T>);
   ops[28].api_func = reinterpret_cast<void*>(& ::elm_obj_win_withdrawn_set);
   ops[28].op = EO_OP_OVERRIDE;
   ops[28].op_type = EO_OP_TYPE_REGULAR;
   ops[28].doc = NULL;

   ops[29].func = reinterpret_cast<void*>(& ::_elm_win_role_get_wrapper<T>);
   ops[29].api_func = reinterpret_cast<void*>(& ::elm_obj_win_role_get);
   ops[29].op = EO_OP_OVERRIDE;
   ops[29].op_type = EO_OP_TYPE_REGULAR;
   ops[29].doc = NULL;

   ops[30].func = reinterpret_cast<void*>(& ::_elm_win_role_set_wrapper<T>);
   ops[30].api_func = reinterpret_cast<void*>(& ::elm_obj_win_role_set);
   ops[30].op = EO_OP_OVERRIDE;
   ops[30].op_type = EO_OP_TYPE_REGULAR;
   ops[30].doc = NULL;

   ops[31].func = reinterpret_cast<void*>(& ::_elm_win_size_step_get_wrapper<T>);
   ops[31].api_func = reinterpret_cast<void*>(& ::elm_obj_win_size_step_get);
   ops[31].op = EO_OP_OVERRIDE;
   ops[31].op_type = EO_OP_TYPE_REGULAR;
   ops[31].doc = NULL;

   ops[32].func = reinterpret_cast<void*>(& ::_elm_win_size_step_set_wrapper<T>);
   ops[32].api_func = reinterpret_cast<void*>(& ::elm_obj_win_size_step_set);
   ops[32].op = EO_OP_OVERRIDE;
   ops[32].op_type = EO_OP_TYPE_REGULAR;
   ops[32].doc = NULL;

   ops[33].func = reinterpret_cast<void*>(& ::_elm_win_focus_highlight_style_get_wrapper<T>);
   ops[33].api_func = reinterpret_cast<void*>(& ::elm_obj_win_focus_highlight_style_get);
   ops[33].op = EO_OP_OVERRIDE;
   ops[33].op_type = EO_OP_TYPE_REGULAR;
   ops[33].doc = NULL;

   ops[34].func = reinterpret_cast<void*>(& ::_elm_win_focus_highlight_style_set_wrapper<T>);
   ops[34].api_func = reinterpret_cast<void*>(& ::elm_obj_win_focus_highlight_style_set);
   ops[34].op = EO_OP_OVERRIDE;
   ops[34].op_type = EO_OP_TYPE_REGULAR;
   ops[34].doc = NULL;

   ops[35].func = reinterpret_cast<void*>(& ::_elm_win_borderless_get_wrapper<T>);
   ops[35].api_func = reinterpret_cast<void*>(& ::elm_obj_win_borderless_get);
   ops[35].op = EO_OP_OVERRIDE;
   ops[35].op_type = EO_OP_TYPE_REGULAR;
   ops[35].doc = NULL;

   ops[36].func = reinterpret_cast<void*>(& ::_elm_win_borderless_set_wrapper<T>);
   ops[36].api_func = reinterpret_cast<void*>(& ::elm_obj_win_borderless_set);
   ops[36].op = EO_OP_OVERRIDE;
   ops[36].op_type = EO_OP_TYPE_REGULAR;
   ops[36].doc = NULL;

   ops[37].func = reinterpret_cast<void*>(& ::_elm_win_screen_constrain_get_wrapper<T>);
   ops[37].api_func = reinterpret_cast<void*>(& ::elm_obj_win_screen_constrain_get);
   ops[37].op = EO_OP_OVERRIDE;
   ops[37].op_type = EO_OP_TYPE_REGULAR;
   ops[37].doc = NULL;

   ops[38].func = reinterpret_cast<void*>(& ::_elm_win_screen_constrain_set_wrapper<T>);
   ops[38].api_func = reinterpret_cast<void*>(& ::elm_obj_win_screen_constrain_set);
   ops[38].op = EO_OP_OVERRIDE;
   ops[38].op_type = EO_OP_TYPE_REGULAR;
   ops[38].doc = NULL;

   ops[39].func = reinterpret_cast<void*>(& ::_elm_win_available_profiles_get_wrapper<T>);
   ops[39].api_func = reinterpret_cast<void*>(& ::elm_obj_win_available_profiles_get);
   ops[39].op = EO_OP_OVERRIDE;
   ops[39].op_type = EO_OP_TYPE_REGULAR;
   ops[39].doc = NULL;

   ops[40].func = reinterpret_cast<void*>(& ::_elm_win_available_profiles_set_wrapper<T>);
   ops[40].api_func = reinterpret_cast<void*>(& ::elm_obj_win_available_profiles_set);
   ops[40].op = EO_OP_OVERRIDE;
   ops[40].op_type = EO_OP_TYPE_REGULAR;
   ops[40].doc = NULL;

   ops[41].func = reinterpret_cast<void*>(& ::_elm_win_focus_highlight_enabled_get_wrapper<T>);
   ops[41].api_func = reinterpret_cast<void*>(& ::elm_obj_win_focus_highlight_enabled_get);
   ops[41].op = EO_OP_OVERRIDE;
   ops[41].op_type = EO_OP_TYPE_REGULAR;
   ops[41].doc = NULL;

   ops[42].func = reinterpret_cast<void*>(& ::_elm_win_focus_highlight_enabled_set_wrapper<T>);
   ops[42].api_func = reinterpret_cast<void*>(& ::elm_obj_win_focus_highlight_enabled_set);
   ops[42].op = EO_OP_OVERRIDE;
   ops[42].op_type = EO_OP_TYPE_REGULAR;
   ops[42].doc = NULL;

   ops[43].func = reinterpret_cast<void*>(& ::_elm_win_title_get_wrapper<T>);
   ops[43].api_func = reinterpret_cast<void*>(& ::elm_obj_win_title_get);
   ops[43].op = EO_OP_OVERRIDE;
   ops[43].op_type = EO_OP_TYPE_REGULAR;
   ops[43].doc = NULL;

   ops[44].func = reinterpret_cast<void*>(& ::_elm_win_title_set_wrapper<T>);
   ops[44].api_func = reinterpret_cast<void*>(& ::elm_obj_win_title_set);
   ops[44].op = EO_OP_OVERRIDE;
   ops[44].op_type = EO_OP_TYPE_REGULAR;
   ops[44].doc = NULL;

   ops[45].func = reinterpret_cast<void*>(& ::_elm_win_alpha_get_wrapper<T>);
   ops[45].api_func = reinterpret_cast<void*>(& ::elm_obj_win_alpha_get);
   ops[45].op = EO_OP_OVERRIDE;
   ops[45].op_type = EO_OP_TYPE_REGULAR;
   ops[45].doc = NULL;

   ops[46].func = reinterpret_cast<void*>(& ::_elm_win_alpha_set_wrapper<T>);
   ops[46].api_func = reinterpret_cast<void*>(& ::elm_obj_win_alpha_set);
   ops[46].op = EO_OP_OVERRIDE;
   ops[46].op_type = EO_OP_TYPE_REGULAR;
   ops[46].doc = NULL;

   ops[47].func = reinterpret_cast<void*>(& ::_elm_win_urgent_get_wrapper<T>);
   ops[47].api_func = reinterpret_cast<void*>(& ::elm_obj_win_urgent_get);
   ops[47].op = EO_OP_OVERRIDE;
   ops[47].op_type = EO_OP_TYPE_REGULAR;
   ops[47].doc = NULL;

   ops[48].func = reinterpret_cast<void*>(& ::_elm_win_urgent_set_wrapper<T>);
   ops[48].api_func = reinterpret_cast<void*>(& ::elm_obj_win_urgent_set);
   ops[48].op = EO_OP_OVERRIDE;
   ops[48].op_type = EO_OP_TYPE_REGULAR;
   ops[48].doc = NULL;

   ops[49].func = reinterpret_cast<void*>(& ::_elm_win_rotation_get_wrapper<T>);
   ops[49].api_func = reinterpret_cast<void*>(& ::elm_obj_win_rotation_get);
   ops[49].op = EO_OP_OVERRIDE;
   ops[49].op_type = EO_OP_TYPE_REGULAR;
   ops[49].doc = NULL;

   ops[50].func = reinterpret_cast<void*>(& ::_elm_win_rotation_set_wrapper<T>);
   ops[50].api_func = reinterpret_cast<void*>(& ::elm_obj_win_rotation_set);
   ops[50].op = EO_OP_OVERRIDE;
   ops[50].op_type = EO_OP_TYPE_REGULAR;
   ops[50].doc = NULL;

   ops[51].func = reinterpret_cast<void*>(& ::_elm_win_icon_object_get_wrapper<T>);
   ops[51].api_func = reinterpret_cast<void*>(& ::elm_obj_win_icon_object_get);
   ops[51].op = EO_OP_OVERRIDE;
   ops[51].op_type = EO_OP_TYPE_REGULAR;
   ops[51].doc = NULL;

   ops[52].func = reinterpret_cast<void*>(& ::_elm_win_icon_object_set_wrapper<T>);
   ops[52].api_func = reinterpret_cast<void*>(& ::elm_obj_win_icon_object_set);
   ops[52].op = EO_OP_OVERRIDE;
   ops[52].op_type = EO_OP_TYPE_REGULAR;
   ops[52].doc = NULL;

   ops[53].func = reinterpret_cast<void*>(& ::_elm_win_quickpanel_priority_minor_get_wrapper<T>);
   ops[53].api_func = reinterpret_cast<void*>(& ::elm_obj_win_quickpanel_priority_minor_get);
   ops[53].op = EO_OP_OVERRIDE;
   ops[53].op_type = EO_OP_TYPE_REGULAR;
   ops[53].doc = NULL;

   ops[54].func = reinterpret_cast<void*>(& ::_elm_win_quickpanel_priority_minor_set_wrapper<T>);
   ops[54].api_func = reinterpret_cast<void*>(& ::elm_obj_win_quickpanel_priority_minor_set);
   ops[54].op = EO_OP_OVERRIDE;
   ops[54].op_type = EO_OP_TYPE_REGULAR;
   ops[54].doc = NULL;

   ops[55].func = reinterpret_cast<void*>(& ::_elm_win_sticky_get_wrapper<T>);
   ops[55].api_func = reinterpret_cast<void*>(& ::elm_obj_win_sticky_get);
   ops[55].op = EO_OP_OVERRIDE;
   ops[55].op_type = EO_OP_TYPE_REGULAR;
   ops[55].doc = NULL;

   ops[56].func = reinterpret_cast<void*>(& ::_elm_win_sticky_set_wrapper<T>);
   ops[56].api_func = reinterpret_cast<void*>(& ::elm_obj_win_sticky_set);
   ops[56].op = EO_OP_OVERRIDE;
   ops[56].op_type = EO_OP_TYPE_REGULAR;
   ops[56].doc = NULL;

   ops[57].func = reinterpret_cast<void*>(& ::_elm_win_keyboard_mode_get_wrapper<T>);
   ops[57].api_func = reinterpret_cast<void*>(& ::elm_obj_win_keyboard_mode_get);
   ops[57].op = EO_OP_OVERRIDE;
   ops[57].op_type = EO_OP_TYPE_REGULAR;
   ops[57].doc = NULL;

   ops[58].func = reinterpret_cast<void*>(& ::_elm_win_keyboard_mode_set_wrapper<T>);
   ops[58].api_func = reinterpret_cast<void*>(& ::elm_obj_win_keyboard_mode_set);
   ops[58].op = EO_OP_OVERRIDE;
   ops[58].op_type = EO_OP_TYPE_REGULAR;
   ops[58].doc = NULL;

   ops[59].func = reinterpret_cast<void*>(& ::_elm_win_focus_highlight_animate_get_wrapper<T>);
   ops[59].api_func = reinterpret_cast<void*>(& ::elm_obj_win_focus_highlight_animate_get);
   ops[59].op = EO_OP_OVERRIDE;
   ops[59].op_type = EO_OP_TYPE_REGULAR;
   ops[59].doc = NULL;

   ops[60].func = reinterpret_cast<void*>(& ::_elm_win_focus_highlight_animate_set_wrapper<T>);
   ops[60].api_func = reinterpret_cast<void*>(& ::elm_obj_win_focus_highlight_animate_set);
   ops[60].op = EO_OP_OVERRIDE;
   ops[60].op_type = EO_OP_TYPE_REGULAR;
   ops[60].doc = NULL;

   ops[61].func = reinterpret_cast<void*>(& ::_elm_win_aspect_get_wrapper<T>);
   ops[61].api_func = reinterpret_cast<void*>(& ::elm_obj_win_aspect_get);
   ops[61].op = EO_OP_OVERRIDE;
   ops[61].op_type = EO_OP_TYPE_REGULAR;
   ops[61].doc = NULL;

   ops[62].func = reinterpret_cast<void*>(& ::_elm_win_aspect_set_wrapper<T>);
   ops[62].api_func = reinterpret_cast<void*>(& ::elm_obj_win_aspect_set);
   ops[62].op = EO_OP_OVERRIDE;
   ops[62].op_type = EO_OP_TYPE_REGULAR;
   ops[62].doc = NULL;

   ops[63].func = reinterpret_cast<void*>(& ::_elm_win_quickpanel_priority_major_get_wrapper<T>);
   ops[63].api_func = reinterpret_cast<void*>(& ::elm_obj_win_quickpanel_priority_major_get);
   ops[63].op = EO_OP_OVERRIDE;
   ops[63].op_type = EO_OP_TYPE_REGULAR;
   ops[63].doc = NULL;

   ops[64].func = reinterpret_cast<void*>(& ::_elm_win_quickpanel_priority_major_set_wrapper<T>);
   ops[64].api_func = reinterpret_cast<void*>(& ::elm_obj_win_quickpanel_priority_major_set);
   ops[64].op = EO_OP_OVERRIDE;
   ops[64].op_type = EO_OP_TYPE_REGULAR;
   ops[64].doc = NULL;

   ops[65].func = reinterpret_cast<void*>(& ::_elm_win_indicator_opacity_get_wrapper<T>);
   ops[65].api_func = reinterpret_cast<void*>(& ::elm_obj_win_indicator_opacity_get);
   ops[65].op = EO_OP_OVERRIDE;
   ops[65].op_type = EO_OP_TYPE_REGULAR;
   ops[65].doc = NULL;

   ops[66].func = reinterpret_cast<void*>(& ::_elm_win_indicator_opacity_set_wrapper<T>);
   ops[66].api_func = reinterpret_cast<void*>(& ::elm_obj_win_indicator_opacity_set);
   ops[66].op = EO_OP_OVERRIDE;
   ops[66].op_type = EO_OP_TYPE_REGULAR;
   ops[66].doc = NULL;

   ops[67].func = reinterpret_cast<void*>(& ::_elm_win_demand_attention_get_wrapper<T>);
   ops[67].api_func = reinterpret_cast<void*>(& ::elm_obj_win_demand_attention_get);
   ops[67].op = EO_OP_OVERRIDE;
   ops[67].op_type = EO_OP_TYPE_REGULAR;
   ops[67].doc = NULL;

   ops[68].func = reinterpret_cast<void*>(& ::_elm_win_demand_attention_set_wrapper<T>);
   ops[68].api_func = reinterpret_cast<void*>(& ::elm_obj_win_demand_attention_set);
   ops[68].op = EO_OP_OVERRIDE;
   ops[68].op_type = EO_OP_TYPE_REGULAR;
   ops[68].doc = NULL;

   ops[69].func = reinterpret_cast<void*>(& ::_elm_win_wm_preferred_rotation_get_wrapper<T>);
   ops[69].api_func = reinterpret_cast<void*>(& ::elm_obj_win_wm_preferred_rotation_get);
   ops[69].op = EO_OP_OVERRIDE;
   ops[69].op_type = EO_OP_TYPE_REGULAR;
   ops[69].doc = NULL;

   ops[70].func = reinterpret_cast<void*>(& ::_elm_win_wm_preferred_rotation_set_wrapper<T>);
   ops[70].api_func = reinterpret_cast<void*>(& ::elm_obj_win_wm_preferred_rotation_set);
   ops[70].op = EO_OP_OVERRIDE;
   ops[70].op_type = EO_OP_TYPE_REGULAR;
   ops[70].doc = NULL;

   ops[71].func = reinterpret_cast<void*>(& ::_elm_win_layer_get_wrapper<T>);
   ops[71].api_func = reinterpret_cast<void*>(& ::elm_obj_win_layer_get);
   ops[71].op = EO_OP_OVERRIDE;
   ops[71].op_type = EO_OP_TYPE_REGULAR;
   ops[71].doc = NULL;

   ops[72].func = reinterpret_cast<void*>(& ::_elm_win_layer_set_wrapper<T>);
   ops[72].api_func = reinterpret_cast<void*>(& ::elm_obj_win_layer_set);
   ops[72].op = EO_OP_OVERRIDE;
   ops[72].op_type = EO_OP_TYPE_REGULAR;
   ops[72].doc = NULL;

   ops[73].func = reinterpret_cast<void*>(& ::_elm_win_profile_get_wrapper<T>);
   ops[73].api_func = reinterpret_cast<void*>(& ::elm_obj_win_profile_get);
   ops[73].op = EO_OP_OVERRIDE;
   ops[73].op_type = EO_OP_TYPE_REGULAR;
   ops[73].doc = NULL;

   ops[74].func = reinterpret_cast<void*>(& ::_elm_win_profile_set_wrapper<T>);
   ops[74].api_func = reinterpret_cast<void*>(& ::elm_obj_win_profile_set);
   ops[74].op = EO_OP_OVERRIDE;
   ops[74].op_type = EO_OP_TYPE_REGULAR;
   ops[74].doc = NULL;

   ops[75].func = reinterpret_cast<void*>(& ::_elm_win_shaped_get_wrapper<T>);
   ops[75].api_func = reinterpret_cast<void*>(& ::elm_obj_win_shaped_get);
   ops[75].op = EO_OP_OVERRIDE;
   ops[75].op_type = EO_OP_TYPE_REGULAR;
   ops[75].doc = NULL;

   ops[76].func = reinterpret_cast<void*>(& ::_elm_win_shaped_set_wrapper<T>);
   ops[76].api_func = reinterpret_cast<void*>(& ::elm_obj_win_shaped_set);
   ops[76].op = EO_OP_OVERRIDE;
   ops[76].op_type = EO_OP_TYPE_REGULAR;
   ops[76].doc = NULL;

   ops[77].func = reinterpret_cast<void*>(& ::_elm_win_fullscreen_get_wrapper<T>);
   ops[77].api_func = reinterpret_cast<void*>(& ::elm_obj_win_fullscreen_get);
   ops[77].op = EO_OP_OVERRIDE;
   ops[77].op_type = EO_OP_TYPE_REGULAR;
   ops[77].doc = NULL;

   ops[78].func = reinterpret_cast<void*>(& ::_elm_win_fullscreen_set_wrapper<T>);
   ops[78].api_func = reinterpret_cast<void*>(& ::elm_obj_win_fullscreen_set);
   ops[78].op = EO_OP_OVERRIDE;
   ops[78].op_type = EO_OP_TYPE_REGULAR;
   ops[78].doc = NULL;

   ops[79].func = reinterpret_cast<void*>(& ::_elm_win_wm_manual_rotation_done_get_wrapper<T>);
   ops[79].api_func = reinterpret_cast<void*>(& ::elm_obj_win_wm_manual_rotation_done_get);
   ops[79].op = EO_OP_OVERRIDE;
   ops[79].op_type = EO_OP_TYPE_REGULAR;
   ops[79].doc = NULL;

   ops[80].func = reinterpret_cast<void*>(& ::_elm_win_wm_manual_rotation_done_set_wrapper<T>);
   ops[80].api_func = reinterpret_cast<void*>(& ::elm_obj_win_wm_manual_rotation_done_set);
   ops[80].op = EO_OP_OVERRIDE;
   ops[80].op_type = EO_OP_TYPE_REGULAR;
   ops[80].doc = NULL;

   ops[81].func = reinterpret_cast<void*>(& ::_elm_win_indicator_mode_get_wrapper<T>);
   ops[81].api_func = reinterpret_cast<void*>(& ::elm_obj_win_indicator_mode_get);
   ops[81].op = EO_OP_OVERRIDE;
   ops[81].op_type = EO_OP_TYPE_REGULAR;
   ops[81].doc = NULL;

   ops[82].func = reinterpret_cast<void*>(& ::_elm_win_indicator_mode_set_wrapper<T>);
   ops[82].api_func = reinterpret_cast<void*>(& ::elm_obj_win_indicator_mode_set);
   ops[82].op = EO_OP_OVERRIDE;
   ops[82].op_type = EO_OP_TYPE_REGULAR;
   ops[82].doc = NULL;

   ops[83].func = reinterpret_cast<void*>(& ::_elm_win_conformant_get_wrapper<T>);
   ops[83].api_func = reinterpret_cast<void*>(& ::elm_obj_win_conformant_get);
   ops[83].op = EO_OP_OVERRIDE;
   ops[83].op_type = EO_OP_TYPE_REGULAR;
   ops[83].doc = NULL;

   ops[84].func = reinterpret_cast<void*>(& ::_elm_win_conformant_set_wrapper<T>);
   ops[84].api_func = reinterpret_cast<void*>(& ::elm_obj_win_conformant_set);
   ops[84].op = EO_OP_OVERRIDE;
   ops[84].op_type = EO_OP_TYPE_REGULAR;
   ops[84].doc = NULL;

   ops[85].func = reinterpret_cast<void*>(& ::_elm_win_size_base_get_wrapper<T>);
   ops[85].api_func = reinterpret_cast<void*>(& ::elm_obj_win_size_base_get);
   ops[85].op = EO_OP_OVERRIDE;
   ops[85].op_type = EO_OP_TYPE_REGULAR;
   ops[85].doc = NULL;

   ops[86].func = reinterpret_cast<void*>(& ::_elm_win_size_base_set_wrapper<T>);
   ops[86].api_func = reinterpret_cast<void*>(& ::elm_obj_win_size_base_set);
   ops[86].op = EO_OP_OVERRIDE;
   ops[86].op_type = EO_OP_TYPE_REGULAR;
   ops[86].doc = NULL;

   ops[87].func = reinterpret_cast<void*>(& ::_elm_win_quickpanel_get_wrapper<T>);
   ops[87].api_func = reinterpret_cast<void*>(& ::elm_obj_win_quickpanel_get);
   ops[87].op = EO_OP_OVERRIDE;
   ops[87].op_type = EO_OP_TYPE_REGULAR;
   ops[87].doc = NULL;

   ops[88].func = reinterpret_cast<void*>(& ::_elm_win_quickpanel_set_wrapper<T>);
   ops[88].api_func = reinterpret_cast<void*>(& ::elm_obj_win_quickpanel_set);
   ops[88].op = EO_OP_OVERRIDE;
   ops[88].op_type = EO_OP_TYPE_REGULAR;
   ops[88].doc = NULL;

   ops[89].func = reinterpret_cast<void*>(& ::_elm_win_rotation_with_resize_set_wrapper<T>);
   ops[89].api_func = reinterpret_cast<void*>(& ::elm_obj_win_rotation_with_resize_set);
   ops[89].op = EO_OP_OVERRIDE;
   ops[89].op_type = EO_OP_TYPE_REGULAR;
   ops[89].doc = NULL;

   ops[90].func = reinterpret_cast<void*>(& ::_elm_win_prop_focus_skip_set_wrapper<T>);
   ops[90].api_func = reinterpret_cast<void*>(& ::elm_obj_win_prop_focus_skip_set);
   ops[90].op = EO_OP_OVERRIDE;
   ops[90].op_type = EO_OP_TYPE_REGULAR;
   ops[90].doc = NULL;

   ops[91].func = reinterpret_cast<void*>(& ::_elm_win_screen_position_get_wrapper<T>);
   ops[91].api_func = reinterpret_cast<void*>(& ::elm_obj_win_screen_position_get);
   ops[91].op = EO_OP_OVERRIDE;
   ops[91].op_type = EO_OP_TYPE_REGULAR;
   ops[91].doc = NULL;

   ops[92].func = reinterpret_cast<void*>(& ::_elm_win_wm_rotation_supported_get_wrapper<T>);
   ops[92].api_func = reinterpret_cast<void*>(& ::elm_obj_win_wm_rotation_supported_get);
   ops[92].op = EO_OP_OVERRIDE;
   ops[92].op_type = EO_OP_TYPE_REGULAR;
   ops[92].doc = NULL;

   ops[93].func = reinterpret_cast<void*>(& ::_elm_win_xwindow_get_wrapper<T>);
   ops[93].api_func = reinterpret_cast<void*>(& ::elm_obj_win_xwindow_get);
   ops[93].op = EO_OP_OVERRIDE;
   ops[93].op_type = EO_OP_TYPE_REGULAR;
   ops[93].doc = NULL;

   ops[94].func = reinterpret_cast<void*>(& ::_elm_win_focus_get_wrapper<T>);
   ops[94].api_func = reinterpret_cast<void*>(& ::elm_obj_win_focus_get);
   ops[94].op = EO_OP_OVERRIDE;
   ops[94].op_type = EO_OP_TYPE_REGULAR;
   ops[94].doc = NULL;

   ops[95].func = reinterpret_cast<void*>(& ::_elm_win_screen_size_get_wrapper<T>);
   ops[95].api_func = reinterpret_cast<void*>(& ::elm_obj_win_screen_size_get);
   ops[95].op = EO_OP_OVERRIDE;
   ops[95].op_type = EO_OP_TYPE_REGULAR;
   ops[95].doc = NULL;

   ops[96].func = reinterpret_cast<void*>(& ::_elm_win_main_menu_get_wrapper<T>);
   ops[96].api_func = reinterpret_cast<void*>(& ::elm_obj_win_main_menu_get);
   ops[96].op = EO_OP_OVERRIDE;
   ops[96].op_type = EO_OP_TYPE_REGULAR;
   ops[96].doc = NULL;

   ops[97].func = reinterpret_cast<void*>(& ::_elm_win_wl_window_get_wrapper<T>);
   ops[97].api_func = reinterpret_cast<void*>(& ::elm_obj_win_wl_window_get);
   ops[97].op = EO_OP_OVERRIDE;
   ops[97].op_type = EO_OP_TYPE_REGULAR;
   ops[97].doc = NULL;

   ops[98].func = reinterpret_cast<void*>(& ::_elm_win_window_id_get_wrapper<T>);
   ops[98].api_func = reinterpret_cast<void*>(& ::elm_obj_win_window_id_get);
   ops[98].op = EO_OP_OVERRIDE;
   ops[98].op_type = EO_OP_TYPE_REGULAR;
   ops[98].doc = NULL;

   ops[99].func = reinterpret_cast<void*>(& ::_elm_win_screen_dpi_get_wrapper<T>);
   ops[99].api_func = reinterpret_cast<void*>(& ::elm_obj_win_screen_dpi_get);
   ops[99].op = EO_OP_OVERRIDE;
   ops[99].op_type = EO_OP_TYPE_REGULAR;
   ops[99].doc = NULL;

   ops[100].func = reinterpret_cast<void*>(& ::_elm_win_inlined_image_object_get_wrapper<T>);
   ops[100].api_func = reinterpret_cast<void*>(& ::elm_obj_win_inlined_image_object_get);
   ops[100].op = EO_OP_OVERRIDE;
   ops[100].op_type = EO_OP_TYPE_REGULAR;
   ops[100].doc = NULL;

   ops[101].func = reinterpret_cast<void*>(& ::_elm_win_type_get_wrapper<T>);
   ops[101].api_func = reinterpret_cast<void*>(& ::elm_obj_win_type_get);
   ops[101].op = EO_OP_OVERRIDE;
   ops[101].op_type = EO_OP_TYPE_REGULAR;
   ops[101].doc = NULL;

   ops[102].func = reinterpret_cast<void*>(& ::_elm_win_noblank_get_wrapper<T>);
   ops[102].api_func = reinterpret_cast<void*>(& ::elm_obj_win_noblank_get);
   ops[102].op = EO_OP_OVERRIDE;
   ops[102].op_type = EO_OP_TYPE_REGULAR;
   ops[102].doc = NULL;

   ops[103].func = reinterpret_cast<void*>(& ::_elm_win_noblank_set_wrapper<T>);
   ops[103].api_func = reinterpret_cast<void*>(& ::elm_obj_win_noblank_set);
   ops[103].op = EO_OP_OVERRIDE;
   ops[103].op_type = EO_OP_TYPE_REGULAR;
   ops[103].doc = NULL;

   return 0;
}
inline void
call_constructor(tag< ::elm_win >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_win, ::std::tuple<> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::eo_constructor());
}

inline void
call_constructor(tag< ::elm_win >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_win, ::std::tuple<std::string, Elm_Win_Type> > const& args)
{
   (void)args;
   eo_do_super(eo, cls, ::elm_obj_win_constructor(::efl::eolian::to_c(args.get<0>()), ::efl::eolian::to_c(args.get<1>())));
}

inline void
call_constructor(tag< ::elm_win >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               args_class<::elm_win, ::std::tuple<efl::eo::parent_type> > const& args)
{
   eo_do_super(eo, cls, ::eo_constructor());
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

template<>
struct extension_inheritance< ::elm_win>
{
   template <typename U>
   struct type
   {
      operator ::elm_win() const
      {
         return ::elm_win(eo_ref(static_cast<U const*>(this)->_eo_ptr()));
      }

      void wm_manual_rotation_done()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_wm_manual_rotation_done());
      }

      bool socket_listen(std::string svcname_, int svcnum_, bool svcsys_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_socket_listen(efl::eolian::to_c(svcname_), svcnum_, efl::eolian::to_c(svcsys_)));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void illume_command_send(Elm_Illume_Command command_, void * params_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_illume_command_send(command_, params_));
      }

      void activate()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_activate());
      }

      void resize_object_add(evas::object subobj_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_resize_object_add(efl::eolian::to_c(subobj_)));
      }

      void raise()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_raise());
      }

      void lower()
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_lower());
      }

      void resize_object_del(evas::object subobj_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_resize_object_del(efl::eolian::to_c(subobj_)));
      }

      void center(bool h_, bool v_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_center(efl::eolian::to_c(h_), efl::eolian::to_c(v_)));
      }

      bool keyboard_win_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_keyboard_win_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void keyboard_win_set(bool is_keyboard_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_keyboard_win_set(efl::eolian::to_c(is_keyboard_)));
      }

      bool autodel_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_autodel_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void autodel_set(bool autodel_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_autodel_set(efl::eolian::to_c(autodel_)));
      }

      bool override_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_override_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void override_set(bool override_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_override_set(efl::eolian::to_c(override_)));
      }

      bool iconified_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_iconified_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void iconified_set(bool iconified_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_iconified_set(efl::eolian::to_c(iconified_)));
      }

      bool wm_available_rotations_get(int ** rotations_, unsigned int* count_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_wm_available_rotations_get(rotations_, count_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void wm_available_rotations_set(const int * rotations_, unsigned int count_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_wm_available_rotations_set(rotations_, count_));
      }

      int quickpanel_zone_get()
      {
         int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_quickpanel_zone_get());
            return _tmp_ret;
      }

      void quickpanel_zone_set(int zone_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_quickpanel_zone_set(zone_));
      }

      bool maximized_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_maximized_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void maximized_set(bool maximized_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_maximized_set(efl::eolian::to_c(maximized_)));
      }

      bool modal_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_modal_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void modal_set(bool modal_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_modal_set(efl::eolian::to_c(modal_)));
      }

      std::string icon_name_get()
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_icon_name_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      void icon_name_set(std::string icon_name_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_icon_name_set(efl::eolian::to_c(icon_name_)));
      }

      bool withdrawn_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_withdrawn_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void withdrawn_set(bool withdrawn_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_withdrawn_set(efl::eolian::to_c(withdrawn_)));
      }

      std::string role_get()
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_role_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      void role_set(std::string role_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_role_set(efl::eolian::to_c(role_)));
      }

      void size_step_get(int* w_, int* h_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_size_step_get(w_, h_));
      }

      void size_step_set(int w_, int h_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_size_step_set(w_, h_));
      }

      std::string focus_highlight_style_get()
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_focus_highlight_style_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      void focus_highlight_style_set(std::string style_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_focus_highlight_style_set(efl::eolian::to_c(style_)));
      }

      bool borderless_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_borderless_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void borderless_set(bool borderless_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_borderless_set(efl::eolian::to_c(borderless_)));
      }

      bool screen_constrain_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_screen_constrain_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void screen_constrain_set(bool constrain_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_screen_constrain_set(efl::eolian::to_c(constrain_)));
      }

      bool available_profiles_get(char *** profiles_, unsigned int* count_)
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_available_profiles_get(profiles_, count_));
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void available_profiles_set(const char ** profiles_, unsigned int count_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_available_profiles_set(profiles_, count_));
      }

      bool focus_highlight_enabled_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_focus_highlight_enabled_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void focus_highlight_enabled_set(bool enabled_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_focus_highlight_enabled_set(efl::eolian::to_c(enabled_)));
      }

      std::string title_get()
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_title_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      void title_set(std::string title_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_title_set(efl::eolian::to_c(title_)));
      }

      bool alpha_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_alpha_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void alpha_set(bool alpha_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_alpha_set(efl::eolian::to_c(alpha_)));
      }

      bool urgent_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_urgent_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void urgent_set(bool urgent_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_urgent_set(efl::eolian::to_c(urgent_)));
      }

      int rotation_get()
      {
         int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_rotation_get());
            return _tmp_ret;
      }

      void rotation_set(int rotation_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_rotation_set(rotation_));
      }

      const evas::object icon_object_get()
      {
         const Evas_Object * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_icon_object_get());
            return efl::eolian::to_cxx<const evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      void icon_object_set(evas::object icon_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_icon_object_set(efl::eolian::to_c(icon_)));
      }

      int quickpanel_priority_minor_get()
      {
         int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_quickpanel_priority_minor_get());
            return _tmp_ret;
      }

      void quickpanel_priority_minor_set(int priority_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_quickpanel_priority_minor_set(priority_));
      }

      bool sticky_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_sticky_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void sticky_set(bool sticky_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_sticky_set(efl::eolian::to_c(sticky_)));
      }

      Elm_Win_Keyboard_Mode keyboard_mode_get()
      {
         Elm_Win_Keyboard_Mode _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_keyboard_mode_get());
            return _tmp_ret;
      }

      void keyboard_mode_set(Elm_Win_Keyboard_Mode mode_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_keyboard_mode_set(mode_));
      }

      bool focus_highlight_animate_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_focus_highlight_animate_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void focus_highlight_animate_set(bool animate_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_focus_highlight_animate_set(efl::eolian::to_c(animate_)));
      }

      double aspect_get()
      {
         double _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_aspect_get());
            return _tmp_ret;
      }

      void aspect_set(double aspect_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_aspect_set(aspect_));
      }

      int quickpanel_priority_major_get()
      {
         int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_quickpanel_priority_major_get());
            return _tmp_ret;
      }

      void quickpanel_priority_major_set(int priority_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_quickpanel_priority_major_set(priority_));
      }

      Elm_Win_Indicator_Opacity_Mode indicator_opacity_get()
      {
         Elm_Win_Indicator_Opacity_Mode _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_indicator_opacity_get());
            return _tmp_ret;
      }

      void indicator_opacity_set(Elm_Win_Indicator_Opacity_Mode mode_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_indicator_opacity_set(mode_));
      }

      bool demand_attention_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_demand_attention_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void demand_attention_set(bool demand_attention_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_demand_attention_set(efl::eolian::to_c(demand_attention_)));
      }

      int wm_preferred_rotation_get()
      {
         int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_wm_preferred_rotation_get());
            return _tmp_ret;
      }

      void wm_preferred_rotation_set(int rotation_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_wm_preferred_rotation_set(rotation_));
      }

      int layer_get()
      {
         int _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_layer_get());
            return _tmp_ret;
      }

      void layer_set(int layer_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_layer_set(layer_));
      }

      std::string profile_get()
      {
         const char * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_profile_get());
            return efl::eolian::to_cxx<std::string>(_tmp_ret, std::tuple<std::false_type>());
      }

      void profile_set(std::string profile_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_profile_set(efl::eolian::to_c(profile_)));
      }

      bool shaped_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_shaped_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void shaped_set(bool shaped_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_shaped_set(efl::eolian::to_c(shaped_)));
      }

      bool fullscreen_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_fullscreen_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void fullscreen_set(bool fullscreen_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_fullscreen_set(efl::eolian::to_c(fullscreen_)));
      }

      bool wm_manual_rotation_done_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_wm_manual_rotation_done_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void wm_manual_rotation_done_set(bool set_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_wm_manual_rotation_done_set(efl::eolian::to_c(set_)));
      }

      Elm_Win_Indicator_Mode indicator_mode_get()
      {
         Elm_Win_Indicator_Mode _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_indicator_mode_get());
            return _tmp_ret;
      }

      void indicator_mode_set(Elm_Win_Indicator_Mode mode_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_indicator_mode_set(mode_));
      }

      bool conformant_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_conformant_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void conformant_set(bool conformant_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_conformant_set(efl::eolian::to_c(conformant_)));
      }

      void size_base_get(int* w_, int* h_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_size_base_get(w_, h_));
      }

      void size_base_set(int w_, int h_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_size_base_set(w_, h_));
      }

      bool quickpanel_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_quickpanel_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void quickpanel_set(bool quickpanel_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_quickpanel_set(efl::eolian::to_c(quickpanel_)));
      }

      void rotation_with_resize_set(int rotation_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_rotation_with_resize_set(rotation_));
      }

      void prop_focus_skip_set(bool skip_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_prop_focus_skip_set(efl::eolian::to_c(skip_)));
      }

      void screen_position_get(int* x_, int* y_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_screen_position_get(x_, y_));
      }

      bool wm_rotation_supported_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_wm_rotation_supported_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      Ecore_X_Window xwindow_get()
      {
         Ecore_X_Window _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_xwindow_get());
            return _tmp_ret;
      }

      bool focus_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_focus_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void screen_size_get(int* x_, int* y_, int* w_, int* h_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_screen_size_get(x_, y_, w_, h_));
      }

      evas::object main_menu_get()
      {
         Evas_Object * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_main_menu_get());
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      Ecore_Wl_Window * wl_window_get()
      {
         Ecore_Wl_Window * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_wl_window_get());
            return _tmp_ret;
      }

      Ecore_Window window_id_get()
      {
         Ecore_Window _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_window_id_get());
            return _tmp_ret;
      }

      void screen_dpi_get(int* xdpi_, int* ydpi_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_screen_dpi_get(xdpi_, ydpi_));
      }

      evas::object inlined_image_object_get()
      {
         Evas_Object * _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_inlined_image_object_get());
            return efl::eolian::to_cxx<evas::object>(_tmp_ret, std::tuple<std::false_type>());
      }

      Elm_Win_Type type_get()
      {
         Elm_Win_Type _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_type_get());
            return _tmp_ret;
      }

      bool noblank_get()
      {
         Eina_Bool _tmp_ret = {};
         eo_do(static_cast<U*>(this)->_eo_ptr(), _tmp_ret = ::elm_obj_win_noblank_get());
            return efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      void noblank_set(bool noblank_)
      {
         eo_do(static_cast<U*>(this)->_eo_ptr(), ::elm_obj_win_noblank_set(efl::eolian::to_c(noblank_)));
      }

   template <typename F>
   ::efl::eo::signal_connection
   callback_delete_request_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_DELETE_REQUEST, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_DELETE_REQUEST );
   }

   template <typename T>
   void
   callback_delete_request_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_DELETE_REQUEST, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focus_out_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_FOCUS_OUT, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_FOCUS_OUT );
   }

   template <typename T>
   void
   callback_focus_out_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_FOCUS_OUT, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focus_in_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_FOCUS_IN, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_FOCUS_IN );
   }

   template <typename T>
   void
   callback_focus_in_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_FOCUS_IN, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_moved_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_MOVED, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_MOVED );
   }

   template <typename T>
   void
   callback_moved_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_MOVED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_withdrawn_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_WITHDRAWN, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_WITHDRAWN );
   }

   template <typename T>
   void
   callback_withdrawn_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_WITHDRAWN, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_iconified_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_ICONIFIED, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_ICONIFIED );
   }

   template <typename T>
   void
   callback_iconified_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_ICONIFIED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_normal_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_NORMAL, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_NORMAL );
   }

   template <typename T>
   void
   callback_normal_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_NORMAL, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_stick_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_STICK, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_STICK );
   }

   template <typename T>
   void
   callback_stick_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_STICK, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unstick_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_UNSTICK, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_UNSTICK );
   }

   template <typename T>
   void
   callback_unstick_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_UNSTICK, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_fullscreen_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_FULLSCREEN, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_FULLSCREEN );
   }

   template <typename T>
   void
   callback_fullscreen_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_FULLSCREEN, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfullscreen_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_UNFULLSCREEN, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_UNFULLSCREEN );
   }

   template <typename T>
   void
   callback_unfullscreen_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_UNFULLSCREEN, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_maximized_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_MAXIMIZED, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_MAXIMIZED );
   }

   template <typename T>
   void
   callback_maximized_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_MAXIMIZED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unmaximized_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_UNMAXIMIZED, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_UNMAXIMIZED );
   }

   template <typename T>
   void
   callback_unmaximized_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_UNMAXIMIZED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_ioerr_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_IOERR, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_IOERR );
   }

   template <typename T>
   void
   callback_ioerr_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_IOERR, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_indicator_prop_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_INDICATOR_PROP_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_INDICATOR_PROP_CHANGED );
   }

   template <typename T>
   void
   callback_indicator_prop_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_INDICATOR_PROP_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_rotation_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_ROTATION_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_ROTATION_CHANGED );
   }

   template <typename T>
   void
   callback_rotation_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_ROTATION_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_profile_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_PROFILE_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_PROFILE_CHANGED );
   }

   template <typename T>
   void
   callback_profile_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_PROFILE_CHANGED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_focused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_FOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_FOCUSED );
   }

   template <typename T>
   void
   callback_focused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_FOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_unfocused_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_UNFOCUSED, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_UNFOCUSED );
   }

   template <typename T>
   void
   callback_unfocused_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_UNFOCUSED, info));
   }
   template <typename F>
   ::efl::eo::signal_connection
   callback_wm_rotation_changed_add(F && callback_,
                                 ::efl::eo::callback_priority priority_ =
                                 ::efl::eo::callback_priorities::default_)
   {
      typedef typename std::remove_reference<F>::type function_type;
      ::std::unique_ptr<function_type> f ( new function_type(std::move(callback_)) );
      eo_do(static_cast<U*>(this)->_eo_ptr(),
            eo_event_callback_priority_add
            (ELM_WIN_EVENT_WM_ROTATION_CHANGED, priority_,
            &efl::eo::_detail::event_callback<::elm_win, function_type>, f.get()));
      return ::efl::eo::make_signal_connection
         (f, static_cast<U*>(this)->_eo_ptr(), &efl::eo::_detail::event_callback<::elm_win, function_type>,
         ELM_WIN_EVENT_WM_ROTATION_CHANGED );
   }

   template <typename T>
   void
   callback_wm_rotation_changed_call(T* info)
   {
      eo_do(static_cast<U*>(this)->_eo_ptr(), eo_event_callback_call
            (ELM_WIN_EVENT_WM_ROTATION_CHANGED, info));
   }
   };
};

inline Eo_Class const* get_eo_class(tag<::elm_win>)
{
   return (ELM_WIN_CLASS);
}

} } }
#endif // EFL_GENERATED_ELM_WIN_HH

